/* The input to this macro is the 
1) PERIOD: (3, 6, 12, 24) for which the variables have
to be aggregated.
If PERIOD=3, then aggregation for last 3 months will be calculated and stored in,
ACC_SNAP_LST_3M_ABT.
If PERIOD=6, then aggregation for last 3 & 6 months will be calculated and stored in,
ACC_SNAP_LST_3M_ABT, ACC_SNAP_LST_6M_ABT. 
If PERIOD=12, then aggregation for last 3, 6 & 12 months will be calculated and stored in,
ACC_SNAP_LST_3M_ABT, ACC_SNAP_LST_6M_ABT, ACC_SNAP_LST_12M_ABT. 
If PERIOD=24, then aggregation for last 13-24 months will be calculated and stored in,
ACC_SNAP_LST_13_24M_ABT. 
If PERIOD=100, then aggregation for last 3, 6, 12 months and life to date data will be
calculated and stored in, ACC_SNAP_LST_3M_ABT, ACC_SNAP_LST_6M_ABT, ACC_SNAP_LST_12M_ABT
and ACC_SNAP_LTD_ABT.
2) TABLE: The input table which is already filter for the PERIOD (3, 6, 12, 13-24). 
*/

%macro acc_snap_lst_abt(PERIOD=, INPUT_TABLE=);

	/* Sort the input data BY CUSTOMER_RK in ascending order 
	and BY TIME_SK in descending order */

	PROC SORT DATA=ABTSCR.&INPUT_TABLE.;
		BY ACCOUNT_RK DESCENDING TIME_SK;
	RUN;

	/* The data step begins here. The data step reads the sorted input data set
	& outputs aggregation tables based on the PERIOD */

	data 
		%if &PERIOD. = 3 %then %do; /*If PERIOD = 3*/
			%acc_snap_lst_3m_abt_keep;
		%end;
		%else %if &PERIOD. = 6 %then %do ; /*If PERIOD = 6*/ 
			%acc_snap_lst_3m_abt_keep 
			%acc_snap_lst_6m_abt_keep;
		%end;
		%else %if &PERIOD. = 12 %then %do; /*If PERIOD = 12*/
			%acc_snap_lst_3m_abt_keep		
			%acc_snap_lst_6m_abt_keep
			%acc_snap_lst_12m_abt_keep;
		%end;
		%else %if &PERIOD. = 24 %then %do; /*If PERIOD = 24*/
			%acc_snap_13_24m_abt_keep;
		%end;
		%else %if &PERIOD. = 100 %then %do; /* If PERIOD = 100*/
			%acc_snap_lst_3m_abt_keep		
			%acc_snap_lst_6m_abt_keep
			%acc_snap_lst_12m_abt_keep
			%acc_snap_ltd_abt_keep;
		%end;
	
	/* Set the input table for reading */
		SET ABTSCR.&INPUT_TABLE.;
		BY ACCOUNT_RK DESCENDING TIME_SK;

	/* Temporary variables used for computing max and min values*/
		MAX_VALUE = &MAX_VALUE; /*Numeric constant */
		MIN_VALUE = &MIN_VALUE; /*Numeric constant */

	/*List of variables to be retained */
		%acc_snap_abt_retain;

	/*Depending on whether the PERIOD is (3, 6, 12) or 24, the retained variable will be
	initialized */
		%if &PERIOD. = 24 %then %do;
			RETAIN CURR_TIME . COUNT 12;
			CURR_TIME = BACK_12M_TIME_SK;
		%end;
		%else %do;
			RETAIN CURR_TIME . COUNT 0 COUNT_TMP .;
			CURR_TIME = CURR_TIME_SK;
		%end;

	/* Assign the value of count at the start of every iteration. 
		Later used to check in conditions where counters are between 3 and 6 */

		COUNT_TMP = COUNT;

	/* Check to see if data is missing for certain period in the input table. If so,
	   then adjust the count accordingly */
		DO WHILE (TIME_SK < CURR_TIME);
			CURR_TIME = CURR_TIME - 1;
/*			COUNT = COUNT + 1;*/
		END;

	/* Check to see if there is more than one entry for certain period in the input table. 
	   If so,  then adjust the count accordingly */
		DO WHILE (CURR_TIME < TIME_SK ) ;
			CURR_TIME = CURR_TIME + 1;
/*			COUNT = COUNT - 1;*/
		END;

	/*Assign the value of following variables to the retained variables. 
		This variables will be written to the data set during LAST.ACCOUNT_RK */
		IF FIRST.ACCOUNT_RK THEN DO;
			CUSTOMER_RK_RET = CUSTOMER_RK;
			ALLOW_OVERDRAFT_FLG_RET = ALLOW_OVERDRAFT_FLG;
			ACCOUNT_TYPE_CD_RET = ACCOUNT_TYPE_CD;
			ACCOUNT_SUB_TYPE_CD_RET = ACCOUNT_SUB_TYPE_CD;
			COLLATERAL_CD_RET = COLLATERAL_CD;
			ACCOUNT_STATUS_CD_RET = ACCOUNT_STATUS_CD;
		END;

	/*Check to see if the count has reached some level (3,6,12), if so then assign the
	value of perivous variable to the next level variable */

		IF FIRST.TIME_SK THEN DO;
			IF COUNT EQ 3 OR (COUNT_TMP <= 3 AND COUNT > 3) THEN DO;	
				%acc_snap_abt_assign_3_to_6;
			END;
			IF COUNT EQ 6 OR (COUNT_TMP <= 6 AND COUNT > 6) THEN DO;
				%acc_snap_abt_assign_6_to_12;
			END;
		END;

	/*The expressions like summations, max, min, count, average are all done here */
		IF (COUNT < 3) THEN DO;

			/*If balance is greater than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_BAL_LST_3M_AMT, MIN_VALUE) < MAX_ACCOUNT_VALUE_AMT THEN
					ACC_MAX_OUT_BAL_LST_3M_AMT = MAX_ACCOUNT_VALUE_AMT;
				
			/*If balance is less than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_BAL_LST_3M_AMT, MAX_VALUE) > MIN_ACCOUNT_VALUE_AMT THEN
					ACC_MIN_OUT_BAL_LST_3M_AMT = MIN_ACCOUNT_VALUE_AMT;

			/*If fees is greater than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_FEE_LST_3M_AMT, MIN_VALUE) < FEES_AMT THEN
					ACC_MAX_OUT_FEE_LST_3M_AMT = FEES_AMT;
				
			/*If fees is less than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_FEE_LST_3M_AMT, MAX_VALUE) > FEES_AMT THEN
					ACC_MIN_OUT_FEE_LST_3M_AMT = FEES_AMT;

			/*If the delinquency  = 1, which means the account is deliquent then */
				IF DELINQUENCY_CNT = 1 THEN DO;
					DELINQUENCY_STATUS_CNT = 1; /*This is a temporary retained variable */

					/*Check to see if the delinquency range is between 1 to 30 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 1 AND DAYS_PAYMENT_PAST_DUE_CNT <= 30) THEN
						ACC_1_30DLQ_LST_3M_CNT + 1;

					/*Check to see if the delinquency range is between 31 to 60 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 31 AND DAYS_PAYMENT_PAST_DUE_CNT <= 60) THEN
						ACC_31_60DLQ_LST_3M_CNT + 1;

					/*Check to see if the delinquency range is between 61 to 90 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 61 AND DAYS_PAYMENT_PAST_DUE_CNT <= 90) THEN
						ACC_61_90DLQ_LST_3M_CNT + 1;

					/*Check to see if the delinquency range is between 91 to 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 91 AND DAYS_PAYMENT_PAST_DUE_CNT <= 120) THEN
						ACC_91_120DLQ_LST_3M_CNT + 1;
	
					/*Check to see if the delinquency range is greater than 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 121) THEN
						ACC_120PDLQ_LST_3M_CNT + 1;

				END;

				/*If delinquency_cnt = 0 and delinquency_status_cnt = 0, which means the account
					has a normal payment till this period */
				ELSE IF (COALESCE(DELINQUENCY_CNT, 0) = 0 AND 
						COALESCE(DELINQUENCY_STATUS_CNT, 0) = 0) THEN DO;
					ACC_1_30DLQ_2NOR_LST_3M_CNT + 1;
					ACC_31_60DLQ_2NOR_LST_3M_CNT + 1;
					ACC_61_90DLQ_2NOR_LST_3M_CNT + 1;
					ACC_91_120DLQ_2NOR_LST_3M_CNT + 1;
					ACC_120PDLQ_2NOR_LST_3M_CNT + 1;
				END;

				/* Summing the value of balance amount,	where SUM_BAL_AMT and BAL_CNT
					are temporary retained variable */
				IF BALANCE_AMT ^= . THEN DO;
					SUM_BAL_AMT + BALANCE_AMT;
					BAL_CNT + 1;
				END;

				/* Summing the value of current limit amount, where SUM_CURR_LMT_AMT 
					and CURR_LMT_CNT are temporary retained variable */
				IF CURRENT_LIMIT_AMT ^= . THEN DO;
					SUM_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
					CURR_LMT_CNT + 1;
				END;

				/* Checking whether the current limit amount count or balance amount count is 0*/
				IF (COALESCE(CURR_LMT_CNT, 0) = 0) OR (COALESCE(BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_LMT_USE_LST_3M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average credit limit usage percent*/
					ACC_AVG_LMT_USE_LST_3M_PCT = ((SUM_BAL_AMT/BAL_CNT)/(SUM_CURR_LMT_AMT/CURR_LMT_CNT))*100;
				END;

				/* If the balance amt is greater than or equal to current limit amount
					then the counter is incremented by 1 to obtain the total number of times
					the limit has been exhausted for the account and also the over the limit amount*/
				IF (BALANCE_AMT >= CURRENT_LIMIT_AMT) THEN DO;
					ACC_LMT_EXH_LST_3M_CNT + 1;

				/* Summing the difference of balance amount and current limit amount
					and the value for current limit amount,	where SUM_OTL_BAL_AMT, OTL_CLMT_CNT
					and SUM_OTL_CURR_LMT_AMT are temporary retained variable */
					IF (BALANCE_AMT ^= .) AND (CURRENT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_BAL_AMT + (BALANCE_AMT - CURRENT_LIMIT_AMT);
						SUM_OTL_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
						OTL_CLMT_CNT + 1;

						/*If over the limit amount is greater than the existing, then replace with 
							the	new value */	
						IF COALESCE(ACC_MAX_OTL_LST_3M_AMT, MIN_VALUE) < (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MAX_OTL_LST_3M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;

						/*If over the limit amount is less than the existing, then replace with the
								new value */	
						IF COALESCE(ACC_MIN_OTL_LST_3M_AMT, MAX_VALUE) > (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MIN_OTL_LST_3M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;
					END;

					/* Checking whether the over the limit amount count is 0*/
					IF (COALESCE(OTL_CLMT_CNT, 0) = 0) THEN DO;
						ACC_AVGOTL_2AVGLMT_LST_3M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit percent */
						ACC_AVGOTL_2AVGLMT_LST_3M_PCT = ((SUM_OTL_BAL_AMT/OTL_CLMT_CNT)/(SUM_OTL_CURR_LMT_AMT/OTL_CLMT_CNT))*100;
					END;

				END;

				/* If the overdraft current amt is greater than or equal to overdraft limit amount
					then computing the over the limit amount for overdraft*/
				IF (OVERDRAFT_CURRENT_AMT >= OVERDRAFT_LIMIT_AMT) THEN DO;

				/* Summing the difference of overdraft current amount and overdraft limit amount
					and the value for overdraft limit amount,	where SUM_OTL_OVD_AMT, OTL_ODLMT_CNT
					and SUM_OTL_OVD_LMT_AMT are temporary retained variable */
					IF (OVERDRAFT_CURRENT_AMT ^= .) AND (OVERDRAFT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_OVD_AMT + (OVERDRAFT_CURRENT_AMT - OVERDRAFT_LIMIT_AMT);
						SUM_OTL_OVD_LMT_AMT + OVERDRAFT_LIMIT_AMT;
						OTL_ODLMT_CNT + 1;
					END;

					/* Checking whether the over the limit overdraft amount count is 0*/
					IF (COALESCE(OTL_ODLMT_CNT, 0) = 0) THEN DO;
						ACC_AVOTL_2AVODLMT_L3M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit overdraft percent */
						ACC_AVOTL_2AVODLMT_L3M_PCT = ((SUM_OTL_OVD_AMT/OTL_ODLMT_CNT)/(SUM_OTL_OVD_LMT_AMT/OTL_ODLMT_CNT))*100;
					END;
				END;

				/* Summing the value of total balance amount, where SUM_TOT_BAL_AMT 
					and TOT_BAL_CNT are temporary retained variable */
				IF TOTAL_BALANCE_AMT ^= . THEN DO;
					SUM_TOT_BAL_AMT + TOTAL_BALANCE_AMT;
					TOT_BAL_CNT + 1;
				END;

				/*Checking whether the total balance amount count is 0*/
				IF (COALESCE(TOT_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_BAL_LST_3M_AMT = .;
				END;
				ELSE DO;
					/* Computing average account balance */
					ACC_AVG_BAL_LST_3M_AMT = (SUM_TOT_BAL_AMT/TOT_BAL_CNT);
				END;

				/* Summing the value of interest expected amount, where SUM_INT_EXP_AMT 
					and INT_EXP_CNT are temporary retained variable */
				IF INTEREST_EXPECTED_AMT ^= . THEN DO;
					SUM_INT_EXP_AMT + INTEREST_EXPECTED_AMT;
					INT_EXP_CNT + 1;
				END;

				/* Checking whether the balance amount count or interest expected count is zero*/
				IF (COALESCE(BAL_CNT, 0) = 0) OR (COALESCE(INT_EXP_CNT, 0) = 0) THEN DO;
					ACC_AVG_OINT_2AVGBAL_L3M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average outstanding interest charges to average balance amount*/
					ACC_AVG_OINT_2AVGBAL_L3M_PCT = ((SUM_INT_EXP_AMT/INT_EXP_CNT)/(SUM_BAL_AMT/BAL_CNT))*100;
				END;

				/* If the current limit amt is greater than or equal to balance amount
					then computing the open to buy amount */
				IF (CURRENT_LIMIT_AMT >= BALANCE_AMT AND 
						CURRENT_LIMIT_AMT ^= . AND BALANCE_AMT ^= .) THEN DO;
					/*If open to buy amount is greater than the existing, then replace with 
						the	new value */	
					IF COALESCE(ACC_MAX_OTB_LST_3M_AMT, MIN_VALUE) < (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN
						ACC_MAX_OTB_LST_3M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
					/*If open to buy amount is less than the existing, then replace with 
						the	new value */
					IF COALESCE(ACC_MIN_OTB_LST_3M_AMT, MAX_VALUE) > (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN 
						ACC_MIN_OTB_LST_3M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
				END;

				/* Summing the value of average daily balance amount, where SUM_AVG_DLY_BAL_AMT 
					and DLY_BAL_CNT are temporary retained variable */
				IF AVERAGE_DAILY_BALANCE_AMT ^= . THEN DO;
					SUM_AVG_DLY_BAL_AMT + AVERAGE_DAILY_BALANCE_AMT;
					DLY_BAL_CNT + 1;
				END;

				/* Checking whether the average daily balance amount count is zero*/
				IF (COALESCE(DLY_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_DLY_BAL_LST_3M_AMT = .;
				END;
				ELSE DO;
					/* Computing the average daily account balance */
					ACC_AVG_DLY_BAL_LST_3M_AMT = (SUM_AVG_DLY_BAL_AMT/DLY_BAL_CNT);
				END;

				/* Checking whether the balance amount is less than the required minimum balance*/
				IF BALANCE_AMT < REQUIRED_MIN_BALANCE_AMT THEN DO;
					ACC_BBLO_LST_3M_CNT + 1;
				END;

				/* Checking if the balance amount is nil */
				IF BALANCE_AMT <= 0 THEN
					ACC_NIL_BAL_LST_3M_MTH_CNT + 1;

				/* Checking if the balance amount is positive */
				IF BALANCE_AMT > 0 THEN
					ACC_PVE_BAL_LST_3M_MTH_CNT + 1;

				/* Checking whether the nil balance count or positive balance count is zero*/
				IF (COALESCE(ACC_NIL_BAL_LST_3M_MTH_CNT, 0) = 0 OR
						COALESCE(ACC_PVE_BAL_LST_3M_MTH_CNT, 0) = 0) THEN DO;
					ACC_PVE_2NIL_LST_3M_PCT = .;
				END;
				ELSE DO;
					/* Computing the postive to nil balance ratio */
					ACC_PVE_2NIL_LST_3M_PCT = (ACC_PVE_BAL_LST_3M_MTH_CNT / ACC_NIL_BAL_LST_3M_MTH_CNT)*100;
				END;

				ACC_MIN_BLL_PAY_LST_3M_CNT + DIFFER_PAYMENT_CNT;

				ACC_DLD_INST_LST_3M_CNT + LATE_PAYMENT_CNT;
	
		END;	
		ELSE IF (COUNT <  6)  THEN DO;

			/*If balance is greater than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_BAL_LST_6M_AMT, MIN_VALUE) < MAX_ACCOUNT_VALUE_AMT THEN
					ACC_MAX_OUT_BAL_LST_6M_AMT = MAX_ACCOUNT_VALUE_AMT;
				
			/*If balance is less than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_BAL_LST_6M_AMT, MAX_VALUE) > MIN_ACCOUNT_VALUE_AMT THEN
					ACC_MIN_OUT_BAL_LST_6M_AMT = MIN_ACCOUNT_VALUE_AMT;

			/*If fees is greater than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_FEE_LST_6M_AMT, MIN_VALUE) < FEES_AMT THEN
					ACC_MAX_OUT_FEE_LST_6M_AMT = FEES_AMT;
				
			/*If fees is less than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_FEE_LST_6M_AMT, MAX_VALUE) > FEES_AMT THEN
					ACC_MIN_OUT_FEE_LST_6M_AMT = FEES_AMT;

			/*If the delinquency  = 1, which means the account is deliquent then */
				IF DELINQUENCY_CNT = 1 THEN DO;
					DELINQUENCY_STATUS_CNT = 1; /*This is a temporary retained variable */

					/*Check to see if the delinquency range is between 1 to 30 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 1 AND DAYS_PAYMENT_PAST_DUE_CNT <= 30) THEN
						ACC_1_30DLQ_LST_6M_CNT + 1;

					/*Check to see if the delinquency range is between 31 to 60 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 31 AND DAYS_PAYMENT_PAST_DUE_CNT <= 60) THEN
						ACC_31_60DLQ_LST_6M_CNT + 1;

					/*Check to see if the delinquency range is between 61 to 90 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 61 AND DAYS_PAYMENT_PAST_DUE_CNT <= 90) THEN
						ACC_61_90DLQ_LST_6M_CNT + 1;

					/*Check to see if the delinquency range is between 91 to 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 91 AND DAYS_PAYMENT_PAST_DUE_CNT <= 120) THEN
						ACC_91_120DLQ_LST_6M_CNT + 1;
	
					/*Check to see if the delinquency range is greater than 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 121) THEN
						ACC_120PDLQ_LST_6M_CNT + 1;

				END;

				/*If delinquency_cnt = 0 and delinquency_status_cnt = 0, which means the account
					has a normal payment till this period */
				ELSE IF (COALESCE(DELINQUENCY_CNT, 0) = 0 AND
						COALESCE(DELINQUENCY_STATUS_CNT, 0) = 0) THEN DO;
					ACC_1_30DLQ_2NOR_LST_6M_CNT + 1;
					ACC_31_60DLQ_2NOR_LST_6M_CNT + 1;
					ACC_61_90DLQ_2NOR_LST_6M_CNT + 1;
					ACC_91_120DLQ_2NOR_LST_6M_CNT + 1;
					ACC_120PDLQ_2NOR_LST_6M_CNT + 1;
				END;

				/* Summing the value of balance amount,	where SUM_BAL_AMT and BAL_CNT
					are temporary retained variable */
				IF BALANCE_AMT ^= . THEN DO;
					SUM_BAL_AMT + BALANCE_AMT;
					BAL_CNT + 1;
				END;

				/* Summing the value of current limit amount, where SUM_CURR_LMT_AMT 
					and CURR_LMT_CNT are temporary retained variable */
				IF CURRENT_LIMIT_AMT ^= . THEN DO;
					SUM_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
					CURR_LMT_CNT + 1;
				END;

				/* Checking whether the current limit amount count or balance amount count is 0*/
				IF (COALESCE(CURR_LMT_CNT, 0) = 0) OR (COALESCE(BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_LMT_USE_LST_6M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average credit limit usage percent*/
					ACC_AVG_LMT_USE_LST_6M_PCT = ((SUM_BAL_AMT/BAL_CNT)/(SUM_CURR_LMT_AMT/CURR_LMT_CNT))*100;
				END;

				/* If the balance amt is greater than or equal to current limit amount
					then the counter is incremented by 1 to obtain the total number of times
					the limit has been exhausted for the account and also the over the limit amount*/
				IF (BALANCE_AMT >= CURRENT_LIMIT_AMT) THEN DO;
					ACC_LMT_EXH_LST_6M_CNT = ACC_LMT_EXH_LST_6M_CNT + 1;

				/* Summing the difference of balance amount and current limit amount
					and the value for current limit amount,	where SUM_OTL_BAL_AMT, OTL_CLMT_CNT
					and SUM_OTL_CURR_LMT_AMT are temporary retained variable */
					IF (BALANCE_AMT ^= .) AND (CURRENT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_BAL_AMT + (BALANCE_AMT - CURRENT_LIMIT_AMT);
						SUM_OTL_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
						OTL_CLMT_CNT + 1;

						/*If over the limit amount is greater than the existing, then replace with 
							the	new value */	
						IF COALESCE(ACC_MAX_OTL_LST_6M_AMT, MIN_VALUE) < (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MAX_OTL_LST_6M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;

						/*If over the limit amount is less than the existing, then replace with the
								new value */	
						IF COALESCE(ACC_MIN_OTL_LST_6M_AMT, MAX_VALUE) > (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MIN_OTL_LST_6M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;

					END;

					/* Checking whether the over the limit amount count is 0*/
					IF (COALESCE(OTL_CLMT_CNT, 0) = 0) THEN DO;
						ACC_AVGOTL_2AVGLMT_LST_6M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit percent */
						ACC_AVGOTL_2AVGLMT_LST_6M_PCT = ((SUM_OTL_BAL_AMT/OTL_CLMT_CNT)/(SUM_OTL_CURR_LMT_AMT/OTL_CLMT_CNT))*100;
					END;

				END;

				/* If the overdraft current amt is greater than or equal to overdraft limit amount
					then computing the over the limit amount for overdraft*/
				IF (OVERDRAFT_CURRENT_AMT >= OVERDRAFT_LIMIT_AMT) THEN DO;

				/* Summing the difference of overdraft current amount and overdraft limit amount
					and the value for overdraft limit amount,	where SUM_OTL_OVD_AMT, OTL_ODLMT_CNT
					and SUM_OTL_OVD_LMT_AMT are temporary retained variable */
					IF (OVERDRAFT_CURRENT_AMT ^= .) AND (OVERDRAFT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_OVD_AMT + (OVERDRAFT_CURRENT_AMT - OVERDRAFT_LIMIT_AMT);
						SUM_OTL_OVD_LMT_AMT + OVERDRAFT_LIMIT_AMT;
						OTL_ODLMT_CNT + 1;
					END;

					/* Checking whether the over the limit overdraft amount count is 0*/
					IF (COALESCE(OTL_ODLMT_CNT, 0) = 0) THEN DO;
						ACC_AVOTL_2AVODLMT_L6M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit overdraft percent */
						ACC_AVOTL_2AVODLMT_L6M_PCT = ((SUM_OTL_OVD_AMT/OTL_ODLMT_CNT)/(SUM_OTL_OVD_LMT_AMT/OTL_ODLMT_CNT))*100;
					END;
				END;

				/* Summing the value of total balance amount, where SUM_TOT_BAL_AMT 
					and TOT_BAL_CNT are temporary retained variable */
				IF TOTAL_BALANCE_AMT ^= . THEN DO;
					SUM_TOT_BAL_AMT + TOTAL_BALANCE_AMT;
					TOT_BAL_CNT + 1;
				END;

				/*Checking whether the total balance amount count is 0*/
				IF (COALESCE(TOT_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_BAL_LST_6M_AMT = .;
				END;
				ELSE DO;
					/* Computing average account balance */
					ACC_AVG_BAL_LST_6M_AMT = (SUM_TOT_BAL_AMT/TOT_BAL_CNT);
				END;

				/* Summing the value of interest expected amount, where SUM_INT_EXP_AMT 
					and INT_EXP_CNT are temporary retained variable */
				IF INTEREST_EXPECTED_AMT ^= . THEN DO;
					SUM_INT_EXP_AMT + INTEREST_EXPECTED_AMT;
					INT_EXP_CNT + 1;
				END;

				/* Checking whether the balance amount count or interest expected count is zero*/
				IF (COALESCE(BAL_CNT, 0) = 0) OR (COALESCE(INT_EXP_CNT, 0) = 0) THEN DO;
					ACC_AVG_OINT_2AVGBAL_L6M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average outstanding interest charges to average balance amount*/
					ACC_AVG_OINT_2AVGBAL_L6M_PCT = ((SUM_INT_EXP_AMT/INT_EXP_CNT)/(SUM_BAL_AMT/BAL_CNT))*100;
				END;

				/* If the current limit amt is greater than or equal to balance amount
					then compute the open to buy amount */
				IF (CURRENT_LIMIT_AMT >= BALANCE_AMT AND 
						CURRENT_LIMIT_AMT ^= . AND BALANCE_AMT ^= .) THEN DO;
					/*If open to buy amount is greater than the existing, then replace with 
						the	new value */	
					IF COALESCE(ACC_MAX_OTB_LST_6M_AMT, MIN_VALUE) < (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN
						ACC_MAX_OTB_LST_6M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
					/*If open to buy amount is less than the existing, then replace with 
						the	new value */
					IF COALESCE(ACC_MIN_OTB_LST_6M_AMT, MAX_VALUE) > (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN 
						ACC_MIN_OTB_LST_6M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
				END;

				/* Summing the value of average daily balance amount, where SUM_AVG_DLY_BAL_AMT 
					and DLY_BAL_CNT are temporary retained variable */
				IF AVERAGE_DAILY_BALANCE_AMT ^= . THEN DO;
					SUM_AVG_DLY_BAL_AMT + AVERAGE_DAILY_BALANCE_AMT;
					DLY_BAL_CNT + 1;
				END;

				/* Checking whether the average daily balance amount count is zero*/
				IF (COALESCE(DLY_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_DLY_BAL_LST_6M_AMT = .;
				END;
				ELSE DO;
					/* Computing the average daily account balance */
					ACC_AVG_DLY_BAL_LST_6M_AMT = (SUM_AVG_DLY_BAL_AMT/DLY_BAL_CNT);
				END;

				/* Checking whether the balance amount is less than the required minimum balance*/
				IF BALANCE_AMT < REQUIRED_MIN_BALANCE_AMT THEN DO;
					ACC_BBLO_LST_6M_CNT + 1;
				END;

				/* Checking if the balance amount is nil */
				IF BALANCE_AMT <= 0 THEN
					ACC_NIL_BAL_LST_6M_MTH_CNT + 1;

				/* Checking if the balance amount is positive */
				IF BALANCE_AMT > 0 THEN
					ACC_PVE_BAL_LST_6M_MTH_CNT + 1;

				/* Checking whether the nil balance count or positive balance count is zero*/
				IF (COALESCE(ACC_NIL_BAL_LST_6M_MTH_CNT, 0) = 0 OR 
						COALESCE(ACC_PVE_BAL_LST_6M_MTH_CNT, 0) = 0) THEN DO;
					ACC_PVE_2NIL_LST_6M_PCT = .;
				END;
				ELSE DO;
					/* Computing the postive to nil balance ratio */
					ACC_PVE_2NIL_LST_6M_PCT = (ACC_PVE_BAL_LST_6M_MTH_CNT / ACC_NIL_BAL_LST_6M_MTH_CNT)*100;
				END;

				ACC_MIN_BLL_PAY_LST_6M_CNT + DIFFER_PAYMENT_CNT;

				ACC_DLD_INST_LST_6M_CNT + LATE_PAYMENT_CNT;
	
		END;	
		ELSE IF (COUNT <  12)  THEN DO;

			/*If balance is greater than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_BAL_LST_12M_AMT, MIN_VALUE) < MAX_ACCOUNT_VALUE_AMT THEN
					ACC_MAX_OUT_BAL_LST_12M_AMT = MAX_ACCOUNT_VALUE_AMT;
				
			/*If balance is less than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_BAL_LST_12M_AMT, MAX_VALUE) > MIN_ACCOUNT_VALUE_AMT THEN
					ACC_MIN_OUT_BAL_LST_12M_AMT = MIN_ACCOUNT_VALUE_AMT;

			/*If fees is greater than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_FEE_LST_12M_AMT, MIN_VALUE) < FEES_AMT THEN
					ACC_MAX_OUT_FEE_LST_12M_AMT = FEES_AMT;
				
			/*If fees is less than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_FEE_LST_12M_AMT, MAX_VALUE) > FEES_AMT THEN
					ACC_MIN_OUT_FEE_LST_12M_AMT = FEES_AMT;

			/*If the delinquency  = 1, which means the account is deliquent then */
				IF DELINQUENCY_CNT = 1 THEN DO;
					DELINQUENCY_STATUS_CNT = 1; /*This is a temporary retained variable */

					/*Check to see if the delinquency range is between 1 to 30 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 1 AND DAYS_PAYMENT_PAST_DUE_CNT <= 30) THEN
						ACC_1_30DLQ_LST_12M_CNT + 1;

					/*Check to see if the delinquency range is between 31 to 60 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 31 AND DAYS_PAYMENT_PAST_DUE_CNT <= 60) THEN
						ACC_31_60DLQ_LST_12M_CNT + 1;

					/*Check to see if the delinquency range is between 61 to 90 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 61 AND DAYS_PAYMENT_PAST_DUE_CNT <= 90) THEN
						ACC_61_90DLQ_LST_12M_CNT + 1;

					/*Check to see if the delinquency range is between 91 to 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 91 AND DAYS_PAYMENT_PAST_DUE_CNT <= 120) THEN
						ACC_91_120DLQ_LST_12M_CNT + 1;
	
					/*Check to see if the delinquency range is greater than 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 121) THEN
						ACC_120PDLQ_LST_12M_CNT + 1;

				END;

				/*If delinquency_cnt = 0 and delinquency_status_cnt = 0, which means the account
					has a normal payment till this period */
				ELSE IF (COALESCE(DELINQUENCY_CNT, 0) = 0 AND
						COALESCE(DELINQUENCY_STATUS_CNT, 0) = 0) THEN DO;
					ACC_1_30DLQ_2NOR_LST_12M_CNT + 1;
					ACC_31_60DLQ_2NOR_LST_12M_CNT + 1;
					ACC_61_90DLQ_2NOR_LST_12M_CNT + 1;
					ACC_91_120DLQ_2NOR_LST_12M_CNT + 1;
					ACC_120PDLQ_2NOR_LST_12M_CNT + 1;
				END;

				/* Summing the value of balance amount,	where SUM_BAL_AMT and BAL_CNT
					are temporary retained variable */
				IF BALANCE_AMT ^= . THEN DO;
					SUM_BAL_AMT + BALANCE_AMT;
					BAL_CNT + 1;
				END;

				/* Summing the value of current limit amount, where SUM_CURR_LMT_AMT 
					and CURR_LMT_CNT are temporary retained variable */
				IF CURRENT_LIMIT_AMT ^= . THEN DO;
					SUM_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
					CURR_LMT_CNT + 1;
				END;

				/* Checking whether the current limit amount count or balance amount count is 0*/
				IF (COALESCE(CURR_LMT_CNT, 0) = 0) OR (COALESCE(BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_LMT_USE_LST_12M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average credit limit usage percent*/
					ACC_AVG_LMT_USE_LST_12M_PCT = ((SUM_BAL_AMT/BAL_CNT)/(SUM_CURR_LMT_AMT/CURR_LMT_CNT))*100;
				END;

				/* If the balance amt is greater than or equal to current limit amount
					then the counter is incremented by 1 to obtain the total number of times
					the limit has been exhausted for the account and also the over the limit amount*/
				IF (BALANCE_AMT >= CURRENT_LIMIT_AMT) THEN DO;
					ACC_LMT_EXH_LST_12M_CNT = ACC_LMT_EXH_LST_12M_CNT + 1;

				/* Summing the difference of balance amount and current limit amount
					and the value for current limit amount,	where SUM_OTL_BAL_AMT, OTL_CLMT_CNT
					and SUM_OTL_CURR_LMT_AMT are temporary retained variable */
					IF (BALANCE_AMT ^= .) AND (CURRENT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_BAL_AMT + (BALANCE_AMT - CURRENT_LIMIT_AMT);
						SUM_OTL_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
						OTL_CLMT_CNT + 1;

						/*If over the limit amount is greater than the existing, then replace with 
							the	new value */	
						IF COALESCE(ACC_MAX_OTL_LST_12M_AMT, MIN_VALUE) < (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MAX_OTL_LST_12M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;

						/*If over the limit amount is less than the existing, then replace with the
								new value */	
						IF COALESCE(ACC_MIN_OTL_LST_12M_AMT, MAX_VALUE) > (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MIN_OTL_LST_12M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;

					END;

					/* Checking whether the over the limit amount count is 0*/
					IF (COALESCE(OTL_CLMT_CNT, 0) = 0) THEN DO;
						ACC_AVGOTL_2AVGLMT_LST_12M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit percent */
						ACC_AVGOTL_2AVGLMT_LST_12M_PCT = ((SUM_OTL_BAL_AMT/OTL_CLMT_CNT)/(SUM_OTL_CURR_LMT_AMT/OTL_CLMT_CNT))*100;
					END;

				END;

				/* If the overdraft current amt is greater than or equal to overdraft limit amount
					then compute the over the limit amount for overdraft*/
				IF (OVERDRAFT_CURRENT_AMT >= OVERDRAFT_LIMIT_AMT) THEN DO;

				/* Summing the difference of overdraft current amount and overdraft limit amount
					and the value for overdraft limit amount,	where SUM_OTL_OVD_AMT, OTL_ODLMT_CNT
					and SUM_OTL_OVD_LMT_AMT are temporary retained variable */
					IF (OVERDRAFT_CURRENT_AMT ^= .) AND (OVERDRAFT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_OVD_AMT + (OVERDRAFT_CURRENT_AMT - OVERDRAFT_LIMIT_AMT);
						SUM_OTL_OVD_LMT_AMT + OVERDRAFT_LIMIT_AMT;
						OTL_ODLMT_CNT + 1;
					END;

					/* Checking whether the over the limit overdraft amount count is 0*/
					IF (COALESCE(OTL_ODLMT_CNT, 0) = 0) THEN DO;
						ACC_AVOTL_2AVODLMT_L12M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit overdraft percent */
						ACC_AVOTL_2AVODLMT_L12M_PCT = ((SUM_OTL_OVD_AMT/OTL_ODLMT_CNT)/(SUM_OTL_OVD_LMT_AMT/OTL_ODLMT_CNT))*100;
					END;
				END;

				/* Summing the value of total balance amount, where SUM_TOT_BAL_AMT 
					and TOT_BAL_CNT are temporary retained variable */
				IF TOTAL_BALANCE_AMT ^= . THEN DO;
					SUM_TOT_BAL_AMT + TOTAL_BALANCE_AMT;
					TOT_BAL_CNT + 1;
				END;

				/*Checking whether the total balance amount count is 0*/
				IF (COALESCE(TOT_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_BAL_LST_12M_AMT = .;
				END;
				ELSE DO;
					/* Computing average account balance */
					ACC_AVG_BAL_LST_12M_AMT = (SUM_TOT_BAL_AMT/TOT_BAL_CNT);
				END;

				/* Summing the value of interest expected amount, where SUM_INT_EXP_AMT 
					and INT_EXP_CNT are temporary retained variable */
				IF INTEREST_EXPECTED_AMT ^= . THEN DO;
					SUM_INT_EXP_AMT + INTEREST_EXPECTED_AMT;
					INT_EXP_CNT + 1;
				END;

				/* Checking whether the balance amount count or interest expected count is zero*/
				IF (COALESCE(BAL_CNT, 0) = 0) OR (COALESCE(INT_EXP_CNT, 0) = 0) THEN DO;
					ACC_AVG_OINT_2AVGBAL_L12M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average outstanding interest charges to average balance amount*/
					ACC_AVG_OINT_2AVGBAL_L12M_PCT = ((SUM_INT_EXP_AMT/INT_EXP_CNT)/(SUM_BAL_AMT/BAL_CNT))*100;
				END;

				/* If the current limit amt is greater than or equal to balance amount
					then compute the open to buy amount */
				IF (CURRENT_LIMIT_AMT >= BALANCE_AMT AND 
						CURRENT_LIMIT_AMT ^= . AND BALANCE_AMT ^= .) THEN DO;
					/*If open to buy amount is greater than the existing, then replace with 
						the	new value */	
					IF COALESCE(ACC_MAX_OTB_LST_12M_AMT, MIN_VALUE) < (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN
						ACC_MAX_OTB_LST_12M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
					/*If open to buy amount is less than the existing, then replace with 
						the	new value */
					IF COALESCE(ACC_MIN_OTB_LST_12M_AMT, MAX_VALUE) > (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN 
						ACC_MIN_OTB_LST_12M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
				END;

				/* Summing the value of average daily balance amount, where SUM_AVG_DLY_BAL_AMT 
					and DLY_BAL_CNT are temporary retained variable */
				IF AVERAGE_DAILY_BALANCE_AMT ^= . THEN DO;
					SUM_AVG_DLY_BAL_AMT + AVERAGE_DAILY_BALANCE_AMT;
					DLY_BAL_CNT + 1;
				END;

				/* Checking whether the average daily balance amount count is zero*/
				IF (COALESCE(DLY_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_DLY_BAL_LST_12M_AMT = .;
				END;
				ELSE DO;
					/* Computing the average daily account balance */
					ACC_AVG_DLY_BAL_LST_12M_AMT = (SUM_AVG_DLY_BAL_AMT/DLY_BAL_CNT);
				END;

				/* Checking whether the balance amount is less than the required minimum balance*/
				IF BALANCE_AMT < REQUIRED_MIN_BALANCE_AMT THEN DO;
					ACC_BBLO_LST_12M_CNT + 1;
				END;

				/* Checking if the balance amount is nil */
				IF BALANCE_AMT <= 0 THEN
					ACC_NIL_BAL_LST_12M_MTH_CNT + 1;

				/* Checking if the balance amount is positive */
				IF BALANCE_AMT > 0 THEN
					ACC_PVE_BAL_LST_12M_MTH_CNT + 1;

				/* Checking whether the nil balance count or positive balance count is zero*/
				IF (COALESCE(ACC_NIL_BAL_LST_12M_MTH_CNT, 0) = 0 OR
						COALESCE(ACC_PVE_BAL_LST_12M_MTH_CNT, 0) = 0) THEN DO;
					ACC_PVE_2NIL_LST_12M_PCT = .;
				END;
				ELSE DO;
					/* Computing the postive to nil balance ratio */
					ACC_PVE_2NIL_LST_12M_PCT = (ACC_PVE_BAL_LST_12M_MTH_CNT / ACC_NIL_BAL_LST_12M_MTH_CNT)*100;
				END;

				ACC_MIN_BLL_PAY_LST_12M_CNT + DIFFER_PAYMENT_CNT;

				ACC_DLD_INST_LST_12M_CNT + LATE_PAYMENT_CNT;
	
		END;	
		ELSE IF (COUNT < 24) THEN DO;

			/*If balance is greater than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_BAL_13_24M_AMT, MIN_VALUE) < MAX_ACCOUNT_VALUE_AMT THEN
					ACC_MAX_OUT_BAL_13_24M_AMT = MAX_ACCOUNT_VALUE_AMT;
				
			/*If balance is less than the existing balance then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_BAL_13_24M_AMT, MAX_VALUE) > MIN_ACCOUNT_VALUE_AMT THEN
					ACC_MIN_OUT_BAL_13_24M_AMT = MIN_ACCOUNT_VALUE_AMT;

			/*If fees is greater than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MAX_OUT_FEE_13_24M_AMT, MIN_VALUE) < FEES_AMT THEN
					ACC_MAX_OUT_FEE_13_24M_AMT = FEES_AMT;
				
			/*If fees is less than the existing fees amount then replace with the new value */	
				IF COALESCE(ACC_MIN_OUT_FEE_13_24M_AMT, MAX_VALUE) > FEES_AMT THEN
					ACC_MIN_OUT_FEE_13_24M_AMT = FEES_AMT;

			/*If the delinquency  = 1, which means the account is deliquent then */
				IF DELINQUENCY_CNT = 1 THEN DO;
					DELINQUENCY_STATUS_CNT = 1; /*This is a temporary retained variable */

					/*Check to see if the delinquency range is between 1 to 30 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 1 AND DAYS_PAYMENT_PAST_DUE_CNT <= 30) THEN
						ACC_1_30DLQ_13_24M_CNT + 1;

					/*Check to see if the delinquency range is between 31 to 60 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 31 AND DAYS_PAYMENT_PAST_DUE_CNT <= 60) THEN
						ACC_31_60DLQ_13_24M_CNT + 1;

					/*Check to see if the delinquency range is between 61 to 90 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 61 AND DAYS_PAYMENT_PAST_DUE_CNT <= 90) THEN
						ACC_61_90DLQ_13_24M_CNT + 1;

					/*Check to see if the delinquency range is between 91 to 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 91 AND DAYS_PAYMENT_PAST_DUE_CNT <= 120) THEN
						ACC_91_120DLQ_13_24M_CNT + 1;
	
					/*Check to see if the delinquency range is greater than 120 */
					IF (DAYS_PAYMENT_PAST_DUE_CNT >= 121) THEN
						ACC_120PDLQ_13_24M_CNT + 1;

				END;

				/*If delinquency_cnt = 0 and delinquency_status_cnt = 0, which means the account
					has a normal payment till this period */
				ELSE IF (COALESCE(DELINQUENCY_CNT, 0) = 0 AND
						COALESCE(DELINQUENCY_STATUS_CNT, 0) = 0) THEN DO;
					ACC_1_30DLQ_2NOR_13_24M_CNT + 1;
					ACC_31_60DLQ_2NOR_13_24M_CNT + 1;
					ACC_61_90DLQ_2NOR_13_24M_CNT + 1;
					ACC_91_120DLQ_2NOR_13_24M_CNT + 1;
					ACC_120PDLQ_2NOR_13_24M_CNT + 1;
				END;

				/* Summing the value of balance amount,	where SUM_BAL_AMT and BAL_CNT
					are temporary retained variable */
				IF BALANCE_AMT ^= . THEN DO;
					SUM_BAL_AMT + BALANCE_AMT;
					BAL_CNT + 1;
				END;

				/* Summing the value of current limit amount, where SUM_CURR_LMT_AMT 
					and CURR_LMT_CNT are temporary retained variable */
				IF CURRENT_LIMIT_AMT ^= . THEN DO;
					SUM_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
					CURR_LMT_CNT + 1;
				END;

				/* Checking whether the current limit amount count or balance amount count is 0*/
				IF (COALESCE(CURR_LMT_CNT, 0) = 0) OR (COALESCE(BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_LMT_USE_13_24M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average credit limit usage percent*/
					ACC_AVG_LMT_USE_13_24M_PCT = ((SUM_BAL_AMT/BAL_CNT)/(SUM_CURR_LMT_AMT/CURR_LMT_CNT))*100;
				END;

				/* If the balance amt is greater than or equal to current limit amount
					then the counter is incremented by 1 to obtain the total number of times
					the limit has been exhausted for the account and also the over the limit amount*/
				IF (BALANCE_AMT >= CURRENT_LIMIT_AMT) THEN DO;
					ACC_LMT_EXH_13_24M_CNT = ACC_LMT_EXH_13_24M_CNT + 1;

				/* Summing the difference of balance amount and current limit amount
					and the value for current limit amount,	where SUM_OTL_BAL_AMT, OTL_CLMT_CNT
					and SUM_OTL_CURR_LMT_AMT are temporary retained variable */
					IF (BALANCE_AMT ^= .) AND (CURRENT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_BAL_AMT + (BALANCE_AMT - CURRENT_LIMIT_AMT);
						SUM_OTL_CURR_LMT_AMT + CURRENT_LIMIT_AMT;
						OTL_CLMT_CNT + 1;

						/*If over the limit amount is greater than the existing, then replace with 
							the	new value */	
						IF COALESCE(ACC_MAX_OTL_13_24M_AMT, MIN_VALUE) < (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MAX_OTL_13_24M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;

						/*If over the limit amount is less than the existing, then replace with the
								new value */	
						IF COALESCE(ACC_MIN_OTL_13_24M_AMT, MAX_VALUE) > (BALANCE_AMT - CURRENT_LIMIT_AMT) THEN
							ACC_MIN_OTL_13_24M_AMT = BALANCE_AMT - CURRENT_LIMIT_AMT;

					END;

					/* Checking whether the over the limit amount count is 0*/
					IF (COALESCE(OTL_CLMT_CNT, 0) = 0) THEN DO;
						ACC_AVGOTL_2AVGLMT_13_24M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit percent */
						ACC_AVGOTL_2AVGLMT_13_24M_PCT = ((SUM_OTL_BAL_AMT/OTL_CLMT_CNT)/(SUM_OTL_CURR_LMT_AMT/OTL_CLMT_CNT))*100;
					END;

				END;

				/* If the overdraft current amt is greater than or equal to overdraft limit amount
					then compute the over the limit amount for overdraft*/
				IF (OVERDRAFT_CURRENT_AMT >= OVERDRAFT_LIMIT_AMT) THEN DO;

				/* Summing the difference of overdraft current amount and overdraft limit amount
					and the value for overdraft limit amount,	where SUM_OTL_OVD_AMT, OTL_ODLMT_CNT
					and SUM_OTL_OVD_LMT_AMT are temporary retained variable */
					IF (OVERDRAFT_CURRENT_AMT ^= .) AND (OVERDRAFT_LIMIT_AMT ^= .) THEN DO;
						SUM_OTL_OVD_AMT + (OVERDRAFT_CURRENT_AMT - OVERDRAFT_LIMIT_AMT);
						SUM_OTL_OVD_LMT_AMT + OVERDRAFT_LIMIT_AMT;
						OTL_ODLMT_CNT + 1;
					END;

					/* Checking whether the over the limit overdraft amount count is 0*/
					IF (COALESCE(OTL_ODLMT_CNT, 0) = 0) THEN DO;
						ACC_AVOTL_2AVODLMT_13_24M_PCT = .;				
					END;
					ELSE DO;
						/* Computing the over the limit overdraft percent */
						ACC_AVOTL_2AVODLMT_13_24M_PCT = ((SUM_OTL_OVD_AMT/OTL_ODLMT_CNT)/(SUM_OTL_OVD_LMT_AMT/OTL_ODLMT_CNT))*100;
					END;
				END;

				/* Summing the value of total balance amount, where SUM_TOT_BAL_AMT 
					and TOT_BAL_CNT are temporary retained variable */
				IF TOTAL_BALANCE_AMT ^= . THEN DO;
					SUM_TOT_BAL_AMT + TOTAL_BALANCE_AMT;
					TOT_BAL_CNT + 1;
				END;

				/*Checking whether the total balance amount count is 0*/
				IF (COALESCE(TOT_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_BAL_13_24M_AMT = .;
				END;
				ELSE DO;
					/* Computing average account balance */
					ACC_AVG_BAL_13_24M_AMT = (SUM_TOT_BAL_AMT/TOT_BAL_CNT);
				END;

				/* Summing the value of interest expected amount, where SUM_INT_EXP_AMT 
					and INT_EXP_CNT are temporary retained variable */
				IF INTEREST_EXPECTED_AMT ^= . THEN DO;
					SUM_INT_EXP_AMT + INTEREST_EXPECTED_AMT;
					INT_EXP_CNT + 1;
				END;

				/* Checking whether the balance amount count or interest expected count is zero*/
				IF (COALESCE(BAL_CNT, 0) = 0) OR (COALESCE(INT_EXP_CNT, 0) = 0) THEN DO;
					ACC_AVG_OINT_2AVGBAL_13_24M_PCT = .;
				END;
				ELSE DO;
					/* Computing the average outstanding interest charges to average balance amount*/
					ACC_AVG_OINT_2AVGBAL_13_24M_PCT = ((SUM_INT_EXP_AMT/INT_EXP_CNT)/(SUM_BAL_AMT/BAL_CNT))*100;
				END;

				/* If the current limit amt is greater than or equal to balance amount
					then compute the open to buy amount */
				IF (CURRENT_LIMIT_AMT >= BALANCE_AMT AND 
						CURRENT_LIMIT_AMT ^= . AND BALANCE_AMT ^= .) THEN DO;
					/*If open to buy amount is greater than the existing, then replace with 
						the	new value */	
					IF COALESCE(ACC_MAX_OTB_13_24M_AMT, MIN_VALUE) < (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN
						ACC_MAX_OTB_13_24M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
					/*If open to buy amount is less than the existing, then replace with 
						the	new value */
					IF COALESCE(ACC_MIN_OTB_13_24M_AMT, MAX_VALUE) > (CURRENT_LIMIT_AMT - BALANCE_AMT) THEN 
						ACC_MIN_OTB_13_24M_AMT = CURRENT_LIMIT_AMT - BALANCE_AMT;
				END;

				/* Summing the value of average daily balance amount, where SUM_AVG_DLY_BAL_AMT 
					and DLY_BAL_CNT are temporary retained variable */
				IF AVERAGE_DAILY_BALANCE_AMT ^= . THEN DO;
					SUM_AVG_DLY_BAL_AMT + AVERAGE_DAILY_BALANCE_AMT;
					DLY_BAL_CNT + 1;
				END;

				/* Checking whether the average daily balance amount count is zero*/
				IF (COALESCE(DLY_BAL_CNT, 0) = 0) THEN DO;
					ACC_AVG_DLY_BAL_13_24M_AMT = .;
				END;
				ELSE DO;
					/* Computing the average daily account balance */
					ACC_AVG_DLY_BAL_13_24M_AMT = (SUM_AVG_DLY_BAL_AMT/DLY_BAL_CNT);
				END;

				/* Checking whether the balance amount is less than the required minimum balance*/
				IF BALANCE_AMT < REQUIRED_MIN_BALANCE_AMT THEN DO;
					ACC_BBLO_13_24M_CNT + 1;
				END;

				/* Checking if the balance amount is nil */
				IF BALANCE_AMT <= 0 THEN
					ACC_NIL_BAL_13_24M_MTH_CNT + 1;

				/* Checking if the balance amount is positive */
				IF BALANCE_AMT > 0 THEN
					ACC_PVE_BAL_13_24M_MTH_CNT + 1;

				/* Checking whether the nil balance count or positive balance count is zero*/
				IF (COALESCE(ACC_NIL_BAL_13_24M_MTH_CNT, 0) = 0 OR
						COALESCE(ACC_PVE_BAL_13_24M_MTH_CNT, 0) = 0) THEN DO;
					ACC_PVE_2NIL_13_24M_PCT = .;
				END;
				ELSE DO;
					/* Computing the postive to nil balance ratio */
					ACC_PVE_2NIL_13_24M_PCT = (ACC_PVE_BAL_13_24M_MTH_CNT / ACC_NIL_BAL_13_24M_MTH_CNT)*100;
				END;

				ACC_MIN_BLL_PAY_13_24M_CNT + DIFFER_PAYMENT_CNT;

				ACC_DLD_INST_13_24M_CNT + LATE_PAYMENT_CNT;
	
		END;

/********************************* Life to Date data *************************************/	
/* Computing variables for Life to Date data */	

	/* Count of records where delinquency range corresponds to any nonzero days*/
	IF (DAYS_PAYMENT_PAST_DUE_CNT > 0) THEN
		ACC_DLQ_LTD_MTH_CNT + 1;

	/* Check if the default_cnt = 1, which means the account is default */
	IF (DEFAULT_CNT = 1 AND COALESCE(DEFAULT_STATUS_CNT, 0) = 0)THEN DO;
		ACC_OUT_PPL_AT_DFT_AMT = PRINCIPAL_BALANCE_AMT;
		ACC_PCL_AT_DFT_AMT = COLLATERAL_AMT;
		IF COALESCE(COLLATERAL_AMT, 0) = 0 THEN
			ACC_OUT_PPL2PCL_AT_DFT_PCT = .;
		ELSE
			ACC_OUT_PPL2PCL_AT_DFT_PCT = (PRINCIPAL_BALANCE_AMT / COLLATERAL_AMT) * 100;
		DEFAULT_STATUS_CNT = 1; /* This is a temporary retained variable */
	END;

	/*If default_cnt = 0 and default_status_cnt = 0, which means the account
			has a normal payment till this period */
	ELSE IF (COALESCE(DEFAULT_CNT, 0) = 0 AND COALESCE(DEFAULT_STATUS_CNT, 0) = 0) THEN
		ACC_DFT_2NOR_LTD_MTH_CNT + 1;

	/* Check if the late payment_cnt = 1, which means the delayed payment */
	IF LATE_PAYMENT_CNT = 1 THEN DO;
		FST_DLD_PAY_TIME_SK = TIME_SK;
		LATE_PAYMENT_STATUS_CNT = 1; /* This is a temporary retained variable */
	END;

	/* Check if late_payment_cnt = 0 and late_payment_status_cnt = 0, which means the account
			has a normal payment till this period */
	ELSE IF (COALESCE(LATE_PAYMENT_CNT, 0) = 0 AND 
			COALESCE(LATE_PAYMENT_STATUS_CNT, 0) = 0) THEN
		ACC_PAY_DLD_2NOR_LTD_MTH_CNT + 1;

	/* Check the delinquent_cnt = 1, which means the account is delinquent */
	IF DELINQUENCY_CNT = 1 THEN
		DELINQUENCY_STATUS_CNT = 1; /* This is a temporary retained variable */

	/* Check if delinquency_cnt = 0 and delinquency_status_cnt = 0, which means the account
			has a normal payment till this period */
	ELSE IF (COALESCE(DELINQUENCY_CNT, 0) = 0 AND
			COALESCE(DELINQUENCY_STATUS_CNT, 0) = 0) THEN
		ACC_DLQ_2NOR_LTD_MTH_CNT + 1;

	/* If balance is greater than the existing balance then replace with the new value */	
	IF COALESCE(ACC_MAX_OUT_BAL_LTD_AMT, MIN_VALUE) < MAX_ACCOUNT_VALUE_AMT THEN DO;
		ACC_MAX_OUT_BAL_LTD_AMT = MAX_ACCOUNT_VALUE_AMT;
		ACC_MAX_OUT_BAL_LTD_MTH_SK = TIME_SK;
	END;
		
	/* If balance is less than the existing balance then replace with the new value */	
	IF COALESCE(ACC_MIN_OUT_BAL_LTD_AMT, MAX_VALUE) > MIN_ACCOUNT_VALUE_AMT THEN DO;
		ACC_MIN_OUT_BAL_LTD_AMT = MIN_ACCOUNT_VALUE_AMT;
		ACC_MIN_OUT_BAL_LTD_MTH_SK = TIME_SK;
	END;

	/* If balance amount is greater than zero, that is account has a positive balance*/
	IF BALANCE_AMT > 0 THEN 
		ZERO_BAL_MTH_STATUS_CNT = 1;/* This is a temporary retained variable */

	/* Check if balance amount <= 0, that is account has nil balance */
	ElSE IF (BALANCE_AMT <= 0 ) THEN DO;
		ACC_NIL_BAL_LTD_MTH_CNT + 1;

		/* If zero_bal_mth_status_cnt = 0, which means the account has a zero balance
			till this period*/
		IF (COALESCE(ZERO_BAL_MTH_STATUS_CNT, 0) = 0) THEN
			ACC_SNC_ZERO_BAL_MTH_CNT + 1;
	END;

/********************************* Life to Date data *************************************/	

	/*Increment the count and at the same time decrement the CURR_TIME to cater to the next
	lowest time period */
		IF LAST.TIME_SK THEN DO;
			COUNT = COUNT + 1;
			CURR_TIME = CURR_TIME - 1;
		END;

	/*If the end of the group is reached then output the data sets */
		IF LAST.ACCOUNT_RK THEN DO;	

			/*Assign the value of retained variables to the actual variable
			being written to the data set */
			CUSTOMER_RK = CUSTOMER_RK_RET;
			ALLOW_OVERDRAFT_FLG = ALLOW_OVERDRAFT_FLG_RET;
			ACCOUNT_TYPE_CD = ACCOUNT_TYPE_CD_RET;
			ACCOUNT_SUB_TYPE_CD = ACCOUNT_SUB_TYPE_CD_RET;
			COLLATERAL_CD = COLLATERAL_CD_RET;
			ACCOUNT_STATUS_CD = ACCOUNT_STATUS_CD_RET;

			IF (COUNT <= 3) THEN DO;
			/*Is needed in case of premature exit, data is present only
			for 3 months */
				%acc_snap_abt_assign_3_to_6;
				%acc_snap_abt_assign_6_to_12;
			END;
			ELSE IF (COUNT <= 6) THEN DO;
			/*Is needed in case of premature exit, data is present only
			for 6 months */
				%acc_snap_abt_assign_6_to_12;
			END;	
			
		/* Life to Date variable*/
			ACC_OPN_TO_FST_DLD_PAY_MTH_CNT = INTCK('MONTH',INPUT(PUT(FST_DLD_PAY_TIME_SK,12.),CALENDER_LAST_MTH_DT.),OPEN_DT);

		/*Output the data set */
			OUTPUT; 
		
		/*Reset all the retain variables for the next customer group */
			%acc_snap_abt_reset_var;

			%IF &PERIOD. = 24 %THEN %DO;
				CURR_TIME=BACK_12M_TIME_SK;
				COUNT = 12;
			%END;
			%ELSE %DO;
				CURR_TIME=CURR_TIME_SK;
				COUNT = 0;
			%END;
		END;

	RUN;
%mend acc_snap_lst_abt;
/*options nomprint mlogic;*/
/*%acc_snap_lst_abt (PERIOD=6, INPUT_TABLE=ACC_SNAP_EXT_LST_6M_LKP);*/

