/*
Macro Name	: PD_CI
Function	: Calls routine which computes Wald's Confidence Limits with given Mean, STDDev and Alpha .
			  for the variable based on ACT_FLAG value and also applies necessary lables to output datasets.
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	:PD CI scrren 
Calls		:CI

Parameters	: 

input_ds		: Name of the input data set 
Alpha			: Value of Alpha to get (1-alpha)*100% CI	
output_ds		: Name of the data set which stores brier score.
ACT_FLAG		: Flag to indicate whether CI to be calculated using actual CCF values (Default value 1)
				 (1: Actual CCF 0: Devlopment CCF)
	
Input Dataset(s) Format:
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
--------------------------------------------------------------------------
Output Dataset(s) Format:
-------------------------------------------------------------------------
Name			Type		Format
------------------------------------------------------------------------
Pool_Name		Character	Default Format
Pool_Seq 
No_of_Acc_Dev 	
	OR 			Numeric		Default Format
No_of_Acc_Actual
PD 				Numeric		Default Format
ActualPD		Numeric		Default Format 
LowerConf 		Numeric		Default Format
UpperConf		Numeric		Default Format
------------------------------------------------------------------------

Logic:
1. Based on ACT_FLAG value CIs are either calculated based on actual proportion(default rate) or PD .
2. In case Actual Proporion (default rate) is near to 0 or 1 then AGRESTI Correction is applicable to
   avoid 0 variance and degenerate CIs.
2. mean and standard deviation is calculated based on obtained proportion.
3. CI macro is called with Value of Mean and Std dev for each pool which gives 100(1-Alpha)% Wald's CI for each pool.
4. proportion always lies between [0,1] there [0,1]^[LCL, UCL] is reported.

Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
%macro pd_ci(input_ds= ,Alpha=,output_ds=, ACT_FLAG=);
%let err_code=;
/*****************************************************************/
%check_alldefaults_nodefaults(&input_ds,No_Of_ACC_Actual,No_Of_Actual_Bads, err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

data work.temp;
	set &input_ds;
	if &ACT_FLAG =0 then
	do;
		Mean = PD;
		Stdev =sqrt(Mean*(1.0-Mean)/No_Of_ACC_Dev);
		call symput('col_name','No_of_Acc_Dev');
		
	end;
	else
	do;
		Mean = No_Of_Actual_Bads/No_Of_ACC_Actual;
		if Mean le &EPSILON or Mean ge (1- &EPSILON) then
			Mean = (No_Of_Actual_Bads+2)/(No_Of_ACC_Actual+4);
		Stdev =sqrt(Mean*(1.0-Mean)/No_Of_ACC_Actual);
		call symput('col_name','No_of_Acc_Actual');
		
	end;
run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

%ci(input_ds=work.temp,Alpha=&Alpha,output_Ci= work.CI);
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

data &output_ds(keep =Pool_Name Pool_Seq &col_name PD ActualPD LowerConf UpperConf);
	merge work.temp work.CI;
	attrib
	/*I18N-scnjih-20080418-0954*/
/*	PD  		label = "Esimated PD"*/
/*	ActualPD	label = "Default Rate"*/
/*	&col_name   label = "No. of Accounts"*/
/*	Pool_name	label = "Pool Name"*/
/*	Pool_Seq	label = "Pool Sequence"*/
/*	;*/

	PD  		label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_ci.sas.1, noquote))"
	ActualPD	label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_ci.sas.2, noquote))"
	&col_name   label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_ci.sas.3, noquote))"
	Pool_name	label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_ci.sas.4, noquote))"
	Pool_Seq	label = "%sysfunc(sasmsg(smd_ds.bismsg,pd_ci.sas.5, noquote))"
	;
	/*I18N-scnjih-20080418-0954*/
	if &ACT_FLAG =0 then
		ActualPD = No_Of_Actual_Bads/No_Of_ACC_Actual;
	else
		ActualPD = Mean;

	LowerConf = max(LowerConf,0);
	UpperConf =min(UpperConf,1);
run;
/*****************************************************************/
%errorhandler(err_code);
%if (&err_code ne 'NONE')%then %goto Error_Handler;
/*****************************************************************/

%return;
/*****************************************************************/
%Error_Handler:
%put ERROR: &err_code;
%defdata(input_ds=&input_ds,stat='PDCI',
		out_graph_ds =,output_ds = &output_ds ,out_stat_ds=);
%mend pd_ci; 


