/*
Macro Name	: SSI
Function	: Generates data for system stability index (SSI)
Created by	: BIS Team
Date		: Apr 07, 2006
SAS Version	: 9.1

Called-by	:SSI screen  
			 
Calls		: None 

Parameters	: 

input_ds		: Name of the input data set
output_ds	: Name of the data set which stores data for graph graph of Observed Default rate estimated PD.

Input Dataset(s) Format:
For PD 
--------------------------------------------------------------------------
Name				Type		Format
--------------------------------------------------------------------------
Pool_Name			Character 	Default Formatting	
Pool_Seq	 		Number		Default Formatting
No_Of_ACC_Actual	Number		Default Formatting
No_of_Acc_Dev	 	Number 		Default Formatting
PD	 				Number		Default Formatting
Score_Points	 	Number		Default Formatting
No_Of_Actual_Bads	Number		Default Formatting	
--------------------------------------------------------------------------
For CCF
-------------------------------------------------------------------------
Name				Type		Format
------------------------------------------------------------------------
Pool_Name			Character	Default Format
Pool_Seq            Numeric		Default Format
ActualCCF           Numeric		Default Format
EstimatedCCF        Numeric		Default Format
No_of_Acc_Actual    Numeric		Default Format
No_of_Acc_Dev       Numeric		Default Format
No_of_Actual_bads   Numeric		Default Format
------------------------------------------------------------------------
For LGD
-------------------------------------------------------------------------
Name				Type		Format
------------------------------------------------------------------------
Pool_Name			Character	Default Format
Pool_Seq            Numeric		Default Format
Actual_LGD			Numeric		Default Format
EstimatedLGD		Numeric		Default Format
No_of_Acc_Actual    Numeric		Default Format
No_of_Acc_Dev       Numeric		Default Format
No_of_Actual_bads   Numeric		Default Format
------------------------------------------------------------------------

Output Dataset(s) Format:
output_ds
-------------------------------------------------------------------------
Name					Type		Format
------------------------------------------------------------------------
Pool_Name				Character 	Default Formatting	
Pool_Seq	 			Number		Default Formatting
Score_Points*	 		Number		Default Formatting
Per_Of_App_Actual		Numeric		percent7.3
Per_of_Acc_Dev 			Numeric		percent7.3
Cum_Per_Of_App_Actual	Numeric		percent7.3
Cum_Per_of_Acc_Dev		Numeric		percent7.3
Diff_AD					Numeric		percent7.3
Ratio_AD				Numeric		7.3
ln_Ratio_AD				Numeric		7.3
SIndex					Numeric		7.3
------------------------------------------------------------------------
* Score_points will only appear in case of PD and Not for LGD and CCF
Logic:
1. First cumulate the number of accounts in development and no accounts in actual sample
2. Compute cumulative percents for the same. 
3. Compute the difference between Actual_cumulative percentage and Development_cumulative percentage
4. Compute natual log for the same
5. SSI for a pool = Diff * Natual log.
6. Sum of SSI per pool will give you SSI for all pooling scheme.


Notes:
1. It is assumed that data set of specified as input_ds is present and has necessarry required rights.
2. It is assumed that data set of specified as input_ds has valid specified fileds.
3. For all output datasets (Viz output_ds),it is assumend that
	a. it has valid name.
	b. Macro has necessary required rights to create the datasets with specified name @ specified location.
	c. Name of the data-set is unique OR if dataset with similar name already exists then it can be safely overwritten.

*/
%macro ssi_app(input_ds=,output_ds=);
data &output_ds;
	set &input_ds;
	retain 
		   Cum_A 0
		   Cum_D 0;	
	cum_A = Sum(cum_A, no_of_appl_actual);
	cum_D = Sum (cum_D, No_of_Acc_Dev);
run;

proc sql noprint;
	select max(Cum_A), max(Cum_D) into :Tot_Act, :Tot_dev from &output_ds;
quit;

/*Calculation of SI*/
/*Inputs: A in % D in %*/
/*OutPuts A-D A/D log(A/D) A-D*ln(A/D)*/
/*Sum (A-D *ln(A/D)*/
data &output_ds;
	set &output_ds;
	attrib
	/*I18N-scnjih-20080418-1051*/
/*	Per_Of_appl_Actual      label="Application-Actual (A)[%]" format=&CS_PERC_FMT. */
/*	Per_of_Acc_Dev         label="Application-Development (D)[%]" format=&CS_PERC_FMT. */
/*	Cum_Per_Of_appl_Actual  format=&CS_PERC_FMT.*/
/*	Cum_Per_of_Acc_Dev     format=&CS_PERC_FMT.*/
/*	Diff_AD				   label="Difference (A-D)[%]" format=&CS_PERC_FMT.	*/
/*	Ratio_AD 			   label="Ratio (A/D)" format= &CS_DEC_FMT.		*/
/*	ln_Ratio_AD			   label="Log Ratio Ln(A/D)" format= &CS_DEC_FMT.  	*/
/*	SIndex				   label="Stability Index (SSI)" format= &CS_DEC_FMT. */
/*    Pool_name              label="Pool Name"	*/
/*	pool_seq				label="Pool Sequence"*/
/*	;*/
	Per_Of_ACC_Actual      label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.1, noquote))" format =&CS_PERC_FMT. 
	Per_of_Acc_Dev         label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.2, noquote))" format =&CS_PERC_FMT. 
	Cum_Per_Of_ACC_Actual  format =&CS_PERC_FMT.
	Cum_Per_of_Acc_Dev     format =&CS_PERC_FMT.
	Diff_AD				   label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.3, noquote))" format =&CS_PERC_FMT.	
	Ratio_AD 			   label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.4, noquote))" format = &CS_DEC_FMT.		
	ln_Ratio_AD			   label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.5, noquote))" format = &CS_DEC_FMT.  	
	SIndex				   label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.6, noquote))" format = &CS_DEC_FMT. 
  Pool_name        label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.7, noquote))"	
	pool_seq				label ="%sysfunc(sasmsg(smd_ds.bismsg,ssi_app.sas.8, noquote))"
	;
	/*I18N-scnjih-20080418-1051*/
	Cum_Per_Of_ACC_Actual = Cum_A/&Tot_Act;
	Cum_Per_of_Acc_Dev  = Cum_D/&Tot_Dev;	
	/*------------------------------------------*/
	Per_Of_ACC_Actual = no_of_appl_actual/&Tot_Act;
	Per_of_Acc_Dev  = No_of_Acc_Dev/&Tot_Dev;
	/*------------------------------------------*/
	Diff_AD = Per_Of_ACC_Actual - Per_of_Acc_Dev;
	Ratio_AD = Per_Of_ACC_Actual/Per_of_Acc_Dev;
	/*------------------------------------------*/
	ln_Ratio_AD = log (Ratio_AD); /* Natural Logarithm*/
	SIndex = Diff_AD * ln_Ratio_AD; /* Since inputs are in percentage*/
	/*------------------------------------------*/
	drop PD No_Of_Actual_Bads cum_A cum_D no_of_appl_actual No_of_Acc_Dev;
run;
%mend ssi_app;
 
