/* The input to this macro is the 
1) PERIOD: (3, 6, 12, 24) for which the variables have
to be aggregated.
If PERIOD=1, then aggregation for last 3 months will be calculated and stored in,
CUS_CONT_CURR_ABT.
If PERIOD=3, then aggregation for last 3 months will be calculated and stored in,
CUS_CONT_LST_3M_ABT.
If PERIOD=6, then aggregation for last 3 & 6 months will be calculated and stored in,
CUS_CONT_LST_3M_ABT, CUS_CONT_LST_6M_ABT. 
If PERIOD=12, then aggregation for last 3, 6 & 12 months will be calculated and stored in,
CUS_CONT_LST_3M_ABT, CUS_CONT_LST_6M_ABT, CUS_CONT_LST_12M_ABT. 
If PERIOD=24, then aggregation for last 13-24 months will be calculated and stored in,
CUS_CONT_13_24M_ABT. 
2) TABLE: The input table which is already filter for the PERIOD (3, 6, 12, 13-24). 
*/

%macro cus_cont_lst_macro(PERIOD=, INPUT_TABLE=);

/*Sort the input data BY CUSTOMER_RK in ascending order 
and BY TIME_SK in descending order */

PROC SORT DATA=ABTSCR.&INPUT_TABLE.;
	BY CUSTOMER_RK DESCENDING TIME_SK;
RUN;

/*The data step begins here. The data step reads the sorted input data set
& outputs aggregation tables based on the PERIOD*/

data
%if &PERIOD. = 1 %then %do; /*If PERIOD = 3*/
abtagg.CUS_CONT_CURR_ABT( KEEP = CUSTOMER_RK CUS_CONT_CURR_MTH_CNT); %end; 
%if &PERIOD. = 3 %then %do; /*If PERIOD = 3*/
abtagg.CUS_CONT_CURR_ABT( KEEP = CUSTOMER_RK CUS_CONT_CURR_MTH_CNT)
abtagg.CUS_CONT_LST_3M_ABT( KEEP = CUSTOMER_RK CUS_CONT_LST_3M_CNT); %end;
%else %if &PERIOD. = 6 %then %do ; /*If PERIOD = 6*/ 
abtagg.CUS_CONT_CURR_ABT( KEEP = CUSTOMER_RK CUS_CONT_CURR_MTH_CNT)
abtagg.CUS_CONT_LST_3M_ABT( KEEP = CUSTOMER_RK CUS_CONT_LST_3M_CNT) 
abtagg.CUS_CONT_LST_6M_ABT( KEEP = CUSTOMER_RK CUS_CONT_LST_6M_CNT); %end;
%else %if &PERIOD. = 12 %then %do; /*If PERIOD = 12*/
abtagg.CUS_CONT_CURR_ABT( KEEP = CUSTOMER_RK CUS_CONT_CURR_MTH_CNT)
abtagg.CUS_CONT_LST_3M_ABT( KEEP = CUSTOMER_RK CUS_CONT_LST_3M_CNT)
abtagg.CUS_CONT_LST_6M_ABT( KEEP = CUSTOMER_RK CUS_CONT_LST_6M_CNT) 
abtagg.CUS_CONT_LST_12M_ABT( KEEP = CUSTOMER_RK CUS_CONT_LST_12M_CNT);  %end;
%else %if &PERIOD. = 24 %then %do; /*If PERIOD = 24*/
abtagg.CUS_CONT_13_24M_ABT( KEEP = CUSTOMER_RK CUS_CONT_13_24M_CNT); %end;

/* Set the input table for reading */
SET ABTSCR.&INPUT_TABLE.;
BY CUSTOMER_RK DESCENDING TIME_SK;

/*List of variables to be retained */
RETAIN  
		CUS_CONT_CURR_MTH_CNT 0
		CUS_CONT_LST_3M_CNT 0
		CUS_CONT_LST_6M_CNT 0 
		CUS_CONT_LST_12M_CNT 0
		CUS_CONT_13_24M_CNT 0;

/*Depending on whether the PERIOD is (3, 6, 12) or 24, the retained variable will be
initialized */
%if &PERIOD. = 24 %then %do;
	RETAIN CURR_TIME &BACK_12M_TIME_SK. COUNT 12;  %end;
%else %do;
	RETAIN CURR_TIME &CURR_TIME_SK. COUNT 0; %end;

/*Assign the value of count at the start of iteration to a temporary variable COUNT_TMP */
COUNT_TMP = COUNT;

/* Check to see if data is missing for certain period in the input table. If so,
   then adjust the count accordingly */
DO WHILE (TIME_SK < CURR_TIME);
	CURR_TIME = CURR_TIME - 1;
/*	COUNT = COUNT + 1;*/
END;

/* Check to see if there is more than one entry for certain period in the input table. 
   If so,  then adjust the count accordingly */
DO WHILE (CURR_TIME < TIME_SK ) ;
	CURR_TIME = CURR_TIME + 1;
/*	COUNT = COUNT - 1;*/
END;

/*Check to see if the count has reached some level (3,6,12), if so then assign the
value of previous variable to the next level variable */
IF FIRST.TIME_SK THEN 
	DO;
		IF COUNT EQ 1 OR (COUNT_TMP <= 1 AND COUNT > 1) THEN 
			CUS_CONT_LST_3M_CNT = CUS_CONT_CURR_MTH_CNT;
		IF COUNT EQ 3 OR (COUNT_TMP <= 3 AND COUNT > 3) THEN 
			CUS_CONT_LST_6M_CNT = CUS_CONT_LST_3M_CNT;
		IF COUNT EQ 6 OR (COUNT_TMP <=6 AND COUNT > 6) THEN 
			CUS_CONT_LST_12M_CNT = CUS_CONT_LST_6M_CNT;
	END;

/*The expressions like summations, max, min, count, average are all done here */
IF (COUNT < 1) THEN 
	CUS_CONT_CURR_MTH_CNT = SUM(CUS_CONT_CURR_MTH_CNT, NO_OF_CONTACTS);						
IF (COUNT < 3) THEN 
	CUS_CONT_LST_3M_CNT = SUM(CUS_CONT_LST_3M_CNT, NO_OF_CONTACTS);						
ELSE IF (COUNT <  6)  THEN 
	CUS_CONT_LST_6M_CNT = SUM(CUS_CONT_LST_6M_CNT, NO_OF_CONTACTS);						
ELSE IF (COUNT <  12)  THEN 
	CUS_CONT_LST_12M_CNT = SUM(CUS_CONT_LST_12M_CNT, NO_OF_CONTACTS);						
ELSE IF (COUNT <24) THEN
	CUS_CONT_13_24M_CNT = SUM(CUS_CONT_13_24M_CNT, NO_OF_CONTACTS);						

/*Increment the count and at the same time decrement the CURR_TIME to cater to the next
lowest time period */
IF LAST.TIME_SK THEN 
	DO;
	COUNT = COUNT + 1;
	CURR_TIME = CURR_TIME - 1;
	END;

/*If the end of the group is reached then output the data sets */
IF LAST.CUSTOMER_RK THEN
DO;	
	IF (COUNT <= 1) THEN	
	/*Is needed in case of premature exit, data is present only
	for 3 months */
		DO;
		CUS_CONT_LST_3M_CNT = CUS_CONT_CURR_MTH_CNT;
		CUS_CONT_LST_6M_CNT = CUS_CONT_CURR_MTH_CNT;	
		CUS_CONT_LST_12M_CNT = CUS_CONT_CURR_MTH_CNT;	
		END;
	ELSE;
	IF (COUNT <= 3) THEN	
	/*Is needed in case of premature exit, data is present only
	for 3 months */
		DO;
		CUS_CONT_LST_6M_CNT = CUS_CONT_LST_3M_CNT;
		CUS_CONT_LST_12M_CNT = CUS_CONT_LST_3M_CNT;	
		END;
	ELSE IF (COUNT <= 6) THEN
	/*Is needed in case of premature exit, data is present only
	for 6 months */
		DO;
		CUS_CONT_LST_12M_CNT = CUS_CONT_LST_6M_CNT;
		END;	
		
	/*Output the data set */
	OUTPUT; 
	
	/*Reset all the retain variables for the next customer group */
	CUS_CONT_CURR_MTH_CNT = 0;
	CUS_CONT_LST_3M_CNT = 0; 
 	CUS_CONT_LST_6M_CNT = 0;
	CUS_CONT_LST_12M_CNT = 0; 
	CUS_CONT_13_24M_CNT = 0; 

	
	%if &PERIOD. = 24 %then %do;
	CURR_TIME=&BACK_12M_TIME_SK.; COUNT = 12;  %end;
	%else %do;
	CURR_TIME=&CURR_TIME_SK.; COUNT = 0; %end;
END;

RUN;
%mend;


