/***********************************************************************************************
       Module:  pool_technique

     Function:  This macro gets the pooling technique of the calling report.
				
      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All monitoring model report screens (except conf_matrix)
				
        Calls:  NA

Datasets used:  No input datasets required for processing of the macro
 
        Logic: 	In this macro the following indicates:
					1.pd_score 			: If NULL then shown as DEFAULT status.
					2.time_key        	: The surrogate key for selected period.
		            3.model1_key        : The surrogate key for the selected model.
		 			4.no_of_quantile    : The range for dynamic pooling will be decided based
										  on the quantile.Quantile ranges will be calculated
										  based on the SCORE/PD/LGD/CCF of the scoring
										  population for the selected score period.
				    5.range_interval    : Dynamic pooling based on the range specified.
			  								E.g. 100, 200 for SCORE and .2, .3 for PD.

				E.g. If pd_score is NULL or DEFAULT then 
						pool_tech is pool_scheme_nm (Default) where pool_scheme_nm is
							for e.g. PD Range, hence the 
							pool_tech will be PD Range (Default)
					 Else if range_interval is 10 then
						if pd_score is SCORE then
							pool_tech is, say , Score Range (10)
						else if model_type_code is PDA or PDO then
							pool_tech is, say, PD Range (10)
						else pool_tech will be
							CCF Range (10) (i.e. if model_type_code=CCF)
					 Else if no_of_quantile is 2 then
						if pd_score is SCORE then
							pool_tech is, say , Score Quantiles (2)
						else if model_type_code is PDA or PDO then
							pool_tech is, say, PD Quantiles (2)
						else pool_tech will be
							CCF Quantiles (2) (i.e. if model_type_code=CCF)

				Create a macro variable pool_tech before calling this macro.
***********************************************************************************************/
%macro pool_technique;
	%let tech=;
/*I18N-scnhuh-20080425-1055*/	
/*Add 99999 as default value for avoiding syntax error of following 'where' condition*/
	%let time_period=99999;
/*I18N-scnhuh-20080425-1055*/	
	%if &pd_score=%str() or &pd_score=%str(DEFAULT) %then %do;
		proc sql noprint;
			select cal_month_last_dt format 8. into :time_period
			from dim.time_dim
			where time_sk=&time_key;

			select strip(pool_scheme_nm) into :tech
			from dim.analytical_model_dim inner join dim.pool_scheme
				on (analytical_model_dim.pool_scheme_sk = pool_scheme.pool_scheme_sk)
			where analytical_model_dim.model_sk=&model1_key and 
				&time_period between datepart(analytical_model_dim.valid_start_dttm) and 
				datepart(analytical_model_dim.valid_end_dttm); 
		quit;
		%let pool_tech=&tech. (Default);
	%end;
	%else %do;
		%if &range_interval ne %str() %then %let tech=Range (&range_interval);
		%else %if &no_of_quantile ne %str() %then %let tech=Quantiles (&no_of_quantile);
		
		%let model_type = %quote(%'&model_type_code%');
		%if &pd_score = %str(SCORE) %then %let pool_tech=Score %trim(%left(&tech));
		%else %if &model_type = &PD_APP_MODEL or &model_type = &PD_ONG_MODEL
			%then %let pool_tech=PD %trim(%left(&tech));
		%else %let pool_tech=%trim(%left(&model_type_code)) %trim(%left(&tech));
	%end;
%mend pool_technique;
