/******************************************************************************************************
       Module:  statistic_overtime

     Function:  This stored process creates the graph showing the performance of a given statistic over
				time. The input to the macro is a dataset with the statistic values over the entire
				period available, the name of the statistic and the name to be given to the gif created
				in the macro.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All reports which need an overtime graph
        Calls:  Macro graph_options which sets all the goptions for the graph.

Datasets used:  Supplied as the parameter
                The input dataset should be in the following structure
                ColumnName      	Type        	Purpose
                MODEL_SK            Number     	It is the Surrogate Key of the model for which the 
												report is being generated.
                SCORE_TIME_SK   	Number     	It is the Surrogate Key of the period for which the data
												is required to generate this graph.
				CAL_MON_LAST_DT		Date		This column refers to the date corresponding to the last
												day of the month which is referred to in SCORE_TIME_SK.
                MEASURE_NM 			Char(100)   This column provides the name of the measure (statistic)
												for which the graph is being generated. It will be the 
												name of the measure as provided in MEASURE_DIM.
                MEASURE_VALUE   	Number  	It is the value of the measure as given in MEASURE_NM 
												calculated as on date SCORE_TIME_SK.
    			BOUND_GREEN   		Number  	This represents a notional value that is used for 
												calculating whether the measure value as provided by
												MEASURE_VALUE can be accepted as a good value or a bad 
												value (traffic light). This value is a boundary which can 
												be configured by the user according to his needs and is 
												available in MEASURE_DIM.
				BOUND_RED			Number		This represents a notional value that is used for 
												calculating whether the measure value as provided by
												MEASURE_VALUE can be accepted as a good value or a bad 
												value (traffic light). This value is a boundary which can 
												be configured by the user according to his needs and is 
												available in MEASURE_DIM.
 
        Logic:  1. The input dataset is subset to get only the data for the selected MEASURE.
				2. Values for BOUND_GREEN and BOUND_RED are taken in macro valriables to draw on 
					the graph.
				3. Macro graph_options is called to set the goptions.
				4. The graph is generated using the name provided to the macro.
				5. A customizable axis considering BOUND_GREEN,BOUND_RED and the measure value is created.
				6. The no.of intervals are capped at 10.
				
   Parameters:  INPUT (From Report Screen when link is used for navigation) 
				ds			:   Input dataset in the structure mentioned above with the data for the
								selected measure.
                statistic	:   Name of the measure for which the graph is being generated.
                name   		:   Name to be given to the gif when the graph is generated.

******************************************************************************************************/
%macro statistic_overtime(ds,statistic,name);
/*Passing the name of data set,ds, and graph name to be ploted*/
%let Flag = ;
data work.over_time;
	set &ds(where=(upcase(MEASURE_NM)=upcase("&statistic")) keep=MODEL_SK SCORE_TIME_SK 
	CAL_MON_LAST_DT MEASURE_NM MEASURE_VALUE BOUND_GREEN BOUND_RED DEV_FLG);
		if upcase(dev_flg)='N';
		call symput('b_green',BOUND_GREEN);
		call symput('b_red',BOUND_RED);
		period = CAL_MON_LAST_DT;
run;
%let color_symbol1=;
%let color_overtime_red=; /* Red */
%let color_overtime_yellow=; /* Yellow */
%let color_overtime_green=; /* Green */
%graph_options;
/*************************ANONATE DATASET***********************************************/
data work.color_slab;
 length function style color $ 8; 
 retain xsys '1' ysys '2'; 
 	%if %sysevalf(&b_green >&b_red) %then %do;

	 function='move'; x=0;   y=%sysevalf(&b_red); output;
	 function='bar';  x=100; y=%sysevalf(&b_green); color="&color_overtime_yellow"; /* BWH = bluish white */
	 style='solid'; output;

	 function='move'; x=0;   ysys='1'; y=0;   output;
	 function='bar';  x=100; ysys='2'; y=%sysevalf(&b_red);  color="&color_overtime_red"; /* PALG = pale yellow green */
	 style='solid'; output;

	 function='move'; x=0;   ysys='2'; y=%sysevalf(&b_green);  output;
	 function='bar';  x=100; ysys='1'; y=100; color="&color_overtime_green";  /* LIO = light orange */
	 style='solid'; output;
%end;

%else %do;
	 function='move'; x=0;   y=%sysevalf(&b_green); output;
	 function='bar';  x=100; y=%sysevalf(&b_red); color="&color_overtime_yellow"; /* BWH = bluish white */
	 style='solid'; output;

	 function='move'; x=0;   ysys='1'; y=0;   output;
	 function='bar';  x=100; ysys='2'; y=%sysevalf(&b_green);  color="&color_overtime_green"; /* PALG = pale yellow green */
	 style='solid'; output;

	 function='move'; x=0;   ysys='2'; y=%sysevalf(&b_red);  output;
	 function='bar';  x=100; ysys='1'; y=100; color="&color_overtime_red";  /* LIO = light orange */
	 style='solid'; output;

 %end;
run;
/*************************ANONATE DATASET********************************************/

data work.over_time2;
	set work.over_time;
	Min_a =min(BOUND_GREEN ,BOUND_RED ,MEASURE_VALUE);
	Max_b =max(BOUND_GREEN ,BOUND_RED ,MEASURE_VALUE);
run;

proc sql noprint;
	select min(Min_a) into :Min from work.over_time2;
%if %sysevalf(&Min > 0) %then 
	%let Flag = 'Y'; 
	select max(Max_b) into :Max from work.over_time2;
	select 10**(int(log10(&Max-&Min))-1)into :step from work.over_time2;
	select Round(&Min-&step,&step) into :Min from work.over_time2;
%if &Flag = 'Y' %then
	%do;
		%if  %sysevalf(&Min < 0) %then
		%let Min =0;
	%end;

	select Round(&Max+&step,&step)into :Max from work.over_time2;
	select (&Max - &Min)/&step into :NSteps from work.over_time2;
%put &Nsteps; 
%if %sysevalf(&Nsteps > 10) %then
%do; 
	%let NSteps = 10;
	%let new_step = %sysevalf((&Max - &Min)/&NSteps);
	%let max = %sysevalf(&max - &step);
	select Round(&new_step,&step) into :step from work.over_time2;
	select Round(&Max+&step,&step)into :Max from work.over_time2;
%end;
 %put &Nsteps; 
 %put &min ;%put &step;%put &max;%put &flag ;
quit;
footnote;

proc gplot data=work.over_time annotate=work.color_slab;
	axis1 label=(a=90"&statistic") order=&Min to &Max by &step;
	/*I18N-scnjih-20080418-1109*/
/*	axis2 label=('Time');*/
	axis2 label =( "%sysfunc(sasmsg(smd_ds.bismsg,statistic_overtime.sas.1, noquote))");
	/*I18N-scnjih-20080418-1109*/
/*	%put &min ;%put &step;%put &max;*/
/*	AXIS1 order=&Min to &Max by &step ;*/
	symbol1 color=&color_symbol1 width=.15 height=2 interpol = join value=dot;
/*I18N-scnhuh-20080428-1010*/
/*change format from &CS_TIME_PER_FMT to &NLDATE_FMT*/
	/*format period yymms5.;*/
	format period &NLDATE_FMT;
/*I18N-scnhuh-20080428-1010*/
		 plot measure_value*period   
	        / lvref=1 haxis=axis2 vaxis=axis1 name="&name";
	run;
quit;
%mend statistic_overtime;
