/**********************************************************************************************
       Module:  feed_pd_pool
     Function:  This macro provides the view table for  PD Model on pool level.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	All report screens. 

        Calls:  NA

Datasets used:  No input datasets required for processing of the macro.
 
 		Logic:  On selected model  and time this macro creates the 
				view for model and time.All columns of Account PD Fact 
				having name with model type and time (E.g. Account_PD_FACT_301_1016,  
				Account_PD_FACT_301_1014) are joined by all respective dimension.
				Log error message if it generate ,in error folder.
   Parameters: 
		INPUT: 
				in_filter 		 	:	where clause .
				out_lib_nm			:	where the dataset will be created.
				out_table_nm_pool	:	The table name for pool level feed.
				out_table_nm_acct	:	The table name for account/application level feed
				model_time_key		:	This is the combination of  selected model and selected 
										time for that model E.G. 100_1025 , 103_1027).
**********************************************************************************************/
%macro feed_pd_pool(in_filter=, out_lib_nm=, out_table_nm_pool=, out_table_nm_acct=,
model_time_key=);

/*Generate a table by joining account_pd_fact with all respective dimensions */
proc sql;
CREATE TABLE &out_lib_nm..&out_table_nm_pool._sql AS
SELECT ACCOUNT_DIM.ACCOUNT_ID, ACCOUNT_PD_FACT&model_time_key..PREDICTED_GOOD_BAD, 
	ACCOUNT_PD_FACT&model_time_key..ACTUAL_GOOD_BAD, 
	ACCOUNT_PD_FACT&model_time_key..ESTIMATED_ACCOUNT_PD, 	
	ACCOUNT_PD_FACT&model_time_key..SCORE_POINTS,		
	ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD, 
	ANALYTICAL_MODEL_DIM.DEPLOYMENT_STATUS_CD, ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD,
    CUSTOMER_DIM.CUSTOMER_ID, 
	FINANCIAL_PRODUCT_DIM.PRODUCT_ID, 
	FINANCIAL_PRODUCT_DIM.FINANCIAL_PRODUCT_TYPE_CD,
	TIME_DIM.CAL_MONTH_LAST_DT AS CAL_MON_LAST_DT, 
	ACCOUNT_PD_FACT&model_time_key..MODEL_SK, ACCOUNT_PD_FACT&model_time_key..SCORE_TIME_SK, 
	ACCOUNT_PD_FACT&model_time_key..ACCOUNT_SK, ACCOUNT_PD_FACT&model_time_key..CUSTOMER_SK, 
	ACCOUNT_PD_FACT&model_time_key..PRODUCT_SK, ACCOUNT_PD_FACT&model_time_key..POOL_SK 
FROM FACT.ACCOUNT_PD_FACT&model_time_key. 
	INNER JOIN DIM.POOL_DIM 
	ON (ACCOUNT_PD_FACT&model_time_key..POOL_SK = POOL_DIM.POOL_SK)  
	INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
	ON (ACCOUNT_PD_FACT&model_time_key..MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK)  
	INNER JOIN DIM.ACCOUNT_DIM 
	ON (ACCOUNT_PD_FACT&model_time_key..ACCOUNT_SK = ACCOUNT_DIM.ACCOUNT_SK)  
	INNER JOIN DIM.FINANCIAL_PRODUCT_DIM 
	ON (ACCOUNT_PD_FACT&model_time_key..PRODUCT_SK = FINANCIAL_PRODUCT_DIM.PRODUCT_SK)  
	INNER JOIN DIM.CUSTOMER_DIM 
	ON (ACCOUNT_PD_FACT&model_time_key..CUSTOMER_SK = CUSTOMER_DIM.CUSTOMER_SK)  
	INNER JOIN DIM.TIME_DIM 
	ON (ACCOUNT_PD_FACT&model_time_key..SCORE_TIME_SK = TIME_DIM.TIME_SK)
	INNER JOIN DIM.INTERNAL_ORG_DIM
	ON (ACCOUNT_PD_FACT&model_time_key..INTERNAL_ORG_SK = INTERNAL_ORG_DIM.INTERNAL_ORG_SK)
	&in_filter ;
quit;
/*End, Generate a table by joining account_pd_fact with all respective dimensions */

/*
Code to check for errors.
Possibly error will happen only if the filter condition is not properly passed. 
In this case, return to the calling program with error_code=ERROR*/

%if &sqlrc = 8 %then
%do;
%let error_code = ERROR;
%RETURN;
%end;
/*End of code to check errors */

/*Get the no of account actual */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._act AS
SELECT SCORE_TIME_SK, POOL_SK, 
COUNT(ACCOUNT_ID) AS NO_OF_ACCOUNT_ACTUAL, 
SUM(ACTUAL_GOOD_BAD) AS NO_OF_ACTUAL_BADS,
MAX(SCORE_POINTS)AS MAX_SCORE_POINTS 
FROM  &out_lib_nm..&out_table_nm_pool._sql 
GROUP BY SCORE_TIME_SK, POOL_SK;
quit;
/*End no. of account actual */

/*Get the model_sk into a temporary table for further use */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dist
as select distinct MODEL_SK
from &out_lib_nm..&out_table_nm_pool._sql
quit;
/*End, of model_sk into a temporary table for further use */

/*For getting no of account development for a model*/
proc sql;
create table &out_lib_nm..&out_table_nm_pool._dev as
select POOL_SK, count(ACCOUNT_SK) as NO_OF_ACCOUNT_DEV 
FROM &out_lib_nm..&out_table_nm_pool._dist
INNER JOIN FACT.MODEL_DEV_FACT
ON (&out_table_nm_pool._dist.MODEL_SK = MODEL_DEV_FACT.MODEL_SK)
GROUP BY POOL_SK;
quit;
/*End, getting no of account development */

/*Get the pool level modeling information from model_x_pool table */
proc sql;
create table &out_lib_nm..&out_table_nm_pool._mdl as
select model_x_pool.POOL_SK as POOL_SK, model_x_pool.rate,
POOL_DIM.POOL_NAME, POOL_DIM.POOL_SEQ_NO AS POOL_SEQ_NO from
bridge.model_x_pool 
INNER JOIN &out_lib_nm..&out_table_nm_pool._dist
ON (model_x_pool.MODEL_SK = &out_table_nm_pool._dist.MODEL_SK)
INNER JOIN dim.POOL_DIM
ON (model_x_pool.POOL_SK = POOL_DIM.POOL_SK);
quit;
/*End, of pool level modeling information */

/*Get the distinct values of 
TIME_SK from _sql
POOL_NAME from _mdl 
Perform cartesian product for TIME_SK, POOL_NAME */

proc sql;
create view &out_lib_nm..&out_table_nm_pool._pool
as select distinct pool_sk from &out_lib_nm..&out_table_nm_pool._mdl;

create view &out_lib_nm..&out_table_nm_pool._time
as select distinct SCORE_TIME_SK as time_sk from &out_lib_nm..&out_table_nm_pool._sql;

create table &out_lib_nm..&out_table_nm_pool._pt
as select time_sk, pool_sk from
&out_lib_nm..&out_table_nm_pool._time, &out_lib_nm..&out_table_nm_pool._pool;
quit;
/*End of cartesian product */

/*Start of pool level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_pool. AS
 /*I18N-scnjih-20080418-1546*/
/*select TIME_SK label="Score Time", POOL_NAME as pool_name label="Pool Name", */
/*POOL_SEQ_NO as pool_seq label="Pool Sequence",*/
/*coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label="No of Accounts (Development)", */
/*coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label="No of Accounts (Actual)", */
/*NO_OF_ACTUAL_BADS as no_of_actual_bads label="No of Events (Actual)", */
/*MAX_SCORE_POINTS as score_points label="Score Points",*/
/*rate as pd label="Estimated PD"*/
select TIME_SK label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.1, noquote))", POOL_NAME as pool_name label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.2, noquote))", 
POOL_SEQ_NO as pool_seq label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.3, noquote))",
coalesce(NO_OF_ACCOUNT_DEV, &epsilon) as no_of_acc_dev label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.4, noquote))", 
coalesce(NO_OF_ACCOUNT_ACTUAL, &epsilon) as no_of_acc_actual label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.5, noquote))", 
NO_OF_ACTUAL_BADS as no_of_actual_bads label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.6, noquote))", 
MAX_SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.7, noquote))",
rate as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.8, noquote))"
 /*I18N-scnjih-20080418-1546*/
FROM &out_lib_nm..&out_table_nm_pool._pt
LEFT JOIN &out_lib_nm..&out_table_nm_pool._mdl
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._mdl.POOL_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._act
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._act.POOL_SK AND
    &out_table_nm_pool._pt.TIME_SK = &out_table_nm_pool._act.SCORE_TIME_SK)
LEFT JOIN &out_lib_nm..&out_table_nm_pool._dev
ON (&out_table_nm_pool._pt.POOL_SK = &out_table_nm_pool._dev.POOL_SK)
where sum(NO_OF_ACCOUNT_DEV, NO_OF_ACCOUNT_ACTUAL) <> .
order by 1, 3;
quit;
/*End of pool level feed */

/*Account level feed */
proc sql;
create view &out_lib_nm..&out_table_nm_acct.
 /*I18N-scnjih-20080418-1546*/
/*as SELECT ACCOUNT_ID as account_id label="Account Identifier", */
/*CUSTOMER_ID as customer_id label="Customer Identifier", */
/*SCORE_POINTS as score_points label="Score Points", */
/*ACTUAL_GOOD_BAD as actual_good_bad label="Observed Default", */
/*PREDICTED_GOOD_BAD as predicted_good_bad label="Predicted Default", */
/*ESTIMATED_ACCOUNT_PD as pd label="Estimated PD"*/
as SELECT ACCOUNT_ID as account_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.9, noquote))", 
CUSTOMER_ID as customer_id label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.10, noquote))", 
SCORE_POINTS as score_points label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.11, noquote))", 
ACTUAL_GOOD_BAD as actual_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.12, noquote))", 
PREDICTED_GOOD_BAD as predicted_good_bad label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.13, noquote))", 
ESTIMATED_ACCOUNT_PD as pd label ="%sysfunc(sasmsg(smd_ds.bismsg,feed_pd_pool.sas.14, noquote))"
 /*I18N-scnjih-20080418-1546*/
FROM &out_lib_nm..&out_table_nm_pool._sql
order by 1;
quit;
/*End of account level feed */


%mend feed_pd_pool;


