/* The input to this macro is the 
1) PERIOD: (3, 6, 12, 24) for which the variables have
to be aggregated.
If PERIOD=3, then aggregation for last 3 months will be calculated and stored in,
OTE_ACC_SNAP_LST_3M_ABT.
If PERIOD=6, then aggregation for last 3 & 6 months will be calculated and stored in,
OTE_ACC_SNAP_LST_3M_ABT, OTE_ACC_SNAP_LST_6M_ABT. 
If PERIOD=12, then aggregation for last 3, 6 & 12 months will be calculated and stored in,
OTE_ACC_SNAP_LST_3M_ABT, OTE_ACC_SNAP_LST_6M_ABT, OTE_ACC_SNAP_LST_12M_ABT. 
2) TABLE: The input table which is already filter for the PERIOD (3, 6, 12). 
*/

%macro ote_acc_snap_lst_abt(PERIOD=, INPUT_TABLE=);

	/*Sort the input data BY CUSTOMER_RK in ascending order 
	and BY TIME_SK in descending order */

	PROC SORT DATA=ABTSCR.&INPUT_TABLE.;
		BY ACCOUNT_RK DESCENDING TIME_SK;
	RUN;

	/*The data step begins here. The data step reads the sorted input data set
	& outputs aggregation tables based on the PERIOD*/

	data 
		/*If PERIOD = 3*/
		%if &PERIOD. = 3 %then %do; 
			abtscr.OTE_ACC_SNAP_LST_3M_ABT(keep = ACCOUNT_RK
									CUSTOMER_RK
									ACC_AVG_BAL_LST_3M_AMT
									ACC_90PDLQ_LST_3M_CNT
									);
		%end;
		/*If PERIOD = 6*/
		%else %if &PERIOD. = 6 %then %do ; 
			abtscr.OTE_ACC_SNAP_LST_3M_ABT(keep = ACCOUNT_RK
									CUSTOMER_RK
									ACC_AVG_BAL_LST_3M_AMT
									ACC_90PDLQ_LST_3M_CNT
									)
			abtscr.OTE_ACC_SNAP_LST_6M_ABT(keep = ACCOUNT_RK
									CUSTOMER_RK
									ACC_AVG_BAL_LST_6M_AMT
									ACC_90PDLQ_LST_6M_CNT
									);
		%end;
		/*If PERIOD = 12*/
		%else %if &PERIOD. = 12 %then %do ; 
			abtscr.OTE_ACC_SNAP_LST_3M_ABT(keep = ACCOUNT_RK
									CUSTOMER_RK
									ACC_AVG_BAL_LST_3M_AMT
									ACC_90PDLQ_LST_3M_CNT
									)
			abtscr.OTE_ACC_SNAP_LST_6M_ABT(keep = ACCOUNT_RK
									CUSTOMER_RK
									ACC_AVG_BAL_LST_6M_AMT
									ACC_90PDLQ_LST_6M_CNT
									)
			abtscr.OTE_ACC_SNAP_LST_12M_ABT(keep = ACCOUNT_RK
									CUSTOMER_RK
									ACC_90PDLQ_LST_12M_CNT
									);
		%end;
	
	/* Set the input table for reading */
		SET ABTSCR.&INPUT_TABLE.;
		BY ACCOUNT_RK DESCENDING TIME_SK;

	/*List of variables to be retained */
		RETAIN
			/* variable for last 3 months */
			ACC_AVG_BAL_LST_3M_AMT .
			ACC_90PDLQ_LST_3M_CNT 0

			/* variable for last 6 months*/
			ACC_AVG_BAL_LST_6M_AMT .
			ACC_90PDLQ_LST_6M_CNT 0

			/* variable for last 12 months*/
			ACC_90PDLQ_LST_12M_CNT 0

			/* Temporary retain variable*/
			SUM_TOT_BAL_AMT .
			TOT_BAL_CNT 0
			CUSTOMER_RK_RET
			;

		RETAIN CURR_TIME;
		CURR_TIME = OTE_CURR_TIME_SK;

		RETAIN COUNT 0 COUNT_TMP;

	/* Assign the value of count at the start of every iteration. 
		Later used to check in conditions where counters are between 3 and 6 */

		COUNT_TMP = COUNT;

	/* Check to see if data is missing for certain period in the input table. If so,
	   then adjust the count accordingly */
		DO WHILE (TIME_SK < CURR_TIME);
			CURR_TIME = CURR_TIME - 1;
/*			COUNT = COUNT + 1;*/
		END;

	/* Check to see if there is more than one entry for certain period in the input table. 
	   If so,  then adjust the count accordingly */
		DO WHILE (CURR_TIME < TIME_SK ) ;
			CURR_TIME = CURR_TIME + 1;
/*			COUNT = COUNT - 1;*/
		END;

	/*Assign the value of following variables to the retained variables. 
		This variables will be written to the data set during LAST.ACCOUNT_RK */
		IF FIRST.ACCOUNT_RK THEN DO;
			CUSTOMER_RK_RET = CUSTOMER_RK;
		END;

	/*Check to see if the count has reached some level (3,6), if so then assign the
	value of perivous variable to the next level variable */

		IF FIRST.TIME_SK THEN DO;
			IF COUNT EQ 3 OR (COUNT_TMP <= 3 AND COUNT > 3) THEN DO;	
				ACC_AVG_BAL_LST_6M_AMT = ACC_AVG_BAL_LST_3M_AMT;
				ACC_90PDLQ_LST_6M_CNT = ACC_90PDLQ_LST_3M_CNT;
			END;
			IF COUNT EQ 6 OR (COUNT_TMP <= 6 AND COUNT > 6) THEN DO;
				ACC_90PDLQ_LST_12M_CNT = ACC_90PDLQ_LST_6M_CNT;				
			END;
		END;

	/*The expressions like summations, max, min, count, average are all done here */
		IF (COUNT < 3) THEN DO;

				/* Summing the value of total balance amount, where SUM_TOT_BAL_AMT 
					and TOT_BAL_CNT are temporary retained variable */
				IF TOTAL_BALANCE_AMT ^= . THEN DO;
					SUM_TOT_BAL_AMT + TOTAL_BALANCE_AMT;
					TOT_BAL_CNT + 1;
				END;

				/*Checking whether the total balance amount count is 0*/
				IF (COALESCE(TOT_BAL_CNT,0) = 0) THEN DO;
					ACC_AVG_BAL_LST_3M_AMT = .;
				END;
				ELSE DO;
					/* Computing average account balance */
					ACC_AVG_BAL_LST_3M_AMT = (SUM_TOT_BAL_AMT/TOT_BAL_CNT);
				END;

				/*Check to see if the delinquency range is greater than 90 */
				IF (COALESCE(DAYS_PAYMENT_PAST_DUE_CNT,0) >= 91) THEN
					ACC_90PDLQ_LST_3M_CNT + 1;

		END;	
		ELSE IF (COUNT <  6)  THEN DO;

				/* Summing the value of total balance amount, where SUM_TOT_BAL_AMT 
					and TOT_BAL_CNT are temporary retained variable */
				IF TOTAL_BALANCE_AMT ^= . THEN DO;
					SUM_TOT_BAL_AMT + TOTAL_BALANCE_AMT;
					TOT_BAL_CNT + 1;
				END;

				/*Checking whether the total balance amount count is 0*/
				IF (COALESCE(TOT_BAL_CNT,0) = 0) THEN DO;
					ACC_AVG_BAL_LST_6M_AMT = .;
				END;
				ELSE DO;
					/* Computing average account balance */
					ACC_AVG_BAL_LST_6M_AMT = (SUM_TOT_BAL_AMT/TOT_BAL_CNT);
				END;

				/*Check to see if the delinquency range is greater than 90 */
				IF (COALESCE(DAYS_PAYMENT_PAST_DUE_CNT,0) >= 91) THEN
					ACC_90PDLQ_LST_6M_CNT + 1;

		END;	
		ELSE IF (COUNT <  12)  THEN DO;

				/*Check to see if the delinquency range is greater than 90 */
				IF (COALESCE(DAYS_PAYMENT_PAST_DUE_CNT,0) >= 91) THEN
					ACC_90PDLQ_LST_12M_CNT + 1;

		END;	

	/*Increment the count and at the same time decrement the CURR_TIME to cater to the next
	lowest time period */
		IF LAST.TIME_SK THEN DO;
			COUNT = COUNT + 1;
			CURR_TIME = CURR_TIME - 1;
		END;

	/*If the end of the group is reached then output the data sets */
		IF LAST.ACCOUNT_RK THEN DO;	

			/*Assign the value of retained variables to the actual variable
			being written to the data set */
			CUSTOMER_RK = CUSTOMER_RK_RET;

			IF (COUNT <= 3) THEN DO;
			/*Is needed in case of premature exit, data is present only
			for 3 months */
				ACC_AVG_BAL_LST_6M_AMT = ACC_AVG_BAL_LST_3M_AMT;
				ACC_90PDLQ_LST_6M_CNT = ACC_90PDLQ_LST_3M_CNT;

				ACC_90PDLQ_LST_12M_CNT = ACC_90PDLQ_LST_6M_CNT;
			END;
			ELSE IF (COUNT <= 6) THEN DO;
			/*Is needed in case of premature exit, data is present only
			for 6 months */
				ACC_90PDLQ_LST_12M_CNT = ACC_90PDLQ_LST_6M_CNT;
			END;
			
		/*Output the data set */
			OUTPUT; 
		
		/*Reset all the retain variables for the next customer group */
			/* variable for last 3 months */
			ACC_AVG_BAL_LST_3M_AMT = .;
			ACC_90PDLQ_LST_3M_CNT = 0;

			/* variable for last 6 months*/
			ACC_AVG_BAL_LST_6M_AMT = .;
			ACC_90PDLQ_LST_6M_CNT = 0;

			/* variable for last 12 months*/
			ACC_90PDLQ_LST_12M_CNT = 0;

			/* Temporary retain variable*/
			SUM_TOT_BAL_AMT = .;
			TOT_BAL_CNT = .;

			CURR_TIME=OTE_CURR_TIME_SK;
			COUNT = 0;
		END;

	RUN;
%mend ote_acc_snap_lst_abt;
/*options nomprint mlogic;*/
/*%ote_acc_snap_lst_abt (PERIOD=6, INPUT_TABLE=OTE_ACC_SNAP_EXT_LST_6M_LKP);*/

