/******************************************************************************************************
       Module:  build_abt

     Function:  To build the selected modeling abt in the background 

      Authors:  BIS Team
         Date:  04 October 2006
          SAS:  9.1
    Called-by:	Stored process build_mdl_abt
        Calls:  1. The deployed job MasterLoopModelingABTJob.sas which will run all the required
        		ABT jobs in the correct orer.
        	2. Macro create_abt which will join the aggregate tables to create the ABT.

Datasets used:  1. analytic.Abt_x_var, analytic.Var_master, analytic.Table_x_job, 
			analytic.Job_x_level: These datasets are used to determine which jobs need 
			to be run and in what order
		2. control.parameter_list_mod_abt: Loaded with the list of required jobs
			in the order of running. This dataset is used by MasterLoopModelingABTJob.sas
		3. analytic.abt_status: It is constantly updated with the status of the 
			ABT building process
 
        Logic:  1. The selected variables to be built for the ABT are picked up from Abt_x_var.
        	2. The respective aggregate tables to be built for these variables are picked
        		up from Var_master.
        	3. The jobs to build the aggregate tables are picked up from Table_x_job
        	4. And the dependency of the jobs is picked up from Job_x_level
        	5. This list of jobs and its dependency is loaded into the table parameter_list_mod_abt
        	6. Then the deployed job MasterLoopModelingABTJob.sas is invoked. This job
        		then takes care of running all the jobs in the correct order. Hence the aggregate 
        		tables are created.
        	7. Once the agregate tables are created, the ABT has to be created. For this, the
        		macro create_abt is called. If the macro runs correctly, the ABT is built
        		in the library abt.
				
   Parameters:  Input:
   				abt_key : This is the key in the abt_x_var table that represents the selected ABT
   				obs_dt	: This is the date of data capture for building the ABT
   				phy_nm	: This is the physical name of the ABT as the user would like to see it.
   		
   				Output:
   				error_code : If the value is NONE, then it means that the ABT generation activity
   					has succeeded. If it is ERROR, it means that the activity has failed.

******************************************************************************************************/
options nomprint;
option SYMBOLGEN;

/* Global Input Parameters */
%global abt_key obs_dt phy_nm;

%let lib=analytic;

%select_abt_vars_screen_links;

%let error_code=NONE;

/*Proc printto will redirect the log to the directory
"Data/bisdata/log". */
%global log_name l_desc l_descfrabt;
data _NULL_;
name=put(time(),mmss8.1);
name1=kscan(name,1,":.");
name2=kscan(name,2,":.");
name3=kscan(name,3,":."); 
name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
call symput('log_name',"Data/bisdata/log/abt_build_"||ktrim(kleft(name4))||".log");
run;

%put NOTE: Sending log messages to :&log_name;

proc printto log="&log_name";
quit;

/* Code to fetch the product type using abt_master and abt_product */
%let prodkey=;
%let prodcode=;
proc sql;
select p_no into :prodkey from &lib..abt_master where a_no = &abt_key;
select CUSTPARA_NM into :prodcode from &lib..abt_product where p_no = &prodkey;
quit;
%let prodcode=&prodcode;
/* End of code to fetch product type */

/************** Build the required aggregate tables **************/
%macro abt_build;
	%if %sysfunc(exist(control.parameter_list_mod_abt)) %then %do;
		/* Backup the existing Parameter List table as _&abt_key._<date>_<time> and 
			create a new one for use */
		%global backup_table_name;
		%let backup_table_name=;
		data _NULL_;
			name=put(date(), date9.)||"_"||strip(tranwrd(put(time(), time6.), ":", "_"));
			call symput('backup_table_name', "_"||"param_mod_abt_"||ktrim(kleft(name)));
		run;

		data control.&backup_table_name.;
			set control.parameter_list_mod_abt;
			output control.&backup_table_name.;
		run;

		proc sql;
			drop table control.parameter_list_mod_abt;
		quit;
	%end;
	
	data control.parameter_list_mod_abt;
		length JOB_NM $40.;
		length LEVEL_NO 8.;
		length RETURN_CD 8.;
		stop;
	run;

	/* Insert the job names for the input variables in Parameter List table 
		CONTROL.PARAMETER_LIST_MOD_ABT
		Columns: JOB_NM, LEVEL_NO, RETURN_CD
	*/
	proc sql;
		create table work.abt_x_var as
		select * 
		from &lib..Abt_x_var
		where a_no=&abt_key and kupcase(is_selected_flg)='Y';

		/* Manual insertion of key variables which are required to build the ABT */
		insert into work.abt_x_var
		(A_NO, V_NO, IS_SELECTED_FLG) 
		values (&abt_key, 999996, 'Y')
		values (&abt_key, 999997, 'Y')
		values (&abt_key, 999998, 'Y');	
		/* End of manual insertion */

		create table work.job_levels as
		select distinct Table_x_job.job_nm, job_level_no as level_no, . as return_cd,
			child_jobs
		from work.abt_x_var inner join &lib..Var_master
		on (Abt_x_var.v_no = Var_master.v_no)
		inner join &lib..Table_x_job
		on (Var_master.agg_table_nm = Table_x_job.var_table_nm)
		inner join &lib..Job_x_level
		on (Table_x_job.job_nm = Job_x_level.job_nm)
		order by job_level_no;
	quit;

	%if &sqlrc > 4 %then %do;
		/* Insert status into the table */
		%trylock(member=&lib..abt_status, timeout=100000);
		proc sql;
			/*I18N-scnjih-20080430-1400*/		
			/*update &lib..abt_status set STATUS_DESC='Failed', */
			update &lib..abt_status set STATUS_DESC= "%sysfunc(sasmsg(smd_ds.bismsg,build_abt.sas.2, noquote))", 
			/*I18N-scnjih-20080430-1400*/
				CREATION_DT=today(), CREATED_BY="&_METAUSER" 
			where A_NO=&abt_key and OBS_DT=&obs_dt;
		quit;
		lock  &lib..abt_status clear;

		%return;
	%end;

	/* To remove extra jobs */
	%global child_jobs;

	proc sql;
		select distinct child_jobs into :child_jobs separated by ',' 
		from work.job_levels 
		where child_jobs NE '';
	quit;
	%if %str(&child_jobs) NE %str() %then %do;
	proc sql;
		delete from work.job_levels where job_nm in ("&child_jobs.");
	quit;
	%end;

	proc sql;
		alter table work.job_levels drop child_jobs;
	quit;

	%if &sqlrc > 4 %then %do;
		/* Insert status into the table */
		%trylock(member=&lib..abt_status, timeout=100000);
		proc sql;
			/*I18N-scnjih-20080430-1400*/		
			/*update &lib..abt_status set STATUS_DESC='Failed', */
			update &lib..abt_status set STATUS_DESC= "%sysfunc(sasmsg(smd_ds.bismsg,build_abt.sas.2, noquote))", 
			/*I18N-scnjih-20080430-1400*/
				CREATION_DT=today(), CREATED_BY="&_METAUSER" 
			where A_NO=&abt_key and OBS_DT=&obs_dt;
		quit;
		lock  &lib..abt_status clear;

		%return;
	%end;

	proc append data=work.job_levels base=control.parameter_list_mod_abt force;	
	quit;	

	/* Insert the job names for the outcome variable in Parameter List table 
		CONTROL.PARAMETER_LIST_MOD_ABT
		Columns: JOB_NM, LEVEL_NO, RETURN_CD
	*/

	proc sql;
		create table work.outcome_x_var as
		select * 
		from &lib..Abt_x_outcome
		where a_no=&abt_key;

		create table work.job_outcome as
		select distinct Table_x_job.job_nm, job_level_no as level_no, . as return_cd
		from work.outcome_x_var inner join &lib..Outcome_master
		on (outcome_x_var.o_no = outcome_master.o_no)
		inner join &lib..Table_x_job
		on (Outcome_master.agg_table_nm=Table_x_job.var_table_nm)
		inner join &lib..Job_x_level
		on (Table_x_job.job_nm = Job_x_level.job_nm)
		order by job_level_no;
	quit;

	%if &sqlrc > 4 %then %do;
		/* Insert status into the table */
		%trylock(member=&lib..abt_status, timeout=100000);
		proc sql;
			/*I18N-scnjih-20080430-1400*/		
			/*update &lib..abt_status set STATUS_DESC='Failed', */
			update &lib..abt_status set STATUS_DESC= "%sysfunc(sasmsg(smd_ds.bismsg,build_abt.sas.2, noquote))", 
			/*I18N-scnjih-20080430-1400*/
				CREATION_DT=today(), CREATED_BY="&_METAUSER" 
			where A_NO=&abt_key and OBS_DT=&obs_dt;
		quit;
		lock  &lib..abt_status clear;

		%return;
	%end;


	proc append data=work.job_outcome base=control.parameter_list_mod_abt force;
	quit;

	proc sort data=control.parameter_list_mod_abt;
	by JOB_NM LEVEL_NO;
	run;

	data control.parameter_list_mod_abt;
	set control.parameter_list_mod_abt;
	by JOB_NM LEVEL_NO;
	if first.job_nm then output;
	else;
	run;

	/* Set the data capture date in macro variable LOAD_ABT_USER_INPUT_DTTM
	1. Only global definition of LOAD_ABT_USER_INPUT_DTTM will be available in autoexec.
	2. Pass this macro thro the loop jobs to the final ETL jobs.
	3. When the autoexec for the ETL jobs run, the other variables dependent on 
		LOAD_ABT_USER_INPUT_DTTM will get set.
	4. Similarly for the variable ABT_CATEGORY. 
		If the level is account, then this variable has to be set according to the model_type
		&LGD_MODEL for LGD models
		&CCF_MODEL for CCF models 
		&PD_ONG_MODEL for PD or CI models.
	5. Similarly the value for OUTCOME_PERIOD is set from the table abt_master  
		where a_no = &abt_key and abt_master.l_no = abt_level.l_no
	*/
	%let model_type =;
	proc sql noprint;
		select level_desc,OUTCOME_PERIOD into :l_desc,:out_come_no
		from &lib..abt_master, &lib..abt_level
		where a_no=&abt_key and abt_master.l_no = abt_level.l_no;

		select (case when kupcase(ABT_PURPOSE_DESC) contains 'LGD' or
		kupcase(ABT_PURPOSE_DESC) contains 'LOSS GIVEN DEFAULT' then &LGD_MODEL.
		when kupcase(ABT_PURPOSE_DESC) contains 'CCF' or
		kupcase(ABT_PURPOSE_DESC) contains 'CREDIT CONVERSION FACTOR' then &CCF_MODEL.
		else &PD_ONG_MODEL. end )
		into :model_type from &lib..abt_purpose,
		&lib..abt_master where (abt_master.ap_no = abt_purpose.ap_no
		and a_no = &abt_key);
	quit;

	data _null_;
		ld_dt=&obs_dt;
		ld_dttm=dhms(ld_dt, 0,0,0);
		call symput('OUTCOME_PERIOD',&out_come_no);
		call symput('LOAD_ABT_USER_INPUT_DTTM', ld_dttm);
		if kupcase(ktrim(kleft("&l_desc"))) = "ACCOUNT" then mod_type="&model_type";
		else mod_type='';
		call symput('ABT_CATEGORY', mod_type); 
	run;
	
	data _null_;
		file _webout &webout_options;
			put '<html>';
			put '<body>';
			put '<form method="post" action="/SASStoredProcess/do" name="form1">';
			put '<input type="hidden" name="_program" VALUE="">';
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
			put "	form1._program.value=&TEMPLATE_LIST";
			put '	form1.submit();';
			put '//-->';
			put	'</script>';
			put '</body>';
			put '</form>';
			put '</html>';
	run;

	/* Call the MasterLoopJob to run the jobs to build the Modeling ABT */
	%include jobs(MasterLoopModelingABTJob.sas);

	/************** End of Build the required aggregate tables **************/

	proc printto log="&log_name";
	quit;

	/* In case of error while running the jobs set prev_status to 'FAILED' 
	and do not build ABT. For this check if all return codes are 0. */
	%let cnt=.;
	proc sql noprint;
		select count(*) into :cnt from CONTROL.PARAMETER_LIST_MOD_ABT
		where return_cd > 4 or return_cd = .;
	quit;
	%let cnt=%trim(%left(&cnt));

	%if %str(&cnt) ne %str(0) %then %do;
		%let error_code=ERROR;

		/* Insert status into the table */
		%trylock(member=&lib..abt_status, timeout=100000);
		proc sql;
			/*I18N-scnjih-20080430-1400*/		
			/*update &lib..abt_status set STATUS_DESC='Failed', */
			update &lib..abt_status set STATUS_DESC= "%sysfunc(sasmsg(smd_ds.bismsg,build_abt.sas.2, noquote))", 
			/*I18N-scnjih-20080430-1400*/
				CREATION_DT=today(), CREATED_BY="&_METAUSER" 
			where A_NO=&abt_key and OBS_DT=&obs_dt;
		quit;
		lock  &lib..abt_status clear;

		%return;
	%end;
	%else %do;
		/************** Create the ABT **************/
	
		/* trimming to remove extra spaces */
		%let phy_nm=&phy_nm;
		%let obs_dt=&obs_dt;		
		
		/* Physical name of the abt being built is the <table_name>_<as_of_date> */	
		%let phy_table_nm=abt.&phy_nm._&obs_dt.;

		%let l_descfrabt=;

		/* Get level of the abt */
		proc sql noprint;
			select kupcase(level_desc) into :l_descfrabt
			from &lib..abt_master inner join &lib..abt_level
			on(abt_master.l_no = abt_level.l_no)
			where abt_master.a_no=&abt_key;
		quit;

		%let l_descfrabt=&l_descfrabt;
	
		/* Call macro to create the abt */
		%create_abt(abt_type=MOD, abt_cat=&l_descfrabt, abt_phy_table=&phy_table_nm, abt_key=&abt_key);

		/************** End of Create the ABT **************/

		/* In case of error while running the jobs set prev_status to 'FAILED'. */
		/* Insert status into the table */
		%if &create_abt_error_cd. > 0 %then %do;
			%trylock(member=&lib..abt_status, timeout=100000);
			proc sql;
				/*I18N-scnjih-20080430-1400*/
				/*update &lib..abt_status set PHY_TABLE_NM="&phy_table_nm", STATUS_DESC='Failed', */
				update &lib..abt_status set PHY_TABLE_NM="&phy_table_nm", STATUS_DESC="%sysfunc(sasmsg(smd_ds.bismsg,build_abt.sas.2, noquote))", 
				/*I18N-scnjih-20080430-1400*/
					CREATION_DT=today(), CREATED_BY="&_METAUSER" 
				where A_NO=&abt_key and OBS_DT=&obs_dt;
			quit;
			lock  &lib..abt_status clear;
		%end;
		/* Filtering the abt based on product */
		%else %if "&l_descfrabt" eq "ACCOUNT" %then %do;
			data &phy_table_nm;
			set &phy_table_nm;
				where ACCOUNT_TYPE_CD=&&&prodcode;
			run;
		%end;
		%else %if "&l_descfrabt" eq "APPLICATION" %then %do;
			data &phy_table_nm;
			set &phy_table_nm;
				where ACC_PRD_TYP_CD=&&&prodcode;
			run;
		%end;			
		%if &create_abt_error_cd. = 0 %then %do;
			/* Insert status into the table */
			%trylock(member=&lib..abt_status, timeout=100000);
			proc sql;
				/*I18N-scnjih-20080430-1400*/
				/*update &lib..abt_status set PHY_TABLE_NM="&phy_table_nm", STATUS_DESC='Completed', */
				update &lib..abt_status set PHY_TABLE_NM="&phy_table_nm", STATUS_DESC="%sysfunc(sasmsg(smd_ds.bismsg,build_abt.sas.1, noquote))", 
				/*I18N-scnjih-20080430-1400*/
					CREATION_DT=today(), CREATED_BY="&_METAUSER" 
				where A_NO=&abt_key and OBS_DT=&obs_dt;
			quit;
			lock  &lib..abt_status clear;
		%end;
%end;
%mend abt_build;
%abt_build;

/*Proc printto will reset the log redirection */
proc printto;
quit; 

%put NOTE: Resetting log to _webout;
/*End of proc printto */
