/******************************************************************************************************
       Module:  model_monitoring

     Function:  To allow the user to view the over ime graph for the median lift value for a selected model

      Authors:  BIS Team
         Date:  
          SAS:  9.1
    Called-by:	main
        Calls:  NA

Datasets used:  The datasets being used in this screen are:
				1. dim.analytical_model_dim : Retrieves the registered models and its details from this dataset
				2. detail.model_lift_detail	: Retrieves the median lift value for the selected model from
					this dataset
 
        Logic:  This screen allows a user to select a model and then builds and shows the overtime graph
				for the median lift values for the selected model. It allows the user to determine the 
				health of the model.
				The various actions on the screen are:
        		N : New screen
        		C : View chart
				
   Parameters:  model_key	:	The key for the selected model
				action		:   Stores the action that has been selected on the screen.
									The actions can be:
									N : New screen
        							C : View chart

******************************************************************************************************/
options nomprint;

/* Global Input Parameters */
%global model_key action;

%let lib=analytic;

/* Setting output library based on the debug flag */
/* Setting default values for any required parameters */
data _null_;
	if "&action"="" then call symput('action','N');
	if "&model_key"="" then call symput('model_key','.');
run;
/**/

/* Action:
	N: None. 
	C: View Chart 
*/

/* Trimming extra spaces for all input paremeters */
%let model_key=&model_key;
%let action=&action;

/* Links specific for the Model Monitoring screen */
%select_abt_vars_screen_links;

%let out_lib=;
%debug_lib_path;

proc sql;
	/* Get Model details */
	create table &out_lib..model_det as
	select model_rk, model_nm, model_desc, target_period_mths_cnt, model_type_cd
	from dim.analytical_model_dim
	where deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT") and model_rk > 0 and
		valid_end_dttm=&valid_high_dttm
	order by model_rk;
quit;

/* Display screen with model details and lift chart except when action = N */
%macro display_screen;
	%if "&action" ne "N" %then %do;
		proc sql noprint;
			select model_desc, target_period_mths_cnt 
				into :model_desc, :tgt_period
			from &out_lib..model_det
			where model_rk=&model_key;
		quit;

		/* All graph options */
		    /* Setting the graph name */
		    /* Calling graph_options macro */
		data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":.");
		name7="ot"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('otn',name7);
		run;

		%let otname=&otn;		

		/* The graph_options macro sets all the graph options and selects the colors to be used when
			rendering the graph. To access the colors being set in this macro, the respective macro
			variables for the color (color_symbol1, color_symbol2, color_symbol3) is created.
			This macro only sets the values in the macro variables.

			This macro sets the out path of the gifs to the folder created in the environment which
			will be shared between the server layer and web layer. This is picked up from the macro
			variable CS_REPORT_PATH in the bis_customize_para.sas. */
		%let color_symbol1=;
		%graph_options;

		/* Get the bound red and bound green depending on the model type for the 
		selected model */
		%let bound_red=.;
		%let bound_green=.;
		data _null_;
			set &out_lib..model_det(where=(model_rk=&model_key));
			if model_type_cd=&PD_APP_MODEL then do;
				call symput('bound_red', "&BOUND_RED_LIFT_PDA");
				call symput('bound_green', "&BOUND_GREEN_LIFT_PDA");
			end;
			else if model_type_cd=&PD_ONG_MODEL then do;
				call symput('bound_red', "&BOUND_RED_LIFT_PDO");
				call symput('bound_green', "&BOUND_GREEN_LIFT_PDO");
			end;
			else if model_type_cd=&LGD_MODEL then do;
				call symput('bound_red', "&BOUND_RED_LIFT_LGD");
				call symput('bound_green', "&BOUND_GREEN_LIFT_LGD");
			end;
			else if model_type_cd=&CCF_MODEL then do;
				call symput('bound_red', "&BOUND_RED_LIFT_CCF");
				call symput('bound_green', "&BOUND_GREEN_LIFT_CCF");
			end;
			else if model_type_cd=&SEG_MODEL then do;
				call symput('bound_red', "&BOUND_RED_LIFT_SEG");
				call symput('bound_green', "&BOUND_GREEN_LIFT_SEG");
			end;
		run;
		%put &bound_red &bound_green;

		%let rec_cnt=.;
		/* Creating the table with columns as required for the macro statistic overtime */
		proc sql noprint;
			create table &out_lib..lift_ot as
			select model_rk as model_sk, . as SCORE_TIME_SK, 
				SCORE_MONTH_LAST_DT as CAL_MON_LAST_DT, 'Lift Value' as MEASURE_NM, 
				MEDIAN_LIFT_VALUE as MEASURE_VALUE, &bound_green as BOUND_GREEN, 
				&bound_red as BOUND_RED, 'N' as DEV_FLG
			from detail.MODEL_LIFT_DETAIL
			where model_rk=&model_key;

			select count(*) into :rec_cnt from &out_lib..lift_ot;
		quit;

		%if &rec_cnt > 0 %then %do;
			/* Creation of all graphs and call to overtime macro */
			/*******Macro statistic_overtime parameter passed
			      	1.Dataset this dataset will be ouput dataset of Macro feed_measure
				  	2.statistic (For Eg. D Statistic etc.)
					3.graph name (generated from timestamp)
			******/
			%statistic_overtime(&out_lib..lift_ot,Lift Value,&otname);
		%end;

		data _null_;
/*I18N-scnhuh-20080418-1137*/
/*add &webout_options*/
			file _webout&webout_options;
/*I18N-scnhuh-20080418-1137*/
			put '			<tr>';
			put '				<td>';
			put '					<table border="0" width="100%" cellpadding="3" cellspacing="0">';
			put '						<tr>';
			put '							<td class="LabelFont" width="20%">' @ ;
/*			put 'Model Description:' @ ;*/
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.moddesc.1, noquote))"@;	
			put ':'@;
			put '</td>';
			put '							<td class="LabelFont">'@;
			put "&model_desc"@;
			put '</td>';
			put '						</tr>';
			put '						<tr>';
			put '							<td class="LabelFont">' @ ;
/*			put 'Outcome Period(Months):' @ ;*/
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modmon_outcome_period.1, noquote))"@;	
			put ':'@;
			put '</td>';
			put '							<td class="LabelFont">'@;
			put "&tgt_period"@;
			put '</td>';
			put '						</tr>';
			put '					</table>';
			put '				</td>';
			put '			</tr>';
			put '			<tr><td>&nbsp;</td></tr>';
			put '			<tr>';

			put '				<td><table width="60%"  border="0" cellspacing="0" cellpadding="0">';
			put '					<tr>';
			put '						<td valign="top"><fieldset>';
			put '							<legend><span class="LabelFont">' @ ;
/*			put 'Lift Value Over Time :' @ ;*/
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modmon_liftvalot.1, noquote))"@;	
			put ':'@;
			put '</span></legend>';
		%if &rec_cnt > 0 %then %do;
			put '							<p><img src="/SASABTFramework/'@;
			put "&otname"@;
			put '.gif" width="460" height="200"></p>';
		%end;
		%else %do;
			put '							<p class="LabelFont">' @ ;
/*			put 'Data not available' @ ;*/
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modmon_datanotavlbl.1, noquote))"@;	
			put '</p>';
		%end;
			put '							</fieldset>';
			put '						</td>';
			put '					</tr>';
			put '				</table></td>';
			put '			</tr>';

		run;
	%end;
%mend display_screen;

/* Start HTML Screen */
data _NULL_;
/*I18N-scnhuh-20080418-1137*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1137*/
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html>';
	put '<head>';
	put '<link href="/SASABTFramework/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css">';
	put '<!--';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';

	put '<script>';
	put '<!-- ';

	/* When a model is selected, set the required values */
	put 'function setModel(){';
	put '	index = document.form1.modelname.selectedIndex;';
	put '	if (index==0) {';
	put '		form1.model_key.value = ''''';
	put '	}';
	put '	else {';
	put '		form1.model_key.value = document.form1.modelname.options[index].value;';
	put '		form1.action.value = "C";';
	put "		form1._program.value=&MONITOR_MODEL";
	put '		form1.submit()';
	put '	}';
	put '}';


	put '//--> ';
	put '</script>';
	put '</head> ';

	put '<body bgcolor="#FAF8ED">';
	put '<form name="form1" action="/SASStoredProcess/do" method="post">';
	put '<input type="hidden" name="_program" value="">';

/* Hidden textboxes for capturing user entered or selected value */
	model_key=symget("model_key");
	x='<input type="hidden" name="model_key" value="'||strip(model_key)||'">';
	put x;
	put '<input type="hidden" name="action" value="">';
run;

data _null_;
/*I18N-scnhuh-20080418-1137*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1137*/
	put '<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
	put '	<tr> ';
	put '		<td align="left"> ';
	put '		<table width="100%" border="0" align="left" cellpadding="0" cellspacing="0"> ';
	put '			<tr> ';
	put '				<td><table width="100%" border="0" cellspacing="0" cellpadding="0"> ';
	put '					<tr> ';

	/* Navigational Links */
	put '						<td><span class="BreadCrumb">&nbsp;</td>';
	put '						<td align="right"><img src="/SASABTFramework/images/Banner.gif" width="259" height="29"></td> ';
	put '					</tr>';
	put '				</table>';                                     /****Banner insert image********/
	/**/

	/* Main Body */
	put '				<H2 align="left"><table width="100%" border="0" cellspacing="0" cellpadding="0">';
	put '					<tr><td>' @ ;
/*	put 'Model Monitoring - Lift Value' @ ;*/
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modmon_monliftval.1, noquote))"@;
	put '</td>';	
	put '				</tr></table></H2>';
	
	put '	   		<tr><td>&nbsp;</td></tr>';
	put '      		<tr>';
	put '        		<td><table width="100%" border="0" cellpadding="3" cellspacing="0">';
	put '					<tr>';
	put '						<td class="LabelFont" width="20%">' @ ;
/*	put 'Model Name' @ ;*/
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modname.1, noquote))"@;	
	put ':' @ ;
	put ' </td>';
	put '						<td class="LabelFont">';
	put '							<p class="LabelFont">';
	put '							<select name="modelname" style="width: 90mm" onChange="javascript:setModel()">';
	put '								<option>' @ ;
/*	put 'Select Model' @ ;*/
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modmon_selmodel.1, noquote))"@;	
	put '</option>';
run;

data _null_;
/*I18N-scnhuh-20080418-1137*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1137*/
	set &out_lib..model_det;
	put '								<option value="'@;
	put model_rk@;
	put '" '@;
	if model_rk=&model_key then put 'selected'@;
	put '>'@;
	put model_nm@;
	put '</option>';
run;

data _null_;
/*I18N-scnhuh-20080418-1137*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1137*/
	put '							</select>';
	put '							</p>';
	put '						</td>';
	put '					</tr>';
	put '				</table>';
	put '				</td>';
	put '			</tr>';
run;

%display_screen;

data _null_;
/*I18N-scnhuh-20080418-1137*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1137*/
	put '</table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;
