/******************************************************************************************************
       Module:  schedule_scr_process

     Function:  This screen allows the user to save a schedule for the running the scoring process for
				a model.

      Authors:  BIS Team
         Date:  
          SAS:  9.1
    Called-by:	main
        Calls:  NA

Datasets used:  The datasets being used in this screen are:
				1. dim.analytical_model_dim : Retrieves the registered models and its details from this dataset
				2. analytic.scr_mdl_schedule : Retrieves the schedule of the models for which a schedule has
					defined and saves new schedules in this dataset
 
        Logic:  This screen allows the user to save a schedule for the running the scoring process for
				a model. The users provide a start date which is the date from which the schedule should 
				begin and the frequency which is the frequency of running the schedule. For example, 
				Monthly, Quarterly, Half Yearly, Yearly.

				The screen shows the above information along with the details of the previous run of the 
				schdeule and the next date of run. The previous run schdule includes previous run date and
				the status of the previous run. For example, Completed, Failed.

				The various actions on the screen are:
        		N : New screen
        		A : Add schedule
        		E : Edit schedule
				U :	Update schedule
				
   Parameters:  model_key	:	The key for the selected model
				model_nm	:	Name of the model
				abt_key		:	The key for the scoring ABT mapped to the selected model
				abt_nm		:	Name of the scoring ABT
				freq		:	Frequency of schedule. For example, Monthly, Quarterly, Half Yearly, Yearly
				year		:	Year of run
				month		:	Month of run
				month_dt	:	Date of run
				action		:	Stores the action that has been selected on the screen.
									The actions can be:
									N : New screen
        							A : Add schedule
        							E : Edit schedule
									U :	Update schedule

******************************************************************************************************/

options nomprint;

/* Global Input Parameters */
%global model_key model_nm abt_key abt_nm freq year month month_dt action;

/* 	Action:
		N: None
		A: Add
		E: Edit
		U: Update
*/

%let lib=analytic;

/* Setting default values for any required parameters */
data _null_;
	if "&action"="" then call symput('action','N');
run;

/* Trimming extra spaces for all input paremeters */
%let action=&action;
%let model_key=&model_key;
%let model_nm=&model_nm;
%let abt_key=&abt_key;
%let abt_nm=&abt_nm;
%let freq=&freq;
%let year=&year;
%let month=&month;
%let month_dt=&month_dt;

/* Links specific for the scheduling selection screens */
%select_abt_vars_screen_links;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

/* Data for Schedule information */
proc sql;
	create table &out_lib..scr_schedule as
	select analytical_model_dim.model_sk, model_nm, start_dt, frequency_cd, 
		prev_run_dt, prev_run_status, next_run_dt
	from dim.analytical_model_dim left join &lib..scr_mdl_schedule
	on(analytical_model_dim.model_sk = scr_mdl_schedule.model_sk)
	where deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT") and 
		analytical_model_dim.model_sk > 0
	order by model_sk;
quit;

/* Data for Frequency */
data &out_lib..frequency;
/*I18N-scnhuh-20080429-1532*/
/*change from $15 to $25*/
	length frequency $25.;
/*I18N-scnhuh-20080429-1532*/
	/*I18N-scnjih-20080421-1338*/
/*	frequency = "Monthly";*/
/*	output;*/
/*	frequency = "Quarterly";*/
/*	output;*/
/*	frequency = "Half Yearly";*/
/*	output;*/
/*	frequency = "Yearly";*/
/*	output;*/
/*	frequency = "Run Once";*/
	frequency =  "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.3, noquote))";
	output;
	frequency = "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.4, noquote))";
	output;
	frequency = "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.5, noquote))";
	output;
	frequency = "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.6, noquote))";
	output;
	frequency = "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.7, noquote))";
	/*I18N-scnjih-20080421-1338*/
	output;
run;

proc sql;
	create table &out_lib..year as
	select distinct cal_year_no as year
	from dim.time_dim;
quit;

/* Date for Month for Data Capture*/
data &out_lib..month;
	length month $10.;
	do month_no=1 to 12;
		month=put(month_no, $MTHFMT.);
		output;
	end;
run;

/* Date for Data for Data Capture*/
data &out_lib..dt;
	dt=1;
	do while(dt <= 31);
		output;
		dt+1;
	end;
run;

%macro edit_update_config;
	%if %str(&action) = %str(N) %then %do;
		/* No Action */
		data _null_;
			file _webout &webout_options;
			put '		   <tr> ';
			put '			<td height="32" bgcolor="#F1EACB">&nbsp; ';
			put '            <input type="button" name="Submit5" value="' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.editbttn.1, noquote))" @;
			put '" class="mmhide_btn" onClick="javascript:editAction()" />';
			put '			</td> ';
			put '		   </tr> ';
		run;
	%end;
	%else %if %str(&action) = %str(E) %then %do;
		/* Action = Edit */
		proc sql;
			create table &out_lib..edit_mdl as
			select analytical_model_dim.model_sk, model_nm
			from dim.analytical_model_dim
			where deployment_status_cd not in ("&EXP_MODEL_DEPLOYMENT") and
				analytical_model_dim.model_sk = &model_key;
		quit;

		data _null_;
			set &lib..scr_mdl_schedule(where=(model_sk = &model_key));
			year=year(start_dt);
			month_nm=put(month(start_dt), $MTHFMT.);
			dt=day(start_dt);
			call symput('freq', frequency_cd);
			call symput('year', year);
			call symput('month', month_nm);
			call symput('month_dt', dt);
		run;

		data _null_;
			file _webout &webout_options;
			set &out_lib..edit_mdl;
			put '	   	   <tr>';
			put '            <td align="left"><H2 align="left">' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_editschinfo.1, noquote))" @;
			put '</H2></td>';
			put '          </tr> ';
			put '          <tr><td>&nbsp</td></tr> ';
			put '          <tr>';
			put '            <td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0" class="tableview">';
			put '              <tr>';
			 /*I18N-scnjih-20080421-1338*/
/*			put '                <td class="LabelFont" width="20%">Model Name: </td><td class="LabelFont">'; */
			put '                <td class="LabelFont" width="20%">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.2, noquote))"@;
			put '</td><td class="LabelFont">'; 
		 	/*I18N-scnjih-20080421-1338*/
			put model_nm;
			put '</td>';
			put '              </tr> ';
			put '              <tr>';
			put '                <td class="LabelFont">' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_frequency.1, noquote))" @;
			put ':';
			put '</td>'; 
			put '                <td><select name="freq">';
			put '                  <option value="">' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_selfreq.1, noquote))" @;			
			put '</option>';                
		run;

		data _null_;
			file _webout &webout_options;
			set &out_lib..frequency;
			put '                  <option value="'@;
			put frequency@;
			put '"'@;               
			if frequency = "&freq" then put ' selected';
			put '>'@; 
			put frequency@;
			put '</option>';
		run;

		data _null_;
			file _webout &webout_options;
			put '                </select>';
			put '                </td>';
			put '              </tr> ';
			put '              <tr>';
			put '                <td class="LabelFont">' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_startdate.1, noquote))" @;
			put ':';
			put ' </td>'; 
			put '                <td><select name="year">';
			put '                  <option value="">' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.year.1, noquote))" @;
			put '</option>';                
		run;

		data _null_;
			file _webout &webout_options;
			set &out_lib..year;
			put '                  <option value="'@;
			put year@;
			put '"'@;               
			if year = "&year" then put ' selected';
			put '>'@; 
			put year@;
			put '</option>';
		run;

		data _null_;
			file _webout &webout_options;
			put '                </select>';
			put '                <select name="month">';
			put '                  <option value="">' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.month.1, noquote))" @;
			put '</option>';                
		run;

		data _null_;
			file _webout &webout_options;
			set &out_lib..month;
			put '                  <option value="'@;
			put month_no@;
			put '"'@;               
			if month = "&month" then put ' selected';
			put '>'@;                
			put month@;
			put '</option>';
		run;

		data _null_;
			file _webout &webout_options;
			put '                </select>';
			put '                <select name="month_dt">';
			put '                  <option value="">' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.date.1, noquote))" @;
			put '</option>';                
		run;

		data _null_;
			file _webout &webout_options;
			set &out_lib..dt;
			put '                  <option value="'@;
			put dt@;
			put '"'@;               
			if dt = "&month_dt" then put ' selected';
			put '>'@;                
			put dt@;
			put '</option>';
		run;

		data _null_;
			file _webout &webout_options;
			put '                </select>';
			put '                </td>';
			put '              </tr> ';
			put '            </table>';
			put '          </td>';
			put '        </tr>';
			put '        <tr><td>&nbsp</td></tr> ';
			put '        <tr bgcolor="#FAF8ED">';
			put '          <td bgcolor="#F1EACB">&nbsp;&nbsp;';
			put '            <INPUT type=button class=mmhide_btn onClick="javascript:updateAction()" value="' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.updatebttn.1, noquote))" @;
			put '">';
			put '            <INPUT type=button class=mmhide_btn onClick="javascript:noAction()" value="' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.cancelbttn.1, noquote))" @;
			put '">';
			put '          </td>';
			put '        </tr>';
		run;
	%end;
	%else %if %str(&action) = %str(U) %then %do;
		/* Action = Update */
		%let error_code=NONE;

		/*Proc printto will redirect the log to the directory
		"Data/bisdata/error". */
		%global log_name;
		data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":."); 
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/log/abt_schedule."||ktrim(kleft(name4))||".log");
		run;

		%put NOTE: Sending log messages to :&log_name;

		proc printto log="&log_name";
		quit;

		%let start_dt=%sysfunc(mdy(&month,&month_dt,&year));

		proc sql noprint;
			select count(*) into :no_records
			from &lib..scr_mdl_schedule
			where model_sk = &model_key;

			%let no_records = %trim(%left(&no_records));

			%if %str(&no_records) > 0 %then %do;
				update &lib..scr_mdl_schedule set
					frequency_cd="&freq", start_dt=&start_dt, next_run_dt=&start_dt 
				where model_sk = &model_key;
			%end;
			%else %do;
				insert into &lib..scr_mdl_schedule(MODEL_SK, START_DT, FREQUENCY_CD, 
					PREV_RUN_DT, PREV_RUN_STATUS, NEXT_RUN_DT)
				values(&model_key, &start_dt, "&freq", ., "", &start_dt);
			%end;
		quit;

		/*Proc printto will reset the log redirection */
		proc printto;
		quit; 

		%put NOTE: Resetting log to _webout;
		/*End of proc printto */

		/* Show the relevant messages on the screen */
		data _null_;
			file _webout &webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
		%if %str(&error_code) eq %str(ERROR) %then %do;
			put '	alert("' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_alert1.1, noquote))"@;
			put "&log_name"@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.alert_frfurtherdtls.1, noquote))"@;
			put '")';
		%end;
		%else %do;
			put '	alert("' @ ;
			put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_alert2.1, noquote))"@;
			put '")';
			put '	noAction();';
		%end;
			put '//-->';
			put	'</script> ';
		run;
	%end;
%mend edit_update_config;

data _null_;
	file _webout &webout_options;
	put '<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">';
	put '<html xmlns="http://www.w3.org/1999/xhtml"><!-- InstanceBegin template="/Templates/dashboard.dwt" codeOutsideHTMLIsLocked="false" -->';
	put '  <head>';
	put '    <meta http-equiv="content-type" content="text/html;charset=utf-8" />';
	 /*I18N-scnjih-20080429-1538*/
	/*put '    <!-- InstanceBeginEditable name="doctitle" --><title>Layout</title><!-- InstanceEndEditable -->';*/
		put '    <!-- InstanceBeginEditable name="doctitle" --><title>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,title_of_layout.1, noquote))"@;
		put '</title><!-- InstanceEndEditable -->';
	
	 /*I18N-scnjih-20080429-1538*/
	put '    <link rel="stylesheet" type="text/css" href="/SASABTFramework/styles/default.css" />';

	/* External scripts */
	put '    <script src="/SASABTFramework/javascript/scripts.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/buttonMenu.js" type="text/javascript"></script>';
	put '    <script src="/SASABTFramework/javascript/overlib.js" type="text/javascript"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/table_controls.js"></script>';
	put '    <script type="text/javascript" src="/SASABTFramework/javascript/boxOver.js"></script>';
	put '    <script type="text/javascript">';
	put '    <!--';

	put 'function setMdl(mdl_val) {';
		if "&action" = "N" then do;
		put '	form1.model_key.value=mdl_val';
		end;
		else do;
	 /*I18N-scnjih-20080429-1019*/
		/*put '	alert("Click on Update or Cancel before selecting another model")';*/
		put '	alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.8, noquote))"@;
		put '")';
		/*I18N-scnjih-20080429-1019*/
		put '	for (var i=0; i < form1.sel_model.length; i++){';
		put "		if(form1.sel_model[i].value==&model_key)";
		put '			form1.sel_model[i].checked=true';
		put '	}';
		end;
	put '}';

	put 'function editAction() {';
	put '	if((form1.model_key.value == '''') || (form1.model_key.value == '' '')){';
	put '		alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_alert3.1, noquote))"@;
	put '")';
	put '	}';
	put '	else {';
	put '		form1.action.value="E"';
	put "		form1._program.value=&SCHEDULE_SCR";
	put '		form1.submit();';
	put '	}';
	put '}';

	put 'function noAction() {';
	put '	form1.action.value="N"';
	put "	form1._program.value=&SCHEDULE_SCR";
	put '	form1.submit();';
	put '}';

	put 'function updateAction() {';
	put '	if((form1.freq.value=='''') || (form1.freq.value=='' '') || '@;
	put '(form1.year.value=='''') || (form1.year.value=='' '') || '@;
	put '(form1.month.value=='''') || (form1.month.value=='' '') || '@;
	put '(form1.month_dt.value=='''') || (form1.month_dt.value=='' '') )';
	put '		alert("' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_alert4.1, noquote))"@;
	put '")';
	put '	else {';
	put '		form1.action.value="U"';
	put "		form1._program.value=&SCHEDULE_SCR";
	put '		form1.submit();';
	put '	}';
	put '}';	

	put '//-->';
	put	'</script> ';

	put '</head> ';

	put '<body> ';
	put '  <body>';
	put '    <div id="overDiv" style="position:absolute; visibility:hidden; z-index:1000;"></div>';
	put '    <div id="banback">';

	/* Banner code */
	put '      <table id="bantabs" border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '        <tr valign="top">';
	put '          <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tablab'><a href='http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?_program=SBIP://Foundation/BIS/analytics/explore_abt/explore_abtvars'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_home.1, noquote))"@;
	put '</a></td>';
	put '          <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '          <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tablab'><a href='http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?_program=SBIP://Foundation/BIS/analytics/templates/templates'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_modeling.1, noquote))"@;
	put '</a></td>';
	put '	       <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '	       <td class="mmhide_tablft"><img src="/SASABTFramework/images/tab_upper_left.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tablab'><a href='http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?_program=SBIP://Foundation/BIS/analytics/scoring/scrabts'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scoring.1, noquote))"@;
	put '</a></td>';
	put '	       <td class="mmhide_tabrgt"><img src="/SASABTFramework/images/tab_upper_right.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '	       <td class="mmhide_tabsellft"><img src="/SASABTFramework/images/tab_upper_left_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put "          <td class='mmhide_tabsellab'><a href='#'>" @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tabs_scheduling.1, noquote))"@;
	put '</a></td>';
	put '	       <td class="mmhide_tabselrgt"><img src="/SASABTFramework/images/tab_upper_right_select.gif" border="0" width="5" height="5" hspace="0" vspace="0" alt="" /></td>';
	put '          <td width="100%">&nbsp;</td>';
	put '        </tr>';
	put '      </table>';
	put '    </div>';
	put '    <table border="0" cellpadding="0" cellspacing="0" width="100%">';
	put '      <tr>';
	put '        <td id="butbar">';
	put '          <span id="butfill">&nbsp;</span>';
	put '        </td>';
	put '        <td id="butbar" align="right">';
	put '          <a href="#"  onClick="javascript:window.print();" >';
	put '          <img src="/SASABTFramework/images/Print.gif" alt="Print" border="0">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.printer_icon.1, noquote))"@;
	put ' </a>&nbsp;';
	put '        </td>';
	put '      </tr>';
	put '    </table>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';
	put '<input type="hidden" name="_program" value="">';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	model_key=symget("model_key");
	x='<input type="hidden" name="model_key" value="'||strip(model_key)||'">';
	put x;
	st_dt=symget("st_dt");
	x='<input type="hidden" name="st_dt" value="'||strip(st_dt)||'">';
	put x;
	put '<input type="hidden" name="action" value="">';
	
	put '<table width="100%" class="tableview"><tr><td></td><td>';
	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
run;

%edit_update_config;

data _null_;
file _webout &webout_options;

	/* Main Body */
	put '      <tr>';
	 /*I18N-scnjih-20080421-1338*/
/*	put '        <td><h2 align="left">Schedule the Scoring Process </h2></td>';*/
	put '        <td><h2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,schedule_scr_process.sas.1, noquote))"@;
	put '</h2></td>';
		 /*I18N-scnjih-20080421-1338*/
	put '      </tr>';

	put '	   <tr><td>&nbsp;</td></tr>';
	put '      <tr>';
	put '        <table width="100%" border="0" cellpadding="0" cellspacing="0" class="tableview"> ';
	put '          <tr> ';
	put '            <td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0"> ';
	put '              <tr bgcolor="#FFFFFF"> ';
	put '                <th class="tabletextcol"><div align="center">&nbsp</div></th> ';
	put '                <th class="tabletextcol">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.modname.1, noquote))"@;
	put '</th> ';
	put '                <th class="tabletextcol">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_frequency.1, noquote))"@;
	put '</th> ';
	put '                <th class="tabletextcol">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_startdate.1, noquote))"@;
	put '</th> ';
	put '                <th class="tabletextcol">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_prevrun.1, noquote))"@;
	put '</th> ';
	put '                <th class="tabletextcol">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_prevrunstatus.1, noquote))"@;
	put '</th> ';
	put '                <th class="tabletextcol">' @ ;
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.sch_scr_proc_nextrun.1, noquote))"@;
	put '</th> ';
	put '              </tr> ';
run;

data _null_;
	file _webout &webout_options;
	set &out_lib..scr_schedule;
	if  mod(_N_,2)=0 then
		put '                <tr class="tableevenrow">';
	else 
		put '                <tr class="tableoddrow">';

    put '              <td width="15" class="LabelFont"><div align="center">';
    put '                <input type="radio" name="sel_model" value="';
	put model_sk@;
	put '" OnClick="javascript:setMdl(this.value)"'@;
	if model_sk eq "&model_key" then put 'checked=checked '@;
    put '              </div></td>';
  	put '                  <td class="tabletextcol">'@;
	put model_nm@; 
	put '</td>';
  	put '                  <td class="tabletextcol">'@;
	put frequency_cd@; 
	put '</td>';
  	put '                  <td class="tabletextcol">'@;
	put start_dt@; 
	put '</td>';
  	put '                  <td class="tabletextcol">'@;
	put prev_run_dt@; 
	put '</td>';
  	put '                  <td class="tabletextcol">'@;
	put prev_run_status@; 
	put '</td>';
  	put '                  <td class="tabletextcol">'@;
	put next_run_dt@; 
	put '</td>';
	put '                </tr>';
run;

data _NULL_;
	file _webout &webout_options;
	put '            </table></td>';
	put '          </tr>';
	put '        </table>';
run;

data _null_;
	file _webout &webout_options;
	put '</table>';
	put '</td> ';
	put '</tr> ';
	put '</table> ';
	put '</td></tr></table>';
	put '  <div id="foot">';
	put "%sysfunc(sasmsg(smd_ds.bismsg,abt.copyright_notice.1, noquote))"@;
	put '  </div>';
	put '</body> ';
	put '</html> ';
run;
