/******************************************************************************************************
       Module:  template_step5

     Function:  This is the fifth step of the ABT template creation wizard. It stores the template data in the database.

      Authors:  BIS Team
         Date:  July 2007
          SAS:  9.1

Datasets used:  The datasets being used in this screen are:
				1. analytic.Abt_master
				2. analytic.Abt_x_var
				3. analytic.Abt_x_outcome
				4. analytic.Var_master
				5. alalytic.Abt_level

******************************************************************************************************/

/* Global input variables */
%global prev_step;

/* Alias for the back-end library */
%let lib=analytic;

/* Loading macro aliases for the rest of the stored processes */
%select_abt_vars_screen_links;

/* Setting output library based on debug flag. */
%let out_lib=;
%debug_lib_path;

/* Start the session. */
%let rc=%sysfunc(stpsrv_session(create));

/* This macro saves the ABT information */
%macro save_abt_info;
	/* Start a new log */
	%global log_name;
	data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":."); 
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/log/abt_master."||ktrim(kleft(name4))||".log");
	run;

	%put NOTE: Sending log messages to :&log_name;

	proc printto log="&log_name";
	quit;
	
	/* Create the dataset containing input variables to be added, HERE. */
	
	/* First, create the appropriate master list for this ABT. */
	proc sql noprint;
		select l_no into :cust_lvl 
		from &lib..abt_level
		where level_desc like '%Customer%';

		create table &out_lib..var_cat as
		select distinct Var_master.var_category, strip(var_sub_category) as var_sub_category, 
			strip(var_group) as var_group, v_no, strip(var_short_nm) as var_short_nm, 
			strip(var_desc) as var_desc
		from &lib..Var_master
		where l_no = &save_level_key or l_no = &cust_lvl
		order by var_category, var_sub_category, var_group;
	quit;

	/* Sort it. */
	proc sort data=&out_lib..var_cat out=&out_lib..var_cat;
		by v_no;
	quit;
	
	/* Initialize condition variables. */
	%let name_exists = ;
	%let inactname_exists = ;

	/* Check whether the name is new or taken. */
	proc sql noprint;
		select count(*) into :name_exists
		from &lib..abt_master
		where kupcase(abt_nm)=kupcase("&save_abt_name") and is_deleted is missing;
	quit;
	%let name_exists=&name_exists;

	/* Check whether the name matches a data set name which is inactive. */
	proc sql noprint;
		select count(*) into :inactname_exists
		from &lib..abt_master
		where kupcase(abt_nm)=kupcase("&save_abt_name") and is_deleted = 'Y';
	quit;
	%let inactname_exists=&inactname_exists;
		
	/*  If the name is new, create a new key and save */
	%if (%str(&name_exists) eq %str(0) and %str(&inactname_exists) eq %str(0) ) %then %do;
		proc sql;
			/* Generate a new key. */
			select max(a_no) into :max_abt_no
			from &lib..abt_master;
		quit;
			%let max_abt_no=%trim(%left(&max_abt_no));
			%if %str(&max_abt_no) eq %str(.) %then %let new_abt_key=1;
			%else %let new_abt_key=%eval(&max_abt_no+1);
			%let save_abt_key = &new_abt_key;

		proc sql;
			/* Insert a record into the master ABT dataset. */
			insert into &lib..abt_master
			(A_NO, ABT_NM, ABT_DESC, ABT_TABLE_NM, OUTCOME_PERIOD, AP_NO, 
			P_NO, L_NO) 
			VALUES(&save_abt_key, "&save_abt_name", "&save_abt_desc", "&save_abt_table_name", 
			&save_outcome_period, &save_purpose_key, &save_prod_key, &save_level_key);

			/* Also add a record for the outcome variable. */
			insert into &lib..abt_x_outcome
			(A_NO, O_NO) 
			VALUES(&save_abt_key, &save_out_key);
		quit;

		/* Add the new records to the abt_x_var dataset. */
		/* First, generate the list of records to be added to the dataset. */
		data &out_lib..var_selection(keep=a_no v_no is_selected_flg);
			length a_no 8.;
			length v_no 8.;
			length is_selected_flg $1.;
			retain cnt 1;
			set &out_lib..var_cat(keep=v_no);
			a_no = &new_abt_key;
			if indexw("&save_var_keys", v_no)>0 then is_selected_flg = "Y";
			else is_selected_flg = "N";
		run;
		
		/* Append the records. */
		proc append data=&out_lib..var_selection base=&lib..abt_x_var force;
		quit;
		
		/* Create a message for the user. */
		 /*I18N-scnjih-20080421-1403*/
/*		%let message = New template succesfully created.;*/
		%let message = %sysfunc(sasmsg(smd_ds.bismsg,template_step5.sas.1, noquote));
		 /*I18N-scnjih-20080421-1403*/

		/* Kill the session and set the variables to take you back to the master template list. */
		%let rc=%sysfunc(stpsrv_session(delete));
		%let program = &template_list;
		%let action = "'/SASStoredProcess/do'";
	%end;

	/* If the name is taken, the key exists, and they belong to the same template, update the records. */
	%else %if (%str(&name_exists) ne %str(0) and %str(&inactname_exists) eq %str(0)) %then %do;
		/* Update the record in the master ABT dataset. */
		proc sql;
			update &lib..abt_master set
				abt_desc="&save_abt_desc", outcome_period=&save_outcome_period
			where a_no=&save_abt_key;

			/* Also update the outcome variable. */
			update &lib..abt_x_outcome set
				O_NO = &save_out_key
			where a_no=&save_abt_key;
		quit;

		/* Merge the records in the abt_x_var dataset. */
		/* First, generate the list of records to be merged. */
		data &out_lib..var_selection(keep=a_no v_no is_selected_flg);
			length a_no 8.;
			length v_no 8.;
			length is_selected_flg $1.;
			retain cnt 1;
			set &out_lib..var_cat(keep=v_no);
			a_no = &save_abt_key;
			if indexw("&save_var_keys", v_no)>0 then is_selected_flg = "Y";
			else is_selected_flg = "N";
		run;

		/* Then do this stuff to achieve the merge. */
		proc sort data=&lib..abt_x_var out=work.abt_x_var_srt;
			by a_no v_no;
		quit;

		proc sort data=&out_lib..var_selection out=work.var_selection_srt;
			by a_no v_no;
		quit;

		data &lib..abt_x_var;
			merge work.abt_x_var_srt(in=A) work.var_selection_srt(in=B);
			by a_no v_no;
			if B;
		run;

		/* Create a message for the user. */
		/*I18N-scnjih-20080421-1403*/
/*		%let message = Template succesfully modified.;*/
		%let message = %sysfunc(sasmsg(smd_ds.bismsg,template_step5.sas.2, noquote));
		/*I18N-scnjih-20080421-1403*/

		/* Kill the session, and set the variables to take you to the master template list. */
		%let rc=%sysfunc(stpsrv_session(delete));
		%let program = &template_list;
		%let action = "'/SASStoredProcess/do'";
	%end;

	/* Otherwise, if the name is taken, don't save. Raise an error, and set the variables to
	move to step 1 to allow the user to change the name. */
	%else %if (%str(&inactname_exists) ne %str(0)) %then 
	%do;
			/*I18N-scnjih-20080421-1403*/
/*		%let message = A template by that name already exists, but in inactive state. Contact system administrate to activate.;*/
		%let message = %sysfunc(sasmsg(smd_ds.bismsg,template_step5.sas.3, noquote));
			/*I18N-scnjih-20080421-1403*/
		%let program = &template_step1;
		%let action = "'&_THISSESSION'";
	%end;
	
	/* Finish up. Close the log, create a form, pop up the message and submit. */
	proc printto;
	quit; 
	%put NOTE: Resetting log to _webout;

	/* Start the HTML over here. Put in the head, and such. */
	data _null_;
		file _webout &webout_options;
		put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
		put '"http://www.w3.org/TR/html4/loose.dtd">';
		put '<html>';
		put '<head>';
		put '<link href="/SASABTFramework/styles/default.css" rel="stylesheet" type="text/css"> ';
		put '<style type="text/css">';
		put '<!--';
		put 'body {';
		put '	background-color: #FAF8ED;';
		put '}';
		put '-->';
		put '</style>';
		put '</head>';
		put '<body>';
		put "  <form name='form1' action=&action method='post'>";
		put "    <input name='_program' value=&program type='hidden' />";
		put '  </form>';
		put '  <script type="text/javascript">';
		put '  <!--';

		/* Pop up the message and proceed. */
		put '    alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,abt.tmplt_stp5_alert1.1, noquote))"@;
		put '")';
		put '    form1.submit();';
		put '  -->';
		put '  </script>';
		put '</body>';
		put '</html>';
	run;
%mend;
%save_abt_info;
