/********************************************************************************************
       Module:  model_in_var (Variable level Dashboard Screen for model input reports)

     Function:  This stored process creates the HTML screen which is used to view the
				all the statistics for the MODEL TYPE (PD Approvals, PD Ongoing,
				LGD, CCF), PRODUCT TYPE (Credit Card, Mortgage, Loan, Core etc.),
				MODEL (PD MODEL 1) and TIME selected in the calling stored process
				(mon_model_inputs).

				In this the user can select a statistic from one of the Variables,
				by clicking the link provided on the traffic lighting,
				for generating the respective model input report screen.
				 
      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	1. mon_model_inputs stored process
				2. From any model input report screen as part of the links provided on
					the page for navigation.
					
        Calls:  Calls the following Stored Process
				1. Any of the reports	(when a traffic lighting for that particular
											report is clicked)
				2. Reporting	  		(when Reporting link is clicked)
				3. mon_model_inputs		(when Monitoring Model Inputs link is clicked)

				Calls the following Macros
				1. model_traffic macro for generating the traffic lighting for all the
					measures.

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2. Access the Star Schema to get the required data for the selected product,
					model type and time.
				3. Call the model_traffic macro for generating the traffic lighting
					for the given measure.
				4. Create a dataset containing data for all the variables with all
					the measures and the required information(measure_value, traffic lighting,
					level_desc, etc.)
				5. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the values
						are easily submitted to the next page. 
					b. Provide javascript functions for the links on top of the page
				
   Parameters: 
			INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				model				:	The selected model (e.g. PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				statistic           :   Measure name(Information Value and Other Statistics)
				model				:	The selected model (e.g. PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				variable			:	The selected variable (Eg. Variable 1)
				variable_key		: 	The surrogate key for selected variable (Eg. 1)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.

*********************************************************************************************/
/*This code is Internationalized*/
/* Global input parameters that are passed from the calling program*/
%global prod_type_desc prod_type_code model_type_desc model_type_code model_measure_type
		model model_key period time_key format_name;

%macro check_macro_variable;
/* Trimming extra spaces from all the input parameters*/
%if "&prod_type_desc" ne "" %then
%let prod_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_desc)))));
%if "&prod_type_code" ne "" %then
%let prod_type_code=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code))));
%if "&model_type_desc" ne "" %then
%let model_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_desc)))));
%if "&model_type_code" ne "" %then
%let model_type_code=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_code)))));
%if "&model_measure_type" ne "" %then
%let model_measure_type=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_measure_type)))));
%if "&model" ne "" %then
%let model=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&model))))));
%if "&model_key" ne "" %then
%let model_key=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_key)))));
%if "&period" ne "" %then
%let period=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&period))))));
%if "&time_key" ne "" %then
%let time_key=%str(%sysfunc(ktrim(%sysfunc(kleft(&time_key)))));
/*******************/
%mend;
%check_macro_variable;


/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name

/* Subsetting the measure_dim by the model_measure_type */
proc sql noprint;
	create table work.measure_in as
	select measure_cd,seq_no, measure_sk, measure_nm, level_desc, program_nm from dim.measure_dim
	where kupcase(model_type_cd)=kupcase("&model_measure_type")
	and kupcase(PRODUCT_TYPE_CD)=kupcase("&prod_type_code") 
	order by seq_no;
quit;
/*******************/

/* Creating dataset containing all the required data depending on the model and
    time selected */
proc sql noprint;
	create table work.score_card_variable_ds as
	select * from fact.score_card_variable_fact
	where model_sk = &model_key and kupcase(dev_flg)="%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.dev_flag_n.1, noquote))" 
		and score_time_sk = &time_key;
quit;


proc sql noprint;
	CREATE TABLE WORK.MEASURE_OUT_REP AS 
	SELECT MEASURE_IN.MEASURE_NM, MEASURE_IN.SEQ_NO, MEASURE_IN.LEVEL_DESC,
		MEASURE_IN.PROGRAM_NM, SCORE_CARD_VARIABLE_DS.VARIABLE_SK, 
		MEASURE_IN.MEASURE_SK, SCORE_CARD_VARIABLE_DS.MEASURE_VALUE,
		ANALYTICAL_MODEL_DIM.TARGET_PERIOD_MTHS_CNT 
	FROM WORK.SCORE_CARD_VARIABLE_DS	
		INNER JOIN DIM.ANALYTICAL_MODEL_DIM 
		ON (SCORE_CARD_VARIABLE_DS.MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK)  
		INNER JOIN DIM.TIME_DIM 
		ON (SCORE_CARD_VARIABLE_DS.SCORE_TIME_SK = TIME_DIM.TIME_SK) 
		INNER JOIN WORK.MEASURE_IN
		ON (SCORE_CARD_VARIABLE_DS.MEASURE_SK = MEASURE_IN.MEASURE_SK);
quit;

%let target_period=.;
proc sql noprint;
	select target_period_mths_cnt into :target_period
	from work.measure_out_rep;
quit;
%let target_period=%sysfunc(ktrim(%sysfunc(kleft(&target_period))));

%let elapsed_time=.;
data _null_;
	dt = input ("&period",&CS_TIME_PER_FMT.);
	diff =  intck('month',dt,today());
	if diff >= &target_period then
		call symput('elapsed_time',&target_period);
	else
		call symput('elapsed_time',diff);
run;
%let elapsed_time=%sysfunc(ktrim(%sysfunc(kleft(&elapsed_time))));

proc sql noprint;
	create table work.measure_otrep as 
	select distinct measure_nm, seq_no, level_desc, program_nm, measure_in.measure_sk, 
		variable_sk, . as measure_value 
	from work.score_card_variable_ds, work.measure_in
	where measure_in.measure_sk not in (select distinct measure_sk 
										from work.score_card_variable_ds);
quit;

data work.measure_out;
set work.measure_out_rep work.measure_otrep;
run;
/*******************/

/* Code to get the variable name */
proc sql noprint;
	create table work.measure_report as
	select measure_out.measure_nm, measure_out.seq_no, measure_out.program_nm,
		measure_out.level_desc, score_card_variable_dim.variable_name,
		measure_out.variable_sk, measure_out.measure_sk, measure_out.measure_value
	from work.measure_out inner join dim.score_card_variable_dim
	on measure_out.variable_sk = score_card_variable_dim.variable_sk;
quit;
/*******************/

/* Code to get data for all measures except those having level_desc as 'Other Reports' */
proc sql noprint;
	create table work.measure_rep as
	select * from work.measure_report
	where kupcase(level_desc) ne kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.level_desc_other_reports.1, noquote))");
quit;
/*******************/

/* Calls the model_traffic macro to get the traffic lighting for the data provided
	The following parameters are passed to this macro
			1. data1	: input dataset containing the columns measure_value and measure_nm
			2. model_cd	: MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF)
	This macro adds one more column named color to the dataset passed which contains
	values ( Green, Red, Yellow, White) depending on the bounds(for red and green) provided
	in the measure_dim dataset */
%model_traffic(data1=work.measure_rep,model_cd=&model_measure_type, product_type_code=&prod_type_code);
/*******************/

/* Code to get data for those measures having level_desc as 'Other Reports' */
proc sql noprint;
	create table work.measure_other as
	select * from work.measure_report
	where kupcase(level_desc) = kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.level_desc_other_reports.1, noquote))");
quit;
/*******************/

/* The measures which have measure_value 1 (in the above dataset) are assigned white color*/
data work.measure_other;
	set work.measure_other;
	length color $ 6;
	if measure_value ne 1 then
		color="%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.color_white.1, noquote))";
run;
/*******************/

proc sort data=work.measure_other ;
by variable_sk seq_no;
run;
/*******************/

/* Code for getting data for all the measures */
data work.measure_all;
	set work.measure_other work.measure_rep;
run;
/*******************/

proc sort data=work.measure_all ;
	by variable_sk variable_name seq_no;
run;
/*******************/

/* Code to get the number of distinct seq_no */
%let lim=.;
proc sql noprint;
	select count(distinct measure_sk) into :lim
	from work.measure_all;
quit;
/*******************/

/* Code to transpose the measure_all dataset created above so that the measure value is 
	available for each variable.
	Here measure value for the 1st seq_no is given as measure1, for 2nd seq_no as measure2
	and so on */
proc transpose data=work.measure_all out=work.trans_ms prefix=measure;
	by variable_sk variable_name;
	var measure_value;
run;
/*******************/

/* Code to transpose the measure_all dataset created above so that the traffic lighting is 
	available for each variable.
	Here color for the 1st seq_no is given as color1, for 2nd seq_no as color2 and so on */
proc transpose data=work.measure_all out=work.trans_color prefix=color;
	by variable_sk variable_name;
	var color;
run;
/*******************/

/* Code to transpose the measure_all dataset created above so that the traffic lighting is 
	available for each variable.
	Here program name for the 1st seq_no is given as program1, 
	for 2nd seq_no as program2 and so on */
proc transpose data=work.measure_all out=work.trans_program prefix=program;
	by variable_sk variable_name;
	var program_nm;
run;
/*******************/

/* Code to transpose the measure_all dataset created above so that the traffic lighting is 
	available for each variable.
	Here level_desc for the 1st seq_no is given as level1, 
	for 2nd seq_no as level2 and so on */
proc transpose data=work.measure_all out=work.trans_level prefix=level;
	by variable_sk variable_name;
	var level_desc;
run;
/*******************/

/* Code to transpose the measure_all dataset created above so that the traffic lighting is 
	available for each variable.
	Here measure name for the 1st seq_no is given as msname1, 
	for 2nd seq_no as msname2 and so on */
proc transpose data=work.measure_all out=work.trans_msname prefix=msname;
	by variable_sk variable_name;
	var measure_nm;
run;

/* Creating a dataset having all the information for all the variables */
data work.measure_final(drop=_name_ _label_);
	merge work.trans_color work.trans_ms work.trans_program work.trans_level work.trans_msname;
	by variable_sk;
run;
/*******************/

/* Start HTML Screen*/
data _NULL_;
/*I18N-scnhuh-20080418-1131*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1131*/
	set work.measure_in end=last;
	if _N_=1 then do;
		put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ' @;
		put '"http://www.w3.org/TR/html4/loose.dtd"> ';
		put '<html> ';
		put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
		put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/		
		put '<title>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.title_monitoring_model_input.1, noquote))"@;
		put '</title> ';
		put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
		put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
		put '<style type="text/css"> ';
		put '<!-- ';
		put '.style2 {color: #990000} ';
		put '--> ';
		put '</style> ';
		put '<script>';
		put '<!-- ';

/* Calls the Reporting stored process if link is clicked */
		put 'function Link1() {';
			put "form2._program.value=&CS_REPORTING";
			put 'form2.submit()';
		put '}';

/* Calls the mon_model_inputs stored process if link is clicked */
		put 'function Link2() {';
			put "form2._program.value=&CS_MON_MDL_IP";
			put 'form2.submit()';
		put '}';

/* Calls the respective report screen */	
		put 'function Reports1(prg_nm,var_k,var_nm,ms_nm){';
			put 'form2._program.value=prg_nm';
			put 'form2.prg_name.value=prg_nm';
			put 'form2.variable_key.value=var_k';
			put 'form2.variable.value=var_nm';
			put 'form2.statistic.value=ms_nm';
			put 'form2.outcome_period.value="'@;
			put "&target_period" @;
			put '"';
			put 'form2.elapsed_time.value="'@;
			put "&elapsed_time" @;
			put '"';
			put 'form2.submit()';
		put '}';

		put '//--> ';
		put '</script>';
		put '</head> ';
		put '<body>';
		put '<form name="form2" action="/SASStoredProcess/do" method="post">';
		put '<input type="hidden" name="_program">';

/* Hidden textboxes to hold the values for the program name and the output paremeters 
	to pass the values to the next Stored Process called */
		prod_type_desc=symget("prod_type_desc");
		put '<input type="hidden" name="prod_type_desc" value="' @;
		put prod_type_desc;
		put '">';
		prod_type_code=symget("prod_type_code");
		put '<input type="hidden" name="prod_type_code" value="' @;
		put prod_type_code;
		put '">';
		model_type_desc=symget("model_type_desc");
		put '<input type="hidden" name="model_type_desc" value="' @;
		put model_type_desc;
		put '">';
		model_type_code=symget("model_type_code");
		put '<input type="hidden" name="model_type_code" value="' @;
		put model_type_code;
		put '">';
		model_measure_type=symget("model_measure_type");
		put '<input type="hidden" name="model_measure_type" value="' @;
		put model_measure_type;
		put '">';
		model=symget("model");
		put '<input type="hidden" name="model" value="' @;
		put model;
		put '">';
		model_key=symget("model_key");
		put '<input type="hidden" name="model_key" value="' @;
		put model_key;
		put '">';
		period=symget("period");
		put '<input type="hidden" name="period" value="' @;
		put period;
		put '">';
		time_key=symget("time_key");
		put '<input type="hidden" name="time_key" value="' @;
		put time_key;
		put '">';
		put '<input type="hidden" name="variable">';
		put '<input type="hidden" name="variable_key">';
		put '<input type="hidden" name="elapsed_time">';
		put '<input type="hidden" name="outcome_period">';
		put '<input type="hidden" name="statistic">';
		put '<input type="hidden" name="prg_name">';
/*********/

		put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
		put '<tr> ';
		put '<td align="left"> ';
		put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
		put '<tr> ';

/*Links on Top of the HTML Page*/
		put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
		put '<tr> ';
		put '<td><span class="BreadCrumb"><a href="javascript:Link1()">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.link_reporting.1, noquote))"@;
		put '</a> &gt; ';
		put '<a href="javascript:Link2()">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.link_monitoring_model_input.1, noquote))"@;
		put '</a> &gt; ';
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.link_select_variable.1, noquote))"@;
		put '</span></td>';
/*********/

/*SAS Banner*/
		put '<td width="215"><div align="right">';
		put '<img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
/*********/

/*Values of Product_type, Model and Period*/
		put '</tr> ';
		put '</table><H2 align="left">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.title_monitoring_model_input.1, noquote))"@;
		put '</H2></td> ';
		put '</tr> ';	
		put '<tr> ';
		put '<td align="left"> ';
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_model_type.1, noquote))"@;
		put "&model_type_desc"@;
		put '</p>';
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_product_type.1, noquote))"@;
		put "&prod_type_desc" @;
		put '</p> ';
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_model.1, noquote))"@;
		put "&model" @;
		put '</p> ';
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_period.1, noquote))"@;
/*I18N-scnhuh-20080425-2010*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080425-2010*/		
		put '</p> ';
/*********/ 
/* Target period and elapsed time*/
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_outcome_period.1, noquote))"@;
		put "&target_period" @;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_months.1, noquote))"@;
		put "&elapsed_time" @;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_months_elapsed.1, noquote))"@;
		put '</p>';
/*********/

/*Note for selecting report*/
		put '<p>&nbsp;</p><p class=NoteFont>'@;
		put '<strong>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_note.1, noquote))"@;
		put '</strong>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_click_trafic_light.1, noquote))"@;
		put '</p>';
/*********/

		put '<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#7F9DB9" class="tableborder"> ';
		put '<tr> ';
		put '<td valign="top">';

/* HTML code for creating a table containing the information for all the variables for the
	selected model */
		put '<table width="100%" border="0" cellpadding="3" cellspacing="0"> ';
		put '<tr bgcolor="#FFFFFF"> ';

	/* Column names for the table */
		put '<td class="HZtableborder" width="10%">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.column_variable_nm.1, noquote))"@;
		put '</td> ';
	end;

	put '<td class="HZtableborder" width="10%">'@;
	put MEASURE_NM @;
	put '</td> ';
	/*********/

	if last then do;
		put '</tr>';
	end;
run;
/*******************/

/* Code for populating the table created on the html screen */
%macro test();
	data _NULL_;
/*I18N-scnhuh-20080418-1131*/
/*add &webout_options*/
		file _webout&webout_options;
/*I18N-scnhuh-20080418-1131*/
		set work.measure_final;
		%let cnt=1;
		%do %while(&cnt<=&lim);
			format measure&cnt 7.3;
			%let cnt=%eval(&cnt+1);
		%end;
		if mod(_N_,2)=0 then do;
			put '<tr bgcolor="#F4F4F2"> ';
			put '<td bgcolor="#F4F4F2" class="Font12px"> '@;
		end;
		else do;
			put '<tr bgcolor="#FFFFFF"> ';
			put '<td class="LabelFont"> '@;
		end;
		put variable_name @;
		put '</td> ';
		%let cnt=1;
		%do %while(&cnt<=&lim);
			put '<td class="verttebleborder"><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
			put '<tr> ';
			if kupcase(level&cnt)=kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.level_desc_other_reports.1, noquote))") then do;
				if kupcase(color&cnt)=kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.color_white.1, noquote))") then do;
					put '<td>';
					put '<img src="/SASCSReports/images/spacer.gif" width="16" height="16" border="0"></td>' @;
				end;
				else do;
					put '<td>';
					put '<a id="';
					put program&cnt @;
					put '" href="javascript:Reports1('''@;
					put program&cnt ;
					put ''','''@;
					put variable_sk @;
					put ''','''@;
					put variable_name @;
					put ''','''@;
					put msname&cnt @;
					put ''')">'@;
					put '<img src="/SASCSReports/images/Report2.gif" width="16" height="16" border="0"></a></td> ';
				end;
			end;
			else do;
				if kupcase(color&cnt)=kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.model_in_var.color_white.1, noquote))") then do;
					put '<td>';
					put '<img src="/SASCSReports/images/spacer.gif" width="16" height="16" border="0"></td>' @;
				end;
				else do;
					put '<td>';
					put '<a id="';
					put program&cnt;
					put '" href="javascript:Reports1('''@;
					put program&cnt;
					put ''','''@;
					put variable_sk @;
					put ''','''@;
					put variable_name @;
					put ''','''@;
					put msname&cnt @;
					put ''')">'@;
					put '<img src="/SASCSReports/images/' @;
					put 'Sphere'@;
					put color&cnt;
					put '.gif" width="16" height="16" border="0"></a></td> ';
				end;
				put '<td class="textlink"><div align="right">';
				put measure&cnt @;
				put '</div></td> ';
			end;
			put '</tr> ';
			put '</table></td> ';
			%let cnt=%eval(&cnt+1);
		%end;

		put '</tr>';	
	run;
%mend test;

%test();
/*******************/

data _NULL_;
/*I18N-scnhuh-20080418-1131*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-1131*/
	put '</table></td> ';
	put '</tr> ';
	put '</table> ';

	put '</td> ';
	put '</tr> ';
	put '<tr> ';
	put '<td align="left"> ';
	put '<p>&nbsp;</p> ';
	put '</td> ';
	put '</tr> ';
	put '</table> ';
	put '</td> ';
	put '</tr> ';
	put '<tr> ';
	put '<td height="32" bgcolor="#F1EACB">&nbsp; ';
	put '</td> ';
	put '</tr> ';
	put '</table> ';
	put '</form> ';
	put '</body> ';
	put '</html> ';
run;
