/******************************************************************************************************
       Module:  mon_model_inputs

     Function:  This stored process creates the HTML screen which is used to capture the 
				information regarding the MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF), 
				PRODUCT TYPE (Credit Card, Mortgage, Loan, Core etc.), model and time period
				for generating the model monitoring input reports. 

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	1. Stored Process to generate the Reporting screen as part of the regular flow.
				2. From any model monitoring input report screen as part of the links provided 
					on the page for navigation.
        Calls:  Stored Process model_in_var

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2. If required parameters are empty or missing, a default value is provided 
					to the parameter.
				3. Access the Star Schema to get the product types available for the selected
					model type.
				4. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the 
						values are easily submitted to the next page. 
					b. Provide validation such that values for PROD_TYPE_DESC, PROD_TYPE_CD, 
						MODEL_TYPE_CD, MODEL_TYPE_DESC, MODEL_KEY and TIME_KEY are available 
						on submit. If not the submit should not happen.
					c. Provide validations such as:
						- If the product type is selected for a certain model type, then any 
							previously selected information for any other product or model
							should be cleared in the hidden textboxes in the HTML page.
				
   Parameters:  INPUT (From Report Screen when link is used for navigation) 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
                prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                model_type_desc   	:   Analytical Model Type Desc (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
				model				:	The selected model (Eg. PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				
				OUTPUT (To the PDModels stored process)
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
                prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                model_type_desc   	:   Analytical Model Type Desc (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
				model				:	The selected model (Eg. PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.

******************************************************************************************************/
/*This code is Internationalized*/
/* Global Input Parameters */
%global prod_type_desc prod_type_code model_type_code model_type_desc model model_key 
	period time_key;
%macro check_macro_value;
/* Trimming extra spaces for all input paremeters */
%if "&prod_type_desc" ne "" %then
%let prod_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_desc)))));
%if "&prod_type_code" ne "" %then
%let prod_type_code=%str(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code)))));
%if "&model_type_code" ne "" %then
%let model_type_code=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_code)))));
%if "&model_type_desc" ne "" %then
%let model_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_desc)))));
%if "&model" ne "" %then
%let model=%str(%sysfunc(ktrim(%sysfunc(kleft(&model)))));
%if "&model_key" ne "" %then
%let model_key=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_key)))));
%if "&period" ne "" %then
%let period=%str(%sysfunc(ktrim(%sysfunc(kleft(&period)))));
%if "&time_key" ne "" %then
%let time_key=%sysfunc(ktrim(%sysfunc(kleft(&time_key))));
%mend;
%check_macro_value;
/* Setting default values for any required parameters */
data _null_;
	if "&model_type_code"="" then do;
		call symput('model_type_code',&PD_APP_MODEL);
		call symput('model_type_desc',put(&PD_APP_MODEL,$modtype.));
	end;
	if "&model_key"="" then call symput('model_key',.);
run;

proc sql noprint;
/* Accessing the Star Schema to get the product types available for the selected model type */
/*	create table work.products as*/
/*	select distinct model_product_type_cd, put(model_product_type_cd, $prtype.) as model_prod_type_desc*/
/*	from dim.analytical_model_dim*/
/*	where ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD ="&model_type_code" and*/
/*		ANALYTICAL_MODEL_DIM.VALID_END_DTTM=&VALID_HIGH_DTTM;*/

/* Accessing the Star Schema to get the models available for the selected model type and
	product type */
/*	create table work.models as*/
/*	select distinct model_sk, model_nm*/
/*	from dim.analytical_model_dim*/
/*	where ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD ="&model_type_code" and */
/*		ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD ="&prod_type_code" and*/
/*		ANALYTICAL_MODEL_DIM.VALID_END_DTTM=&VALID_HIGH_DTTM;*/

/* Accessing the Star Schema to get the periods available for the selected model type, 
	product type and model */
/*	create table work.periods as*/
/*	select distinct score_time_sk, put(TIME_DIM.CAL_MONTH_LAST_DT, &CS_TIME_PER_FMT.) as period*/
/*	from dim.analytical_model_dim INNER JOIN FACT.SCORE_CARD_VARIABLE_FACT*/
/*		ON (analytical_model_dim.model_sk = SCORE_CARD_VARIABLE_FACT.model_sk)*/
/*		INNER JOIN DIM.TIME_DIM */
/*		ON (SCORE_CARD_VARIABLE_FACT.SCORE_TIME_SK = TIME_DIM.TIME_SK)*/
/*	where ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD ="&model_type_code" and */
/*		ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD ="&prod_type_code" and */
/*		kupcase(SCORE_CARD_VARIABLE_FACT.DEV_FLG)="N" and*/
/*		ANALYTICAL_MODEL_DIM.MODEL_SK =&model_key;*/

	create table work.model_period as
	select distinct MODEL_TYPE_CD, MODEL_PRODUCT_TYPE_CD, 
		put(model_product_type_cd, $prtype.) as MODEL_PROD_TYPE_DESC,
		analytical_model_dim.MODEL_SK, MODEL_NM, SCORE_TIME_SK, 
		put(TIME_DIM.CAL_MONTH_LAST_DT, &CS_TIME_PER_FMT.) as PERIOD,
		TIME_DIM.CAL_MONTH_NO
	from dim.analytical_model_dim INNER JOIN FACT.SCORE_CARD_VARIABLE_FACT
		ON (analytical_model_dim.model_sk = SCORE_CARD_VARIABLE_FACT.model_sk)
		INNER JOIN DIM.TIME_DIM 
		ON (SCORE_CARD_VARIABLE_FACT.SCORE_TIME_SK = TIME_DIM.TIME_SK)
	where ANALYTICAL_MODEL_DIM.VALID_END_DTTM=&VALID_HIGH_DTTM and
		kupcase(SCORE_CARD_VARIABLE_FACT.DEV_FLG)="%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.dev_flag_n.1, noquote))"
	order by MODEL_TYPE_CD, MODEL_PRODUCT_TYPE_CD, MODEL_SK, SCORE_TIME_SK;
quit;

%let periodicity = .;
%macro time_period;

	%if &model_type_code ne and &prod_type_code ne %then %do;
		%let model_code = %quote(%'&model_type_code%');
		%let product_code = %quote(%'&prod_type_code%'); 
		%if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&PD_APP_MODEL.)) %then %do;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
				%let periodicity = &PDA_MTG_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
				%let periodicity = &PDA_LON_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
				%let periodicity = &PDA_COR_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
				%let periodicity = &PDA_CCD_PERIOD;
			%end;
		%end;
		%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&PD_ONG_MODEL.)) %then %do;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
				%let periodicity = &PDO_MTG_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
				%let periodicity = &PDO_LON_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
				%let periodicity = &PDO_COR_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
				%let periodicity = &PDO_CCD_PERIOD;
			%end;
		%end;
		%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&LGD_MODEL.)) %then %do;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
				%let periodicity = &LGD_MTG_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
				%let periodicity = &LGD_LON_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
				%let periodicity = &LGD_COR_PERIOD;
			%end;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
				%let periodicity = &LGD_CCD_PERIOD;
			%end;
		%end;
		%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&CCF_MODEL.)) %then %do;
			%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
				%let periodicity = &CCF_CCD_PERIOD;
			%end;
		%end;

		%if &periodicity gt 12 %then %do; 
			%let periodicity = 12;
		%end;
		data work.model_period;
			set work.model_period;
			where cal_month_no in (
				%do i = 1 %to %eval(12/&periodicity);
					%if &i eq %eval(12/&periodicity) %then %eval(&periodicity*&i);
					%else %eval(&periodicity*&i),;
				%end;
			);
		run;
	%end;
%mend time_period;
%time_period;

/* Start HTML Screen */
data _NULL_;
	file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html>';
	put '<head>';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8">';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.title_mon_model.1, noquote))"@;
	put '</title>';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css">';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css">';
	put '<style type="text/css">';
	put '<!--';
	put '.style2 {font-size: small}';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';
	put'<script language="JavaScript" type="text/JavaScript"> ';
	put'<!-- ';

	/*	Initialize class for Model - Product Details */
	put 'function Prod(model_type, product, product_desc){';
	put '	this.model_type = model_type;';
	put '	this.product = product;';
	put '	this.product_desc = product_desc;';
	put '}';

	put 'function ProdModel(model_type, product, product_desc, model, model_desc){';
	put '	this.model_type = model_type;';
	put '	this.product = product;';
	put '	this.product_desc = product_desc;';
	put '	this.model = model;';
	put '	this.model_desc = model_desc;';
	put '}';
/*I18N-scnhuh-20080426-2148*/
/*add one argument for national language support:period_nl. add one line:put '	this.period_nl = period_nl;';*/
	put 'function ProdModelTime(model_type, product, product_desc, model, model_desc, time_key, period, period_nl){';
	put '	this.model_type = model_type;';
	put '	this.product = product;';
	put '	this.product_desc = product_desc;';
	put '	this.model = model;';
	put '	this.model_desc = model_desc;';
	put '	this.time_key = time_key;';
	put '	this.period = period;';
	put '	this.period_nl = period_nl;';
	put '}';
/*I18N-scnhuh-20080426-2148*/	
run;

data _null_;
	file _webout&webout_options;
	set work.model_period end=last;
	by MODEL_TYPE_CD MODEL_PRODUCT_TYPE_CD;
	if _N_=1 then put 'ProdArray = new Array(';
	if first.MODEL_PRODUCT_TYPE_CD then do;
		if _N_ > 1 then put ',';
		put '	new Prod("'@;
		put MODEL_TYPE_CD@;
		put '", "'@;
		put MODEL_PRODUCT_TYPE_CD@;
		put '", "'@;
		put MODEL_PROD_TYPE_DESC@;
		put '")'@;
	end;
/*	if not last then put '"),';*/
	if last then do;
/*		put '")';*/
		put ;
		put ');';
	end;
run;

data _null_;
	file _webout&webout_options;
	set work.model_period end=last;
	by MODEL_TYPE_CD MODEL_PRODUCT_TYPE_CD MODEL_SK;
	if _N_=1 then put 'ProdModelArray = new Array(';
	if first.MODEL_SK then do;
		if _N_ > 1 then put ',';
		put '	new ProdModel("'@;
		put MODEL_TYPE_CD@;
		put '", "'@;
		put MODEL_PRODUCT_TYPE_CD@;
		put '", "'@;
		put MODEL_PROD_TYPE_DESC@;
		put '", '@;
		put MODEL_sk@;
		put ', "'@;
		put MODEL_NM@;
		put '")'@;
	end;
/*	if not last then put '"),';*/
	if last then do;
/*		put '")';*/
		put ;
		put ');';
	end;
/*	else put ',';*/
run;

data _null_;
	file _webout&webout_options;
	set work.model_period end=last;
	if _N_=1 then put 'ProdModelTimeArray = new Array(';
	put '	new ProdModelTime("'@;
	put MODEL_TYPE_CD@;
	put '", "'@;
	put MODEL_PRODUCT_TYPE_CD@;
	put '", "'@;
	put MODEL_PROD_TYPE_DESC@;
	put '", '@;
	put MODEL_sk@;
	put ', "'@;
	put MODEL_NM@;
	put '", '@;
	put SCORE_TIME_SK@;
	put ', "'@;
	put PERIOD@;
/*I18N-scnhuh-20080425-2021*/	
/*add three lines. For displaying in NLS format */	
		put '", "'@;
		Period_WEBUI=put(input(Period,&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080425-2021*/		
	if not last then put '"),';
	if last then do;
		put '")';
		put ');';
	end;
run;


data _null_;
	file _webout&webout_options;
	put 'function init(){';
		 /*I18N-scnjih-20080421-1457*/
/*	put '	document.form1.product.options[0]	= new Option("Select Product");';*/
/*	put '	document.form1.models.options[0]	= new Option("Select Model");';*/
/*	put '	document.form1.periods.options[0]	= new Option("Select Period");';*/
	put '	document.form1.product.options[0]	= new Option("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,mon_model_inputs.sas.1, noquote))"@;
	put '");';
	put '	document.form1.models.options[0]	= new Option("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,mon_model_inputs.sas.2, noquote))"@;
	put '");';
	put '	document.form1.periods.options[0]	= new Option("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,mon_model_inputs.sas.3, noquote))"@;
	put '");';
			 /*I18N-scnjih-20080421-1457*/
	put '}';

	put 'function initProd(mdl_type){';
	put '	for(i = document.form1.product.length - 1; i > 0; i--)';
	put '		document.form1.product.options[i] = null;';
	put '	var j = 1';
	put '	for(i = 1; i <= ProdArray.length; i++){';
	put '		if(ProdArray[i-1].model_type.replace(/ /,"") == mdl_type){';
	put '			document.form1.product.options[j] = new Option(ProdArray[i-1].product_desc, ProdArray[i-1].product+":"+ProdArray[i-1].product_desc);';
	put '			if(ProdArray[i-1].product.replace(/ /,"") == form1.prod_type_code.value.replace(/ /,"")){';
	put '				document.form1.product.options[j].selected = true';
	put '				getCodeDesc(form1.product.options[j].value, form1.prod_type_code, form1.prod_type_desc)';
	put '			}';
	put '			j++';
	put '		}';
	put '	}';
	put '}';

	put 'function initMdl(mdl_type, prod){';
	put '	for(i = document.form1.models.length - 1; i > 0; i--)';
	put '		document.form1.models.options[i] = null;';
	put '	var j = 1';
	put '	for(i = 1; i <= ProdModelArray.length; i++){';
	put '		if((ProdModelArray[i-1].model_type.replace(/ /,"") == mdl_type) && '@;
	put '(ProdModelArray[i-1].product.replace(/ /,"") == prod)){';
	put '			document.form1.models.options[j] = new Option(ProdModelArray[i-1].model_desc, ProdModelArray[i-1].model+" :"+ProdModelArray[i-1].model_desc);';
	put '			if(ProdModelArray[i-1].model == form1.model_key.value){';
	put '				document.form1.models.options[j].selected = true';
	put '				getCodeDesc(form1.models.options[j].value, form1.model_key, form1.model)';
	put '			}';
	put '			j++';
	put '		}';
	put '	}';
	put '}';

	put 'function initPeriod(mdl_type, prod, mdl){';
	put '	for(i = document.form1.periods.length - 1; i > 0; i--)';
	put '		document.form1.periods.options[i] = null;';
	put '	var j = 1';
	put '	for(i = 1; i <= ProdModelTimeArray.length; i++){';
/*	put 'alert("/"+ProdModelTimeArray[i-1].model_type.replace(/ /,"")+"/=/"+mdl_type+"/")';*/
/*	put 'alert("/"+ProdModelTimeArray[i-1].product.replace(/ /,"")+"/=/"+prod+"/")';*/
/*	put 'alert("/"+ProdModelTimeArray[i-1].model+"/=/"+mdl+"/")';*/
	put '		if((ProdModelTimeArray[i-1].model_type.replace(/ /,"") == mdl_type) && '@;
	put '(ProdModelTimeArray[i-1].product.replace(/ /,"") == prod) && '@;
	put '(ProdModelTimeArray[i-1].model == mdl)){';
/*I18N-scnhuh-20080426-2148*/	
/*change to period_nl*/
	put '			document.form1.periods.options[j] = new Option(ProdModelTimeArray[i-1].period_nl, ProdModelTimeArray[i-1].time_key+" :"+ProdModelTimeArray[i-1].period);';
/*I18N-scnhuh-20080426-2148*/	
/*	put 'alert("/"+ProdModelTimeArray[i-1].time_key+"/=/"+form1.time_key.value+"/")';*/
	put '			if(ProdModelTimeArray[i-1].time_key == form1.time_key.value){';
	put '				document.form1.periods.options[j].selected = true';
	put '				getCodeDesc(form1.periods.options[j].value, form1.time_key, form1.period)';
	put '			}';
	put '			j++';
	put '		}';
	put '	}';
	put '}';

	/* Call the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit();';
	put '}';

	/* For all dropdowns and model_types, the value holds the information such as 
	prod_type_cd:prod_type_desc. Hence depending on the selected index in the dropdown, 
	the code and descriptions have to extracted. This function does the job of extracting 
	the codes and descriptions. */
	put 'function getCodeDesc(prod_val,prod_code,prod_desc) {';
		put 'var len=prod_val.length';
		put 'var indx=prod_val.indexOf(":")';
		put 'var code_end=indx-1';
		put 'var desc_st=indx+1';
		put 'var desc_len=len-desc_st';
		put 'var code=prod_val.substr(0,code_end)';
		put 'var desc=prod_val.substr(desc_st,desc_len)';
		put 'prod_code.value=code';
		put 'prod_desc.value=desc';
	put '}';

	/* When the radio button for a model type is clicked, this function is called to
	set the model_type_code and model_type_desc. And when the model type code is set, 
	the prod_type_code, prod_type_desc values are reset. */
/*	put 'function setType(val) {';*/
/*		put 'getCodeDesc(val, form1.model_type_code, form1.model_type_desc)';*/
/*		put 'form1.prod_type_code.value=""';*/
/*		put 'form1.prod_type_desc.value=""';*/
/*		put 'form1.model.value=""';*/
/*		put 'form1.model_key.value=""';*/
/*		put 'form1.period.value=""';*/
/*		put 'form1.time_key.value=""';*/
/*		put 'form1.product.selectedIndex=0';*/
/*		put 'form1.models.selectedIndex=0';*/
/*		put 'form1.periods.selectedIndex=0';*/
/*		put 'form1.submit();';*/
/*	put '}';*/
	put 'function setType(mdl_type){';
	put '	getCodeDesc(mdl_type, form1.model_type_code, form1.model_type_desc)';
	put '	form1.prod_type_code.value=""';
	put '	form1.prod_type_desc.value=""';
	put '	form1.model_key.value=""';
	put '	form1.model.value=""';
	put '	form1.time_key.value=""';
	put '	form1.period.value=""';
	put '	for(i = document.form1.product.length - 1; i > 0; i--)';
	put '		document.form1.product.options[i] = null;';
	put '	document.form1.product.options[0].selected = true;';
	put '	for(i = document.form1.models.length - 1; i > 0; i--)';
	put '		document.form1.models.options[i] = null;';
	put '	document.form1.models.options[0].selected = true;';
	put '	for(i = document.form1.periods.length - 1; i > 0; i--)';
	put '		document.form1.periods.options[i] = null;';
	put '	document.form1.periods.options[0].selected = true;';
	put '	var j = 1';
	put '	for(i = 1; i <= ProdArray.length; i++){';
	put '		if(ProdArray[i-1].model_type.replace(/ /,"") == form1.model_type_code.value){';
	put '			document.form1.product.options[j] = new Option(ProdArray[i-1].product_desc, ProdArray[i-1].product+":"+ProdArray[i-1].product_desc);';
	put '			j++';
	put '		}';
	put '	}';
	put '}';

	/* When the product type for a model is selected, this function is called to set 
	the values of prod_type_code and prod_type_desc and the values of models and 
	periods are reset. */
/*	put 'function setCode() {';*/
/*	put '	var indx=form1.product.selectedIndex';*/
/*	put '	if (indx!=0) {';*/
/*	put '		getCodeDesc(form1.product.options[indx].value, form1.prod_type_code, form1.prod_type_desc)';*/
/*	put '		form1.models.selectedIndex=0';*/
/*	put '		form1.periods.selectedIndex=0';*/
/*	put '		form1.model.value=""';*/
/*	put '		form1.model_key.value=""';*/
/*	put '		form1.period.value=""';*/
/*	put '		form1.time_key.value=""';*/
/*	put '	}';*/
/*	put '	else {';*/
/*	put '		form1.prod_type_code.value=""';*/
/*	put '		form1.prod_type_desc.value=""';*/
/*	put '	}';*/
/*	put '	form1.submit();';*/
/*	put '}';*/
	put 'function setCode() {';
	put '	var indx=form1.product.selectedIndex';
	put '	if (indx!=0) {';
	put '		getCodeDesc(form1.product.options[indx].value, form1.prod_type_code, form1.prod_type_desc)';
	put '		form1.model.value=""';
	put '		form1.model_key.value=""';
	put '		form1.period.value=""';
	put '		form1.time_key.value=""';
	put '		for(i = document.form1.models.length - 1; i > 0; i--)';
	put '			document.form1.models.options[i] = null;';
/*	put '		document.form1.models.options[0].selected = true;';*/
	put '		for(i = document.form1.periods.length - 1; i > 0; i--)';
	put '			document.form1.periods.options[i] = null;';
/*	put '		document.form1.periods.options[0].selected = true;';*/
	put '		var j = 1';
	put '		for(i = 1; i <= ProdModelArray.length; i++){';
	put '			if((ProdModelArray[i-1].model_type.replace(/ /,"") == form1.model_type_code.value.replace(/ /,"")) && '@;
	put '(ProdModelArray[i-1].product.replace(/ /,"") == form1.prod_type_code.value.replace(/ /,""))){';
	put '				document.form1.models.options[j] = new Option(ProdModelArray[i-1].model_desc, ProdModelArray[i-1].model+" :"+ProdModelArray[i-1].model_desc);';
	put '				j++';
	put '			}';
	put '		}';
	put '	}';
	put '	else {';
	put '		for(i = document.form1.models.length - 1; i > 0; i--)';
	put '			document.form1.models.options[i] = null;';
	put '		document.form1.models.options[0].selected = true;';
	put '		for(i = document.form1.periods.length - 1; i > 0; i--)';
	put '			document.form1.periods.options[i] = null;';
	put '		document.form1.periods.options[0].selected = true;';
	put '		form1.prod_type_code.value=""';
	put '		form1.prod_type_desc.value=""';
	put '		form1.model.value=""';
	put '		form1.model_key.value=""';
	put '		form1.period.value=""';
	put '		form1.time_key.value=""';
	put '	}';
	put '}';

	/* When the model is selected, this function is called to set the values of model and
	model_key and the value of periods is reset. */
/*	put 'function setModel() {';*/
/*	put '	var indx=form1.models.selectedIndex';*/
/*	put '	if (indx!=0) {';*/
/*	put '		getCodeDesc(form1.models.options[indx].value, form1.model_key, form1.model)';*/
/*	put '		form1.periods.selectedIndex=0';*/
/*	put '		form1.period.value=""';*/
/*	put '		form1.time_key.value=""';*/
/*	put '	}';*/
/*	put '	else {';*/
/*	put '		form1.model_key.value=""';*/
/*	put '		form1.model.value=""';*/
/*	put '	}';*/
/*	put '	form1.submit();';*/
/*	put '}';*/
	put 'function setModel() {';
	put '	document.form1.periods.disabled=true';
	put '	var indx=form1.models.selectedIndex';
	put '	if (indx!=0) {';
	put '		getCodeDesc(form1.models.options[indx].value, form1.model_key, form1.model)';
	put '		form1.period.value=""';
	put '		form1.time_key.value=""';
	put '		for(i = document.form1.periods.length - 1; i > 0; i--)';
	put '			document.form1.periods.options[i] = null;';
	put '		var j = 1';
	put '		for(i = 1; i <= ProdModelTimeArray.length; i++){';
	put '			if((ProdModelTimeArray[i-1].model_type.replace(/ /,"") == form1.model_type_code.value.replace(/ /,"")) && '@;
	put '(ProdModelTimeArray[i-1].product.replace(/ /,"") == form1.prod_type_code.value.replace(/ /,"")) && '@;
	put '(ProdModelTimeArray[i-1].model == form1.model_key.value)){';
/*I18N-scnhuh-20080426-2148*/
/*change to period_nl*/
	put '				document.form1.periods.options[j] = new Option(ProdModelTimeArray[i-1].period_nl, ProdModelTimeArray[i-1].time_key+" :"+ProdModelTimeArray[i-1].period);';
/*I18N-scnhuh-20080426-2148*/	
	put '				j++';
	put '			}';
	put '		}';
	put "		form1._program.value=&CS_MON_MDL_IP";
	put '		form1.submit()';
	put '	}';
	put '	else {';
	put '		for(i = document.form1.periods.length - 1; i > 0; i--)';
	put '			document.form1.periods.options[i] = null;';
	put '		document.form1.periods.options[0].selected = true;';
	put '		form1.model_key.value=""';
	put '		form1.model.value=""';
	put '		form1.period.value=""';
	put '		form1.time_key.value=""';
	put '	}';
	put '}';

	/* When the period for a model is selected, this function is called to set the values of 
	period and time_key. */
	put 'function setPeriod() {';
	put '	var indx=form1.periods.selectedIndex';
	put '	if (indx!=0) {';
	put '		getCodeDesc(form1.periods.options[indx].value, form1.time_key, form1.period)';
	put '	}';
	put '	else {';
	put '		form1.time_key.value=""';
	put '		form1.period.value=""';
	put '	}';
	put '}';

	/* This function validates that values exist for all the output paremeters before the 
	page is submitted. */
	put 'function Onsubmit(){';
	put '	if (form1.prod_type_desc.value=="" || form1.prod_type_desc.value.charAt(0)==" ")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_pro_typ.1, noquote))"@;
	put '");';
	put '	else if (form1.prod_type_code.value=="" || form1.prod_type_code.value.charAt(0)==" ")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_pro_typ.1, noquote))"@;
	put '");';
	put '	else if (form1.model_type_code.value=="" || form1.model_type_code.value.charAt(0)==" ")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_mdl_typ.1, noquote))"@;
	put '");';
	put '	else if (form1.model_type_desc.value=="" || form1.model_type_desc.value.charAt(0)==" ")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_mdl_typ.1, noquote))"@;
	put '");';
	put '	else if (form1.model.value=="" || form1.model.value.charAt(0)==" ")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_mdl.1, noquote))"@;
	put '");';
	put '	else if (form1.model_key.value=="" || form1.model_key.value.charAt(0)==".")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_mdl.1, noquote))"@;
	put '");';
	put '	else if (form1.period.value=="" || form1.period.value.charAt(0)==" ")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_time_prd.1, noquote))"@;
	put '");';
	put '	else if (form1.time_key.value=="" || form1.time_key.value.charAt(0)==" ")';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.alert_error_sel_time_prd.1, noquote))"@;
	put '");';
	put '	else {';
	put "		form1._program.value=&CS_VAR_LVL_DB";
	put '		form1.submit();';
	put '	}';
	put '}';

	put '//-->';
	put	'</script> ';
	put '</head>';

	put '<body>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	put '<input type="hidden" name="_program" VALUE=';
	put "&CS_MON_MDL_IP";
	put '>';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc @;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code @;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code @;
	put '">';
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc @;
	put '">';
	model=symget("model");
	put '<input type="hidden" name="model" value="' @;
	put model @;
	put '">';
	model_key=symget("model_key");
	put '<input type="hidden" name="model_key" value="' @;
	put model_key @;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period @;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key @;
	put '">';
	put '<input type="hidden" name="model_measure_type" value="MIP">';

	put '  <table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '    <tr>';
	put '      <td align="left">';
	put '        <table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '          <tr>';
	put '            <td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '  <tr>';

	/* Navigational Links */
	put '    <td><span class="BreadCrumb"><a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.link_reporting.1, noquote))"@;
	put '</a> &gt; </span><span class="BreadCrumb">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.column_monitoring_model_input.1, noquote))"@;
	put '</span></td>';
	put '    <td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
	put '  </tr></table>';

	/* Main Body */
	put '            <H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.column_monitoring_model_input.1, noquote))"@;
	put '</H2></td>';
	put '          </tr>';
	put '          <tr>';
	put '            <td valign="top">';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &PD_APP_MODEL @;
	put ' :'@;
	desc=put(&PD_APP_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &PD_APP_MODEL then 
		put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.radio_model_risk_bsd_approval.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &PD_ONG_MODEL @;
	put ' :'@;
	desc=put(&PD_ONG_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &PD_ONG_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.radio_model_ong_risk_bsd_approval.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &LGD_MODEL @;
	put ' :'@;
	desc=put(&LGD_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &LGD_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.radio_model_for_lgd.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &CCF_MODEL @;
	put ' :'@;
	desc=put(&CCF_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &CCF_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.radio_model_for_ccf.1, noquote))"@;
	put '</p>';

	put '              <p class="LabelFont">&nbsp;</p>';
	put '              <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.radio_nm_model_for_prd_type.1, noquote))"@;
	put ':';
	put '                  <select id="product" size="1" width="30" style="width: 50mm" onChange="javascript:setCode()">';
/*	put '<option value="None">None</option>';*/
run;

/* Populate the Product dropdown depending on the selection of the Model type */
/*data _null_;*/
/*	set work.products end=last;*/
/*	file _webout&webout_options;*/
/*	put '<option value="'@;*/
/*	put model_product_type_cd@;*/
/*	put ':';*/
/*	put model_prod_type_desc@;*/
/*	put '" ' @;*/
/*	if "&prod_type_code" = model_product_type_cd then put 'selected';*/
/*	put '>'@;*/
/*	put model_prod_type_desc@;*/
/*	put '</option>';*/
/*run;*/

data _null_;
	file _webout&webout_options;
	put '                  </select>';
	put '              </p>';
	put '              <p class="LabelFont">';
	put '              <p class="LabelFont">&nbsp;</p>';
	put '              <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.column_model.1, noquote))"@;
	put '                  <select id="models" size="1" width="30" style="width: 50mm" onChange="javascript:setModel()">';
/*	put '<option value="None">None</option>';*/
run;

/* Populate the Models dropdown depending on the selection of the Model type and 
Product type */
/*data _null_;*/
/*	set work.models end=last;*/
/*	file _webout&webout_options;*/
/*	put '<option value="'@;*/
/*	put model_sk@;*/
/*	put ':';*/
/*	put model_nm@;*/
/*	put '" ' @;*/
/*	if "&model_key" = model_sk then put 'selected';*/
/*	put '>'@;*/
/*	put model_nm@;*/
/*	put '</option>';*/
/*run;*/

data _null_;
	file _webout&webout_options;
	put '                  </select>';
	put '              </p>';
	put '              <p class="LabelFont">';
	put '              <p class="LabelFont">&nbsp;</p>';
	put '              <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_model_inputs.column_period.1, noquote))"@;
	put '                  <select id="periods" size="1" onChange="javascript:setPeriod()">';
/*	put '<option value="None">None</option>';*/
run;

/* Populate the Periods dropdown depending on the selection of the Model type,  
Product type and model */
/*data _null_;*/
/*	set work.periods end=last;*/
/*	file _webout&webout_options;*/
/*	put '<option value="'@;*/
/*	put score_time_sk@;*/
/*	put ':';*/
/*	put period@;*/
/*	put '" ' @;*/
/*	if "&time_key" = score_time_sk then put 'selected';*/
/*	put '>'@;*/
/*	put period@;*/
/*	put '</option>';*/
/*run;*/

/* End the HTML */
data _null_;
	file _webout&webout_options;
	put '                  </select>';
	put '              </p>';
	put '              <p class="LabelFont">';
	put '              <p class="LabelFont">&nbsp;</p>';
	put '          </tr>';
	put '          <tr bgcolor="#FAF8ED">';
	put '            <td bgcolor="#F1EACB">&nbsp;&nbsp;';
	put '                <INPUT type=button class=mmhide_btn onClick="javascript:Onsubmit()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.button_ok.1, noquote))"@;
	put '">';
	put '            </td>';
	put '          </tr>';
	put '        </table>';
	put '      </td>';
	put '    </tr>';
	put '</table>';

	/* Initialize combobox for Product Name */
	put '<script>';
	put '<!-- ';
	put 'init();';
	if "&model_type_code" ne "" or "&model_type_code" ne " " then do;
		put 'initProd("'@;
		put "&model_type_code"@;
		put '");';
		if "&prod_type_code" ne "" or "&prod_type_code" ne " " then do;
			put 'initMdl("'@;
			put "&model_type_code"@;
			put '", "'@;
			put "&prod_type_code"@;
			put '");';
			if "&model_key" ne "" or "&model_key" ne " " then do;
				put 'initPeriod("'@;
				put "&model_type_code"@;
				put '", "'@;
				put "&prod_type_code"@;
				put '", '@;
				put "&model_key"@;
				put ');';
			end;
		end;
	end;
 	put '//--> ';	
	put '</script>';
	put '</body>';
	put '</html>';
run;
