/******************************************************************************************************
       Module:  mon_models

     Function:  This stored process creates the HTML screen which is used to capture the 
				information regarding the MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF), 
				PRODUCT TYPE (Credit Card, Mortgage, Loan, Core etc.) for generating the 
				model monitoring reports. If the user wishes to include expired models 
				also to view in reports, the user can select to do so by clicking the 
				checkbox for Include Expired Models.

      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	1. Stored Process to generate the Reporting screen as part of the regular flow.
				2. From any model monitoring report screen as part of the links provided on 
					the page for navigation.
        Calls:  Stored Process select_models

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2. If required parameters are empty or missing, a default value is provided 
					to the parameter.
				3. Access the Star Schema to get the product types available for the selected
					model type.
				4. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the 
						values are easily submitted to the next page. 
					b. Provide validation such that values for PROD_TYPE_DESC, PROD_TYPE_CD, 
						MODEL_TYPE_CD, MODEL_TYPE_DESC and INCLUDE_EXP_MDL are available on 
						submit. If not the submit should not happen.
					c. Provide validations such as:
						- If the product type is selected for a certain model type, then any 
							previously selected information for any other product or model
							should be cleared in the hidden textboxes in the HTML page.
				
   Parameters:  INPUT (From Report Screen when link is used for navigation) 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
                prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                model_type_desc   	:   Analytical Model Type Desc (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                include_exp_mdl		:   Information to include the expired models for 
										selection of model from the traffic light dashboard.
				
				OUTPUT (To the PDModels stored process)
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
                prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
                model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                model_type_desc   	:   Analytical Model Type Desc (e.g., PD Approvals, PD 
										Ongoing, LGD, CCF)
                include_exp_mdl		:   Information to include the expired models for 
										selection of model from the traffic light dashboard.

******************************************************************************************************/
/*This code is Internationalized*/
/* Global Input Parameters */
%global prod_type_desc prod_type_code model_type_code model_type_desc include_exp_mdl;

/* Setting default values for any required parameters */
data _null_;
	if "&model_type_code"="" then do;
		call symput('model_type_code',&PD_APP_MODEL);
		call symput('model_type_desc',put(&PD_APP_MODEL,$modtype.));
	end;
	if "&prod_type_code"="" then call symput('prod_type_code'," ");
	if "&include_exp_mdl"="" then call symput('include_exp_mdl','N');
run;
%macro check_macro_values;
/* Trimming extra spaces for all input paremeters */ 
%if "&prod_type_desc" ne "" %then 
	%let prod_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_desc)))));
 
%if "&prod_type_code" ne " " %then 
	%let prod_type_code=%str(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code)))));
 
%if "&model_type_code" ne "" %then
	%let model_type_code=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_code)))));
 
%if "&model_type_desc" ne "" %then
	%let model_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_desc)))));
 
%if "&include_exp_mdl" ne "" %then
	%let include_exp_mdl=%str(%sysfunc(ktrim(%sysfunc(kleft(&include_exp_mdl)))));
%mend;
%check_macro_values
/* Accessing the Star Schema to get the product types available for the selected model type */
proc sql noprint;
	create table work.products as
	select distinct model_type_cd, model_product_type_cd, 
		put(model_product_type_cd, $prtype.) as model_prod_type_desc
	from dim.analytical_model_dim;
quit;

/* Start HTML Screen */
data _NULL_;
	file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"';
	put '"http://www.w3.org/TR/html4/loose.dtd">';
	put '<html>';
	put '<head>';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8">';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.title_monitoring_model.1, noquote))"@;
	put '</title>';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css">';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css">';
	put '<style type="text/css">';
	put '<!--';
	put '.style2 {font-size: small}';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';
	put'<script language="JavaScript" type="text/JavaScript"> ';
	put'<!-- ';

	/*	Initialize class for Model - Product Details */
	put 'function ModelProd(model, product, product_desc){';
	put '	this.model = model;';
	put '	this.product = product;';
	put '	this.product_desc = product_desc;';
	put '}';
run;

data _null_;
	file _webout&webout_options;
	set work.products end=last;
	if _N_=1 then put 'ModelProdArray = new Array(';
	put '	new ModelProd("'@;
	put MODEL_TYPE_CD@;
	put '", "'@;
	put MODEL_PRODUCT_TYPE_CD@;
	put '", "'@;
	put MODEL_PROD_TYPE_DESC@;
	if not last then put '"),';
	if last then do;
		put '")';
		put ');';
	end;
run;

data _null;
	file _webout&webout_options;

	put 'function init(){';
	 /*I18N-scnjih-20080421-1453*/
/*	put '	document.form1.product.options[0]	= new Option("Select Product");';*/
	put '	document.form1.product.options[0]	= new Option("'@;
 	put "%sysfunc(sasmsg(smd_ds.bismsg,mon_models.sas.2, noquote))"@;
	put '");';
	 /*I18N-scnjih-20080421-1453*/
	put '}';

	put 'function initProd(mdl_type){';
	put '	for(i = document.form1.product.length - 1; i > 0; i--)';
	put '		document.form1.product.options[i] = null;';
	put '	var j = 1';
	put '	for(i = 1; i <= ModelProdArray.length; i++){';
	put '		if(ModelProdArray[i-1].model.replace(/ /,"") == mdl_type){';
	put '			document.form1.product.options[j] = new Option(ModelProdArray[i-1].product_desc, ModelProdArray[i-1].product+":"+ModelProdArray[i-1].product_desc);';
	put '			if(ModelProdArray[i-1].product.replace(/ /,"") == form1.prod_type_code.value.replace(/ /,"")){';
	put '				document.form1.product.options[j].selected = true';
	put '				getCodeDesc(form1.product.options[j].value, form1.prod_type_code, form1.prod_type_desc)';
	put '			}';
	put '			j++';
	put '		}';
	put '	}';
	put '}';

	put 'function initExp(){';
	put '	if (form1.include_exp_mdl.value.replace(/ /,"") == "Y"){';
	put '		form1.exp_mdl.checked=true';
	put '		setMdl()';
	put '	}';
	put '}';

	/* Call the Reporting stored process if link is clicked */
	put 'function Link1() {';
	put "	form1._program.value=&CS_REPORTING";
	put '	form1.submit();';
	put '}';

	/* For all dropdowns and model_types, the value holds the information such as 
	prod_type_cd:prod_type_desc. Hence depending on the selected index in the dropdown, 
	the code and descriptions have to extracted. This function does the job of extracting 
	the codes and descriptions. */
	put 'function getCodeDesc(prod_val,prod_code,prod_desc) {';
	put '	var len=prod_val.length';
	put '	var indx=prod_val.indexOf(":")';
	put '	var code_end=indx-1';
	put '	var desc_st=indx+1';
	put '	var desc_len=len-desc_st';
	put '	var code=prod_val.substr(0,code_end)';
	put '	var desc=prod_val.substr(desc_st,desc_len)';
	put '	prod_code.value=code';
	put '	prod_desc.value=desc';
	put '}';

	/* When the radio button for a model type is clicked, this function is called to
	set the model_type_code and model_type_desc. And when the model type code is set, 
	the prod_type_code, prod_type_desc and include_exp_mdl values are reset. */
/*	put 'function setType(val) {';*/
/*		put 'getCodeDesc(val, form1.model_type_code, form1.model_type_desc)';*/
/*		put 'form1.prod_type_code.value=""';*/
/*		put 'form1.prod_type_desc.value=""';*/
/*		put 'form1.product.selectedIndex=0';*/
/*		put 'form1.exp_mdl.checked=false';*/
/*		put 'form1.include_exp_mdl.value="N"';*/
/*		put 'form1.submit();';*/
/*	put '}';*/
	put 'function setType(mdl_type){';
	put '	getCodeDesc(mdl_type, form1.model_type_code, form1.model_type_desc)';
	put '	form1.prod_type_code.value=""';
	put '	form1.prod_type_desc.value=""';
	put '	form1.exp_mdl.checked=false';
	put '	form1.include_exp_mdl.value="N"';
	put '	for(i = document.form1.product.length - 1; i > 0; i--)';
	put '		document.form1.product.options[i] = null;';
	put '	var j = 1';
	put '	for(i = 1; i <= ModelProdArray.length; i++){';
	put '		if(ModelProdArray[i-1].model.replace(/ /,"") == form1.model_type_code.value){';
	put '			document.form1.product.options[j] = new Option(ModelProdArray[i-1].product_desc, ModelProdArray[i-1].product+":"+ModelProdArray[i-1].product_desc);';
	put '			j++';
	put '		}';
	put '	}';
	put '}';

	/* When the product type for a model is selected, this function is called to set 
	the values of prod_type_code and prod_type_desc and the value for include_exp_mdl 
	is reset. */
	put 'function setCode() {';
	put '	var indx=form1.product.selectedIndex';
	put '	if (indx!=0) {';
	put '		getCodeDesc(form1.product.options[indx].value, form1.prod_type_code, form1.prod_type_desc)';
	put '	}';
	put '	else {';
	put '		form1.prod_type_code.value=""';
	put '		form1.prod_type_desc.value=""';
	put '	}';
	put '	form1.exp_mdl.checked=false';
	put '	form1.include_exp_mdl.value="N"';
	put '}';

	/* When the include_exp_mdl for a model is selected, this function is called to set 
	the value of include_exp_mdl. */
	put 'function setMdl() {';
	put '	if (form1.exp_mdl.checked==true) ';
	put '		form1.include_exp_mdl.value="Y"';
	put '	else';
	put '		form1.include_exp_mdl.value="N"';
	put '}';

	/* This function validates that values exist for all the output paremeters before the 
	page is submitted. */
	put 'function Onsubmit(){';
	put '	if( (form1.prod_type_desc.value == '''') || (form1.prod_type_desc.value == '' '') || '@;
	put '(form1.prod_type_code.value == '''') || (form1.prod_type_code.value == '' '') )';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.alert_sel_prod_type.1, noquote))"@;
	put '");';
	put '	else if( (form1.model_type_desc.value == '''') || (form1.model_type_desc.value == '' '') || '@;
	put '(form1.model_type_code.value == '''') || (form1.model_type_code.value == '' '') )';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.alert_sel_model_type.1, noquote))"@;
	put '");';
	put '	else if( (form1.include_exp_mdl.value == '''') || (form1.include_exp_mdl.value == '' '') )';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.alert_sel_includ_exp_model.1, noquote))"@;
	put '");';
	put '	else{';
	put "		form1._program.value=&CS_MDL_LVL_DB";
	put '		form1.submit();';
	put '	}';
	put '}';

	put '//-->';
	put	'</script> ';
	put '</head>';

	put '<body>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	put '<input type="hidden" name="_program" VALUE=';
	put "&CS_MON_MDL";
	put '>';
	prod_type_desc=symget("prod_type_desc");
	x='<input type="hidden" name="prod_type_desc" value="'||strip(prod_type_desc)||'">';
	put x;
	prod_type_code=symget("prod_type_code");
	x='<input type="hidden" name="prod_type_code" value="'||strip(prod_type_code)||'">';
	put x;
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';

	put '  <table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '    <tr>';
	put '      <td align="left">';
	put '        <table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '          <tr>';
	put '            <td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '  <tr>';

	/* Navigational Links */
	put '    <td><span class="BreadCrumb"><a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.link_reporting.1, noquote))"@;
	put '</a> &gt; </span><span class="BreadCrumb">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.link_monitoring_model.1, noquote))"@;
	put '</span></td>';
	put '    <td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
	put '  </tr></table>';

	/* Main Body */
	put '            <H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.link_monitoring_model.1, noquote))"@;
	put '</H2></td>';
	put '          </tr>';
	put '          <tr>';
	put '            <td valign="top">';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &PD_APP_MODEL @;
	put ' :'@;
	desc=put(&PD_APP_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &PD_APP_MODEL then 
		put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.drp_dwn_model_risk_bsd_approval.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &PD_ONG_MODEL @;
	put ' :'@;
	desc=put(&PD_ONG_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &PD_ONG_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.drp_dwn_model_ong_risk_bsd_approval.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &LGD_MODEL @;
	put ' :'@;
	desc=put(&LGD_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &LGD_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.drp_dwn_model_for_lgd.1, noquote))"@;
	put '</p>';
	put '              <p class="LabelFont">';
	put '                <input name="radio" type="radio" value="'@;
	put &CCF_MODEL @;
	put ' :'@;
	desc=put(&CCF_MODEL,$modtype.);
	put desc @;
	put '"'@;
	if "&model_type_code" = &CCF_MODEL then put 'checked=checked '@;
	put 'onClick="javascript:setType(this.value)">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.drp_dwn_model_for_ccf.1, noquote))"@;
	put'</p>';
	put '              <p class="LabelFont">&nbsp;</p>';
	put '              <p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.drp_dwn_nm_model_for_prd_type.1, noquote))"@;
	put '                  <select id="product" size="1" width="30" style="width: 50mm" onChange="javascript:setCode()">';
/*	put '<option value="None">None</option>';*/
run;

/* Populate the Product dropdown depending on the selection of the Model */
/*data _null_;*/
/*	set work.products end=last;*/
/*	file _webout&webout_options;*/
/*	put '<option value="'@;*/
/*	put model_product_type_cd@;*/
/*	put ':';*/
/*	put model_prod_type_desc@;*/
/*	put '" ' @;*/
/*	if "&prod_type_code" = model_product_type_cd then put 'selected';*/
/*	put '>'@;*/
/*	put model_prod_type_desc@;*/
/*	put '</option>';*/
/*run;*/

/* End the HTML */
data _null_;
	file _webout&webout_options;
	put '                  </select>';
	put '			   </p>';
	put '              <p class="LabelFont">&nbsp;</p>';
	put '              <p class="LabelFont">';
	put '                <input type="checkbox" name="exp_mdl" value="checkbox" onClick="javascript:setMdl()" '@;
	if "&include_exp_mdl" = "Y" then put 'checked=true' @;
	put '>'@;
	 /*I18N-scnjih-20080421-1304*/
/*	put 'Include expired Models'@;*/
	put  "%sysfunc(sasmsg(smd_ds.bismsg,mon_models.sas.1, noquote))"@;
	 /*I18N-scnjih-20080421-1304*/
	put '</p>';
	put '              </p>';
	put '              <p class="LabelFont">';
	put '              <p class="LabelFont">&nbsp;</p>';
	put '          </tr>';
	put '          <tr bgcolor="#FAF8ED">';
	put '            <td bgcolor="#F1EACB">&nbsp;&nbsp;';
	put '                <INPUT type=button class=mmhide_btn onClick="javascript:Onsubmit()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.mon_models.button_ok.1, noquote))"@;
	put '">';
	put '            </td>';
	put '          </tr>';
	put '        </table>';
	put '      </td>';
	put '    </tr>';
	put '</table>';

	/* Initialize combobox for Product Name */
	put '<script>';
	put '<!-- ';
	put 'init();';
/*	put 'alert("'@;*/
/*	put "&model_type_code"@;*/
/*	put '")';*/
	if "&model_type_code" ne "" or "&model_type_code" ne " " then do;
		put 'initProd("'@;
		put "&model_type_code"@;
		put '");';
		put 'initExp()';
	end;
 	put '//--> ';	
	put '</script>';
	put '</body>';
	put '</html>';
run;
