/********************************************************************************************
       Module:  select_models (Model level Dashboard Screen for model monitoring reports)
 
     Function:  This stored process creates the HTML screen which is used to view the traffic
				lighting for all the MODELS of a particular MODEL TYPE (PD Approvals,
				PD Ongoing, LGD, CCF), PRODUCT TYPE (Credit Card, Mortgage, Loan, Core etc.)
				selected in the mon_models stored process depending whether the expired
				models are included or not.

				In this the user can select two MODELS for comparison, by clicking the
				checkbox for the particular model, and a period for which the user wishes
				to view the reports, by clicking on the link provided on each period,
				for generating the measure level dashboard screen for model monitoring
				reports.
				 
      Authors:  BIS Team
         Date:  05 April 2006
          SAS:  9.1
    Called-by:	1. Mon_models stored process
				2. From any model monitoring report screen as part of the links provided on
					the page for navigation.
					
        Calls:  Calls the following Stored Process
				1. test_levels		(when a period is clicked)
				2. Reporting	  	(when Reporting link is clicked)
				3. mon_models     	(when Monitoring Models link is clicked)

				Calls the following Macros
				1. model_traffic macro for generating the traffic lighting for all the
					measures.

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2. Setting default value for mdl_dep (Deployment Status Code).
				3. Access the Star Schema to get the required data for the selected product
					and model type.
				4. Call the model_traffic macro for generating the traffic lighting
					for the given measure.
				5. Assign traffic lighting according to the values of the macro variables
					NO_RED_FOR_RED, NO_YELLOW_FOR_RED, NO_RED_FOR_YELLOW, NO_YELLOW_FOR_YELLOW
					in the bis_customize_para.sas
				6. Create a dataset with the traffic lighting for all the models across time.
				7. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the values
						are easily submitted to the next page. 
					b. Provide javascript functions for the links on top of the page
					c. Provide validation such that atleast one and atmost two models are
						selected.
				
   Parameters: 
			INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										 PD Ongoing, LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for 
										selection of model from the traffic light dashboard.
				score_dt           	:   By default its the highest score date. When user 
										clicks on the arrow the score_dt decreases or 
										increases by 1 accordingly as left or right arrow is
										clicked.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        include_exp_mdl		:   Information to include the expired models for 
										selection of model from the traffic light dashboard.
				score_dt           	:   By default its the highest score date. When user 
										clicks on the arrow the score_dt decreases or 
										increases by 1 accordingly as left or right arrow is
										clicked.
				model1				:	The selected model (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.

*********************************************************************************************/
/*This code is Internationalized*/
/* Global input parameters that are passed from the calling program*/
%global prod_type_desc prod_type_code model_type_desc model_type_code include_exp_mdl 
		score_dt high_score_dt format_name;

/* Trimming extra spaces from all the input parameters*/
	%let prod_type_desc=&prod_type_desc;
	%let prod_type_code=&prod_type_code;
	%let model_type_desc=&model_type_desc;
	%let model_type_code=&model_type_code;
	%let include_exp_mdl=&include_exp_mdl;
	%let high_score_dt=&score_dt;
    %let high_score_dt=&score_dt;

/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
  
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)

/* Setting value for mdl_dep (Deployment status code) depending whether the user has included
	expired models or not */
%let mdl_dep=;
data _NULL_;
	if kupcase("&include_exp_mdl")="Y" then
		call symput('mdl_dep','DEPLOYMENT_STATUS_CD in (&PRD_MODEL_DEPLOYMENT,&DEV_MODEL_DEPLOYMENT,&EXP_MODEL_DEPLOYMENT)');
	else
		call symput('mdl_dep','DEPLOYMENT_STATUS_CD in (&PRD_MODEL_DEPLOYMENT,&DEV_MODEL_DEPLOYMENT)');
run;
/*******************/
/* Subsetting the measure_dim by the model_type_code */
proc sql noprint;
	create table work.measure_rep as
	select * from dim.measure_dim
	where kupcase(level_desc) ne kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.level_desc_other_reports.1, noquote))")
		and kupcase(model_type_cd)=kupcase("&model_type_code")
	order by measure_nm;
quit;
/*******************/

/* Creating dataset containing all the required data depending on the product and model_type
	selected */
proc sql noprint;
	create table work.measure_out AS
	SELECT ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD,
		ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD,
		measure_rep.MEASURE_NM, measure_rep.SEQ_NO,
		measure_rep.LEVEL_DESC, MODEL_MEASURE_FACT.SCORE_TIME_SK,
		MODEL_MEASURE_FACT.MEASURE_SK, MODEL_MEASURE_FACT.MEASURE_VALUE,
		MODEL_MEASURE_FACT.MODEL_SK, MODEL_MEASURE_FACT.DEV_FLG,
		TIME_DIM.CAL_MONTH_LAST_DT AS CAL_MON_LAST_DT,
		TIME_DIM.CAL_MONTH_NO,
		ANALYTICAL_MODEL_DIM.DEPLOYMENT_STATUS_CD,
		ANALYTICAL_MODEL_DIM.MODEL_NM, ANALYTICAL_MODEL_DIM.TARGET_PERIOD_MTHS_CNT
	FROM FACT.MODEL_MEASURE_FACT
		INNER JOIN work.measure_rep
		ON (MODEL_MEASURE_FACT.MEASURE_SK = measure_rep.MEASURE_SK)
		INNER JOIN DIM.ANALYTICAL_MODEL_DIM
		ON (MODEL_MEASURE_FACT.MODEL_SK = ANALYTICAL_MODEL_DIM.MODEL_SK)
		INNER JOIN DIM.TIME_DIM
		ON (MODEL_MEASURE_FACT.SCORE_TIME_SK = TIME_DIM.TIME_SK)
		where kupcase(ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD)=kupcase("&prod_type_code")
			and kupcase(MODEL_MEASURE_FACT.DEV_FLG)="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.dev_flag_n.1, noquote))"
			and kupcase(ANALYTICAL_MODEL_DIM.MODEL_TYPE_CD)=kupcase("&model_type_code")
			and &mdl_dep
			and ANALYTICAL_MODEL_DIM.VALID_END_DTTM=&VALID_HIGH_DTTM;
quit;



/*******************/


%let periodicity = .; 
%macro time_period;
	%let model_code = %quote(%'&model_type_code%');
	%let product_code = %quote(%'&prod_type_code%'); 
	%if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&PD_APP_MODEL.)) %then %do;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
			%let periodicity = &PDA_MTG_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
			%let periodicity = &PDA_LON_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
			%let periodicity = &PDA_COR_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
			%let periodicity = &PDA_CCD_PERIOD;
		%end;
	%end;
	%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&PD_ONG_MODEL.)) %then %do;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
			%let periodicity = &PDO_MTG_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
			%let periodicity = &PDO_LON_PERIOD; 
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
			%let periodicity = &PDO_COR_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
			%let periodicity = &PDO_CCD_PERIOD;
		%end;
	%end;
	%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&LGD_MODEL.)) %then %do;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&MTG_PRD_TYPE.)) %then %do;
			%let periodicity = &LGD_MTG_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&LON_PRD_TYPE.)) %then %do;
			%let periodicity = &LGD_LON_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&COR_PRD_TYPE.)) %then %do;
			%let periodicity = &LGD_COR_PERIOD;
		%end;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
			%let periodicity = &LGD_CCD_PERIOD;
		%end;
	%end;
	%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&CCF_MODEL.)) %then %do;
		%if %sysfunc(kupcase(&product_code)) eq %sysfunc(kupcase(&CCD_PRD_TYPE.)) %then %do;
			%let periodicity = &CCF_CCD_PERIOD;
		%end;
	%end;

	%if &periodicity gt 12 %then %do; 
		%let periodicity=12;
	%end;

	data work.measure_out;
		set work.measure_out;
		where cal_month_no in (
			%do i = 1 %to %eval(12/&periodicity);
				%if &i eq %eval(12/&periodicity) %then %eval(&periodicity*&i);
				%else %eval(&periodicity*&i),;
			%end;
		);
	run;
%mend time_period;
%time_period;



/* Calls the model_traffic macro to get the traffic lighting for the data provided
	The following parameters are passed to this macro
			1. data1	: input dataset containing the columns measure_value and measure_nm
			2. model_cd	: MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF)
	This macro adds one more column named color to the dataset passed which contains
	values ( Green, Red, Yellow, White) depending on the bounds(for red and green) provided
	in the measure_dim dataset */

%model_traffic(data1=work.measure_out,model_cd=&model_type_code,product_type_code=&prod_type_code);
/*******************/

%macro traffic_light(msr_nm=, red_for_red=., yellow_for_red=., red_for_yellow=.,
		 yellow_for_yellow=.);

	%if &msr_nm ne %then %do;
		proc sql noprint;
			create table work.Period_color as
			select * from work.measure_out
			where kupcase(measure_nm) = kupcase(&msr_nm);
		quit;
	%end;

	%else %do;
		proc sort data=work.measure_out ;
			by Model_sk score_time_sk;
		run;

		/* Calculates the number of green, red and yellow color for each model_sk across time */
		data work.Time_Color(keep=model_sk score_time_sk model_nm model_product_type_cd
									model_type_cd deployment_status_cd Green Red Yellow);
			set work.measure_out;
			by Model_sk score_time_sk;
			retain Green Yellow Red;
			if first.score_time_sk then do;
				Green=0;
				Red=0;
				Yellow=0;
			end;
			if color="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_green.1, noquote))" then
				Green+1;
			else if color="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_red.1, noquote))" then
				Red+1;
			else if color="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_yellow.1, noquote))" then
				Yellow+1;
			if last.score_time_sk;
		run;
		/*******************/

		/* Assigns traffic lighting according to the values of the macro variables
			red_for_red, yellow_for_red, red_for_yellow, yellow_for_yellow
			in the bis_customize_para.sas, where the macro variables represent:
			red_for_red	  	 : No of statistics that should be red to have a red traffic 
										light in the model dashboard 
			yellow_for_red	 : No of statistics that should be yellow to have a red traffic 
										light in the model dashboard 
			red_for_yellow	 : No of statistics that should be red to have a yellow traffic 
										light in the model dashboard 
			yellow_for_yellow: No of statistics that should be yellow to have a yellow traffic  
										light in the model dashboard */

		data work.Period_color(drop=Green Yellow Red);
			set work.Time_Color;
			length color $ 6.;
			if Red = 0 and Yellow = 0 and Green = 0 then
				color="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_white.1, noquote))";
			else if Red >= &red_for_red. or Yellow >= &yellow_for_red. then
				color="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_red.1, noquote))";
			else if Red >= &red_for_yellow. or Yellow >= &yellow_for_yellow. then
				color="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_yellow.1, noquote))";
			else color="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_green.1, noquote))";
		run;
	%end;
%mend traffic_light;

%macro select_traffic();
	%let model_code=%quote(%'&model_type_code%');
	%if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&PD_APP_MODEL.))
				or %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&PD_ONG_MODEL.)) %then
	%do;
		%if %sysfunc(kupcase(&CS_MDL_DB_SEL_MSR_PD.)) eq %sysfunc(kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.mesure_flag_y.1, noquote))")) %then %do;
			%traffic_light(msr_nm=&CS_MSR_NAME_PD.);
		%end;
		%else %do;
			%traffic_light(red_for_red=&CS_NO_RED_FOR_RED_PD.,
						yellow_for_red=&CS_NO_YELLOW_FOR_RED_PD.,
						red_for_yellow=&CS_NO_RED_FOR_YELLOW_PD.,
						yellow_for_yellow=&CS_NO_YELLOW_FOR_YELLOW_PD.);
		%end;
	%end;

	%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&LGD_MODEL.))
				or %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&LGD_APP_MODEL.)) %then
	%do;
		%if %sysfunc(kupcase(&CS_MDL_DB_SEL_MSR_LGD.)) eq %sysfunc(kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.mesure_flag_y.1, noquote))")) %then %do;
			%traffic_light(msr_nm=&CS_MSR_NAME_LGD.);
		%end;
		%else %do;
			%traffic_light(red_for_red=&CS_NO_RED_FOR_RED_LGD.,
						yellow_for_red=&CS_NO_YELLOW_FOR_RED_LGD.,
						red_for_yellow=&CS_NO_RED_FOR_YELLOW_LGD.,
						yellow_for_yellow=&CS_NO_YELLOW_FOR_YELLOW_LGD.);
		%end;
	%end;

	%else %if %sysfunc(kupcase(&model_code)) eq %sysfunc(kupcase(&CCF_MODEL.)) %then 
	%do;
		%if %sysfunc(kupcase(&CS_MDL_DB_SEL_MSR_CCF.)) eq %sysfunc(kupcase("%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.mesure_flag_y.1, noquote))")) %then %do;
			%traffic_light(msr_nm=&CS_MSR_NAME_CCF.);
		%end;
		%else %do;
			%traffic_light(red_for_red=&CS_NO_RED_FOR_RED_CCF.,
						yellow_for_red=&CS_NO_YELLOW_FOR_RED_CCF.,
						red_for_yellow=&CS_NO_RED_FOR_YELLOW_CCF.,
						yellow_for_yellow=&CS_NO_YELLOW_FOR_YELLOW_CCF.);
		%end;
	%end;
%mend select_traffic;

%select_traffic();

/* Selects the max and min date for which data is available for the given product
	and stores the information in score_high and score_low macro variable respectively */
%let score_high=.;
%let score_low=.;
%let cnt_time=.;

proc sql noprint;
	select max(CAL_MON_LAST_DT), min(CAL_MON_LAST_DT) into :score_high,:score_low
	from work.measure_out;
quit;
/*******************/
 
/* Calculates the number of months for which data is available for the given product
	and stores the information in cnt_time macro variable*/
data _NULL_;

	no_of_months=intck("month&periodicity",&score_low,&score_high);
	call symput('cnt_time',no_of_months); 
run;
/*******************/

/* Setting default value for high_score_dt (highest score date for the selected product)
	and cnt_limit (number of periods to be displayed on screen)*/
%let cnt_limit=.;
data _NULL_;
	if ktrim(kleft("&high_score_dt"))="" then do;
		sum_score=sum(&cnt_time,1);
		call symput('high_score_dt',sum_score);
		
	end; 
	/*Calculates the number of periods to be displayed on the html screen.
		If the number of period is greater than 12, then data for 12 periods are displayed
		else data for all the periods are displayed */
	if &cnt_time lt 12 then 
		call symput('cnt_limit',&cnt_time);
	else
		call symput('cnt_limit',11);
run;
/*******************/

/* Generating all the periods from the highest score date till the lowest score date */
data work.Period_Time(keep=period);
	set dim.Time_dim;
	if CAL_MONTH_LAST_DT=&score_high then do;
		format period date9.;
		date=CAL_MONTH_LAST_DT;
		period=date;
		output;
		do i=1 to &cnt_time;
			date=intnx('month',date,-&periodicity,'e');
			period=date;
			output;
		end;
	end;
run;
/*******************/

proc sort data=work.Period_Time ;
	by period;
run;
/*******************/

proc sort data=dim.Time_dim out=work.Time_dim(rename=(CAL_MONTH_LAST_DT=CAL_MON_LAST_DT)) ;
	by CAL_MONTH_LAST_DT;
run;
/*******************/

/* To get the respective score_time_sk for the periods generated above */
data work.Period_Time;
	merge work.Period_Time(rename=(period=CAL_MON_LAST_DT) in=inPeriod)
			work.Time_dim(rename=(time_sk=score_time_sk) in=inTime);
	by CAL_MON_LAST_DT;
	if inPeriod and inTime;
	Period=put(CAL_MON_LAST_DT,&CS_TIME_PER_FMT.);
	keep period score_time_sk CAL_MON_LAST_DT;
run;
/*******************/

/* Creating a dataset having distinct model_sk and the required columns */
proc sql noprint;
	create table work.temp_model as
	select distinct(model_sk), model_type_cd, model_product_type_cd, model_nm,
				deployment_status_cd, target_period_mths_cnt
	from work.measure_out;
quit;
/*******************/

/*data work.temp_model;*/
/*	set work.temp_model;*/
/*	if Model_sk ne '';*/
/*run;*/
/*******************/

/* Creating a dataset containing data for the distinct model_sk
	for each period generated above */
proc sql noprint;
	create table work.model_period as
	select model_sk, model_type_cd, model_product_type_cd, model_nm, deployment_status_cd,
			score_time_sk, period, target_period_mths_cnt
	from work.temp_model, work.period_time;
quit;
/*******************/

proc sort data=work.model_period ;
	by score_time_sk model_sk;
run;
/*******************/

proc sort data=work.Period_color ;
	by score_time_sk model_sk;
run;
/*******************/

/* Creating a dataset with the traffic lighting for all the models for all time_sk
	For the model_sk and score_time_sk for which color is not assigned,
	White color is assigned */
data work.Period_Color;
	merge work.Period_Color(in=perc) work.model_period(in=mper);
	by score_time_sk model_sk;
	if mper and not perc then color ="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_white.1, noquote))";
run;
/*******************/

proc sort data=work.Period_color ;
	by model_sk model_nm;
run;
/*******************/

/* Code to transpose the Period_color dataset created above so that the traffic lighting is 
	available for each model_sk across time.
	Here color for the 1st period is given as color1, for 2nd period as color2 and so on*/
proc transpose data=work.Period_color prefix=color out=work.trans_period let;
	by model_sk model_nm deployment_status_cd target_period_mths_cnt;
	var color;
run;
/*******************/

/*%let cnt_prod=.;*/
/*proc sql noprint;*/
/*select Count(*) into :cnt_prod from work.Period_color*/
/*where upcase(model_product_type_cd)=upcase("&prod_type_code")*/
/*	and upcase(model_type_cd)=upcase("&model_type_code");*/
/*run;*/
/*quit;*/
/*******************/

proc sort data=work.trans_period ;
by model_sk;
run;
/*******************/

/* Code to get the lower and higher score date to be displayed with the arrows to indicate
	the range of months shown on screen */
%let low=.;
%let high=.; 
data _NULL_;
	if &cnt_time eq . then do;
		call symput('low',0);
		call symput('high',0);
	end;
	else do;
		count=sum(&high_score_dt,-&cnt_limit);
		call symput('low',count);
		call symput('high',&high_score_dt);	
	end;
run;
%let low=%sysfunc(ktrim(%sysfunc(kleft(&low))));
%let high=%sysfunc(ktrim(%sysfunc(kleft(&high))));
/*******************/
 

/* Start HTML Screen*/
data _NULL_;
file _webout&webout_options;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ' @;
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.title_monitoring.1, noquote))"@;
	if "&model_type_code"=&PD_APP_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_appl_pd.1, noquote))"@;
	else if "&model_type_code"=&PD_ONG_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_ong_pd.1, noquote))"@;
	else if "&model_type_code"=&LGD_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_lgd.1, noquote))"@;
	else if "&model_type_code"=&CCF_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_ccf.1, noquote))"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.title_model.1, noquote))"@;
	put '</title> ';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {color: #990000} ';
	put '--> ';
	put '</style> ';
	put '<script>';
	put '<!-- ';

/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form2._program.value=&CS_REPORTING";
		put 'form2.submit()';
	put '}';

/* Calls the mon_models stored process if link is clicked */
	put 'function Link2() {';
		put "form2._program.value=&CS_MON_MDL";
		put 'form2.submit()';
	put '}';

/* Checks whether two models are selected or not (atleast one model should be selected).
	 This function is called by the onClick event when any of the link(on period)
	 is clicked */
	put 'function validate_select(link_id,time_sk){';
	/*	if(&cnt_prod=0) then do;*/
	/*		put 'alert("No models available for comparison");';*/
	/*		put "form2._program.value=&CS_MON_MDL";*/
	/*		put 'document.form2.submit();';*/
	/*		put 'return;';*/
	/*	end;*/
		put 'if (form2.model1.value=="" && form2.model2.value==""){';
			put 'alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.alert_choose_models_for_comp.1, noquote))"@;
			put '");';
			put "form2._program.value=&CS_MDL_LVL_DB";
			put 'document.form2.submit();';
		put '}';
		put 'else{';
			put 'form2.period.value=link_id';
			put 'form2.time_key.value=time_sk';
			put "form2._program.value=&CS_MSR_LVL_DB";
			put 'document.form2.submit();';
		put '}';
	put '}';

/* Function to keep the models checked in a hidden textbox, so that the model_nm and model_sk
	selected is passed to the called stored process(test_levels). This function is called
	when any of the checkboxes are checked or unchecked.
	Atleast one and at the most two models can be selected */
	put 'function validate_check(check,model_k){';
		put 'if (check.checked == true){';
			put 'if (form2.model1.value==""){';
				put 'form2.model1.value=check.value;';
				put 'form2.model1_key.value=model_k;';
			put '}';
			put 'else if (form2.model2.value==""){';
				put 'form2.model2.value=check.value;';
				put 'form2.model2_key.value=model_k;';
			put '}';
			put 'else {';
				put 'alert("'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.alert_only_two_model.1, noquote))"@;
				put '");';
				put 'check.checked=false;';
			put '}';
		put '}';
		put 'else{';
			put 'if (form2.model1.value==check.value){';
				put 'form2.model1.value="";';
				put 'form2.model1_key.value="";';
			put '}';
			put	'else if (form2.model2.value==check.value){';
				put 'form2.model2_key.value="";';
				put 'form2.model2.value="";';
			put '}';
		put '}';
	put '}';

/* Function to change the range of months displayed with the arrows. This function is
	called when the arrow on the right side is clicked */
	put 'function change_right_arrow(){';
		x=sum(&high_score_dt,1);
		y=sum(&cnt_time,1);
		if x le y then do;
			put 'form2.score_dt.value="'@;
			put x @;
			put '"';
		end;
		else do;
			put 'alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.alert_no_more_data_available.1, noquote))"@;
			put'")';
		end;
		put "form2._program.value=&CS_MDL_LVL_DB";
		put 'form2.submit()';
	put '}';

/* Function to change the range of months displayed with the arrows. This function is
	called when the arrow on the left side is clicked */
	put 'function change_left_arrow(){';
		x=sum(&high_score_dt,-1);
		if x > &cnt_limit then do;
			put 'form2.score_dt.value="'@;
			put x @;
			put '"';
		end;
		else do;
			put 'alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.alert_no_more_data_available.1, noquote))"@;
			put '")';
		end;
		put "form2._program.value=&CS_MDL_LVL_DB";
		put 'form2.submit()';
	put '}';

	put '//--> ';
	put '</script>';
	put '</head> ';
	put '<body>';
	put '<form name="form2" action="/SASStoredProcess/do" method="post">';

/* Hidden textboxes to hold the values for the program name and the output paremeters 
	to pass the values to the next Stored Process called */
	put '<input type="hidden" name="_program">';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';

	score_dt=symget("score_dt");
	put '<input type="hidden" name="score_dt" value="' @;
	put score_dt;
	put '">';

	put '<input type="hidden" name="model1">';
	put '<input type="hidden" name="model1_key">';
	put '<input type="hidden" name="model2">';
	put '<input type="hidden" name="model2_key">';
	put '<input type="hidden" name="period">';
	put '<input type="hidden" name="time_key">';
/*********/

	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '<tr> ';
	put '<td align="left"> ';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0"> ';
	put '<tr> ';

/*Links on Top of the HTML Page*/
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '<tr> ';
	put '<td><span class="BreadCrumb">';
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.link_reporting.1, noquote))"@;
	put '</a> &gt; ';
	put '<a href="javascript:Link2()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.link_monitoring_model.1, noquote))"@;
	put '</a> &gt; ';
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.link_select_model.1, noquote))"@;
	put '</span></td>';
/*********/

/*SAS Banner*/
	put '<td width="215"><div align="right">';
	put '<img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td> ';
/*********/

	put '</tr> ';
	put '</table><H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.title_monitoring.1, noquote))"@;
	if "&model_type_code"=&PD_APP_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_appl_pd.1, noquote))"@;
	else if "&model_type_code"=&PD_ONG_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_ong_pd.1, noquote))"@;
	else if "&model_type_code"=&LGD_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_lgd.1, noquote))"@;
	else if "&model_type_code"=&CCF_MODEL then
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_ccf.1, noquote))"@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.title_model.1, noquote))"@;
	put'</H2></td> ';
	put '</tr> ';
run;

/* Code to display the periods */
data _NULL_;
	file _webout&webout_options;
	set work.Period_Time end=last;
	if _N_=1 then do;
		put '<tr> ';
		put '<td align="left"> ';
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_model_type.1, noquote))"@;
		put "&model_type_desc" @;
		put '</p> ';
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_product_type.1, noquote))"@;
		put "&prod_type_desc";
		put '</p> ';

	/*Note for selecting two models*/
		put '<p>&nbsp;</p><p class=NoteFont>'@;
		put '<strong>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.Note_Note.1, noquote))"@;
		put '</strong><br>';
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.Note_sel_two_model_p1.1, noquote))"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.Note_sel_two_model_p2.1, noquote))"@;
		put '<br>';
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.Note_model_nm_in_red.1, noquote))"@;
		put '<br>';
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.Note_reporting_period.1, noquote))"@;
		put '</p>';
	/*********/

		put '<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#7F9DB9" class="tableborder"> ';
		put '<tr> ';
		put '<td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0"> ';
		put '<tr bgcolor="#FFFFFF"> ';
		put '<td class="HZtableborder">&nbsp;</td> ';
		put '<td class="HZtableborder">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_model_name.1, noquote))"@;
		put '</td> ';
	end;
	limit=sum(&cnt_limit,1);
	score=sum(&high_score_dt,-limit);
	if _N_ > score and _N_ <= &high_score_dt then do;
		put '<td class="HZtableborder"> <div align="center"><span class="textlink">';
		put '<a id="' @;
		put Period @;
		put '" href="javascript:validate_select('''@;
		put Period @;
		put ''','@;
		put score_time_sk @;
		put ')">' @;
/*I18N-scnhuh-20080425-1928*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put Period @;*/
		Period_WEBUI=put(input(Period,&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080425-1928*/		
		put '</a>';
		put '</span></div></td>';
	end;
	if last then do;
		put '</tr> ';
	end;
run;
/*******************/ 
/* Code to display the model names with the checkboxes and the traffic lighting */
data _NULL_;
	file _webout&webout_options;
	set work.trans_period end=last;
	by model_sk;
	
	limit=sum(&cnt_limit,1);

	if &low gt 0 then do;
		array period(*) $ color&low-color&high;
		if first.model_sk then do;
			if mod(_N_,2)=0 then do;
				put '<tr bgcolor="#F4F4F2"> ';
				put '<td bgcolor="#F4F4F2" class="Font12px"> ';
			end;
			else do;
				put '<tr bgcolor="#FFFFFF"> ';
				put '<td class="Font12px"> ';
			end;
			put '<input type="checkbox" name="check_box" ' @;
			put 'value="' @;
			put model_nm @;
			put '" onClick="validate_check(this,'@;
			put model_sk @;
			put ')"> ';
			put '</td> ';
			if deployment_status_cd in (&PRD_MODEL_DEPLOYMENT) then do;
				put '<td class="verttebleborder style2">' @;
				put Model_nm @;
				put '('@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_outcome_period.1, noquote))"@;
				put target_period_mths_cnt @;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_months.1, noquote))"@;
				put ')' @;
				put '</td> ';
			end;
			else do;
				put '<td class="verttebleborder">' @;
				put Model_nm @;
				put '('@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_outcome_period.1, noquote))"@;
				put target_period_mths_cnt @;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_months.1, noquote))"@;
				put ')' @;
				put '</td> ';
			end;

			do i=1 to limit;
				put '<td class="verttebleborder"><div align="center">';
				put '<img src="/SASCSReports/images/'@;
				if period(i)="%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.color_white.1, noquote))" then do;
					put 'spacer' @;
				end;
				else do;
					put 'Sphere'@;
					put period(i);
				end;
				put '.gif" width="16" height="16" border="0"></div></td> ';
			end;
			put '</tr> ';
		end;
	end;
	if last then do;
		put '</table></td> ';
		put '</tr> ';
		put '</table> ';
		put '<table width="100%"  border="0" cellspacing="3" cellpadding="0"> ';
		put '<tr> ';
		put '<td>';
	/* Code for displaying the arrows*/
		put '<a href="javascript:change_left_arrow()">';
		put '<img name="up" src="/SASCSReports/images/arrow-left-default.gif" width="16" height="16" border="0"></a>';
		put '<span class="LabelFont">'@;
			 /*I18N-scnjih-20080421-1444*/
/*		put 'Months '@;*/
/*		put "%sysfunc(sasmsg(smd_ds.bismsg,select_models.sas.1, noquote))"@;*/
		 /*I18N-scnjih-20080421-1444*/
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.column_months.1, noquote))  " ;
		put "&low";
		put ' - '@;
		put "&high" @;
		 /*I18N-scnjih-20080421-1444*/
/*		put ' of '@;*/
		put '&nbsp;'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,select_models.sas.2, noquote))" @;
		put '&nbsp;'@;
	/*I18N-scnjih-20080421-1444*/
		if &cnt_time >= 0 then
			sum_score=sum(&cnt_time,1);
		else sum_score=0;
		put sum_score @;
		put '<a href="javascript:change_right_arrow()">';
		put '<img name="down" src="/SASCSReports/images/arrow-right-default.gif" width="16" height="16" border="0">';
		put '</a></span> ';
	/*********/

		put '</td></tr> ';
		put '</table> ';

		put '</td></tr> ';
		put '<tr> ';
		put '<td align="left"> ';
		put '<p>&nbsp;</p> ';
		put '</td> ';
		put '</tr> ';
		put '</table> ';
		put '</td> ';
		put '</tr> ';
		put '<tr> ';
		put '<td height="32" bgcolor="#F1EACB">&nbsp; ';
		put '</td> ';
		put '</tr> ';
		put '</table> ';
		put '</form> ';
		put '</body> ';
		put '</html> ';
	end;
run;
