/******************************************************************************************************
Module:  Cumulative Accuracy Profile report (CAP) for LGD.

Function:  This stored process generates an HTML report displaying Accuracy Ration (Gini)((LGD)) statistics, the CAP(CCF) graph
and the Accuracy Ratio(Gini)((LGD)) overtime graph.

Authors:  BIS Team
Date:  05 April 2006
SAS:  9.1
Called-by:	Stored Process test_levels
  
Calls:  Calls the following Stored Process    
 1.Reporting	  	(when Reporting link is clicked)
 2.mon_models     	(when Monitoring Models link is clicked)
 3.select_models    (when Select Models link is clicked) 
 4.test_levels    	(when Select Statistic link is clicked)
 5.cap_lgd			(when the reset button is clicked)
 6.filtering_criteria(when the Filter/Re-Pool button is clicked)

Calls the following Macros
 1. graph_options macro sets all the graph options and selects the colors
     to be used when rendering the graph.
 2. generate_feed macro for obtaining the required feed.
 3. feed_measure macro which makes data for the overtime graphs
 4. ar_stat macro for preparing data for plotting the graphs.
 5. conf_interval macro which is used to determine the confidence interval. 

Datasets used:  No input datasets required for processing of the stored process

Logic:  
1. All inputs to the stored process are accepted as global parameters. 
2. Standards
 a. 	Naming of data set which are input to and output from macro using
         <prod_type_code><sel_model_key><time_ke> Extension as per requrment  
i.e.		CCD           105          1024     pool
		as CCD1051024pool.
 b. Setting the default values for feed_pd and where_feed to be passed as
     parameter(infilter) to the generating feed macro.
 c.	Naming the graphs using timestamp and two letters for identifying 
     the graph.
3. Set all the graph options and select the colors to be used when rendering
 the graph.
4. Call the macro generate_feed for obtaining the required feed.
5. Check whether the generate_feed macro generated any error.
 If any error is generated then the same report(cap_lgd) is called
 with the default criteria.
6. If there no data, in the case of business filter or dynamic pooling,
 is generated by the generate_feed macro then the same report(cap_lgd)
 is called with the default criteria.
7. Call the ar_stat macro for preparing data for plotting the graphs.
8. Call the conf_interval macro which is used to determine the confidence interval
9. Get the pooling technique.
10. Generate the HTML using streaming webout.
 a. Provide hidden textboxes for all output parameters so that the values 
     are easily submitted to the next page. 
 b. Provide javascript functions for the links on top of the page
     and for edit and reset buttons.

Parameters: 
INPUT 
prod_type_desc		:   Product Type Description (e.g., Credit Card,
                 	Mortgage, Loan, Core)
prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
model_type_desc		:	Analytical Model Type Description 
					(e.g., PD Approvals, PD Ongoing, LGD, CCF)
model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
                 	LGD, CCF)
include_exp_mdl		:   Information to include the expired models for selection of
                 	model from the traffic light dashboard.
statistic           :   Statistic name (Accuracy Ratio (Gini)).
model1				:	The first model if selected (Eg. LGD MODEL 1).		
model1_key			:	The surrogate key for the first selected model.
model2				:	The  second model if  selected. (Eg. LGD MODEL 2)
model2_key			:	The surrogate key for the second selected model.
sel_model			: 	Model selected on the Measure level dashboard screen.
sel_model_key		:	Key of the selected model.
period				:	The selected period (month and year)(Eg DEC05 JAN06).
time_key			:	The surrogate key for selected period.
filter				:	Used for displaying or hiding the modeling values and
                 	overtime graph.
filter_clause		: 	Contains the selected business filter.
pd_score 			:	If null then shown  as DEFAULT stautus.
no_of_quantile      :	The range for dynamic pooling will be decided based on the 
                      quantile.Quantile ranges will be calculated based on the 
                      SCORE/PD/LGD/CCF of the scoring  population for the
                 	selected score period  
range_interval      : 	Dynamic pooling based on the range specified.
                 	E.g. 100, 200 for SCORE and .2, .3 for PD.
prg_name			:	The program name, for calling the report, which is
					picked from program_nm column of dim.measure_dim.
outcome_period		:	The target period in months.
elapsed_time		:	The time elapsed.

OUTPUT
prod_type_desc		:   Product Type Description (e.g., Credit Card,
                 	Mortgage, Loan, Core)
prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
model_type_desc		:	Analytical Model Type Description 
					(e.g., PD Approvals, PD Ongoing, LGD, CCF)
model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals, PD Ongoing,
                 	LGD, CCF)
include_exp_mdl		:   Information to include the expired models for selection of
                 	model from the traffic light dashboard.
statistic           :   Statistic name (Accuracy Ratio (Gini)).
model1				:	The first model if selected (Eg. LGD MODEL 1).		
model1_key			:	The surrogate key for the first selected model.
model2				:	The  second model if  selected. (Eg. LGD MODEL 2)
model2_key			:	The surrogate key for the second selected model.
sel_model			: 	Model selected on the Measure level dashboard screen.
sel_model_key		:	Key of the selected model.
period				:	The selected period (month and year)(Eg DEC05 JAN06).
time_key			:	The surrogate key for selected period.
filter				:	Used for displaying or hiding the modeling values and
                 	overtime graph.
filter_clause		: 	Contains the selected business filter.
pd_score 			:	If null then shown  as DEFAULT stautus.
no_of_quantile      :	The range for dynamic pooling will be decided based on the 
                      quantile.Quantile ranges will be calculated based on the 
                      SCORE/PD/LGD/CCF of the scoring  population for the
                 	selected score period  
range_interval      : 	Dynamic pooling based on the range specified.
                 	E.g. 100, 200 for SCORE and .2, .3 for PD.
called_program		:	Passes the path of the current program(cap_lgd)
prg_name			:	The program name, for calling the report, which is
					picked from program_nm column of dim.measure_dim.
outcome_period		:	The target period in months.
elapsed_time		:	The time elapsed.
 
 ***********************************************************************************************/
goptions reset=all;
options nomprint;
 
/* Global variable declaration */
%global prod_type_desc prod_type_code model_type_desc model_type_code include_exp_mdl
		model1 model1_key model2 model2_key period time_key filter filter_clause
		statistic pd_score range_interval no_of_quantile prg_name outcome_period elapsed_time
		sel_model sel_model_key format_name;

/* Trimming extra spaces from all the input parameters*/


	%let prod_type_desc=&prod_type_desc;
	%let prod_type_code=&prod_type_code;
	%let model_type_desc=&model_type_desc;
	%let model_type_code=&model_type_code;
	%let model1=&model1;
	%let model1_key=&model1_key;
	%let sel_model=&sel_model;
	%let sel_model_key=&sel_model_key;
	%let period=&period;
	%let time_key=&time_key;
	%let statistic=&statistic;
	%let filter=&filter;
	%let filter_clause=&filter_clause;
	%let pd_score=&pd_score;
	%let prg_name=&prg_name;
	%let outcome_period=&outcome_period;
	%let elapsed_time=&elapsed_time;
	%let statistic=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&statistic))))));
/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name

/*Assigning standard names for datasets which are input to and ouput from macro using
		<prod_type_code><sel_model_key><time_key> Extension as per requrment  
	i.e.		COR           106          1030     pool
		as COR1061030pool.*/
%let ot_name=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_ot))));
%let out_lib=;
%debug_lib_path;

%let out_pool=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.pool))));
%let out_account=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.account))));

/*Used in calls to feed measure, data preparation and ar_stat macro*/
%let out_data_prep=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.data_prep))));
%let out_graph_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ar_graph))));
%let out_stat_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ar_stat))));
%let out_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_ot))));
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ar_in))));

/*Used to name graphs*/
%let gname=;
%let otn=;

/* Creation of where_clauses */
%let where_feed=;
%let where_measure=;

/*The data _null_ step below is to perform checking and initialize the required variables*/
data _NULL_;

if ktrim(kleft("&statistic"))="" then
   call symput('statistic',"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_roc.1, noquote))");

/* Setting the where clause for the generate_feed macro depending upon the value of the
		filter_clause*/
if ktrim(kleft("&filter_clause"))="" and ktrim(kleft("&pd_score"))=""  then
            call symput('filter','NO');
      else
            call symput('filter','YES');
call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" and ANALYTICAL_MODEL_DIM.MODEL_SK=&sel_model_key');
if ktrim(kleft("&filter_clause"))="" then
	call symput('where_feed','where 1');
else
	call symput('where_feed','where &filter_clause');
run;

/* All graph options */
    /* Setting the graph name */
    /* Calling graph_options macro */
data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4="cp"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	name5="ot"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('gname',name4);
	call symput('otn',name5);
run;

%let name=%sysfunc(ktrim(%sysfunc(kleft(&gname))));
%let otname=%sysfunc(ktrim(%sysfunc(kleft(&otn))));

/* The graph_options macro sets all the graph options and selects the colors to be used when
	rendering the graph. To access the colors being set in this macro, the respective macro
	variables for the color (color_symbol1, color_symbol2, color_symbol3) is created.
	This macro only sets the values in the macro variables.

	This macro sets the out path of the gifs to the folder created in the environment which
	will be shared between the server layer and web layer. This is picked up from the macro
	variable CS_REPORT_PATH in the bis_customize_para.sas. */
%let color_symbol1=;
%let color_symbol2=;
%let color_symbol3=;

%graph_options;
 
/*The data _NULL_ step below is to produce the first part of the HTML which also includes 
the javascript blocks*/
data _NULL_;
	file _webout&webout_options;
	rep="&statistic.";
	format rep &format_name..;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" '@;
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put rep @;
	put '</title>'@;
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {font-size: small} ';
	put '--> ';
	put '</style> ';

/**************************Javascript Starts here ****************************************/
	put '<script>';
	put '<!--';

	/*Checking for missing global parameters*/
	if "&prod_type_desc" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_prod_type_desc.1, noquote))"@;
		put'");';
	end;
	else if "&prod_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_prod_type_desc.1, noquote))"@;
		put '");';
	end;
	else if "&model_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_model_type_cd.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_select_model.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_select_model_key.1, noquote))"@;
		put '");';
	end;
	else if "&period" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_period.1, noquote))"@;
		put '");';
	end;
	else if "&time_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_put_time_key.1, noquote))"@;
		put '");';
	end;

	/******************/


	/*Functions for the links on top of the html page*/

	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL";
		put 'form1.submit()';
	put '}';

	put 'function Link3() {';
		put "form1._program.value=&CS_MDL_LVL_DB";
		put 'form1.submit()';
	put '}';

	put 'function Link4() {';
		put "form1._program.value=&CS_MSR_LVL_DB";
		put 'form1.submit()';
	put '}';
	
	/*********************/
	/*Function EditPage() for calling the Filter Screen
		(this changes the filter_clause and hence the where_feed)*/
	put 'function EditPage() {';
		put 'form1.filter_clause.value=""';
		put "form1._program.value=&CS_FLTR_SCRN";
		put 'form1.submit()';
	put '}';
	/*********EditPage() ends here**************/

	/*Function ResetPage() for reseting the value of filter_clause to null*/
	put 'function ResetPage() {';
		put 'form1.filter_clause.value=""';
		put 'form1.pd_score.value=""';
		put 'form1.range_interval.value=""';
		put 'form1.no_of_quantile.value=""';
		put 'form1.filter.value="NO"';
		put 'form1._program.value="'@;
		put "&prg_name"@;
		put '";';
		put 'form1.submit()';
	put '}';
	/*********ResetPage() ends here*************/

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put '//-->';
	put '</script>';

/**************************Javascript Ends here ****************************************/

	put '</head> ';
	put '<body>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';

	/* Stores the values of all the global variables in hidden textboxes
	This is done to pass the values to the next Stored Process */
	put '<input type="hidden" name="_program" VALUE="'@;
	put "&prg_name"@;
	put '">';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';
	model1=symget("model1");
	put '<input type="hidden" name="model1" value="' @;
	put model1;
	put '">';
	model1_key=symget("model1_key");
	put '<input type="hidden" name="model1_key" value="' @;
	put model1_key;
	put '">';
	model2=symget("model2");
	put '<input type="hidden" name="model2" value="' @;
	put model2;
	put '">';
	model2_key=symget("model2_key");
	put '<input type="hidden" name="model2_key" value="' @;
	put model2_key;
	put '">';
	sel_model=symget("sel_model");
	put '<input type="hidden" name="sel_model" value="' @;
	put sel_model @;
	put '">';
	sel_model_key=symget("sel_model_key");
	put '<input type="hidden" name="sel_model_key" value="' @;
	put sel_model_key @;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';
	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="'@;
	put statistic;
	put '">';
	filter=symget("filter");
	put '<input type="hidden" name="filter" value="'@;
	put filter;
	put '">';
	filter_clause=symget("filter_clause");
	put '<input type="hidden" name="filter_clause" value="'@;
	put filter_clause;
	put '">';

	pd_score=symget("pd_score");
	put '<input type="hidden" name="pd_score" value="' @;
	put pd_score;
	put '">';
	range_interval=symget("range_interval");
	put '<input type="hidden" name="range_interval" value="' @;
	put range_interval;
	put '">';
	no_of_quantile=symget("no_of_quantile");
	put '<input type="hidden" name="no_of_quantile" value="' @;
	put no_of_quantile;
	put '">';
	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';
	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">'; 
	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put elapsed_time;
	put '">';
	put '<input type="hidden" name="called_program" value="'@;
	put "&prg_name"@;
	put '">';
	/**********************/
run;

/*Calls the macro generate_feed for obtaining the required feed by passing
	the following parameters
	1. in_filter		: Where clause (on the basis of the filter clause)
	2. out_lib_nm		: Library name where the output feed will be created. 
	3. out_table_nm_pool: The table name for pool level feed
	4. out_table_nm_acct: The table name for account/application level feed
	5. feed_for			: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro parameter
							decides whether estimated pd/lgd/ccf has to calculated at account 
							level or application level 
	6. pd_score			: Possible values are (Empty), PD, SCORE
          a. (empty)	: The default pooling technique will be used
          b. PD			: If PD then dynamic pooling technique will be used, 
              			  based on PD/LGD/CCF as mentioned in the previous parameter(feed_for) 
          c. SCORE		: If SCORE then dynamic pooling technique will be used,
              				based on SCORE_POINTS. Applicable only if PD or APPLPD value
              				is set in the previous variable (feed_for)
	7. range_interval	: Dynamic pooling based on the range specified. E.g. 100, 200 for
	              			SCORE and .2, .3 for PD. Similar ranges for LGD/CCF
	8. no_of_quantile	: The range for dynamic pooling will be decided based on the quantile.
							Quantile ranges will be calculated based on the SCORE/PD/LGD/CCF 
							of the scoring population for the selected score period
	9. long_run			: Possible values Y/N. Whether the long run calculation is to be
							used to find estimated pd/lgd/ccf
	10. long_run_type	: Possible values are MAX/AVG. Method for calculating the long run
							pd/lgd/ccf  
	11. model_time_key  : Contains the concatenated values of model and time in the
							format _<model_sk>_<time_sk>. This is used to identify
							which fact table should be considered while generating 
							the feed.
*/
%global error_code;
%let error_code=NONE;
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&sel_model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
/*Macro that creates data feeds for further processing*/
%generate_feed(in_filter=&where_feed, out_lib_nm=&out_lib., 
      out_table_nm_pool=&out_pool, out_table_nm_acct=&out_account, feed_for=&FEED_FOR_LGD, long_run=&LONG_RUN,
      pd_score=&pd_score, range_interval=&range_interval, no_of_quantile=&no_of_quantile,
		long_run_type=&LONG_RUN_TYPE, model_time_key=&model_time);
 
/* Checks whether the generate_feed macro generated any error.
	If any error is generated then the ResetPage function defined above is called*/
data _NULL_;
	file _webout&webout_options;
	if ktrim(kleft("&error_code")) ne "NONE" and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_selec_filter_criteria.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
run;

/* Checks whether the dataset created in the generate_feed macro has any observations
			and sets cnt to the number of observations in the dataset*/
%let cnt=.;
proc sql noprint;
      select Count(*) into :cnt from &out_lib..&out_pool;
quit;

/* If there is no observation in the above dataset i.e. cnt=0 then the ResetPage function
	defined above is called */
%let log_name=;
data _NULL_;
	file _webout&webout_options;
	if &cnt eq 0 and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.alert_error_no_data_available.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
	call symput('log_name',"&CS_DEBUG_PATH./&out_pool."||".log");
run;

%debug_log_file(log_file_nm=&log_name);

%let name_html=;
/* Data creation for measure_nm in a dataset and call for feed_measure */
proc sql;
	create table &out_lib..&in_stat_ot as
	select measure_nm, help_file_nm 
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name") and model_type_cd="&model_type_code";
/*	order by measure_nm;*/
quit;

data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;

/******feed_measure requires 
	   1. where condition on basis of filter clause
       2. out_lib=output liberary  
	   3. Input dataset  
	   4. output dataset(required for statistic overtime graph)**********************/
%feed_measure(in_filter=&where_measure, out_lib_nm=&out_lib., in_table_nm=&in_stat_ot, out_table_nm_measure=&out_stat_ot);

/*The ar_stat macro is used to produce the table which is plotted as the CAP graph*/
%let AR=;
%ar_stat(input_ds=&out_lib..&out_pool,output_graph_ds=&out_graph_ds,output_stat_ds=&out_stat_ds);

/*for finding the confidence interval the following 3 steps are used*/
proc sql noprint;
select AR into :Area from &out_stat_ds;
quit;

%conf_interval(input_ds=&out_lib..&out_pool,Area=&Area,alpha=&alpha,output_CI_ds=&out_lib..output_CI_ds,STAT=AR);
proc sql noprint;
select Mid_Pt-CI_low into :Mid_Pt from &out_lib..output_CI_ds;
quit;

/* All other data and macro variable creations (as required in the report) */
/* Modeling Values for statistics */
proc sql noprint;
	select Measure_value format=&CS_DEC_FMT. into :MDL_MEASURE_VALUE
	from &out_lib..&out_stat_ot
	where kupcase(dev_flg)="%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.dev_flag_y.1, noquote))"
	order by Measure_nm;
quit;
/*
data _null_;
pos_AR = abs(&AR);
call symput('pos_AR',pos_AR); *//*Since only positive value can be passed to Model_Traffic*/
/*run;*/

/*****Input having statistic name  1.data set as(work.datset)   2.Model type code for 
		eg.PDA which willl passed from calling stored process*****output willbe the color 
   		for that value and statistic we will collect that in 'color' parameter***************/
%let color=;
%model_traffic (model_cd=&model_type_code,value=&AR,ms_name=&statistic, product_type_code=&prod_type_code);
%let color=&color;
/* Creation of all graphs and call to overtime macro */
/*******Macro statistic_overtime parameter passed
      	1.Dataset this dataset will be ouput dataset of Macro feed_measure
	  	2.statistic (For Eg. D Statistic etc.)
		3.graph name (generated from timestamp)******/
%statistic_overtime(&out_lib..&out_stat_ot,&statistic,&otname);

/*to plot the graph*/
proc gplot data=&out_graph_ds;
title1 "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.graph_title_ar.1, noquote))";
axis1 label=(a=90 "&statistic");
axis2 label=("%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.graph_axix2_lable.1, noquote))");
/*footnote  'Legend:    ' c=&color_symbol1 '    CAP LGD  ' c=&color_symbol2 '    Random Model    ' c=&color_symbol3 '    Perfect Model    ';*/
symbol1 color=&color_symbol1 width=.15 height=2 interpol=spline value=dot;
symbol2 color=&color_symbol2 width=.15 height=2 interpol=spline value=none;
symbol3 color=&color_symbol3 width=.15 height=2 interpol=join value=none;
legend1 label=(justify=left "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.graph_legend.1, noquote))") 
value=(justify=center "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.graph_center_lable_1.1, noquote))"
					  "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.graph_center_lable_2.1, noquote))"
					  "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.graph_center_lable_3.1, noquote))");
plot caprespcum*cum_totacc=1 cum_propRan_bads*cum_totacc=2 cum_propIdealBads*cum_totacc=3
       / haxis=axis2 vaxis=axis1 overlay  cframe=white
         description="%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.graph_description_cap_plot.1, noquote))"  name="&name" legend=legend1;
run;
quit;

/* Macro for getting the Pooling Technique.
	In this macro the following indicates:
			1.pd_score 			: If null then shown  as DEFAULT stautus.
			2.time_key        	: The surrogate key for selected period.
            3.sel_model_key     : The surrogate key for the selected model.
 			4.no_of_quantile    : The range for dynamic pooling will be decided based on
								  the quantile.Quantile ranges will be calculated based
								  on the SCORE/PD/LGD/CCF of the scoring  population
								  for the selected score period.
		    5.range_interval    : Dynamic pooling based on the range specified.
			  						E.g. 100, 200 for SCORE and .2, .3 for PD.	*/
%let pool_tech=;
%pool_technique;

%debug_log_web;

/* All data _null_ statements to create the html */
%let view_feed=&out_pool..html;
data _null_;
	file _webout&webout_options;
	rep="&statistic";
	format rep  &format_name..;
	name_html=symget("name_html");
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
		put "&view_feed"@; 
	put '")};';
		
	/*********************************************/
	put'</script>';

	put '  <table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';

	/* To display SAS credit scoring as heading */
	put '<tr>';
	put '<td align="left">';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr>';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';

	put '<td><span class="BreadCrumb">'; 
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_reporting.1, noquote))"@;
	put '</a> &gt;<a href="javascript:Link2()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_monitoring_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link3()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_sel_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link4()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.link_sel_stats.1, noquote))"@;
	put '</a> &gt;';
	put '</span><span class="BreadCrumb">'@;
	put rep @;
	put '</span></td>';

	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
	put '</tr></table>';
	/* Heading ends */

	put '<H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
	put rep @;
	put '</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a> '@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';
	put '<tr>';
	put '<td align="left">';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_model_type.1, noquote))"@;
	put "&model_type_desc"@;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_product_type.1, noquote))"@;
	put "&prod_type_desc" @;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_model.1, noquote))"@;
	put "&sel_model" @;
	put '</p>';

	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_pooling_tech.1, noquote))"@;
	put "&pool_tech";
	put '</p>';

	/* Target period and elapsed time*/
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_outcome_period.1, noquote))"@;
	put "&outcome_period" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_months.1, noquote))"@;
	put "&elapsed_time" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_month_elapsed.1, noquote))"@;
	put '</p>';

	format mid &CS_DEC_FMT.;
	format calc &CS_PERC_FMT.;
	mid=&Mid_Pt;
	put '<table  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td><span class="LabelFont">'@;
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_actual_value.1, noquote))"@;
	put "&AR" @;

	/*I18N-scnhuh-20080429-1433*/
	/*minus-plus symbol error */
			/*put '  '@;*/
			put ' &#177;'@;
	/*I18N-scnhuh-20080429-1433*/
			put mid @;
			put ' ('@;
			calc=1-&ALPHA;
			put calc @;
			put ')';
	put '</span></td><td>&nbsp;</td>';

	put'<td width="25"><div align="center"><span class="LabelFont"><img src="/SASCSReports/images/';
	if "&color"="%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.colour_white.1, noquote))" then do;
		put 'spacer.gif"';
	end;
	else do;
		put 'Sphere'@;
		put "&color"@;
		put '.gif"';
	end;
	put 'width="16" height="16" border="0"></a> </span></div></td>';
	put '<td width="50"><span class="LabelFont"></span></td>';
	if %str("&filter")=%str("NO") then do;
		put '<td><span class="LabelFont">'@;
		put rep @;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_modeling_value.1, noquote))"@;
		if symexist("MDL_MEASURE_VALUE") eq 0 then 
			put '.' @;
		else 
			put "&MDL_MEASURE_VALUE" @;
		put '</span></td>';
	end;
	put '</tr></table>';
	put '<tr>';
	put '<td align="left">';
	put '<p>';
	put '<H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_cap_lgd_graph.1, noquote))"@;
	put '</H2>';
	put '</td>';
	put '</tr>';
	put '<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td width="49%" valign="top"><fieldset>';
	put '<legend><span class="style2">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_cap_graph.1, noquote))"@;
	put '</span></legend>';
	put '<p><img src="/SASCSReports/'@;
	put "&name";
	put '.gif" width="460" height="200"></p>';
	put '<td width="2%">&nbsp;</td>';

	/*filter is no then display*/
	if %str("&filter")=%str("NO") then do;
		put '<td width="49%" valign="top"><fieldset>';
		put '<legend><span class="style2">';
		put rep ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.label_sats_overtime.1, noquote))"@;
		put'</span></legend>';
		put '<p><img src="/SASCSReports/'@;
		put "&otname";
		put '.gif" width="460" height="200"></p>';
		put '</fieldset></td>';
		put '</tr>';
	end;
	else do;
	        put '<td width="49%" valign="top">';
	        put '</td>';
	end;

	put '</fieldset></td>';
	put '</tr>';
	put '</table>';
	put '<p>&nbsp;</p></td>';
	put '</tr>';
	put '</table>';
	put '</td>';
	put '</tr>';
	put '<tr>';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
	val=PRXMATCH(kupcase('/cluster/'),kupcase("&pool_tech"));
	if val = 0 then do;
		put '<INPUT type=button class=mmhide_btn onClick=EditPage() value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.button_filter_repool.1, noquote))"@;
		put '">';
		put '<INPUT type=button class=mmhide_btn onClick=ResetPage() value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.button_reset.1, noquote))"@;
		put '">';
	end;
	put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.cap_lgd.button_view_feed.1, noquote))"@;
	put '">';
	put '</td>';
	put '</tr>';
	put '</table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;
/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/

	 /*I18N-scnjih-20080421-1517*/
/*%let dt_nm=Pool Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,Call_feed_table.sas.dt_nm.1, noquote));
	 /*I18N-scnjih-20080421-1517*/
%let dt_st=&out_pool.;
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);


goptions reset=all;
options nomprint;
 
