/********************************************************************************************
       Module:  KS (Kolmogorov-Smirnov statistic)

     Function:  This stored process generates an HTML report displaying 
				Kolmogorov-Smirnov Statistic, the KS graph and 
				the KS overtime graphs.

      Authors:  BIS Team
         Date:  30 November 2006
          SAS:  9.1
    Called-by:	Stored Process model_in_var
				
        Calls:  Calls the following Stored Process
					1. Reporting	  	 (when Reporting link is clicked)
					2. mon_model_inputs	 (when Monitoring Model Inputs link is clicked)
					3. model_in_var    	 (when Select Variable link is clicked)

				Calls the following Macros
					1. generate_feed_mip macro for obtaining the required feed.
					2. feed_measure_mip macro for generating the dataset containing the
						statistic values over time.
					3. model_traffic macro for generating the traffic lighting for the
						given measure.
					4. ks macro for preparing data for plotting the graphs.
					5. statistic_overtime macro to generate the overtime graph.

Datasets used:  No input datasets required for processing of the stored process
 
        Logic:  1. All inputs to the stored process are accepted as global parameters.
				2. Standards
					a. Naming of data set which are input to and output from macro using
						<prod_type_code><model1_key><time_key>Extension as per requirement
						i.e.		MTG           100          1036     pool
							as MTG1001036pool.
					b. Setting the default values for where_measure, where_feed and
						feed_for. where_feed and feed_for is passed as parameter(infilter
						& feed_for) to the generate_feed_mip macro, and where_measure is 
						passed as parameter to the feed_measure_mip macro.
					c.	Naming the graphs using timestamp and two letters for  
						identifying the graph.
				3. Call the macro generate_feed_mip for obtaining the required feed.
				4. Call the feed_measure_mip macro for generating the dataset containing
					the statistic values over time.
				5. Call the model_traffic macro for generating the traffic lighting
					for the given measure.
			    6. Call the ks macro for generating KS value based on
					Actual and Development sample and compares the two.
			    7. Call the statistic_overtime macro to generate the overtime graph.
			    8. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that the 
						values are easily submitted to the next page. 
					b. Provide javascript functions for the links on top of the page
						and for edit and reset buttons.
				
   Parameters:
			INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				statistic           :   Measure name(Information Value and Other Statistics)
				model				:	The selected model (e.g., PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				variable			:	The selected variable (e.g., Variable 1)
				variable_key		: 	The surrogate key for selected variable (e.g., 1)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
				
			OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
										Mortgage, Loan, Core)
		        prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
		        model_type_code   	:   Analytical Model Type Code (e.g., PD Approvals,
										PD Ongoing, LGD, CCF)
		        model_measure_type	:   Model type code (MIP) for referring the models
										for model input reports in measure_dim.
				statistic           :   Measure name(e.g., Information Value Statistic,
										Gini Index, Pearson Chi-Square value)
				model				:	The selected model (e.g. PD MODEL 1).		
				model_key			:	The surrogate key for the selected model.
				period				:	The selected period (month and year)(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				variable			:	The selected variable (Eg. Variable 1)
				variable_key		: 	The surrogate key for selected variable (Eg. 1)
				prg_name			:	The program name, for calling the report, which is
										picked from program_nm column of dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.

********************************************************************************************/
goptions reset=all;
options nomprint;


/* Global input parameters that are passed from the calling program*/
%global prod_type_desc prod_type_code model_type_desc model_type_code model_measure_type
		model model_key period time_key variable variable_key statistic prg_name
		outcome_period elapsed_time format_name;

/* Trimming extra spaces from all the input parameters*/
%macro macro_val_check;
%if "&prod_type_desc" ne "" %then
%let prod_type_desc=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&prod_type_desc))))));
%if "&prod_type_code" ne "" %then
%let prod_type_code=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code))));
%if "&model_type_desc" ne "" %then
%let model_type_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&model_type_desc)))));
%if "&model_type_code" ne "" %then
%let model_type_code=%sysfunc(ktrim(%sysfunc(kleft(&model_type_code))));
%if "&model_measure_type" ne "" %then
%let model_measure_type=%sysfunc(ktrim(%sysfunc(kleft(&model_measure_type))));
%if "&model" ne "" %then
%let model=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&model))))));
%if "&model_key" ne "" %then
%let model_key=%sysfunc(ktrim(%sysfunc(kleft(&model_key))));
%if "&period" ne "" %then
%let period=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&period))))));
%if "&time_key" ne "" %then
%let time_key=%sysfunc(ktrim(%sysfunc(kleft(&time_key))));
%if "&variable" ne "" %then
%let variable=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable))))));
%if "&variable_key" ne "" %then
%let variable_key=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&variable_key))))));
%if "&statistic" ne "" %then
%let statistic=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&statistic))))));
%if "&prg_name" ne "" %then
%let prg_name=%str(%sysfunc(ktrim(%sysfunc(kleft(&prg_name)))));
%if "&outcome_period" ne "" %then
%let outcome_period=%str(%sysfunc(ktrim(%sysfunc(kleft(&outcome_period)))));
%if "&elapsed_time" ne "" %then
%let elapsed_time=%str(%sysfunc(ktrim(%sysfunc(kleft(&elapsed_time)))));
/*************/
%mend;
%macro_val_check
/*************/

/*Assigning standard names for datasets which are input to and ouput from macro using
		<prod_type_code><model1_key><time_key><variable_key> Extension as per requrment  
	i.e.		COR           106          1030     1			pool
		as COR10610301pool.*/

/* Standard names for datasets that are passed to generate_feed_mip macro */
%let out_lib=;
%debug_lib_path;
/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name
%let out_mip=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.&variable_key.ks_mp))));
%let out_acc_mip=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.&variable_key.ks_ac_mp))));
/*************/

/* Standard names for datasets that are passed to feed_measure_mip macro*/
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.&variable_key.msr_in))));
%let out_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.&variable_key.msr_out))));
/*************/

/* Standard names for datasets that are passed to Report_Info_WOE macro */
%let out_stat_ds=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&model_key.&time_key.&variable_key.ks_out))));
/*************/

/* Setting values for feed_for and where_clauses*/
%let where_feed=;
%let where_measure=;
%let feed_for=;

data _null_;

/* Setting the default value for statistic*/
	if trim(left("&statistic"))="" then
		call symput('statistic',"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_info_val_stats.1, noquote))");

/* Setting the feed_for depending on the analytical model type.
	This is passed as parameter to generate_feed_mip */
	if trim(left("&model_type_code"))=&PD_APP_MODEL then
    	call symput('feed_for',"&FEED_FOR_APPLPD");
	else if trim(left("&model_type_code"))=&PD_ONG_MODEL then
	    call symput('feed_for',"&FEED_FOR_PD");
	else if trim(left("&model_type_code"))=&LGD_MODEL then
        call symput('feed_for',"&FEED_FOR_LGD");
	else if trim(left("&model_type_code"))=&LGD_APP_MODEL then
        call symput('feed_for',"&FEED_FOR_APPLLGD");
	else if trim(left("&model_type_code"))=&CCF_MODEL then
        call symput('feed_for',"&FEED_FOR_CCF");

/* Setting the where clause for the feed_measure_mip macro */
	call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" and ANALYTICAL_MODEL_DIM.MODEL_SK=&model_key and SCORE_CARD_VARIABLE_FACT.VARIABLE_SK=&variable_key');

/* Setting the where clause for the generate_feed_mip macro */
	call symput('where_feed','1');
run;
/******************/

/* Assigning standard name for the gifs using timestamp and two characters
	for identifying the graph*/
%let gname=;
data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4="k"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('gname',name4);
run;

%let graph_name=%sysfunc(ktrim(%sysfunc(kleft(&gname))));

/* Start HTML Screen*/
data _NULL_;
/*I18N-scnhuh-20080418-2017*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-2017*/
	rep="&statistic";
	format rep &format_name..;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" '@;
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put rep @;
	put '</title> ';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {font-size: small} ';
	put '--> ';
	put '</style> ';
	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

/* Calls the mon_model_inputs stored process if link is clicked */
	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL_IP";
		put 'form1.submit()';
	put '}';

/* Calls the model_in_var stored process if link is clicked */
	put 'function Link3() {';
		put "form1._program.value=&CS_VAR_LVL_DB";
		put 'form1.submit()';
	put '}';
/*********************/

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put '//--> ';
	put '</script> ';
	put '</head> ';
	put '<body><form name="form1" method="post" action="/SASStoredProcess/do"> ';

/* Hidden textboxes to hold the values for the program name and the output paremeters 
	to pass the values to the next Stored Process called */
	put '<input type="hidden" name="_program" VALUE="'@;
	put "&prg_name"@;
	put '">';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	model_measure_type=symget("model_measure_type");
	put '<input type="hidden" name="model_measure_type" value="' @;
	put model_measure_type;
	put '">';
	model=symget("model");
	put '<input type="hidden" name="model" value="' @;
	put model;
	put '">';
	model_key=symget("model_key");
	put '<input type="hidden" name="model_key" value="' @;
	put model_key;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';
	variable=symget("variable");
	put '<input type="hidden" name="variable" value="' @;
	put variable;
	put '">';
	variable_key=symget("variable_key");
	put '<input type="hidden" name="variable_key" value="' @;
	put variable_key;
	put '">';
	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="' @;
	put statistic;
	put '">';
	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';
	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">'; 
	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put elapsed_time;
	put '">';

	/**********************/
run;

/*Calls the macro generate_feed_mip for obtaining the required feed by passing
	the following parameters
	1. in_filter		: Where clause
	2. out_lib_nm		: Library name where the output feed will be created. 
	3. out_table_nm_pool: The table name for pool level feed
	4. out_table_nm_acct: The table name for account/application level feed
	5. feed_for			: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro
							parameter decides whether estimated pd/lgd/ccf has to calculated 
							at account level or application level 
	6. var				: variable_key that is passed from the calling stored process
							(model_in_var) 
	7. model_time_key  	: Contains the concatenated values of model and time in the
							format _<model_sk>_<time_sk>. This is used to identify
							which fact table should be considered while generating 
							the feed.
	8. product_type_code	: This is the selected product type code (E.G. MTG, LON).
*/

%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
%generate_feed_mip(in_filter=&where_feed, out_lib_nm=&out_lib, out_table_nm_pool=&out_mip, 
					out_table_nm_acct=&out_acc_mip, feed_for=&feed_for, var=&variable_key,
					model_time_key=&model_time, product_type_code=&prod_type_code);


%let log_name=;
data _NULL_;
	call symput('log_name',"&CS_DEBUG_PATH./&out_mip."||".log");
run;

%debug_log_file(log_file_nm=&log_name);

%let name_html=;
/* Generates the dataset with measure names for the given model_type_cd and the called
	program name(the current stored process info_val)
	from the measure_dim dataset to be passed as a parameter to the feed_measure_mip macro*/
proc sql;
	create table &out_lib..&in_stat_ot as
	select measure_nm, help_file_nm, monotonic() as tot_count 
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name")
			and kupcase(model_type_cd)=upcase("&model_measure_type");
/*	order by measure_nm;*/
quit;


data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;

/* Calls the feed_measure_mip macro for generating the dataset containing the statistic
	values over time. The following parameter is passed to this macro:
		1. in_filter			: where clause 
		2. out_lib_nm			: library name from where the input dataset is picked from
								  and where the ouput dataset is stored
		3. in_table_nm			: the input dataset to be passed
		4. out_table_nm_measure	: the output dataset created in the macro*/
%feed_measure_mip(in_filter=&where_measure, out_lib_nm=&out_lib., in_table_nm=&in_stat_ot,
					out_table_nm_measure=&out_stat_ot);


/* Code to get the Actual values for statistics*/
/*proc sql;*/
/*	create table &out_lib..ms_traf as*/
/*	select Measure_nm, Measure_value format = &CS_DEC_FMT.*/
/*	from &out_lib..&out_stat_ot*/
/*	where upcase(dev_flg)="N" and score_time_sk=&time_key*/
/*	order by Measure_nm;*/
/*quit;*/

/* Calls KS for generating KS values based on Actual and Development
	sample and compares the two.*/
%ks(input_ds=&out_lib..&out_mip., out_graph_ds=&out_lib..&out_stat_ds);

proc sql noprint;
	select max(ks) format = &CS_DEC_FMT. into :ks_val from &out_lib..&out_stat_ds;
quit;


/* Calls the model_traffic macro to get the traffic lighting for the data provided
	The following parameters are passed to this macro
			1. data1	: input dataset containing the columns measure_value and measure_nm
			2. model_cd	: MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF)
	This macro adds one more column named color to the dataset passed which contains
	values ( Green, Red, Yellow, White) depending on the bounds(for red and green) provided
	in the measure_dim dataset*/
/*%Model_Traffic(data1=&out_lib.&out_stat_ot,model_cd=&model_measure_type);*/
%let color=;
%model_traffic(model_cd=&model_type_code,value=&KS_val, ms_name=&statistic, product_type_code=&prod_type_code);
%let color=&color;
/* Code to get the Modeling value for statistic*/
proc sql noprint;
	select Measure_value format=&CS_DEC_FMT. into :MDL_MEASURE_VALUE
	from &out_lib..&out_stat_ot
	where kupcase(dev_flg)="%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.dev_flag_y.1, noquote))"
	order by Measure_nm;
quit;

/* Creation of all graphs and call to overtime macro */
/*******Macro statistic_overtime parameter passed
      	1.Dataset this dataset will be ouput dataset of Macro feed_measure
	  	2.statistic (For Eg. D Statistic etc.)
		3.graph name (generated from timestamp)
******/
%statistic_overtime(&out_lib..&out_stat_ot,&statistic,&graph_name);

%debug_log_web;

/*data _NULL_;*/
/*	file _webout;*/
/*	put '<script>';*/
/*	put '<!--';*/
 /*Calls this stored process again after assigning statistic the value selected from the
		combo box and hence displaying the overtime graph for the selected statistic */
/*	put 'function display(){';*/
/*		put 'var indx=form1.measure_name.selectedIndex';*/
/*		put 'var choice=form1.measure_name.options[indx].value';*/
/*		put	'if(document.images) {';*/
/*		put	'document.form1.my_img.src=choice';*/
/*		put	'}';*/
/*	put '}';*/
/*******************/
/*	put '//-->';*/
/*	put '</script>';*/
/*run;*/

%let view_feed=&out_mip..html;
/* HTML Screen */
data _NULL_;
/*I18N-scnhuh-20080418-2017*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-2017*/
	rep="&statistic";
	format rep &format_name..;
	name_html=symget("name_html");
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
		put "&view_feed"@; 
	put '")};';
			
		/*********************************************/
	put'</script>';
	
	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';
	put '<tr> ';
	put '<td align="left"> ';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr> ';

/*Links on Top of the HTML Page*/
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0"> ';
	put '<tr> ';
	put '<td><span class="BreadCrumb">'@;
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.linnk_reporting.1, noquote))"@;
	put '</a> &gt; ';
	put '<a href="javascript:Link2()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.linnk_mon_model_input.1, noquote))"@;
	put '</a> &gt; ';
	put '<a href="javascript:Link3()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.linnk_sel_var.1, noquote))"@;
	put '</a> &gt;'@;
	put '</span><span class="BreadCrumb">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks_mip.link_ks.1, noquote))"@;
	put '</span></td> ';
/*********/

/*SAS Banner*/
	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td> ';
/*********/

	put '</tr> ';
	put '</table>';
	put '<H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks_mip.link_ks.1, noquote))"@;
	put '</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

/*Values of Product_type Period Model and Variable*/
	put '<tr> ';
	put '<td align="left"> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_model_type.1, noquote))"@;
	put "&model_type_desc"@;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_product_type.1, noquote))"@;
	put "&prod_type_desc";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_model.1, noquote))"@;
	put "&model";
	put '</p> ';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_variable.1, noquote))"@;
	put "&variable";
	put '</p> ';

/* Target period and elapsed time*/
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_outcome_period.1, noquote))"@;
	put "&outcome_period" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_months.1, noquote))"@;
	put "&elapsed_time" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_month_elapsed.1, noquote))"@;
	put '</p>';

	/* Number of months of Historic data */
	if kupcase("&model_type_code") eq kupcase(&PD_APP_MODEL.) then do;
		put '<p class="LabelFont">'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_hist.label_historic_data.1, noquote))"@;
		if kupcase("&prod_type_code") eq kupcase(&MTG_PRD_TYPE.) then do;
			put "&PDA_MTG_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&LON_PRD_TYPE.) then do;
			put "&PDA_LON_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&COR_PRD_TYPE.) then do;
			put "&PDA_COR_HIST" @;
		end;
		if kupcase("&prod_type_code") eq kupcase(&CCD_PRD_TYPE.) then do;
			put "&PDA_CCD_HIST" @;
		end;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pd_stored_proc_month.label_months.1, noquote))"@;
		put '</p>';
	end;

/* Actual value for the given statistic */
	put '<table  border="0" cellspacing="0" cellpadding="0">';
    put '<tr><td><span class="LabelFont">'@;
	put rep @;
	put "   "@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_actual_val.1, noquote))"@;
	put "&ks_val" @;
	put '</span></td><td>&nbsp;</td>';
	put'<td width="25"><div align="center"><span class="LabelFont">';
	put '<img src="/SASCSReports/images/';
	if "&color"="%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.colour_white.1, noquote))"  then do;
		put 'spacer.gif"';
	end;
	else do;
		put 'Sphere'@;
		put "&color";
		put '.gif"';
	end;
	put 'width="16" height="16" border="0"></a> </span></div></td> ';
	put'<td width="50"><span class="LabelFont"></span></td> ';

/* Modeling value for the given statistic. */
	put '<td><span class="LabelFont">'@;
	put rep @;
	put "   "@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.label_modeling_val.1, noquote))"@;
		if symexist("MDL_MEASURE_VALUE") eq 0 then 
			put '.' @;
		else 
			put "&MDL_MEASURE_VALUE" @;
	put '</span></td> ';

    put '</tr>';
    put '</table>';
/* Overtime Graph */
	put '<H2 align="left">'@;
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks_mip.graph_nm_ks.1, noquote))"@;
	put '</H2>';
	put '</td>';
	put '</tr>';
	put '<tr><td><table width="50%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
    put '<td width="49%" valign="top"><fieldset>';
    put '<legend><span class="style2">'; 
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks_mip.over_time.1, noquote))"@;
	put '</span></legend>';
    put '<p><img src="/SASCSReports/'@;
	put "&graph_name" @;
	put '.gif" width="460" height="200"></p>';
    put '</fieldset></td>';
    put '</tr>';

run;

data _NULL_;
/*I18N-scnhuh-20080418-2017*/
/*add &webout_options*/
	file _webout&webout_options;
/*I18N-scnhuh-20080418-2017*/
/*	put '<p>&nbsp;</p></td> ';*/
	put '<tr><td>&nbsp;</td></tr> ';
	put '</table> ';
	put '</td> ';
	put '</tr> ';
	put '<tr> ';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
	put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.info_val.button_view_feed.1, noquote))"@;
	put '">';
	put '</td> ';
	put '</tr> ';
	put '</table> ';
	put '</form> ';
	put '</body> ';
	put '</html> ';
run;
/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/

	 /*I18N-scnjih-20080421-1517*/
/*%let dt_nm=Pool Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,Call_feed_table.sas.dt_nm.1, noquote));
	 /*I18N-scnjih-20080421-1517*/
%let dt_st=&out_mip.;
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);

goptions reset=all;
options nomprint;
