/*****************************************************************************
	   Module:  KS

	 Function:  This stored process generates an HTML report displaying 
				Kolmogorov-Smirnov Statistic, the KS graph, KS Cutoff plot and 
				the KS overtime graphs.

	  Authors:  BIS Team
		 Date:  05 April 2006
		  SAS:  9.1
	Called-by:  Stored Process test_levels

		Calls:  Calls the following Stored Process    
  				1. Reporting	 	 (when Reporting link is clicked)
  				2. mon_models     	 (when Monitoring Models link is clicked)
  				3. select_models     (when Select Models link is clicked) 
				4. test_levels    	 (when Select Statistic link is clicked)
				5. ks				 (when the reset button is clicked)
				6. filtering_criteria(when the Filter/Re-Pool button is clicked)

				Calls the following Macros
				1. graph_options macro sets all the graph options and selects the 
					colors to be used when rendering the graph.
				2. generate_feed macro for obtaining the required feed.
				3. feed_measure macro which makes data for the overtime graphs
				4. ks_stat macro for preparing data for plotting the graphs.
				5. cs_rep_data_prep macro for preparing data of Actual and 
					Estimated types.
				6. drawtable macro					

Datasets used:  No input datasets required for processing of the stored process

		Logic:  1. All inputs to the stored process are accepted as global parameters. 
				2. Standards
  					a. 	Naming of data set which are input to and output from macro 
						using
      			<prod_type_code><sel_model_key><time_key> Extension as per requirement  
      		i.e.		MTG           100          1036     pool
      					as MTG1001036pool.
  					b. Setting the default values for feed_pd and where_feed to be 
						passed as parameter(infilter) to the generating feed macro.
  					c. Naming the graphs using timestamp and two letters for 
						identifying the graph.
				3. Set all the graph options and select the colors to be used when 
					rendering the graph.
				4. Call the macro generate_feed for obtaining the required feed.
				5. Check whether the generate_feed macro generated any error.
  					If any error is generated then the same report(ks) is called
  					with the default criteria.
				6. If there no data, in the case of business filter or dynamic 
					pooling, is generated by the generate_feed macro then the same 
					report(ks) is called with the default criteria.
				7. Call the cs_rep_data_prep for preparing data of Actual and 
					Estimated types.
				8. Call the ks_stat macro for preparing data for plotting the graphs.
				9. Macros which enclose the code blocks have been called. They are 
					chkselection, chkksDistype, sqlproc, plotgraph_distline, plotKSP 
					and mparent.	

				10. Get the pooling technique.
 				11. Generate the HTML using streaming webout.
					a. Provide hidden textboxes for all output parameters so that 
						the values are easily submitted to the next page. 
  					b. Provide javascript functions for the links on top of the page
      					and for edit and reset buttons.

   Parameters: 
				INPUT 
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
				      					Mortgage, Loan, Core)
				prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
				model_type_code   	:   Analytical Model Type Code (e.g., PD 
										Approvals, PD Ongoing, LGD, CCF)
				include_exp_mdl		:   Information to include the expired models for
										selection of model from the traffic light 
										dashboard.
				statistic           :   Statistic name (Kolmogorov-Smirnov Statistic).
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)
										(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling 
										values and overtime graph.(Not used in this 
										report)
				filter_clause		: 	Contains the selected business filter.
				pd_score 			:	If null then shown  as DEFAULT stautus.
				no_of_quantile      :	The range for dynamic pooling will be decided
										based on the quantile.Quantile ranges will be 
										calculated based on the SCORE/PD/LGD/CCF of 
										the scoring  population for the selected 
										score period  
				range_interval      : 	Dynamic pooling based on the range specified.
				      					E.g. 100, 200 for SCORE and .2, .3 for PD.
				prg_name			:	The program name, for calling the report, 
										which is picked from program_nm column of 
										dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.

				OUTPUT
				prod_type_desc		:   Product Type Description (e.g., Credit Card,
				      					Mortgage, Loan, Core)
				prod_type_code		:   Product Type Code (e.g., CCD, MTG, LON, COR)
				model_type_desc		:	Analytical Model Type Description 
										(e.g., PD Approvals, PD Ongoing, LGD, CCF)
				model_type_code   	:   Analytical Model Type Code (e.g., PD 
										Approvals, PD Ongoing, LGD, CCF)
				include_exp_mdl		:   Information to include the expired models for
										selection of model from the traffic light 
										dashboard.
				statistic           :   Statistic name (Kolmogorov-Smirnov Statistic).
				model1				:	The first model if selected (Eg. PD MODEL 1).		
				model1_key			:	The surrogate key for the first selected model.
				model2				:	The  second model if  selected. (Eg. PD MODEL 2)
				model2_key			:	The surrogate key for the second selected model.
				sel_model			: 	Model selected on the Measure level dashboard screen.
				sel_model_key		:	Key of the selected model.
				period				:	The selected period (month and year)
										(Eg DEC05 JAN06).
				time_key			:	The surrogate key for selected period.
				filter				:	Used for displaying or hiding the modeling 
										values and overtime graph.(Not used in this 
										report)
				filter_clause		: 	Contains the selected business filter.
				pd_score 			:	If null then shown  as DEFAULT stautus.
				no_of_quantile      :	The range for dynamic pooling will be decided
										based on the quantile.Quantile ranges will be 
										calculated based on the SCORE/PD/LGD/CCF of 
										the scoring  population for the selected 
										score period  
				range_interval      : 	Dynamic pooling based on the range specified.
				      					E.g. 100, 200 for SCORE and .2, .3 for PD.
				prg_name			:	The program name, for calling the report, 
										which is picked from program_nm column of 
										dim.measure_dim.
				outcome_period		:	The target period in months.
				elapsed_time		:	The time elapsed.
      
******************************************************************************/
goptions reset=all;
options nomprint;

/* Global variable declaration */
%global prod_type_desc prod_type_code model_type_desc model_type_code include_exp_mdl
		model1 model1_key model2 model2_key period time_key filter filter_clause
		statistic pd_score range_interval no_of_quantile ksDist prg_name
		outcome_period elapsed_time sel_model sel_model_key format_name; 
 	%let prod_type_desc=&prod_type_desc;
	%let prod_type_code=&prod_type_code;
	%let model_type_desc=&model_type_desc;
	%let model_type_code=&model_type_code;
	%let model1=&model1;
	%let model1_key=&model1_key;
	%let sel_model=&sel_model;
	%let sel_model_key=&sel_model_key;
	%let period=&period;
	%let time_key=&time_key;
	%let statistic=%str(%bquote(%sysfunc(ktrim(%sysfunc(kleft(&statistic))))));
	%let filter=&filter;
	%let filter_clause=&filter_clause;
	%let pd_score=&pd_score;
	%let prg_name=&prg_name;
	%let outcome_period=&outcome_period;
	%let elapsed_time=&elapsed_time;
 
/*Assigning standard names for datasets which are input to and ouput from macro using
		<prod_type_code><sel_model_key><time_key> Extension as per requrment  
	i.e.		COR           106          1030     pool
		as COR1061030pool.*/
%let out_lib=;
%debug_lib_path;

/*This macro outputs the format for the stattistics for combination of 
  product type code and the model type code.*/
%format_for_model_product(model_type_code_fm=&model_type_code,prod_type_code_fm=&prod_type_code)
/*This macro chnage the dataset name and hardcode it on the product type*/
%change_dataset_name
 

%let out_pool=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.pool))));
%let out_account=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.account))));

/*Used in calls to feed measure, data preparation and ks_stat macro*/
%let out_data_prep=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.data_prep))));
%let out_graph_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ks_graph))));
%let out_stat_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib..&prod_type_code.&sel_model_key.&time_key.ks_stat))));
%let out_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ks_ot))));
%let in_stat_ot=%sysfunc(ktrim(%sysfunc(kleft(&prod_type_code.&sel_model_key.&time_key.ks_in))));


/*Used to name graphs*/
%let gname1=;
%let gname2=;
%let gname3=;
%let otn=;

/*macro variables used for stat calculations*/
%let KS_Cutof=;
%let Max_KS_fmt=;
%let Max_KS=;

%let dg=;
%let db=;

/* Setting values for the feed_pd and where_clause*/
%let where_feed=;
%let where_measure=;
%let feed_pd=;

/*The data _null_ step below is to perform checking and initialize the required variables*/
data _null_;
/* Setting the feed_pd depending on whether its an application model or not.
	This is passed as parameter to generate_feed */
	if ktrim(kleft("&model_type_code"))=&PD_APP_MODEL then
		call symput('feed_pd',"&FEED_FOR_APPLPD");
	else
		call symput('feed_pd',"&FEED_FOR_PD");

/* Setting the default value for statistic*/
	if ktrim(kleft("&statistic"))="" then
   		call symput('statistic',"%sysfunc(sasmsg(smd_ds.bismsg,crs.measure_nm.measure_nm_ks.1, noquote))");

/* Setting value for filter depending on whether the filter_clause and pd_score has any
	value set.
		The filter_clause and pd_score value is getting passed from the Filter Screen
		(stored process FilteringCriteria)
		If the filter is NO then the modeling value and the statistic overtime graph
		is displayed else it is not displayed */	
	if ktrim(kleft("&filter_clause"))="" and ktrim(kleft("&pd_score"))=""  then
		call symput('filter','NO');
    else
        call symput('filter','YES');

	if ktrim(kleft("&ksDist"))= "" then
		call symput('ksDist','AGAB');

/* Setting the where clause for the feed_measure macro*/
	call symput('where_measure','where ANALYTICAL_MODEL_DIM.MODEL_PRODUCT_TYPE_CD="&prod_type_code" and ANALYTICAL_MODEL_DIM.MODEL_SK=&sel_model_key');

/* Setting the where clause for the generate_feed macro depending upon the value of the
		filter_clause*/
	if ktrim(kleft("&filter_clause"))="" then
		call symput('where_feed','where 1');
	else
		call symput('where_feed','where &filter_clause');
run;

/* All graph options */
    /* Setting the graph name */
    /* Calling graph_options macro */
data _NULL_;
name=put(time(),mmss8.1);
name1=kscan(name,1,":.");
name2=kscan(name,2,":.");
name3=kscan(name,3,":.");
name4="k1"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
name5="k2"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
name6="kc"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
name7="ot"||ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
call symput('gname1',name4);
call symput('gname2',name5);
call symput('gname3',name6);
call symput('otn',name7);
run;

%let name1=%sysfunc(ktrim(%sysfunc(kleft(&gname1))));
%let name2=%sysfunc(ktrim(%sysfunc(kleft(&gname2))));
%let name3=%sysfunc(ktrim(%sysfunc(kleft(&gname3))));
%let otname=%sysfunc(ktrim(%sysfunc(kleft(&otn))));

/* The graph_options macro sets all the graph options and selects the colors to be used when
	rendering the graph. To access the colors being set in this macro, the respective macro
	variables for the color (color_symbol1, color_symbol2, color_symbol3) is created.
	This macro only sets the values in the macro variables.

	This macro sets the out path of the gifs to the folder created in the environment which
	will be shared between the server layer and web layer. This is picked up from the macro
	variable CS_REPORT_PATH in the bis_customize_para.sas. */
%let color_symbol1=;
%let color_symbol2=;
%let color_symbol3=;
%let color_symbol20=;

%graph_options;

/*The data _NULL_ step below is to produce the first part of the HTML which also includes 
the javascript blocks*/
data _NULL_;
	file _webout&webout_options;
	rep="&statistic";
	format rep &format_name..;
	put '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" '@;
	put '"http://www.w3.org/TR/html4/loose.dtd"> ';
	put '<html> ';
	put '<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put '<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put '<title>'@;
	put rep @;
	put '</title>';
	put '<link href="SASTheme_default/themes/default/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<link href="/SASCSReports/styles/default.css" rel="stylesheet" type="text/css"> ';
	put '<style type="text/css"> ';
	put '<!-- ';
	put '.style2 {font-size: small} ';
	put '--> ';
	put '</style> ';

/**************************Javascript Starts here ****************************************/
	put '<script>';
	put '<!--';

	/*Checking for missing global parameters*/
	if "&prod_type_desc" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_put_prod_type_desc.1, noquote))"@;
		put'");';
	end;
	else if "&prod_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_put_prod_type_desc.1, noquote))"@;
		put '");';
	end;
	else if "&model_type_code" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_put_model_type_cd.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_put_select_model.1, noquote))"@;
		put '");';
	end;
	else if "&sel_model_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_put_select_model_key.1, noquote))"@;
		put '");';
	end;
	else if "&period" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_put_period.1, noquote))"@;
		put '");';
	end;
	else if "&time_key" eq %str("") then 
	do;
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_put_time_key.1, noquote))"@;
		put '");';
	end;
	/******************/

	/*Functions for the links on top of the html page*/

/* Calls the Reporting stored process if link is clicked */
	put 'function Link1() {';
		put "form1._program.value=&CS_REPORTING";
		put 'form1.submit()';
	put '}';

/* Calls the mon_models stored process if link is clicked */
	put 'function Link2() {';
		put "form1._program.value=&CS_MON_MDL";
		put 'form1.submit()';
	put '}';

/* Calls the select_models stored process if link is clicked */
	put 'function Link3() {';
		put "form1._program.value=&CS_MDL_LVL_DB";
		put 'form1.submit()';
	put '}';

/* Calls the test_levels stored process if link is clicked */
	put 'function Link4() {';
		put "form1._program.value=&CS_MSR_LVL_DB";
		put 'form1.submit()';
	put '}';
	
	/*********************/

	put 'function persist(cval){';
	put 'radb=document.forms[0].radiobutton;';
	put 'if (cval==1)';
	put '{radb[0].checked=true;}';
	put 'else if (cval==2)';
	put '{radb[1].checked=true;}';
	put '}';

	put 'function assign_to_ksDist(val){';
	put 'form1.ksDist.value=val;';
	put 'form1.submit();';
	put '}';

	/*********************/

	/*Function EditPage() for calling the Filter Screen
		(this changes the filter_clause and hence the where_feed)*/
	put 'function EditPage() {';
		put 'form1.filter_clause.value=""';
		put "form1._program.value=&CS_FLTR_SCRN";
		put 'form1.submit()';
	put '}';
	/*********EditPage() ends here**************/

	/*Function ResetPage() for reseting the value of filter_clause to null*/
	put 'function ResetPage() {';
		put 'form1.filter_clause.value=""';
		put 'form1.pd_score.value=""';
		put 'form1.range_interval.value=""';
		put 'form1.no_of_quantile.value=""';
		put 'form1.filter.value="NO"';
		put 'form1.ksDist.value=""';
		put 'form1._program.value="'@;
		put "&prg_name"@;
		put '";';
		put 'form1.submit()';
	put '}';
	/*********ResetPage() ends here*************/

	/*Function savepage() for saving the page to disk */
	%savepage;
	/*********savepage() ends here*************/

	/*Function printpage() for printing the page to a printer or to a pdf file*/
	%printpage;
	/*********printpage() ends here*************/

	put '//-->';
	put '</script>';

/**************************Javascript Ends here ****************************************/

	put '</head> ';
	put '<body>';
	put '<form name="form1" method="post" action="/SASStoredProcess/do">';

	/* Stores the values of all the global variables in hidden textboxes
	This is done to pass the values to the next Stored Process */
	put '<input type="hidden" name="_program" VALUE="'@;
	put "&prg_name"@;
	put '">';
	prod_type_desc=symget("prod_type_desc");
	put '<input type="hidden" name="prod_type_desc" value="' @;
	put prod_type_desc;
	put '">';
	prod_type_code=symget("prod_type_code");
	put '<input type="hidden" name="prod_type_code" value="' @;
	put prod_type_code;
	put '">';
	model_type_code=symget("model_type_code");
	put '<input type="hidden" name="model_type_code" value="' @;
	put model_type_code;
	put '">';
	include_exp_mdl=symget("include_exp_mdl");
	put '<input type="hidden" name="include_exp_mdl" value="' @;
	put include_exp_mdl;
	put '">';
	model1=symget("model1");
	put '<input type="hidden" name="model1" value="' @;
	put model1;
	put '">';
	model1_key=symget("model1_key");
	put '<input type="hidden" name="model1_key" value="' @;
	put model1_key;
	put '">';
	model2=symget("model2");
	put '<input type="hidden" name="model2" value="' @;
	put model2;
	put '">';
	model2_key=symget("model2_key");
	put '<input type="hidden" name="model2_key" value="' @;
	put model2_key;
	put '">';
	sel_model=symget("sel_model");
	put '<input type="hidden" name="sel_model" value="' @;
	put sel_model @;
	put '">';
	sel_model_key=symget("sel_model_key");
	put '<input type="hidden" name="sel_model_key" value="' @;
	put sel_model_key @;
	put '">';
	period=symget("period");
	put '<input type="hidden" name="period" value="' @;
	put period;
	put '">';
	time_key=symget("time_key");
	put '<input type="hidden" name="time_key" value="' @;
	put time_key;
	put '">';
	statistic=symget("statistic");
	put '<input type="hidden" name="statistic" value="'@;
	put statistic;
	put '">';
	filter=symget("filter");
	put '<input type="hidden" name="filter" value="'@;
	put filter;
	put '">';
	filter_clause=symget("filter_clause");
	put '<input type="hidden" name="filter_clause" value="'@;
	put filter_clause;
	put '">';
	ksDist=symget("ksDist");
	put '<input type="hidden" name="ksDist" value="'@;
	put ksDist;
	put '">';
	pd_score=symget("pd_score");
	put '<input type="hidden" name="pd_score" value="' @;
	put pd_score;
	put '">';
	range_interval=symget("range_interval");
	put '<input type="hidden" name="range_interval" value="' @;
	put range_interval;
	put '">';
	no_of_quantile=symget("no_of_quantile");
	put '<input type="hidden" name="no_of_quantile" value="' @;
	put no_of_quantile;
	put '">';
	prg_name=symget("prg_name");
	put '<input type="hidden" name="prg_name" value="' @;
	put prg_name;
	put '">';
	model_type_desc=symget("model_type_desc");
	put '<input type="hidden" name="model_type_desc" value="' @;
	put model_type_desc;
	put '">';
	outcome_period=symget("outcome_period");
	put '<input type="hidden" name="outcome_period" value="' @;
	put outcome_period;
	put '">';
	elapsed_time=symget("elapsed_time");
	put '<input type="hidden" name="elapsed_time" value="' @;
	put  elapsed_time;
	put '">';
	put '<input type="hidden" name="called_program" value="'@;
	put "&prg_name"@;
	put '">';
	/**********************/
run;

/*Calls the macro generate_feed for obtaining the required feed by passing
	the following parameters
	1. in_filter		: Where clause (on the basis of the filter clause)
	2. out_lib_nm		: Library name where the output feed will be created. 
	3. out_table_nm_pool: The table name for pool level feed
	4. out_table_nm_acct: The table name for account/application level feed
	5. feed_for			: Possible values are PD, LGD, CCF, APPLPD, APPLLGD. This macro parameter
							decides whether estimated pd/lgd/ccf has to calculated at account 
							level or application level 
	6. pd_score			: Possible values are (Empty), PD, SCORE
          a. (empty)	: The default pooling technique will be used
          b. PD			: If PD then dynamic pooling technique will be used, 
              			  based on PD/LGD/CCF as mentioned in the previous parameter(feed_for) 
          c. SCORE		: If SCORE then dynamic pooling technique will be used,
              				based on SCORE_POINTS. Applicable only if PD or APPLPD value
              				is set in the previous variable (feed_for)
	7. range_interval	: Dynamic pooling based on the range specified. E.g. 100, 200 for
	              			SCORE and .2, .3 for PD. Similar ranges for LGD/CCF
	8. no_of_quantile	: The range for dynamic pooling will be decided based on the quantile.
							Quantile ranges will be calculated based on the SCORE/PD/LGD/CCF 
							of the scoring population for the selected score period
	9. long_run			: Possible values Y/N. Whether the long run calculation is to be
							used to find estimated pd/lgd/ccf
	10. long_run_type	: Possible values are MAX/AVG. Method for calculating the long run
							pd/lgd/ccf  
	11. model_time_key  : Contains the concatenated values of model and time in the
							format _<model_sk>_<time_sk>. This is used to identify
							which fact table should be considered while generating 
							the feed.
	12. product_type_code	: This is the selected product type code (E.G. MTG, LON).
*/
%global error_code;
%let error_code=NONE;
%let model_time=_%sysfunc(ktrim(%sysfunc(kleft(&sel_model_key.))))_%sysfunc(ktrim(%sysfunc(kleft(&time_key.))));
/*Macro that creates data feeds for further processing*/
%generate_feed(in_filter=&where_feed, out_lib_nm=&out_lib., 
      out_table_nm_pool=&out_pool, out_table_nm_acct=&out_account, feed_for=&feed_pd, 
	  long_run=&LONG_RUN, pd_score=&pd_score, range_interval=&range_interval, 
	  no_of_quantile=&no_of_quantile, long_run_type=&LONG_RUN_TYPE, 
	  model_time_key=&model_time, product_type_code=&prod_type_code);

/* Checks whether the generate_feed macro generated any error.
	If any error is generated then the ResetPage function defined above is called*/
 
data _NULL_;
	file _webout&webout_options;
		if ktrim(kleft("&error_code")) ne "NONE" and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_selec_filter_criteria.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
run;

/* Checks whether the dataset created in the generate_feed macro has any observations
			and sets cnt to the number of observations in the dataset*/
%let cnt=.;
proc sql noprint;
      select Count(*) into :cnt from &out_lib..&out_pool;
quit;

/* If there is no observation in the above dataset i.e. cnt=0 then the ResetPage function
	defined above is called */
%let log_name=;
data _NULL_;
	file _webout&webout_options;
	if &cnt eq 0 and (ktrim(kleft("&filter_clause")) ne "" or ktrim(kleft("&pd_score")) ne "") then do;
		put '<script>';
		put '<!--';
		put 'alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.alert_error_selec_filter_criteria.1, noquote))"@;
		put '")';
		put 'ResetPage()';
		put '//-->';
		put '</script>';
	end;
	call symput('log_name',"&CS_DEBUG_PATH./&out_pool."||".log");
run;

/******ERROR TO GET LOG IN THE Specified LIBNAME*************/
%debug_log_file(log_file_nm=&log_name);

/* Data creation for measure_nm in a dataset and call for feed_measure */
proc sql;
	create table &out_lib..&in_stat_ot as
	select measure_nm, help_file_nm 
	from dim.measure_dim
	where kupcase(program_nm)=kupcase("&prg_name") and 
		kupcase(model_type_cd)="&model_type_code";
/*	order by measure_nm;*/
quit;

data _null_;
	set &out_lib..&in_stat_ot;
	call symput('name_html',help_file_nm);
run;

/* Calls the feed_measure macro for generating the dataset containing the statistic 
	values over time. The following parameters are passed to this macro:
		1. in_filter			: where clause 
		2. out_lib_nm			: library name from where the input dataset is picked
								  from and where the ouput dataset is stored
		3. in_table_nm			: the input dataset to be passed
		4. out_table_nm_measure	: the output dataset created in the macro
*/
%feed_measure(in_filter=&where_measure, out_lib_nm=&out_lib., in_table_nm=&in_stat_ot, 
	out_table_nm_measure=&out_stat_ot);

proc sql noprint;
	select cut_off_score into :cutoff 
	from dim.analytical_model_dim 
	where model_sk=&sel_model_key;
quit;

/* Depending on the ksDistribution type the data preparation macros are called
with respective arguments*/
%macro chkksDistype;
%if &ksDist=AGAB %then
	%cs_rep_data_prep(input_ds=&out_lib..&out_pool,output_ds=&out_data_prep,Dist_type="ACT");
%else %if &ksDist=EGEB %then
	%cs_rep_data_prep(input_ds=&out_lib..&out_pool,output_ds=&out_data_prep,Dist_type="EST");
%mend chkksDistype;
%chkksDistype;

/* The KS_Stat macro creates the data set for plotting the KS graph.
	The following parameters are passed to this macro:
	input_ds		: Name of the input data set
	output_graph_ds	: Name of the data set which stores data for graph of ks
*/
%ks_stat(input_ds=&out_data_prep,output_graph_ds=&out_graph_ds);

/* All other data and macro variable creations (as required in the report) */
/* Modeling Values for statistics */
proc sql noprint;
	select Measure_value format=&CS_DEC_FMT. into :MDL_MEASURE_VALUE
	from &out_lib..&out_stat_ot
	where kupcase(dev_flg)="%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.dev_flag_y.1, noquote))"
	order by Measure_nm;
quit;

/*The sqlproc macro performs the needed sqls for creating and updating intermediate
tables used for processing*/
%macro sqlproc(firstvar,secondvar);
proc sql;
	create table work.maxtab
	as select diff, &firstvar, &secondvar, score 
	from work.KS_dev  
	where ks=(select max(ks) from work.KS_dev); /* To find the max diff and co-ords*/

	update work.KS_dev set maxval=(select diff from work.maxtab),
	dgoods=(select &firstvar from work.maxtab),
	dbads=(select &secondvar from work.maxtab)
	where score=(select score from work.maxtab);
		
	update work.KS_dev set maxval=NULL, dgoods=NULL, dbads=NULL
	where dgoods=0; 
	select diff into :ks from work.maxtab;

	select dist_good,dist_bad into :dg,:db from work.maxtab;
quit;
%mend sqlproc;

/*This macro plots the KS graph*/
%macro plotgraph_distline(fvar,svar);
proc gplot data=work.KS_dev;
	symbol1 color=&color_symbol1 width=.15 height=2 interpol=spline value=dot;
	symbol2 color=&color_symbol2 width=.15 height=2 interpol=spline value=none;
	symbol3 color=&color_symbol3 width=.15 height=2 interpol=needle value=none;
	symbol4 color=&color_symbol20 width=.15 height=2 interpol=needle value=none;

	axis1 label=("%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_ks_axis1.1, noquote))") width=1;
	axis2 label=(a=90 "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_ks_axis2.1, noquote))") order=(0 to 1 by .1) width=1;
	legend1 label=("%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_legend.1, noquote))") 
		value=( "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_legend_value_1.1, noquote))"
			    "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_legend_value_2.1, noquote))"
				"%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_legend_value_3.1, noquote))" 
			COLOR=WHITE 'dgoods');

	%if &ksDist=AGAB %then %do;
	   	plot &fvar * score=1
			 &svar * score=2
		%if %sysevalf(&dg > &db) %then %do;	
			dgoods * score=3
			 dbads * score=4
		%end;
		%else %do;
			 dbads * score=3
	 		dgoods * score=4
		%end;
		/ overlay haxis=axis1 vaxis=axis2 hminor=0 vminor=1
			name="&name1" legend=legend1;
	%end;
	%else %if &ksDist=EGEB %then %do;
		plot &fvar * score=1
			 &svar * score=2
		%if %sysevalf(&dg > &db) %then %do;	
			dgoods * score=3
			 dbads * score=4
		%end;
		%else %do;
			 dbads * score=3
			dgoods * score=4
		%end;	
		/ overlay haxis=axis1 vaxis=axis2 hminor=0 vminor=1
			name="&name2" legend=legend1;
	%end;
	run;
quit;
%mend plotgraph_distline;

/*This macro plots the KS cutof graph*/
%macro plotKSP;
symbol5 color=&color_symbol1 interpol=join;
axis1 label=("%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_ks_cut_off_axis1.1, noquote))");
axis2 label=(a=90 "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_ks_cutt_off_axis2.1, noquote))");
proc gplot data=work.KS_dev;
	%if &feed_pd eq &FEED_FOR_APPLPD %then %do;
		footnote "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_legend.1, noquote))" 
			c=red '--' 
			c=black "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_foot_note_value1.1, noquote))"
			c=&color_symbol3 '--' 
			c=black "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_foot_note_value2.1, noquote))";
	%end;
	%else %do;
		footnote "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_legend.1, noquote))"
		c=&color_symbol3 '--'
		c=black "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_foot_note_value2.1, noquote))";
	%end;
	format KS &CS_DEC_FMT.;
	plot KS*score=5 
	%if &feed_pd eq &FEED_FOR_APPLPD %then %do;
		/ haxis=axis1 vaxis=axis2 href=&KS_Cutof &cutoff chref=(&color_symbol3. red) 
		name="&name3" cframe=white legend=legend1;         
	%end;
	%else %do;
		/ haxis=axis1 vaxis=axis2 href=&KS_Cutof chref=(&color_symbol3.)
		name="&name3" cframe=white legend=legend1;         
	%end;
	run;
quit;
%mend plotKSP;

/*This macro performs the required initial calculations and also calls the other
macros as per the option selected.*/
options mprint nomlogic;
%macro mparent;
proc sql noprint;
	drop table work.KS_dev;
quit;

data work.KS_dev;
	set &out_graph_ds;
	diff = Dist_Good - Dist_Bad; 
	maxval=0; dgoods=0; dbads=0;
run;

proc sql noprint;
	select max(ks) into :Max_KS from work.KS_dev;
	/*The select stmt below is for display purpose only*/
	select max(ks) format=&CS_DEC_FMT. into  :Max_KS_fmt from work.KS_dev;
	select score format &CS_DEC_FMT. into :KS_Cutof from work.KS_dev 
		where put(ks,best8.6)=put(&Max_KS,best8.6);
quit;

%if &ksDist=AGAB %then %do;
	%sqlproc(Dist_Good,Dist_Bad); 
	%plotgraph_distline(Dist_Good,Dist_Bad);
	%plotKSP;
%end;
%else %if &ksDist=EGEB %then %do; 
	%sqlproc(Dist_Good,Dist_Bad); 
	%plotgraph_distline(Dist_Good,Dist_Bad);
	%plotKSP;
%end;
%mend mparent;
%mparent; /* Call the parent macro from here so that o/p is proper */

/* Calls the model_traffic macro to get the traffic lighting for the data provided
	The following parameters are passed to this macro
			1. data1	: input dataset containing the columns measure_value and 
							measure_nm
			2. model_cd	: MODEL TYPE (PD Approvals, PD Ongoing, LGD, CCF)
	This macro adds one more column named color to the dataset passed which contains
	values ( Green, Red, Yellow, White) depending on the bounds(for red and green) 
	provided in the measure_dim dataset.
*/
%let color=;
%model_traffic (model_cd=&model_type_code,value=&Max_KS, ms_name=&statistic, product_type_code=&prod_type_code);
%let color=&color;
/* Creation of all graphs and call to overtime macro */
/*******Macro statistic_overtime parameter passed
      	1.Dataset this dataset will be ouput dataset of Macro feed_measure
	  	2.statistic (For Eg. D Statistic etc.)
		3.graph name (generated from timestamp)
******/
%statistic_overtime(&out_lib..&out_stat_ot,&statistic,&otname);

/* Macro for getting the Pooling Technique.
	In this macro the following indicates:
		1.pd_score 			: If null then shown  as DEFAULT stautus.
		2.time_key        	: The surrogate key for selected period.
        3.sel_model_key        : The surrogate key for the selected model.
 		4.no_of_quantile    : The range for dynamic pooling will be decided based on
							  the quantile.Quantile ranges will be calculated based
							  on the SCORE/PD/LGD/CCF of the scoring  population
							  for the selected score period.
	    5.range_interval    : Dynamic pooling based on the range specified.
		  						E.g. 100, 200 for SCORE and .2, .3 for PD.	*/
%let pool_tech=;
%pool_technique;

%debug_log_web;
%let view_feed=&out_pool..html;
/* All data _null_ statements to create the html */
data _null_;
	file _webout&webout_options;
	rep="&statistic";
	format rep &format_name..;
	name_html=symget("name_html");
	put'<script>';
		/**************Help File *********************/
	%helpfile(filename=&name_html);

		/*************feed Table*********************/
	put 'function feed_table(){';
		put'window.open("/SASCSReports/'@; 
			put "&view_feed"@; 
	put '")};';
		
	put'</script>';

	put '<table width="100%"  border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED">';

	/* To display SAS credit scoring as heading */
	put '<tr>';
	put '<td align="left">';
	put '<table width="100%"  border="0" align="left" cellpadding="3" cellspacing="0">';
	put '<tr>';
	put '<td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td><span class="BreadCrumb">'; 
	put '<a href="javascript:Link1()">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.link_reporting.1, noquote))"@;
	put '</a> &gt;<a href="javascript:Link2()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.link_monitoring_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link3()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.link_sel_model.1, noquote))"@;
	put '</a> &gt; <a href="javascript:Link4()" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.link_sel_stats.1, noquote))"@;
	put '</a> &gt;';
	put '</span><span class="BreadCrumb" >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.link_ks.1, noquote))"@;
	put '</span></td>';
	put '<td width="215"><div align="right"><img src="/SASCSReports/images/CrBanner.gif" width="259" height="29"></div></td>';
	put '</tr></table>';

	/* Heading ends */
	put '<H2 align="left"><table width="100%"  border="0" cellspacing="0" cellpadding="0"><tr><td>';
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.report_nm_ks.1, noquote))"@;
	put '</td>';
	if kupcase(&print) eq 'Y' then do;
		put '<td width=65><div align="center"><span class="LabelFont">';
		put '<a href="javascript:printpage()">';
		put '<img src="/SASCSReports/images/Print.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_print.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&save) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:enregistre()">';
		put '<img src="/SASCSReports/images/SaveFile.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_save.1, noquote))"@;
		put '</div></td>';
	end;
	if kupcase(&help) eq 'Y' then do;
		put '<td width=50><div align="center"><span class="LabelFont">';
		put '<a href="javascript:Info()">';
		put '<img src="/SASCSReports/images/Info.gif" border="0"></a>'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.report_help.1, noquote))"@;
		put '</div></td>';
	end;
	put '</tr></table></H2>';
	put '</td></tr>';

	/*Values of Product_type Period and Model*/
	put '<tr>';
	put '<td align="left">';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_model_type.1, noquote))"@;
	put "&model_type_desc"@;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_product_type.1, noquote))"@;
	put "&prod_type_desc" @;
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_period.1, noquote))"@;
/*I18N-scnhuh-20080427-1455*/	
/* del one line, add two lines. For displaying in NLS format */	
/*	put "&period" @;*/
		Period_WEBUI=put(input("&period",&CS_TIME_PER_FMT.),&NLDATE_FMT.);
		put Period_WEBUI @;
/*I18N-scnhuh-20080427-1455*/		
	put '</p>';
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_model.1, noquote))"@;
	put "&sel_model" @;
	put '</p>';

	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_pooling_tech.1, noquote))"@;
	put "&pool_tech";
	put '</p>';

	/* Target period and elapsed time*/
	put '<p class="LabelFont">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_outcome_period.1, noquote))"@;
	put "&outcome_period" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_months.1, noquote))"@;
	put "&elapsed_time" @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_month_elapsed.1, noquote))"@;
	put '</p>';

	/* Display Actual and Modeling values */
	put '<table  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';
	put '<td><span class="LabelFont">'@;
	put rep @;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_actual_val.1, noquote))"@;
	put ': '@;
	put "&Max_KS_fmt" @;
	put '</span></td><td>&nbsp;</td>';

	put'<td width="25"><div align="center"><span class="LabelFont"><img src="/SASCSReports/images/';
	if "&color"="%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.colour_white.1, noquote))" then do;
		put 'spacer.gif"';
	end;
	else do;
		put 'Sphere'@;
		put "&color"@;
		put '.gif"';
	end;
	put 'width="16" height="16" border="0"></a> </span></div></td>';
	put '<td width="50"><span class="LabelFont"></span></td>';
	if %str("&filter")=%str("NO") then do;
		put '<td><span class="LabelFont">'@;
		put rep @;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_modeling_val.1, noquote))"@;
		put': '@;
		if symexist("MDL_MEASURE_VALUE") eq 0 then 
			put '.' @;
		else 
			put "&MDL_MEASURE_VALUE" @;
		put '</span></td>';
	end;
	put '<td>&nbsp;</td>';
	put '</tr>';
	put '</table>';
	put '<p class="LabelFont">&nbsp;</p><fieldset>';

	/* Display distribution selection */
	put '<legend><span class="style2">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.label_distribution.1, noquote))"@;
	put '</span></legend>';
	put '<p class="style2">';
	put '<input name="radiobutton" type="radio" value="radiobutton" onClick="javascript:assign_to_ksDist(''AGAB'')"'@;
	if &ksDist=AGAB then do;
		put ' checked="checked"'@;
	end;
	put ' >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_nm_actual_good_actual_bad.1, noquote))"@;
	put '&nbsp;&nbsp;&nbsp;'; 
	put '<input name="radiobutton" type="radio" value="radiobutton" onClick="javascript:assign_to_ksDist(''EGEB'')"'@; 
	if &ksDist=EGEB then do;
		put ' checked="checked"'@;
	end;
	put ' >'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_nm_estimated_good_estimated_bad.1, noquote))"@;
	put'</p>';
	put '</fieldset>';
	put '</td>';
	put '</tr>';
	put '<tr>';
	put '<td align="left">';
	put '<p>';

/* Graphs */
	put '<H2 align="left">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_nm_ks.1, noquote))"@;
	put '</H2>';
	put '</td>';
	put '</tr>';
	put '<tr><td><table width="100%"  border="0" cellspacing="0" cellpadding="0">';
	put '<tr>';

	/* KS Graph */
	put '<td width="49%" valign="top"><fieldset>';
	put '<legend><span class="style2">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_nm_ks.1, noquote))"@;
	put ':</span></legend>';
	if "&ksDist"="AGAB" then do;
			put '<p><img src="/SASCSReports/'@;
			put "&name1";
			put '.gif" width="460" height="200" onload="persist(1)"></p>';
	end;
	else if "&ksDist"="EGEB" then do;
			put '<p><img src="/SASCSReports/'@;
			put "&name2";
			put '.gif" width="460" height="200" onload="persist(2)"></p>';
	end;
	put '</fieldset></td>';
	put '<td width="2%">&nbsp;</td>';

	/* KS Cutoff Plot */
	put '<td width="49%" valign="top"><fieldset>';
	put '<legend><span class="style2">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.graph_nm_ks_cutt_of_plot.1, noquote))"@;
	put ':'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.select_models.model_appl_pd.1, noquote))"@;
	put '</span></legend>';
		put '<p><img src="/SASCSReports/'@;
		put "&name3"@;
		put '.gif" width="460" height="200"></p>';
	put '</fieldset></td>';
	put '</tr>';

	/*filter is no then display the statistic overtime graph*/
	if %str("&filter")=%str("NO") then do;
	    put '<td width="49%" valign="top"><fieldset>';
	    put '<legend><span class="style2">'; 
		put rep ;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.stats_over_time.1, noquote))"@;
		put ':</span></legend>';
	    put '<p><img src="/SASCSReports/'@;
		put "&otname";
		put '.gif" width="460" height="200"></p>';
	    put '</fieldset></td>';
	    put '</tr>';
	end;
	else do;
	        put '<td width="49%" valign="top">';
	        put '</td>';
	end;
	put '</fieldset></td>';
	put '</tr>';
	put '</table>';
	put '<p>&nbsp;</p></td>';
	put '</tr>';
	put '</table>';
	put '</td>';
	put '</tr>';
	put '<tr>';
	put '<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';

/* Filter/Re-Pool and Reset button will get displayed only if the pooling technique
	 is not of clustering type*/
	val=PRXMATCH(kupcase('/cluster/'),kupcase("&pool_tech"));
	if val = 0 then do;
		put '<INPUT type=button class=mmhide_btn onClick=EditPage() value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.button_filter_repool.1, noquote))"@;
		put '">';
		put '<INPUT type=button class=mmhide_btn onClick=ResetPage() value="'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.button_reset.1, noquote))"@;
		put '">';
	end;
	put '<INPUT type=button class=mmhide_btn onClick="feed_table()" value="'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.ks.button_view_feed.1, noquote))"@;
	put '">';
	put '</td>';
	put '</tr>';
	put '</table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;

/******macro feed_table pass parameter  separated by #

		Input parameter 
		1.dt_st =Pass dataset name in string separated by #
		2.dt_nm=pass name u want to give to the table
		3.out_libout library  which is defined above
		        *****************************************************************/
/*I18N-scnjih-20080424-0928*/
/*%let dt_nm=Pool Feed;*/
%let dt_nm=%sysfunc(sasmsg(smd_ds.bismsg,Call_feed_table.sas.dt_nm.1, noquote));

data &out_lib..&out_pool._1; 
set &out_lib..&out_pool.;
SCORE_POINTS=round(SCORE_POINTS);
run;

/*I18N-scnjih-20080424-0928*/
%let dt_st=&out_pool._1;
%feed_table(ds=&dt_st,out_lib1=&out_lib,data_name=&dt_nm,name_html=&view_feed);

goptions reset=all;
options nomprint;
