/******************************************************************************************************
       Module:  build_scheme_score_pool

     Function:  To define the pools for the selected pool scheme

      Authors:  BIS Team
         Date:  14 May 2007
          SAS:  9.1
    Called-by:	pool_main
        Calls:

Datasets used:  1. pool.pool_scheme_defn: Retrieves the defn of existing pool schemes and saves the defn
					for new schemes in this dataset
				2. dim.analytical_model_dim: Retrieves the PD, LGD and CCF models from this
					dataset
				3. pool.build_abt_status: Stores the status of the building activity of the various ABTs
					to be built for the pool scheme
				4. The scored datasets _<PD_MODEL_RK>_PD, _<LGD_MODEL_RK>_LGD, _<CCF_MODEL_RK>_CCF
				5. The long run datasets _LNG_<PD_MODEL_RK>_PD, _LNG_<PD_MODEL_RK>_PD_LGDYRS,
					_LNG_<LGD_MODEL_RK>_LGD, _LNG_<CCF_MODEL_RK>_CCF, _LNG_<CCF_MODEL_RK>_CCF_LGDYRS
				6. pool.pool_defn: Retrieves the defn of existing pools for the pool scheme and saves
					the defn for new pools in this dataset

        Logic:  1. The user may select for the list of completed schemes which are of Score ranges based
				2. If an existing pool defn exists for the selected scheme, retrieve it from
					pool.pool_defn and display it on screen
				3. If an existing pool defn does not exist, create pools with a default interval of 100
					and calculate the no of accounts and assigned PD, LGD and CCF for the pools
				4. Other actions available on the screen are defining of pools based on a
					specified interval or quantile, change the defn on screen by merging selected
					pools or spliting at a given value and editing the description of a pool.
				5. Once a pool is defined, it may be saved by clicking the Save button.
				6. The no of accounts are deterined by pooling the scored PD dataset.
				7. The ssigned PD, LGD, CCF values for the pools are determined by the assignment
					methods AVG, LRA, LRM and the scored or long run datasets.
				8. The available actions are:
						N: None.
						R: Retrieve. If the scheme_nm and scheme_no exist in the pool tables, a retrieval
							is done.
						M: Merge
						S: Split
						I: Interval
						Q: Quantile
						D: Edit Pool Description
						V: Save

   Parameters:  scheme_no 		: The unique identifier of an existing pool scheme
   				scheme_type		: Pool scheme type. For e.g., SCR, PDR, PLR, PLC, PMS
				action 			: Screen action code
				interval		: Determines the pool boundaries based on the interval specified
				quantile		: Determines the pool boundaries based on the number of equi
									sized pools specified
				split_val		: Splits the pool at the value specified
				merge_min_val	: Specifies the lowest pool to be considered for merging
				merge_max_val	: Specifies the highest pool to be considered for merging
				pool_desc		: Specifies the description to be set for the specified pool
				pool_no_desc	: Specifies the pool to which the pool description should be set
				ks_value		: Specifies the calculated KS value for the scheme
				stab_value		: Specifies the calculated pool stability index value for the scheme

 ******************************************************************************************************/
/*This code is Internationalized*/
options nomprint;

/* Global Input Parameters */
%global scheme_no scheme_type action interval quantile split_val merge_min_val merge_max_val
	pool_desc pool_no_desc ks_value stab_value;

%let lib=pool;
 options mlogic mprint;

/* Trimming extra spaces for all input paremeters */
%macro check_macro_variable;
%if "&scheme_no" ne "" %then
	%let scheme_no=%str(%sysfunc(ktrim(%sysfunc(kleft(&scheme_no)))));
%if "&action" ne "" %then
	%let action=%str(%sysfunc(ktrim(%sysfunc(kleft(&action)))));
%if "&interval" ne "" %then
	%let interval=%str(%sysfunc(ktrim(%sysfunc(kleft(&interval)))));
%if "&quantile" ne "" %then
	%let quantile=%str(%sysfunc(ktrim(%sysfunc(kleft(&quantile)))));
%if "&split_val" ne "" %then
	%let split_val=%str(%sysfunc(ktrim(%sysfunc(kleft(&split_val)))));
%if "&merge_min_val" ne "" %then
	%let merge_min_val=%str(%sysfunc(ktrim(%sysfunc(kleft(&merge_min_val)))));
%if "&merge_max_val" ne "" %then
	%let merge_max_val=%str(%sysfunc(ktrim(%sysfunc(kleft(&merge_max_val)))));
%if "&pool_no_desc" ne "" %then
	%let pool_no_desc=%str(%sysfunc(ktrim(%sysfunc(kleft(&pool_no_desc)))));
%if "&ks_value" ne "" %then
	%let ks_value=%str(%sysfunc(ktrim(%sysfunc(kleft(&ks_value)))));
%if "&stab_value" ne "" %then
	%let stab_value=%str(%sysfunc(ktrim(%sysfunc(kleft(&stab_value)))));
/*%if "&pool_desc" ne "" %then %do;*/
			%let pool_desc=&pool_desc;
/*Code to remove the doubble quotes or single quotes if present*/
			%let pool_desc_c1=%index(&pool_desc,%str(%'));
			%let pool_desc_c2=%index(&pool_desc,%str(%"));
			data _null_;
				%if %str(&pool_desc_c1) ne %str(0) %then %do;
					x=compress(&pool_desc,"'");
					call symput('pool_desc',x);
				%end;
				%else %if %str(&pool_desc_c2) ne %str(0) %then %do;
					x=compress(&pool_desc,'"');
					call symput('pool_desc',x);
				%end;
			run;
/*	%let pool_desc=&pool_desc_out;*/
/**************************************/	
/*%end;*/
%mend;
%check_macro_variable;

/* Links specific for the Score Range screens */
%let SELECT_POOL_SCHEME='SBIP://Foundation/BIS/pool/build_scheme_score_pool';
%let VIEW_POOL_SCHEME=SBIP://Foundation/BIS/pool/view_scheme;

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;


%let in_score_range=%sysfunc(ktrim(%sysfunc(kleft(_&scheme_no._score_range_in))));
%let out_score_range=%sysfunc(ktrim(%sysfunc(kleft(_&scheme_no._score_range_out))));
%let pool_defn=%sysfunc(ktrim(%sysfunc(kleft(_&scheme_no._pool_defn))));
%let out_data_prep=%sysfunc(ktrim(%sysfunc(kleft(&out_lib.._&scheme_no._data_prep))));
%let out_graph_ds=%sysfunc(ktrim(%sysfunc(kleft(&out_lib.._&scheme_no._ks_graph))));
%let out_pool_stab=%sysfunc(ktrim(%sysfunc(kleft(&out_lib.._&scheme_no._psi))));

/* Setting default values for any required parameters */
data _null_;
	if "&action"="" then call symput('action', 'N');
	if "&scheme_no"="" then call symput('scheme_no', '.');
	if "&ks_value"="" then call symput('ks_value','.');
	if "&stab_value"="" then call symput('stab_value','.');
run;

/* Display screen with table and pool stability index in all cases except when action = N */
%macro display_screen;
	%if "&action" ne "N" %then %do;
		data _null_;
			file _webout&webout_options;
			put '			<tr>';
			put '				<td>';

			/* If action ne N */
				/*table*/
			put '					<table border="0" width="100%" cellpadding="" cellspacing="0" class="tableborder">';
			put '						<tr bgcolor="#7F9DB9">';
			put '							<td width="3%" align="center" class="HZtableborder" rowspan=2>';
				/*<!-- slide down content goes here -->*/
			put '								<div id="dhtmlgoodies_slidedown">';
			put '								<div id="dhtmlgoodies_control"><a href="#" onclick="slidedown_showHide();return false;"><img src="/SASCSPooling/images/ActionMenu.gif" style="border:0"/></a>
			</div>';
			put '								<div id="dhtmlgoodies_contentBox">';
			put '									<div id="dhtmlgoodies_content">';
			put '									<table width="100%" border="1" class="tableborder" cellpadding="3" cellspacing="0">';
			put '										<tr><td>';
			put '										<table width="100%" border="0" cellpadding="3" cellspacing="0">';
			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="M"></td>';
			put '											<td width=35% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.radio_nm_merge.1, noquote)) "@;
			put '</td>';
			put '											<td align="left">';
			put '												<input type="hidden" name="merge_pool" size=15 maxlength=70 value="'@;
			put '"></td>';
			put '										</tr>';

			spt=ktrim(kleft("&split"));
/*			spt="&split1";*/
/*			if spt='' then spt=.;*/
			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="S"></td>';
			put '											<td width=30% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.radio_nm_split.1, noquote))"@;
			put '</td>';
			put '											<td align="left">';
			put '												<input type="text" name="split_val" size=15 maxlength=70 value="'@;
			if spt='' then ;
			else
				put spt @;
			put '"></td>';
			put '										</tr>';

			int=ktrim(kleft("&interval"));
/*			if int='' then int=.;*/
			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" checked="checked" value="I"></td>';
			put '											<td width=30% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.radio_nm_interval.1, noquote))"@;
			put '</td>';
			put '											<td align="left">';
			put '												<input type="text" name="interval_val" size=15 maxlength=70 value="'@;
			if int='' then ;
			else
				put int@;

			put '"></td>';
			put '										</tr>';

			qnt=ktrim(kleft("&quantile"));
/*			if qnt='' then qnt=.;*/
			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="Q"></td>';
			put '											<td width=30% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.radio_nm_quantile.1, noquote))"@;
			put '</td>';
			put '											<td align="left">';
			put '												<input type="text" name="quantile_val" size=15 maxlength=70 value="'@;
			if qnt='' then ;
			else
				put qnt@;
			put '"></td>';
			put '										</tr>';

			put '										<tr>';
			put '											<td width=5% align="center">';
			put '												<input type="radio" name="action_radio" value="D"></td>';
			put '											<td width=30% align="left">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.radio_nm_desc.1, noquote))"@;
			put '</td>';
			put '											<td align="left">';
			put '												<input type="text" name="edit_desc" size=15 maxlength=70 value=""'@;
			put '"></td>';
			put '										</tr>';
			put '										</table>';
			put '										<table width="100%" border="0" cellpadding="3" cellspacing="0">';
			put '										<tr>';
			put '											<td align="left">&nbsp;';
			put '												<INPUT type=button class=mmhide_btn onClick="javascript:OK()" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.button_ok.1, noquote))"@;
			put '">';
			put '												<INPUT type=button class=mmhide_btn onclick="slidedown_showHide();return false;" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.button_cancel.1, noquote))"@;
			put '"></td>';
			put '										</tr>';
			put '										</table>';
			put '										<tr><td>';
			put '									</table>';
			put '									</div>';
			put '								</div>';
			put '								</div>';
				/*		<!-- End slide down content -->*/
			put '							</td>';
			put '							<td width="5%" align="right" class="HZtableborder" rowspan=2>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_pool_seq_no.1, noquote))"@;
			put '</td>';
			put '							<td width="10%" align="right" class="HZtableborder" rowspan=2>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_strt_scr_rng.1, noquote))"@;
			put '</td>';
			put '							<td width="10%" align="right" class="HZtableborder" rowspan=2>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_end_scr_rng.1, noquote))"@;
			put '</td>';
			put '							<td align="left" class="HZtableborder" rowspan=2>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_pool_desc.1, noquote))"@;
			put '</td>';
			put '							<td width="10%" align="right" class="HZtableborder" rowspan=2>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_no_of_acct.1, noquote))"@;
			put '</td>';
			put '							<td class="HZtableborder" align="center" colspan=3>'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_assigned.1, noquote))"@;
			put '</td>';
			put '						</tr>';
			put '						<tr>';
			put '							<td width="7%" align="right" class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_pd.1, noquote))"@;
			put '</td>';
			put '							<td width="7%" align="right" class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_lgd.1, noquote))"@;
			put '</td>';
			put '							<td width="7%" align="right" class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_ccf.1, noquote))"@;
			put '</td>';
			put '						</tr>';
		run;

		data _null_;
			file _webout&webout_options;
			set &lib..&pool_defn.;
			if  mod(_N_,2)=0 then
				put '						<tr bgcolor="#F4F4F2" class="Font12px">';
			else
				put '						<tr bgcolor="#FFFFFF" class="Font12px">';
			put '							<td class="verttebleborder">&nbsp;';
			put '								<input type="checkbox" name="c" value="'@;
			put pool_seq_no@;
			put '" OnClick="javascript:SelPool(this)"'@;
			put '><br></td>';

			put '							<td class="verttebleborder" align="right">' @;
			put pool_seq_no  @;
			put '</td>';

			put '							<td class="verttebleborder" align="right">' @;
			put from_score @;
			put '</td>'@;

		  	put '							<td class="verttebleborder" align="right">'@;
			put to_score @;
			put '</td>' ;

			put '							<td class="verttebleborder">';
			put pool_name;
			put'</td>';

			put '							<td class="verttebleborder" align="right">';
			put No_of_Accounts;
			put'</td>';

			assigned_pd=put(assigned_pd, &CS_DEC_FMT);
			put '							<td class="verttebleborder" align="right">';
			put assigned_pd@;
			put '</td>';
			assigned_lgd=put(assigned_lgd, &CS_DEC_FMT);
			put '							<td class="verttebleborder" align="right">';
			put assigned_lgd@;
			put '</td>';
			assigned_ccf=put(assigned_ccf, &CS_DEC_FMT);
			put '							<td class="verttebleborder" align="right">';
			put assigned_ccf@;
			put '</td>';
			put '						</tr>';
		run;

		data _null_;
			file _webout&webout_options;
			put '					</table>';
			put '					</td>';
			put '				</tr>';

			put '			<tr>';
			put '				<td>';
			put '					<table width="60%" border="0" cellpadding="5" cellspacing="0">';
			put '						<tr>';
			put '							<td class="LabelFont" width="35%">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_pool_stab_indx.1, noquote))"@;
			put '</td>';
			put '							<td class="LabelFont">'@;
			stab=ktrim(kleft("&stab_value"));
			put '<input type="text" name="stab_value" readonly style="width: 30mm; background-color:#FAF8ED; border:0" value="'@;
			put stab@;
			put '"/>'@;
			put '</td>';
			put '						</tr>';
			put '						<tr>';
			put '							<td class="LabelFont">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_ks_value.1, noquote))"@;
			put '</td>';
			put '							<td class="LabelFont">'@;
			ks=ktrim(kleft("&ks_value"));
			put '<input type="text" name="ks_value" readonly style="width: 30mm; background-color:#FAF8ED; border:0" value="'@;
			put ks@;
			put '"/>'@;
			put '</td>';
			put '						</tr>';
			put '					</table>';
			put '				</td>';
			put '			</tr>';
			put '		</table>';
			put '		</td>';
			put '	</tr>';
			put '	<tr><td>&nbsp;</td></tr>';
			put '	<tr> ';
			put '		<td height="32" bgcolor="#F1EACB">&nbsp;&nbsp;';
			put '			<INPUT type=button class=mmhide_btn onClick="Save()" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.button_save.1, noquote))"@;
			put '" align="left">';
			put '		</td>';
			put '	</tr>';
		run;
	%end;
%mend display_screen;

/************ Macros for Pool Calculation and definition ************/
/* Save Pool Information */
%macro save_pool;
	%let error_code=NONE;

	/*Proc printto will redirect the log to the directory
	"Data/bisdata/error". */
	%global log_name;
	data _NULL_;
	name=put(time(),mmss8.1);
	name1=kscan(name,1,":.");
	name2=kscan(name,2,":.");
	name3=kscan(name,3,":.");
	name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
	call symput('log_name',"Data/bisdata/log/score_pool."||ktrim(kleft(name4))||".log");
	run;

	%put NOTE: Sending log messages to :&log_name;

	proc printto log="&log_name";
	quit;

	/* Save scheme information in pool.pool_scheme_defn */
	proc sql;
		update pool.pool_scheme_defn set
			ks_value=&ks_value, stability_value=&stab_value
		where pool_scheme_no=&scheme_no;

		delete from pool.pool_defn where pool_scheme_no=&scheme_no;
	quit;

	%if &sqlrc > 4 %then %do;
		%let error_code = ERROR;
	%end;
	%else %do;
		data &out_lib..pool_temp(drop=from_score to_score);
			set pool.&pool_defn.(keep=pool_seq_no pool_name from_score to_score no_of_accounts
				assigned_pd assigned_lgd assigned_ccf score_points);
			pool_scheme_no=&scheme_no;
			score_seq_no=pool_seq_no;
			from_score_no=from_score;
			to_score_no=to_score;
			pd_seq_no=.;
			from_pd_no=.;
			to_pd_no=.;
			lgd_seq_no=.;
			from_lgd_no=.;
			to_lgd_no=.;
			ccf_seq_no=.;
			from_ccf_no=.;
			to_ccf_no=.;
		run;

		/* Save pool information in pool.pool_defn */
		proc append data=&out_lib..pool_temp base=pool.pool_defn force;
		quit;
	%end;

	/*Proc printto will reset the log redirection */
	proc printto;
	quit;

	%put NOTE: Resetting log to _webout&webout_options;
	/*End of proc printto */

	/* Show the relevant messages on the screen */
	data _null_;
		file _webout&webout_options;
		put '<script language="JavaScript" type="text/JavaScript"> ';
		put '<!-- ';
	%if %str(&error_code) eq %str(ERROR) %then %do;
		put '	alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_pool_detail_not_saved_p1.1, noquote))"@;
		put "&log_name"@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_pool_detail_not_saved_p2.1, noquote))"@;
		put '")';
	%end;
	%else %do;
		put '	alert("'@;
		put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_pool_detail_saved.1, noquote))"@;
		put '")';
		put '	form1.action.value = "R";';
		put "	form1._program.value=&SELECT_POOL_SCHEME";
		put '	form1.submit()';
	%end;
		put '//-->';
		put	'</script> ';
	run;
%mend;
/* Split Pool */
%macro split(split=);
	proc sql;
		create table &out_lib..&out_score_range. as
		select pool_seq_no, from_score, to_score, pool_name
		from &lib..&pool_defn.
	quit;

	proc sql;
		select min(from_score), max(to_score) into :frm_scr ,:to_scr
		from &lib..&pool_defn.;
	quit;
	%let frm_scr=&frm_scr.;
	%let to_scr=&to_scr.;
	
		data _null_;
			file _webout&webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';

			put "if((&split<&frm_scr) || (&split>&to_scr)) {";
				put 'alert("'@;
				put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_enter_scr_rng_val.1, noquote))"@;
				put '")';
			put '}';

			put '//-->';
			put	'</script> ';
		run;

	%if (&split>=&frm_scr) and (&split<&to_scr) %then %do;
		proc sql noprint ;
			select from_score, to_score into :split_frm, :split_to
			from &lib..&pool_defn.
			where &split > from_score and &split <= to_score;
		quit;
	%let split_frm=&split_frm.;
	%let split_to=&split_to.;
		%if &split ne &split_frm and &split ne &split_to %then %do;
			proc sql noprint ;
				create table &out_lib..&out_score_range. as
					select pool_seq_no, from_score, to_score, pool_name
					from &lib..&pool_defn.
					where from_score ne  input(put(&split_frm,7.2),8.) and
					to_score ne input(put(&split_to,7.2),8.);

				select max(pool_seq_no)+1, max(pool_seq_no)+2 into :pool1, :pool2
				from &out_lib..&out_score_range.;

				INSERT INTO &out_lib..&out_score_range.
					(pool_seq_no, from_score, to_score, pool_name)
					VALUES(&pool1, &split_frm, &split, '')
					VALUES(&pool2, &split, &split_to, '');
			quit;
		%end;
	%end;
%mend;
/* Merge Selected Pools */
%macro Merge(min_val=, max_val=);
	proc sql noprint;
		select from_score into :merge_frm
			from &lib..&pool_defn.
			where pool_seq_no=&min_val;

		select to_score into :merge_to
			from &lib..&pool_defn.
			where pool_seq_no=&max_val;

		create table &out_lib..&out_score_range. as
			select pool_seq_no, from_score, to_score, pool_name
			from &lib..&pool_defn.
			where from_score<&merge_frm or to_score>&merge_to;

		INSERT INTO &out_lib..&out_score_range.
			(pool_seq_no, from_score, to_score, pool_name)
			VALUES (&min_val, &merge_frm, &merge_to, '');
	quit;
%mend;
/* Build all pool information */
%macro build_pool;
	proc sort data=&out_lib..&out_score_range. out=work.temp SORTSEQ=EBCDIC;
		by from_score;
	quit;

	proc sql;
		create table &out_lib..&out_score_range. as
		select monotonic() as pool_seq_no, from_score, to_score, pool_name
		from work.temp;
	quit;

	/* Calculate the no. of accounts and assigned pd, lgd, ccf in case of AVG estimated */
	proc sql noprint;
		create table &out_lib..temp_avg as
			select *
			from &lib..&scored_ds_nm., &out_lib..&out_score_range.
			where &scored_ds_nm..score_points > &out_score_range..from_score and
				&scored_ds_nm..score_points <= &out_score_range..to_score;

		create table &out_lib..temp2_avg as
			select pool_seq_no, count(account_rk) as No_of_Accounts,
				avg(estimated_pd) as assigned_pd,
				avg(estimated_lgd) as assigned_lgd,
				avg(estimated_ccf) as assigned_ccf,
				max(score_points) as score_points
			from &out_lib..temp_avg
			group by pool_seq_no;

		create table &lib..&pool_defn. as
			select &out_score_range..pool_seq_no, &out_score_range..from_score,
				&out_score_range..to_score,
				put(&out_score_range..from_score, 7.2)||"%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_range_score.1, noquote))"||put(&out_score_range..to_score, 7.2) as pool_name,
				case when no_of_accounts = . then 0 else no_of_accounts end as no_of_accounts,
				assigned_pd, assigned_lgd, assigned_ccf, score_points
			from &out_lib..&out_score_range. left outer join &out_lib..temp2_avg
			on (&out_score_range..pool_seq_no=temp2_avg.pool_seq_no);
	quit;

	%put ************&pd_method********&lgd_method**********&ccf_method********;
	/* If pd method is Long run max or avg, calculate the assigned pd */
	%let pd_mtd=%quote(%'&pd_method%');
	%if %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
		%sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) %then %do;
		%put ************LR: PD********;
		proc sql;
			create table &out_lib..temp_lr_pd AS
			select year_start_dt, pool_name, pool_seq_no,
				sum(actual_good_bad) as NO_OF_BADS,
				count(*) as NO_OF_ACCOUNTS,
				calculated NO_OF_BADS / calculated NO_OF_ACCOUNTS as ESTIMATED_POOL_PD
			from longrun.&long_run_ds_nm., &out_lib..&out_score_range.
			where score_points > from_score and score_points <= to_score
			group by year_start_dt, pool_name, pool_seq_no;

			%if %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) %then %do;
				create table &out_lib..temp2_lr_pd AS
				select pool_name, pool_seq_no,
					max(estimated_pool_pd) as assigned_pd
				from &out_lib..temp_lr_pd
				group by pool_name, pool_seq_no;
			%end;
			%else %do;
				create table &out_lib..temp2_lr_pd AS
				select pool_name, pool_seq_no,
					avg(estimated_pool_pd) as assigned_pd
				from &out_lib..temp_lr_pd
				group by pool_name, pool_seq_no;
			%end;

			create table &lib..&pool_defn. as
			select monotonic() as pool_seq_no, &pool_defn..from_score,
				&pool_defn..to_score, &pool_defn..pool_name, &pool_defn..no_of_accounts,
				temp2_lr_pd.assigned_pd, &pool_defn..assigned_lgd, &pool_defn..assigned_ccf,
				&pool_defn..score_points
			from &lib..&pool_defn. left join &out_lib..temp2_lr_pd
			on (&pool_defn..pool_seq_no=temp2_lr_pd.pool_seq_no);
		quit;
	%end;

	/* If lgd method is Long run max or avg, calculate the assigned lgd */
	%let lgd_mtd=%quote(%'&lgd_method%');
	%if %sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
		%sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) %then %do;
		%put ********LR: LGD**********;
		proc sql;
			create table &out_lib..temp_lr_lgd AS
			select year_start_dt, pool_name, pool_seq_no,
				sum (ACTUAL_LOSS) as ACTUAL_LOSS,
				sum (EXPOSURE_AT_DEFAULT) as EXPOSURE_AT_DEFAULT,
				calculated ACTUAL_LOSS / calculated EXPOSURE_AT_DEFAULT as ESTIMATED_POOL_LGD
			from longrun.&long_run_ds_nm., &out_lib..&out_score_range.
			where score_points > from_score and score_points <= to_score
			group by year_start_dt, pool_name, pool_seq_no;

			%if %sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) %then %do;
				create table &out_lib..temp2_lr_lgd AS
				select pool_name, pool_seq_no,
					max(estimated_pool_lgd) as assigned_lgd
				from &out_lib..temp_lr_lgd
				group by pool_name, pool_seq_no;
			%end;
			%else %do;
				create table &out_lib..temp2_lr_lgd AS
				select pool_name, pool_seq_no,
					avg(estimated_pool_lgd) as assigned_lgd
				from &out_lib..temp_lr_lgd
				group by pool_name, pool_seq_no;
			%end;

			create table &lib..&pool_defn. as
			select monotonic() as pool_seq_no, &pool_defn..from_score,
				&pool_defn..to_score, &pool_defn..pool_name, &pool_defn..no_of_accounts,
				&pool_defn..assigned_pd, temp2_lr_lgd.assigned_lgd, &pool_defn..assigned_ccf,
				&pool_defn..score_points
			from &lib..&pool_defn. left outer join &out_lib..temp2_lr_lgd
			on (&pool_defn..pool_seq_no=temp2_lr_lgd.pool_seq_no);
		quit;
	%end;

	/* If ccf method is Long run max or avg, calculate the assigned ccf */
	%let ccf_mtd=%quote(%'&ccf_method%');
	%if %sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
		%sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) %then %do;
		%put **********LR: CCF********;
/* Actual CCF calculation
	(BALANCE_AMT * (PR_CURRENT_LIMIT_AMT / CURRENT_LIMIT_AMT)) as Balance_Default
	(Balance_Default - PR_BALANCE_AMT) / (CURRENT_LIMIT_AMT - PR_BALANCE_AMT) as
*/
		proc sql;
			create table &out_lib..temp_lr_act_ccf as
			select BALANCE_AT_DEFAULT * (LIMIT_AT_START / LIMIT_AT_DEFAULT) as
				APPR_BALANCE_DEFAULT, (calc APPR_BALANCE_DEFAULT - BALANCE_AT_START) /
				(LIMIT_AT_DEFAULT - BALANCE_AT_START) as ACTUAL_CCF
			from longrun.&long_run_ds_nm.;

			create table &out_lib..temp_lr_ccf AS
			select year_start_dt, pool_name, pool_seq_no,
				sum (ACTUAL_CCF) as ACTUAL_CCF,
				count (*) as NO_OF_ACCOUNTS,
				calculated ACTUAL_CCF / calculated NO_OF_ACCOUNTS as ESTIMATED_POOL_CCF
			from &out_lib..temp_lr_act_ccf, &out_lib..&out_score_range.
			where score_points > from_score and score_points <= to_score
			group by year_start_dt, pool_name, pool_seq_no;

			%if %sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) %then %do;
				create table &out_lib..temp2_lr_ccf AS
				select pool_name, pool_seq_no,
					max(estimated_pool_ccf) as assigned_ccf
				from &out_lib..temp_lr_ccf
				group by pool_name, pool_seq_no;
			%end;
			%else %do;
				create table &out_lib..temp2_lr_ccf AS
				select pool_name, pool_seq_no,
					avg(estimated_pool_ccf) as assigned_ccf
				from &out_lib..temp_lr_ccf
				group by pool_name, pool_seq_no;
			%end;

			create table &lib..&pool_defn. as
			select monotonic() as pool_seq_no, &pool_defn..from_score,
				&pool_defn..to_score, &pool_defn..pool_name, &pool_defn..no_of_accounts,
				&pool_defn..assigned_pd, &pool_defn..assigned_lgd, temp2_lr_ccf.assigned_ccf,
				&pool_defn..score_points
			from &lib..&pool_defn. left outer join &out_lib..temp2_lr_ccf
			on (&pool_defn..pool_seq_no=temp2_lr_ccf.pool_seq_no);
		quit;
	%end;
%mend build_pool;
/* Macro to calculete the value of Pool Stability Index for the pool definition */
%macro calculate_pool_stab;
	/* The pool_stability_index macro creates the data with the value for Pool Stability
		Index. The following parameters are passed to this macro:
		input_ds		: Name of the input data set
		input_pool_ds	:
		output_ds		: Name of the data set which stores data for pool_stability_index
		scheme_type		: Type of Pooling scheme
	*/
	proc sql noprint;
		select  count(*)  into: count_recs
		from &lib..&pool_defn.
		where ASSIGNED_PD < 1 and ASSIGNED_PD >0;
	quit;
	/*checking the all default , No default before calculating the statistics.*/
	%let count_recs=&count_recs;
/*	%let var_ASSIGNED_PD=&var_ASSIGNED_PD.;*/
	%put ********count_recs=&count_recs;
	%if (&count_recs eq 0)%then %do;		
		data _null_;
			file _webout&webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
			put '	alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pooling.alert_default_no_default.1, noquote))"@;
			put '")';
			put '	form1.action.value = "R";';
			put "	form1._program.value=&SELECT_POOL_SCHEME";
			put '	form1.submit()';
			put '//-->';
			put	'</script> ';
		run;	
	%end;
	%else %do;
		%let scheme_type1=%nrquote(%'&scheme_type%');
		%pool_stability_index(input_ds=&out_lib..temp_avg, input_pool_ds=&lib..&pool_defn.,
			output_ds=&out_pool_stab., scheme_type_cd=&scheme_type1);

		proc sql noprint;
			/*The select stmt below is for display purpose only*/
			select pool_stability_index format=&CS_DEC_FMT. into :stab_value from &out_pool_stab.;
		quit;
	%end;
%mend calculate_pool_stab;
/* Macro to calculete the value of KS for the pool definition */
%macro calculate_ks;
	proc sql;
		create table &out_lib..ks_ds as
		select monotonic() as pool_seq_no, &pool_defn..from_score,
			&pool_defn..to_score, &pool_defn..pool_name,
			&pool_defn..no_of_accounts as No_Of_ACC_Actual,
			&pool_defn..assigned_pd as PD, &pool_defn..assigned_lgd,
			&pool_defn..assigned_ccf, score_points, . as No_of_Actual_bads
		from &lib..&pool_defn.;
	quit;

	/* The cs_rep_data_prep macro prepares the data which is required as the input to
		calculate KS.
		The following parameters are passed to this macro:
		input_ds	: Name of the input data set
		output_ds	: Name of the data set which stores data for graph of ks
		Dist_type	: This mentions which distribution the ks has to be calculated on
						E.g., ACT will calculate the KS on Actual data and
							  EST will calculate the KS on Modeling predictions.
	*/
	%cs_rep_data_prep(input_ds=&out_lib..ks_ds, output_ds=&out_data_prep, Dist_type="EST");
/*checking the all default , No default before calculating the statistics.*/
	%let err_code_var=;
	%check_alldefaults_nodefaults(&out_lib..ks_ds,No_Of_ACC_Actual,No_of_Actual_bads, err_code_var);
	%if (&err_code_var ne 'NONE')%then %do;
		data _null_;
			file _webout&webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
			put '	alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.pooling.alert_default_no_default.1, noquote))"@;
			put '")';
			put '	form1.action.value = "R";';
			put "	form1._program.value=&SELECT_POOL_SCHEME";
			put '	form1.submit()';
			put '//-->';
			put	'</script> ';
		run;	
	%end;
	%else %do;
		/* The KS_Stat macro creates the data set for plotting the KS graph.
			The following parameters are passed to this macro:
			input_ds		: Name of the input data set
			output_graph_ds	: Name of the data set which stores data for graph of ks
		*/
		%ks_stat(input_ds=&out_data_prep,output_graph_ds=&out_graph_ds);

		proc sql noprint;
			/*The select stmt below is for display purpose only*/
			select max(ks) format=&CS_DEC_FMT. into :ks_value from &out_graph_ds;
		quit;
	%end;
%mend calculate_ks;
/* Perform action according to screen click */
%macro screenaction;
	/* Logic:
		Always
			scheme type
		N
			empty pool_defn
		R
			if no pools exist,
				should become I
				scored and long run datasets needed
			if pools exist,
				get pool definition in pool_defn
		I
			scored and long run datasets needed
			defn in pool_defn
		Q
			scored and long run datasets needed
			defn in pool_defn
		M
			scored and long run datasets needed
			defn in pool_defn
		S
			scored and long run datasets needed
			defn in pool_defn
		D
			scored and long run datasets needed
			defn in pool_defn
		V
			pool_defn to be saved
			KS, stability values to be saved as scheme detail
	*/

	/* Start: In case of all screens we need scheme details */
	proc sql;
		create table &out_lib..scheme_details as
		select *
		from &lib..pool_scheme_defn
		where pool_scheme_type_cd in (&SCORE_RANGE_TYPE) and
		status_desc="%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.status_desc_completed.1, noquote))";
	quit;

	/* Empty pool definition for first screen */
	%if %sysfunc(kupcase("&action")) eq "N" %then %do;
		proc sql;
			create table &lib..&pool_defn. (
				pool_seq_no numeric(8),
				from_score numeric(8),
				to_score numeric(8),
				pool_name char(100),
				no_of_accounts numeric(8),
				assigned_pd numeric(8),
				assigned_lgd numeric(8),
				assigned_ccf numeric(8),
				score_points numeric(8)
			);
		quit;
	%end;
	%else %do;
		/* In all cases except for None, get the pool scheme information */
		proc sql noprint;
			select obs_dt, pd_method_type_cd, pd_model_rk, lgd_method_type_cd, lgd_model_rk,
				ccf_method_type_cd, ccf_model_rk, pool_scheme_type_cd into
				:obsdt, :pd_method, :pd_model_key, :lgd_method, :lgd_model_key,
				:ccf_method, :ccf_model_key, :scheme_type
			from &lib..pool_scheme_defn
			where pool_scheme_no=&scheme_no;
		quit;

/*		%let obsdt=%trim(%left(&obsdt));*/
/*		%let model_key=%trim(%left(&model_key));*/
		%let pd_model_key=%sysfunc(ktrim(%sysfunc(kleft(&pd_model_key))));
		%let lgd_model_key=%sysfunc(ktrim(%sysfunc(kleft(&lgd_model_key))));
		%let ccf_model_key=%sysfunc(ktrim(%sysfunc(kleft(&ccf_model_key))));

		/* In all cases except for None, get the names of the scored and long run datasets */
		data _null_;
			dt=&obsdt;
			mth=put(month(dt),z2.);
			yr=year(dt);
			dt1=yr||mth;
			call symput('data_dt', dt1);
		run;
		%let data_dt=%sysfunc(ktrim(%sysfunc(kleft(&data_dt))));

		/* Scored Dataset */
		%let scr_pd_ds=_&pd_model_key._PD_&data_dt.;
		%let scr_lgd_ds=_&lgd_model_key._LGD_&data_dt.;
		%let scr_ccf_ds=_&ccf_model_key._CCF_&data_dt.;

		/* PD Dataset has to be available */
		proc sort data=&lib..&scr_pd_ds. out=work.&scr_pd_ds. SORTSEQ=EBCDIC;
			by account_rk;
		quit;

		data &lib..scr_&data_dt.;
			set work.&scr_pd_ds.;
			estimated_lgd=.;
			estimated_ccf=.;
		run;

		/* If LGD dataset is available, merge */
		%if %sysfunc(exist(&lib..&scr_lgd_ds.)) %then %do;
			proc sort data=&lib..&scr_lgd_ds. out=work.&scr_lgd_ds. SORTSEQ=EBCDIC;
				by account_rk;
			quit;

			data &lib..scr_&data_dt.;
				merge &lib..scr_&data_dt. work.&scr_lgd_ds.;
				by account_rk;
			run;
		%end;
		/* If CCF dataset is available, merge */
		%if %sysfunc(exist(&lib..&scr_ccf_ds.)) %then %do;
			proc sort data=&lib..&scr_ccf_ds. out=work.&scr_ccf_ds. SORTSEQ=EBCDIC;
				by account_rk;
			quit;

			data &lib..scr_&data_dt.;
				merge &lib..scr_&data_dt. work.&scr_ccf_ds.;
				by account_rk;
			run;
		%end;

		/* The structure of the scored dataset will be:
		----------------------------------------------------------------------------------
			Account Key, Score Points, Estimated PD, Estimated LGD, Estimated CCF
		----------------------------------------------------------------------------------
			First three columns will always have data. Estimated LGD and Estimated CCF
			will have data based on whether the user has provided LGD and CCF models.
		*/
		%let scored_ds_nm=scr_&data_dt.;

		/* Long Run Dataset:
		Datasets to be considered with the various cases for method types.
		----------------------------------------------------------------------------------
		PD		LGD		CCF							For Assignment
								----------------------------------------------------------
								PD					LGD					CCF
		----------------------------------------------------------------------------------
		E		E		E		_<M>_PD				_<M>_LGD			_<M>_CCF
		E		E		L		_<M>_PD				_<M>_LGD			_LNG_<M>_PD
		E		L		E		_<M>_PD				_LNG_<M>_PD_LGDYRS	_<M>_CCF
		L		E		E		_LNG_<M>_PD			_<M>_LGD			_<M>_CCF
		E		L		L		_<M>_PD				_LNG_<M>_PD_LGDYRS	_LNG_<M>_PD_LGDYRS
		L		E		L		_LNG_<M>_PD			_<M>_LGD			_LNG_<M>_PD
		L		L		E		_LNG_<M>_PD_LGDYRS	_LNG_<M>_PD_LGDYRS	_<M>_CCF
		L		L		L		_LNG_<M>_PD_LGDYRS	_LNG_<M>_PD_LGDYRS	_LNG_<M>_PD_LGDYRS
		----------------------------------------------------------------------------------
		Note: <M> stands for the PD model Key
		*/
		/* Long Run Dataset */
		%let long_run_ds_nm=;
		%let longrun_pd_ds=_lng_&pd_model_key._PD;
		%let longrun_pd_lgdyrs_ds=_lng_&pd_model_key._PD_LGDYRS;
		%let pd_mtd=%quote(%'&pd_method%');
		%let lgd_mtd=%quote(%'&lgd_method%');
		%let ccf_mtd=%quote(%'&ccf_method%');
			/* AVG: PD, LGD
			   LRM: CCF */
		%if %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) and
			%sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) and
			( %sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) %then %do;
			%let long_run_ds_nm=&longrun_pd_ds;
		%end;
			/* AVG: PD, CCF
			   LRM: LGD */
		%else %if %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) and
			( %sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&lgd_mtd))eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			%sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) %then %do;
			%let long_run_ds_nm=&longrun_pd_lgdyrs_ds;
		%end;
			/* AVG: LGD, CCF
			   LRM: PD */
		%else %if ( %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			%sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) and
			%sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) %then %do;
			%let long_run_ds_nm=&longrun_pd_ds;
		%end;
			/* AVG: PD
			   LRM: LGD, CCF */
		%if %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) and
			( %sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			( %sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) %then %do;
			%let long_run_ds_nm=&longrun_pd_lgdyrs_ds;
		%end;
			/* AVG: LGD
			   LRM: PD, CCF */
		%else %if ( %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			%sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&AVG_EST_TYPE.)) and
			( %sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) %then %do;
			%let long_run_ds_nm=&longrun_pd_ds;
		%end;
			/* AVG: CCF
			   LRM: PD, LGD */
		%else %if ( %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&pd_mtd))eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			( %sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			%sysfunc(kupcase(&ccf_mtd))eq %sysfunc(kupcase(&AVG_EST_TYPE.)) %then %do;
			%let long_run_ds_nm=&longrun_pd_lgdyrs_ds;
		%end;
			/* AVG: -
			   LRM: PD, LGD, CCF */
		%else %if ( %sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&pd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			( %sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&lgd_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) and
			( %sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_MAX_TYPE.)) or
			%sysfunc(kupcase(&ccf_mtd)) eq %sysfunc(kupcase(&LONG_RUN_AVG_TYPE.)) ) %then %do;
			%let long_run_ds_nm=&longrun_pd_lgdyrs_ds;
		%end;

		%put ************&scored_ds_nm*********&long_run_ds_nm*********;

		/* Retrieve Pool Information */
		%if %sysfunc(kupcase("&action")) eq "R" %then %do;
			proc sql noprint;
				select ks_value, stability_value into
				:ks_value, :stab_value
				from &lib..pool_scheme_defn
				where pool_scheme_no=&scheme_no;

				select count(*) into :cnt_pool
				from &lib..pool_defn
				where pool_scheme_no=&scheme_no;
			quit;

			/* If pool definitions exist for the scheme, get pool definitions */
			%if &cnt_pool ne 0 %then %do;
				proc sql;
					create table &lib..&pool_defn. as
					select pool_seq_no, from_score_no as from_score, to_score_no as to_score,
						pool_name, no_of_accounts, assigned_pd, assigned_lgd, assigned_ccf,
						score_points
					from &lib..pool_defn
					where pool_scheme_no=&scheme_no;
				quit;
			%end;
			/* If no pool definitions exist for the scheme, by default action should be
			to create pools using the Range Interval method using 100 as the interval */
			%else %do;
				%let action=I;
				%let interval=100;
			%end;
		%end;

		/* Quantile Calculation */
		%if %sysfunc(kupcase("&action")) eq "Q" %then %do;
			/* The input dataset to interval / quantile calculation requires the cut_off_score,
			factor and offset with the scored dataset information. */
			proc sql noprint;
				create table &out_lib..&in_score_range. as
				select Analytical_model_dim.cut_off_score,
					Analytical_model_dim.factor,
					Analytical_model_dim.offset_rt as offset,
					&scored_ds_nm..account_rk,
					&scored_ds_nm..score_points,
					&scored_ds_nm..estimated_pd,
					&scored_ds_nm..estimated_lgd,
					&scored_ds_nm..estimated_ccf
				from dim.Analytical_model_dim, &lib..&scored_ds_nm.
				where Analytical_model_dim.model_rk=&pd_model_key. and
					Analytical_model_dim.valid_end_dttm = &valid_high_dttm;
			quit;

			%quantile_calculation(out_lib_nm=&out_lib, out_table_nm_pool=&out_score_range,
				in_lib_nm=&out_lib, in_table_nm_pool=&in_score_range,
				pd_score=SCORE, no_of_quantile=&quantile, score_card_column=score_points,
				pd_ccf_lgd_column=estimated_pd);

			%build_pool;
			%calculate_ks;
			%calculate_pool_stab;
		%end;
		/* Interval Calculation */
		%else %if %sysfunc(kupcase("&action")) eq "I" %then %do;
		%put *********************I**********************;
			/* The input dataset to interval / quantile calculation requires the cut_off_score,
			factor and offset with the scored dataset information. */
			proc sql noprint;
				create table &out_lib..&in_score_range. as
				select Analytical_model_dim.cut_off_score ,
					Analytical_model_dim.factor,
					Analytical_model_dim.offset_rt as offset,
					&scored_ds_nm..account_rk,
					&scored_ds_nm..score_points,
					&scored_ds_nm..estimated_pd,
					&scored_ds_nm..estimated_lgd,
					&scored_ds_nm..estimated_ccf
				from dim.Analytical_model_dim, &lib..&scored_ds_nm.
				where Analytical_model_dim.model_rk=&pd_model_key. and
					Analytical_model_dim.valid_end_dttm = &valid_high_dttm;
			quit;

			%create_range_table(out_lib_nm=&out_lib, out_table_nm_pool=&out_score_range,
				in_lib_nm=&out_lib, in_table_nm_pool=&in_score_range,
				pd_score=SCORE, range_interval=&interval);

			%build_pool;
			%calculate_ks;
			%calculate_pool_stab;
		%end;
		/* Merge Selected Pools */
		%else %if %sysfunc(kupcase("&action")) eq "M" %then %do;
			%merge(min_val=&merge_min_val, max_val=&merge_max_val);
			%build_pool;
			%calculate_ks;
			%calculate_pool_stab;
		%end;
		/* Split Pool */
		%else %if %sysfunc(kupcase("&action")) eq "S" %then %do;
			%split(split=&split_val);
			%build_pool;
			%calculate_ks;
			%calculate_pool_stab;
		%end;
		/* Edit Description */
		%else %if %sysfunc(kupcase("&action")) eq "D" %then %do;
			proc sql;
				update &lib..&pool_defn. set pool_name="&pool_desc"
				where pool_seq_no=&pool_no_desc;
			quit;
		%end;
		/* Save Pool Information */
		%else %if %sysfunc(kupcase("&action")) eq "V" %then %do;
			%save_pool;
		%end;
	%end;
%mend screenaction;
/************ END of Macros for Pool Calculation and definition ************/

data _null_;
	file _webout&webout_options;
	put'<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ';
	put'"http://www.w3.org/TR/html4/loose.dtd"> ';
	put'<html> ';
	put'<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put'<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put'<title>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.title_pooling_scr2.1, noquote))"@;
	put'</title> ';
	put'<link href="/SASCSPooling/styles/default.css"rel="stylesheet" type="text/css"> ';
	put '<style type="text/css">';
	put '<!--';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';

	put '	<style type="text/css"> ';
	put '	#dhtmlgoodies_contentBox{ ';
	put '		border:1px solid #7F9DB9; ';
	put '		height:0px; ';
	put '		visibility:hidden; ';
	put '		position:absolute; ';
	put '		background-color:#FAF8ED; ';
	put '		overflow:hidden; ';
	put '		padding:2px; ';
	put '		width:250px; ';
	put '	} ';
	put '	#dhtmlgoodies_content{ ';
	put '		position:relative;		 ';
	put '		font-family: Trebuchet MS ';
	put '		width:100%; ';
/*	put '		font-size:0.8em; ';*/
	put '	} ';
	put '	#dhtmlgoodies_slidedown{ ';
	put '		position:relative; ';
	put '		width:20px; ';
	put '	} ';
	put '	</style> ';

	put '<script language="JavaScript" src="/SASCSPooling/script/action_menu.js"></script>';
	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

	/* When a scheme is selected, set the values in the required text boxes */
	put 'function setScheme(){';
	put '	index = document.form1.schemename.selectedIndex;';
	put '	if (index==0) {';
	put '		form1.scheme_no.value = ''''';
	put '		form1.action.value = "N";';
	put "		form1._program.value=&SELECT_POOL_SCHEME";
	put '		form1.submit()';
	put '	}';
	put '	else {';
	put '		form1.scheme_no.value = document.form1.schemename.options[index].value;';
	put '		form1.action.value = "R";';
	put "		form1._program.value=&SELECT_POOL_SCHEME";
	put '		form1.submit()';
	put '	}';
	put '}';

	put 'function viewScheme(){';
	put '	index = document.form1.schemename.selectedIndex;';
	put '	if (index==0) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_sel_scheme_to_view.1, noquote))"@;
	put '")';
	put '	}';
	put '	else {';
	put '		form1.scheme_no.value = document.form1.schemename.options[index].value;';
	link="http://&_SRVNAME:&_SRVPORT/SASStoredProcess/do?"||'&_program='||"&VIEW_POOL_SCHEME"||'&scheme_no='||"&scheme_no";
	put '		window.open("'@;
	put link@;
	put '");';
	put '	}';
	put '}';

	put 'function SelPool(obj) {';
	put '	if(obj.checked==true) {';
	put '		if(form1.merge_min_val.value==0){';
	put '			form1.merge_min_val.value=obj.value';
	put '			form1.merge_max_val.value=obj.value';
	put '		}';
	put '		else if(Math.min(form1.merge_min_val.value,obj.value)==obj.value){';
	put '			form1.merge_min_val.value=obj.value';
	put '		}';
	put '		else if(Math.max(form1.merge_max_val.value,obj.value)==obj.value) {';
	put '			form1.merge_max_val.value=obj.value';
	put '		}';
	put '	}';
	put '	else {';
	put '		if(form1.merge_min_val.value==form1.merge_max_val.value){';
	put '			form1.merge_min_val.value=""';
	put '			form1.merge_max_val.value=""';
	put '		}';
	put '		else if(form1.merge_min_val.value==obj.value) {';
		/* find the next smallest checked pool */
	put '			var min=Number(form1.merge_min_val.value)';
	put '			var max=Number(form1.merge_max_val.value)';
	put '			for (var i=min;i<=max;i=i+1) {';
	put '				if(form1.c[i].checked==true) {';
	put '					form1.merge_min_val.value=form1.c[i].value';
	put '					return true';
	put '				}';
	put '			}';
	put '		}';
	put '		else if(form1.merge_max_val.value==obj.value) {';
		/* find the next largest checked pool */
	put '		var min=Number(form1.merge_min_val.value)';
	put '		var max=Number(form1.merge_max_val.value)';
	put '		form1.merge_max_val.value=form1.merge_min_val.value';
	put '			for (var i=min;i<max;i=i+1) {';
	put '				if(form1.c[i].checked==true) {';
	put '					form1.merge_max_val.value=form1.c[i].value';
	put '				}';
	put '			}';
	put '		}';
	put '	}';
	put '}';

	put 'function Merge() {';
	put '	var min=Number(form1.merge_min_val.value)';
	put '	var max=Number(form1.merge_max_val.value)';
	put '	if(min==max) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_sel_two_pools.1, noquote))"@;
	put '")';
	put '		slidedown_showHide();';
	put '	}';
	put '	else {';
	put '		form1.interval.value=""';
	put '		form1.quantile.value=""';
	put '		form1.split.value=""';
	put '		form1.action.value="M"';
	put "		form1._program.value=&SELECT_POOL_SCHEME";
	put '		form1.submit()';
	put '	}';
	put '}';

	put 'function SplitPool() {';
	put '	var split=form1.split_val.value';
	put '	if((split=='''') || (split==''.'') || (split==''0'') || (isNaN(split))) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_split_pool_schm_val.1, noquote))"@;
	put '")';
	put '	}';
	put '	else {';
	put '		form1.interval.value=""';
	put '		form1.quantile.value=""';
	put '		form1.split.value=Number(form1.split_val.value)';
	put "		form1._program.value=&SELECT_POOL_SCHEME";
	put '		form1.action.value="S"';
	put '		form1.submit()';
	put '	}';
	put '}';

	put 'function Interval() {';
	put '	var intv=form1.interval_val.value';
	put '	if((intv=='''') || (intv==''.'') || (intv==''0'') || (isNaN(intv))) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_enter_val_interval.1, noquote))"@;
	put'")';
	put '	}';
	put '	else {';
	put '		form1.interval.value=intv';
	put '		form1.quantile.value=""';
	put '		form1.split.value=""';

	put "		form1._program.value=&SELECT_POOL_SCHEME";
	put '		form1.action.value="I"';
	put '		form1.submit()';
	put '	}';
	put '}';

	put 'function Quantile() {';
	put '	var quant=form1.quantile_val.value';
	put '	if((quant=='''') || (quant==''.'') || (quant==''0'') || (isNaN(quant))) {';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_enter_val_quantile.1, noquote))"@;
	put '")';
	put '	}';
	put '	else {';
	put '		form1.interval.value=""';
	put '		form1.quantile.value=quant';
	put '		form1.split.value=""';
	put "		form1._program.value=&SELECT_POOL_SCHEME";
	put '		form1.action.value="Q"';
	put '		form1.submit()';
	put '	}';
	put '}';

	put 'function EditDesc() {';
	put '	if((form1.merge_min_val.value!=form1.merge_max_val.value) || '@;
	put '(form1.merge_min_val.value=='''') || (form1.merge_min_val.value=='' '') || '@;
	put '(form1.merge_max_val.value=='''') || (form1.merge_max_val.value=='' '') ){';
	put '		alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.alert_sel_one_pool_desc_edit.1, noquote))"@;
	put '")';
	put '		slidedown_showHide();';
	put '	}';
	put '	else {';
	put '		form1.pool_no_desc.value=form1.merge_min_val.value';
	put '		form1.pool_desc.value=form1.edit_desc.value';
	put "		form1._program.value=&SELECT_POOL_SCHEME";
	put '		form1.action.value="D"';
	put '		form1.submit()';
	put '	}';
	put '}';

	put 'function OK() {';
	put '	for(var i=0; i<form1.action_radio.length; i++){';
	put '		if(form1.action_radio[i].checked == true){';
	put '			val = form1.action_radio[i].value';
	put '			if(val == "M") Merge()';
	put '			else if(val == "S") SplitPool()';
	put '			else if(val == "I") Interval()';
	put '			else if(val == "Q") Quantile()';
	put '			else if(val == "D") EditDesc()';
	put '		}';
	put '	}';
	put '}';

	put 'function Save() {';
	put "	form1._program.value=&SELECT_POOL_SCHEME";
	put '	form1.action.value="V"';
	put '	form1.submit()';
	put '}';

	put '//-->';
	put	'</script> ';
	put '</head>';

	put '<body>';
	put '<form name="form1" method="post" ACTION="/SASStoredProcess/do"> ';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	put '<input type="hidden" name="_program" VALUE="">';
	scheme_type=symget("scheme_type");
	put '<input type="hidden" name="scheme_type" value="' @;
	put scheme_type;
	put '">';
	scheme_no=symget("scheme_no");
	put '<input type="hidden" name="scheme_no" value="' @;
	put scheme_no;
	put '">';
	put '<input type="hidden" name="action" value="">';
	put '<input type="hidden" name="merge_min_val" value="">';
	put '<input type="hidden" name="merge_max_val" value="">';
	put '<input type="hidden" name="interval" value="">';
	put '<input type="hidden" name="quantile" value="">';
	put '<input type="hidden" name="split" value="">';
	put '<input type="hidden" name="pool_desc" value="">';
	put '<input type="hidden" name="pool_no_desc" value="">';
run;

/* Calculate the data according to the screen events */
%screenaction;

data _null_;
	file _webout&webout_options;
	put '<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
	put '	<tr> ';
	put '		<td align="left"> ';
	put '		<table width="100%" border="0" align="left" cellpadding="0" cellspacing="0"> ';
	put '			<tr> ';
	put '				<td><table width="100%" border="0" cellspacing="0" cellpadding="0"> ';
	put '					<tr> ';

	/* Navigational Links */
	put '						<td><span class="BreadCrumb">&nbsp;</td>';
	put '						<td align="right"><img src="/SASCSPooling/images/CrBanner.gif" width="259" height="29"></td> ';
	put '					</tr>';
	put '				</table>';                                     /****Banner insert image********/
	/**/

	/* Main Body */
	put '				<H2 align="left"><table width="100%" border="0" cellspacing="0" cellpadding="0">';
	put '					<tr><td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_pool_based_scr_rng.1, noquote))"@;
	put '</td>';
	put '				</tr></table></H2>';

	put '	   		<tr><td>&nbsp;</td></tr>';
	put '      		<tr>';
	put '        		<td><table width="100%" border="0" cellpadding="3" cellspacing="0">';
	put '					<tr>';
	put '						<td class="LabelFont" width="15%">'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_score_pool.column_schm_nm.1, noquote))"@;
	put '</td>';
	put '						<td class="LabelFont">';
	put '							<p class="LabelFont">';
	put '							<select name="schemename" style="width: 90mm" onChange="javascript:setScheme()">';
	/*I18N-scnjih-20080421-1133*/
/*	put '								<option>Select Scheme</option>';*/
put '								<option>'@;
put "%sysfunc(sasmsg(smd_ds.bismsg,build_scheme_score_pool.sas.2, noquote))"@;
put '</option>';
	/*I18N-scnjih-20080421-1133*/
run;

data _null_;
	file _webout&webout_options;
	set &out_lib..scheme_details;
	put '								<option value="'@;
	put pool_scheme_no@;
	put '" '@;
	if pool_scheme_no=&scheme_no then put 'selected'@;
	put '>'@;
	put pool_scheme_name@;
	put '</option>';
run;


data _null_;
	file _webout&webout_options;
	put '							</select>';
	/*I18N-scnjih-20080421-1133*/
/*	put '								<a href="javascript:viewScheme()">View Details</a>';*/
	put '	<a href="javascript:viewScheme();">'@;
	put "%sysfunc( sasmsg(smd_ds.bismsg, build_scheme_score_pool.sas.1, noquote))" @;
	put '</a>';
	/*I18N-scnjih-20080421-1133*/
	put '							</p>';
	put '						</td>';
	put '					</tr>';
	put '				</table>';
	put '				</td>';
	put '			</tr>';

	put '			<tr><td>&nbsp;</td></tr>';
run;

%display_screen;

data _null_;
	file _webout&webout_options;
	put '</table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;
 options nomlogic nomprint;
 
