/******************************************************************************************************
       Module:  build_scheme_pd_pool

     Function:  To define the pools for the selected pool scheme

      Authors:  BIS Team
         Date:  14 May 2007
          SAS:  9.1
    Called-by:	pool_main
        Calls:  

Datasets used:  1. pool.pool_scheme_defn: Retrieves the defn of existing pool schemes from this dataset
				2. pool.pool_defn: Retrieves the defn of existing pools for the pool scheme from
					this dataset
				3. dim.analytical_model_dim: Updates the pool scheme information in this dataset for 
					the deployed scheme
				4. dim.pool_scheme: Inserts the new pool scheme information in this dataset for the
					deployed scheme
				5. dim.pool_dim: Inserts the new pool definition in this dataset for the deployed scheme
				6. bridge.model_x_pool: Inserts the assigned PD, LGD and CCF values in this dataset
					for the deployed scheme
 
        Logic: 1. Backup the dimension tables POOL_SCHEME, POOL_DIM and ANALYTICAL_MODEL_DIM
					and the bridge table MODEL_X_POOL
			   2. Retrieve scheme details from pool.pool_scheme_defn
			   3. Retrieve pool information from pool.pool_defn
			   4. Retrieve assigned PD, LGD, CCF values in pool.model_x_pool
			   5. Populate scheme information in backup table pool_scheme
			   6. Populate pool information in backup table pool_dim
			   7. Update backup table analytical_model_dim with pool_scheme_sk
			   8. Populate model pool mapping information in backup table model_x_pool
			   7. Replace original dimension and bridge table with updated backups
			   9. Delete backups if everything is successful
			  10. If there is an error at any stage, alert the user that deployment is
					not successful
			  11. The available actions are:
						N: None.
						D: Deploy selected scheme
					
   Parameters:  scheme_no 		: The unique identifier of an existing pool scheme
   				scheme_type		: Pool scheme type. For e.g., SCR, PDR, PLR, PLC, PMS
				action 			: Screen action code
   		
 ******************************************************************************************************/
/*This code is Internationalized*/
options nomprint;

/* Global Input Parameters */
%global scheme_no scheme_type action count_row_scheme_detail;

%let lib=pool;
/* proc printto log='Data/bisdata/deploy_pool_scheme.log';*/
/* run;*/
/* Trimming extra spaces for all input paremeters */
%macro check_variable;
%if "&scheme_no" ne "" %then 	
	%let scheme_no=%str(%sysfunc(ktrim(%sysfunc(kleft(&scheme_no)))));
%if "&scheme_type" ne "" %then
	%let scheme_type=%str(%sysfunc(ktrim(%sysfunc(kleft(&scheme_type)))));
%if "&action" ne "" %then
	%let action=%str(%sysfunc(ktrim(%sysfunc(kleft(&action)))));
%mend;
%check_variable;
/* Links specific for the PD Range screens */
%let DEPLOY_POOL_SCHEME='SBIP://Foundation/BIS/pool/deploy_pool_scheme';

/* Setting output library based on the debug flag */
%let out_lib=;
%debug_lib_path;

/* Setting default values for any required parameters */
data _null_;
	if "&action"="" then call symput('action', 'N');
run;

/* Display screen with table and pool stability index in all cases except when action = N */
%macro display_screen;
	%if "&action" eq "N" %then %do;
		proc sql noprint;
			create table &out_lib..scheme_details as
			select distinct pool_scheme_defn.*, a.model_nm as pd_model_nm, 
				b.model_nm as lgd_model_nm, c.model_nm as ccf_model_nm,
				d.model_nm as seg_model_nm, master_scale_name
			from &lib..pool_scheme_defn inner join &lib..pool_defn
			on (pool_scheme_defn.pool_scheme_no = pool_defn.pool_scheme_no)
			left join dim.analytical_model_dim as a
			on (pool_scheme_defn.pd_model_rk = a.model_rk and 
				a.valid_end_dttm = &valid_high_dttm)
			left join dim.analytical_model_dim as b
			on (pool_scheme_defn.lgd_model_rk = b.model_rk and 
				b.valid_end_dttm = &valid_high_dttm)			
			left join dim.analytical_model_dim as c
			on (pool_scheme_defn.ccf_model_rk = c.model_rk and 
				c.valid_end_dttm = &valid_high_dttm)			
			left join dim.analytical_model_dim as d
			on (pool_scheme_defn.seg_model_rk = d.model_rk and 
				d.valid_end_dttm = &valid_high_dttm)			
			left join &lib..master_scale_defn
			on (pool_scheme_defn.master_scale_no = master_scale_defn.master_scale_no)
			where pool_scheme_defn.status_desc ne "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.status_desc.1, noquote))";
		quit;
/*If this count is missing then button deploy scheme will not work. */
		proc sql;
		 select count(*) into: count_row_scheme_detail from &out_lib..scheme_details;
		quit;

		data _null_;
			file _webout&webout_options;
			put '		</table>';
			put '		</td></tr>';
			put '		<tr><td>&nbsp;</td></tr>';
			put '		<tr>';
			put '			<td><table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#7F9DB9" class="tableborder">';
			put '          		<tr>';
			put '            		<td valign="top"><table width="100%" border="0" cellpadding="3" cellspacing="0">';
			put '                		<tr bgcolor="#FFFFFF">';
		    put '              	   			<td class="HZtableborder">&nbsp;</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.Scheme Name.1, noquote))"@;
			put'</td>';
/*		%if %quote(%'&scheme_type%') eq &SEGMENT_TYPE %then %do;*/
			/* Segmentation Type */
/*			put '                  			<td class="HZtableborder">Segment Method Type</td>';*/
/*			put '                  			<td class="HZtableborder">Segment Model Name</td>';*/
/*		%end;*/
/*		%else %do;*/
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.PD Method Type.1, noquote))"@;
			put'</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.PD Model Name.1, noquote))"@;
			put'</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.LGD Method Type.1, noquote))"@;
			put'</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.LGD Model Name.1, noquote))"@;
			put'</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.CCF Method Type.1, noquote))"@;
			put'</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.CCF Model Name.1, noquote))"@;
			put'</td>';
/*			%if %quote(%'&scheme_type%') eq &MAP_PD_MASTER_TYPE %then %do;*/
				/* Map PD to Master Scale */
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.Master Scale Name.1, noquote))"@;
			put'</td>';
/*			%end;*/
/*		%end;*/
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.KS Value.1, noquote))"@;
			put'</td>';
			put '                  			<td class="HZtableborder">'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.Pool Stability Index.1, noquote))"@;
			put'</td>';
			put '                		</tr>';
		run;

		data _NULL_;
			file _webout&webout_options;
			set &out_lib..scheme_details;
			if  mod(_N_,2)=0 then
				put '                		<tr bgcolor="#F4F4F2">';
			else 
				put '                		<tr bgcolor="#FFFFFF">';
		    put '              	   			<td width="15" class="LabelFont"><div align="center">'@;
		    put '<input type="radio" name="checkbox" value="'@;
			put pool_scheme_no@;
			put '" onClick="javascript:selScheme(this)" />'@;
		    put '							</div></td>';
			put '              	   			<td class="verttebleborder">' @;
			put pool_scheme_name@; 
			put '</td>';
/*		%if %quote(%'&scheme_type%') eq &SEGMENT_TYPE %then %do;*/
			/* Segmentation Type */
/*			desc_seg=put(seg_method_type_cd, $poolasgn.);*/
/*			put '              	   			<td class="verttebleborder">' @;*/
/*			put desc_seg@; */
/*			put '</td>';*/
/*			put '              	   			<td class="verttebleborder">' @;*/
/*			put seg_model_rk@; */
/*			put '</td>';*/
/*		%end;*/
/*		%else %do;*/
			desc_pd=put(pd_method_type_cd, $poolasgn.);
			put '              	   			<td class="verttebleborder">' @;
			put desc_pd@; 
			put '</td>';
			put '              	   			<td class="verttebleborder">' @;
			put pd_model_nm@; 
			put '</td>';
			desc_lgd=put(lgd_method_type_cd, $poolasgn.);
			put '              	   			<td class="verttebleborder">' @;
			put desc_lgd@; 
			put '</td>';
			put '              	   			<td class="verttebleborder">' @;
			put lgd_model_nm@; 
			put '</td>';
			desc_ccf=put(ccf_method_type_cd, $poolasgn.);
			put '              	   			<td class="verttebleborder">' @;
			put desc_ccf@; 
			put '</td>';
			put '              	   			<td class="verttebleborder">' @;
			put ccf_model_nm@; 
			put '</td>';
/*			%if %quote(%'&scheme_type%') eq &MAP_PD_MASTER_TYPE %then %do;*/
				/* Map PD to Master Scale */
			put '              	   			<td class="verttebleborder">' @;
			put master_scale_name@; 
			put '</td>';
/*			%end;*/
/*		%end;*/
			put '              	   			<td class="verttebleborder">' @;
			put ks_value@; 
			put '</td>';
			put '              	   			<td class="verttebleborder">' @;
			put stability_value@; 
			put '</td>';
			put '                		</tr>';
		run;

		data _null_;
			file _webout&webout_options;
			put '					</table>';
			put '				</td></tr>';
			put '			</table>';
			put '		</td></tr>';
			put '		<tr><td>&nbsp;</td></tr>';
			put '		<tr> ';
			put '			<td height="32" bgcolor="#F1EACB">&nbsp; ';
			put '				<input type="button" name="Submit" value="'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.button_deploy_scheme.1, noquote))"@;
			put ' " class="mmhide_btn" onClick="javascript:Deploy()" />';
			put '			</td> ';
			put '		</tr> ';
		run;
	%end;
%mend display_screen;

%global create_error_cd;
%let create_error_cd =0;
%macro chk_error(return_err);
	%if &return_err. > &create_error_cd. %then %do;
		%let create_error_cd = &return_err.;		
	%end;
%mend;
%macro deploy_scheme;
	%if "&action" eq "D" %then %do;
		%let error_code=NONE;

		/*Proc printto will redirect the log to the directory
		"Data/bisdata/log". */
		%global log_name;
		data _NULL_;
		name=put(time(),mmss8.1);
		name1=kscan(name,1,":.");
		name2=kscan(name,2,":.");
		name3=kscan(name,3,":."); 
		name4=ktrim(kleft(name1))||ktrim(kleft(name2))||ktrim(kleft(name3));
		call symput('log_name',"Data/bisdata/log/deploy_scheme_"||ktrim(kleft(name4))||".log");
		run;

		%put NOTE: Sending log messages to :&log_name;

		proc printto log="&log_name";
		quit;			

		/* 1. Backup the dimension tables POOL_SCHEME, POOL_DIM and ANALYTICAL_MODEL_DIM
				and the bridge table MODEL_X_POOL
		   2. Retrieve scheme details from pool.pool_scheme_defn
		   3. Retrieve pool information from pool.pool_defn
		   4. Retrieve assigned PD, LGD, CCF values in pool.model_x_pool
		   5. Populate scheme information in backup table pool_scheme
		   6. Populate pool information in backup table pool_dim
		   7. Update backup table analytical_model_dim with pool_scheme_sk
		   8. Populate model pool mapping information in backup table model_x_pool
		   7. Replace original dimension and bridge table with updated backups
		   9. Delete backups if everything is successful
		  10. If there is an error at any stage, alert the user that deployment is
				not successful
		*/
 		%let max_no=0;
   		proc sql noprint;
/*			select case when max(pool_scheme_sk)=. then 0 else max(pool_scheme_sk) end */
/*				into :max_no */
/*			from dim.POOL_SCHEME;*/

			select pd_model_rk, lgd_model_rk, ccf_model_rk, seg_model_rk
				into :pd_model, :lgd_model, :ccf_model, :seg_model
			from &lib..POOL_SCHEME_DEFN where pool_scheme_no=&scheme_no;

			select max(coalesce(pool_scheme_sk, 0) )into :max_no 
			from dim.POOL_SCHEME;

/*			select case when max(pool_sk)=. then 0 else max(pool_sk) end */
/*				into :max_pool_no */
/*			from dim.POOL_DIM;*/

			select max(coalesce(pool_sk, 0) )into :max_pool_no 
			from dim.POOL_DIM;

		quit;

		%if &sqlrc > 4 %then %do;
			%let error_code = ERROR;
		%end;
		%else %do;
			/* Backup the dimension tables POOL_SCHEME, POOL_DIM and ANALYTICAL_MODEL_DIM
				and the bridge table MODEL_X_POOL */
			proc copy out=abtscr in=dim constraint=yes index=yes;
				select POOL_SCHEME POOL_DIM ANALYTICAL_MODEL_DIM;
			quit;
			
			%chk_error(&syserr.);	

			proc copy out=abtscr in=bridge constraint=yes index=yes;
				select MODEL_X_POOL;
			quit;	

			%chk_error(&syserr.);	

			%if &create_error_cd > 4 %then %let error_code = ERROR;
			%else %do; /* Backup successful */
				/* Retrieve scheme details from pool.pool_scheme_defn */
				%let max_no=%eval(&max_no+1); 
				data &out_lib..pool_scheme_temp(drop=POOL_SCHEME_NO);
					set &lib..pool_scheme_defn(drop=OBS_DT STATUS_DESC KS_VALUE 
					STABILITY_VALUE where=(POOL_SCHEME_NO=&scheme_no) 
						rename=(POOL_SCHEME_NAME=POOL_SCHEME_NM));
					POOL_SCHEME_SK = &max_no;
				run;

				%chk_error(&syserr.);	

				/* Retrieve pool information from pool.pool_defn */
				%let max_pool_no=%eval(&max_pool_no+1); 
				data &out_lib..pool_temp(drop=POOL_SCHEME_NO);
					retain pool_no &max_pool_no;
					set &lib..pool_defn(drop=SCORE_POINTS NO_OF_ACCOUNTS MS_CALC_PD_NO 
						where=(POOL_SCHEME_NO=&scheme_no) 
						rename=(FROM_SCORE_NO=SCORE_FROM_NO TO_SCORE_NO=SCORE_TO_NO 
						FROM_PD_NO=PD_FROM_NO TO_PD_NO=PD_TO_NO 
						FROM_LGD_NO=LGD_FROM_NO TO_LGD_NO=LGD_TO_NO 
						FROM_CCF_NO=CCF_FROM_NO TO_CCF_NO=CCF_TO_NO
						SEG_NAME=SEG_NM MS_GRADE_NAME=MS_GRADE_NM));
					POOL_SCHEME_SK = &max_no;
					POOL_SK = pool_no;
					pool_no = pool_no + 1;
					VALID_START_DTTM ="%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.start_dt.1, noquote))";
					VALID_END_DTTM = &valid_high_dttm;
				run;

				%chk_error(&syserr.);	

				/* Retrieve assigned PD, LGD, CCF values in pool.model_x_pool */
				proc sql;
					create table &out_lib..model_pool_temp as
					select pool_sk, assigned_pd as rate, model_sk
					from &out_lib..pool_temp inner join &out_lib..pool_scheme_temp
					on (pool_temp.pool_scheme_sk = pool_scheme_temp.pool_scheme_sk)
					inner join dim.analytical_model_dim
					on (pool_scheme_temp.pd_model_rk = analytical_model_dim.model_rk and
						analytical_model_dim.VALID_END_DTTM=&valid_high_dttm);

					insert into &out_lib..model_pool_temp(POOL_SK, RATE, MODEL_SK)
					select pool_sk, assigned_lgd as rate, model_sk
					from &out_lib..pool_temp inner join &out_lib..pool_scheme_temp
					on (pool_temp.pool_scheme_sk = pool_scheme_temp.pool_scheme_sk)
					inner join dim.analytical_model_dim
					on (pool_scheme_temp.lgd_model_rk = analytical_model_dim.model_rk and
						analytical_model_dim.VALID_END_DTTM=&valid_high_dttm);

					insert into &out_lib..model_pool_temp(POOL_SK, RATE, MODEL_SK)
					select pool_sk, assigned_ccf as rate, model_sk
					from &out_lib..pool_temp inner join &out_lib..pool_scheme_temp
					on (pool_temp.pool_scheme_sk = pool_scheme_temp.pool_scheme_sk)
					inner join dim.analytical_model_dim
					on (pool_scheme_temp.ccf_model_rk = analytical_model_dim.model_rk and
						analytical_model_dim.VALID_END_DTTM=&valid_high_dttm);
				quit;

				%chk_error(&sqlrc.);	

				%if &create_error_cd > 4 %then %let error_code = ERROR;
				%else %do; /* Retrieve information successful */
					/* Populate scheme information in backup table pool_scheme */
					proc append data=&out_lib..pool_scheme_temp base=abtscr.pool_scheme force;
					quit;

					%chk_error(&syserr.);	

					/* Populate pool information in backup table pool_dim */
					proc append data=&out_lib..pool_temp base=abtscr.pool_dim force;
					quit;

					%chk_error(&syserr.);	

					/* Update backup table analytical_model_dim with pool_scheme_sk */
					proc sql;
						update abtscr.analytical_model_dim 
						set POOL_SCHEME_SK=&max_no 
						where model_rk in (&pd_model, &lgd_model, &ccf_model, &seg_model)
							and VALID_END_DTTM=&valid_high_dttm;
					quit;

					%chk_error(&sqlrc.);	

					/* Populate model pool mapping information in backup table model_x_pool */
					proc append data=&out_lib..model_pool_temp base=abtscr.model_x_pool force;
					quit;

					%chk_error(&syserr.);
	
					%if &create_error_cd > 4 %then %let error_code = ERROR;
					%else %do; /* Populate info in backup successful */
						/* Replace original dimension and bridge table with updated backups */
						proc copy out=dim in=abtscr constraint=yes index=yes;
							select POOL_SCHEME POOL_DIM ANALYTICAL_MODEL_DIM;
						quit;
						
						%chk_error(&syserr.);	

						proc copy out=bridge in=abtscr constraint=yes index=yes;
							select MODEL_X_POOL;
						quit;	

						%chk_error(&syserr.);
						
						%if &create_error_cd > 4 %then %let error_code = ERROR;
						%else %do; /* Replace dimension and bridge tables successful */
							proc sql;
								/* Delete backups */
								drop table abtscr.pool_scheme;
								drop table abtscr.pool_dim;
								drop table abtscr.analytical_model_dim;
								drop table abtscr.model_x_pool;

								/* Update pool schemes as deployed */
								update &lib..pool_scheme_defn 
								set status_desc="%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.status_desc_comm.1, noquote))"
								where pd_model_rk=&pd_model or lgd_model_rk=&lgd_model or 
									ccf_model_rk=&ccf_model or seg_model_rk=&seg_model;

								update &lib..pool_scheme_defn 
								set status_desc="%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.status_desc_Deployed.1, noquote))"
								where pool_scheme_no=&scheme_no;
							quit;

						%end; /* Replace dimension and bridge tables successful */
					%end; /* Populate info in backup successful */
				%end; /* Retrieve information successful */
			%end; /* Backup successful */
		%end;

		/*Proc printto will reset the log redirection */
		proc printto;
		quit; 

		%put NOTE: Resetting log to _webout&webout_options;
		/*End of proc printto */

		/* Show the relevant messages on the screen */
		data _null_;
			file _webout&webout_options;
			put '<script language="JavaScript" type="text/JavaScript"> ';
			put '<!-- ';
		%if %str(&error_code) eq %str(ERROR) %then %do;
			put '	alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.log_alert_p1.1, noquote))"@;
			put "&log_name"@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.log_alert_p2.1, noquote))"@;
			put '")';
		%end;
		%else %do;
			put '	alert("'@;
			put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.alert_deploy_successfully.1, noquote))"@;
			put'")';
			put '	form1.action.value = "N";';
			put "	form1._program.value=&DEPLOY_POOL_SCHEME";
			put '	form1.submit()';
		%end;
			put '//-->';
			put	'</script> ';
		run; 
	%end;
%mend deploy_scheme;

data _null_;
	file _webout&webout_options;
	put'<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" ';
	put'"http://www.w3.org/TR/html4/loose.dtd"> ';
	put'<html> ';
	put'<head> ';
/*I18N-scnhuh-20080418-1023*/
/*from iso-8859-1 to utf-8*/
	put'<meta http-equiv="Content-Type" content="text/html; charset=utf-8"> ';
/*I18N-scnhuh-20080418-1023*/	
	put'<title>'@; 
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.pooling_title.1, noquote))"@;
	put'</title> ';
	put'<link href="/SASCSPooling/styles/default.css"rel="stylesheet" type="text/css"> ';
	put '<style type="text/css">';
	put '<!--';
	put 'body {';
	put '	background-color: #FAF8ED;';
	put '}';
	put '-->';
	put '</style>';

	put '<script language="JavaScript" src="/SASCSPooling/script/action_menu.js"></script>';
	put '<script language="JavaScript" type="text/JavaScript"> ';
	put '<!-- ';

	put 'function selScheme(obj) {';
	put '	if(obj.checked==true) {';
	put '		form1.scheme_no.value=obj.value';
	put '	}';
	put '}';

	put 'function Deploy() {';
	put 'if ((form1.count_row_scheme_detail.value!="") ||(form1.checkbox.checked==true))';
		put '{';
		put "	form1._program.value=&DEPLOY_POOL_SCHEME";
		put '	form1.action.value="D"';
		put '	form1.submit()';
	put '}';
	put 'else {';
	put '	alert("'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.alert_sel_schm_deploy.1, noquote))"@;
	put '")';
	put '}';
	put '}';

	put '//-->';
	put	'</script> ';
	put '</head>';

	put '<body>';
	put '<form name="form1" method="post" ACTION="/SASStoredProcess/do"> ';

	/* Hidden textboxes to hold the values for the program name and the output paremeters */
	put '<input type="hidden" name="_program" VALUE="">';
	scheme_no=symget("scheme_no");
	x='<input type="hidden" name="scheme_no" value="'||ktrim(kleft(scheme_no))||'">';
	put x;
	action=symget("action");
	x='<input type="hidden" name="action" value="'||ktrim(kleft(action))||'">';
	put x;
	count_row_scheme_detail=symget("count_row_scheme_detail");
	x='<input type="hidden" name="count_row_scheme_detail" value="'||ktrim(kleft(count_row_scheme_detail))||'">';
	put x;
run;

/* Deploy Scheme */
%deploy_scheme;

data _null_;
	file _webout&webout_options;
	put '<table width="100%" border="0" cellpadding="0" cellspacing="0" bgcolor="#FAF8ED"> ';
	put '	<tr> ';
	put '		<td align="left"> ';
	put '		<table width="100%" border="0" align="left" cellpadding="0" cellspacing="0"> ';
	put '			<tr> ';
	put '				<td><table width="100%" border="0" cellspacing="0" cellpadding="0"> ';
	put '					<tr> ';

	/* Navigational Links */
	put '						<td><span class="BreadCrumb">&nbsp;</td>';
	put '						<td align="right"><img src="/SASCSPooling/images/CrBanner.gif" width="259" height="29"></td> ';
	put '					</tr>';
	put '				</table>';                                     /****Banner insert image********/
	/**/

	/* Main Body */
	put '				<H2 align="left"><table width="100%" border="0" cellspacing="0" cellpadding="0">';
	put '					<tr><td>'@;
	put "%sysfunc(sasmsg(smd_ds.bismsg,crs.build_scheme_pd_pool.button_deploy_scheme_table.1, noquote))"@;
	put'</td>';
	put '				</tr></table></H2>';
	put '	   		<tr><td>&nbsp;</td></tr>';
	put '      		<tr>';
	put '        		<td><table width="100%" border="0" cellpadding="3" cellspacing="0">';
	put '					<tr>';
/*	put '						<td class="LabelFont" width="15%">Scheme Type: </td>';*/
/*	put '						<td class="LabelFont">';*/
/*	put '							<select name="schemetype" style="width: 90mm" onChange="javascript:setSchemeType()">';*/
/*	put '								<option>Select Scheme Type</option>';*/
/*run;*/
/**/
/*data _null_;*/
/*	file _webout;*/
/*	set &out_lib..scheme_type;*/
/*	put '								<option value="'@;*/
/*	put scheme_type_cd@;*/
/*	put '" '@;*/
/*	if scheme_type_cd="&scheme_type" then put 'selected'@;*/
/*	put '>'@;*/
/*	put scheme_type_nm@;*/
/*	put '</option>';*/
/*run;*/
/**/
/*data _null_;*/
/*	file _webout;*/
/*	put '							</select>';*/
/*	put '						</td>';*/
/*	put '					</tr>';*/
run;

%display_screen;

data _null_;
	file _webout&webout_options;
	put '				</table>';
	put '				</td>';
	put '			</tr>';

	put '			<tr><td>&nbsp;</td></tr>';
	put '</table>';
	put '</form>';
	put '</body>';
	put '</html>';
run;

